""" Cisco_IOS_XR_ipv4_pim_oper 

This module contains a collection of YANG definitions
for Cisco IOS\-XR ipv4\-pim package operational data.

This module contains definitions
for the following management objects\:
  pim\-ma\: PIM MA operational data
  pim\: pim
  ipv6\-pim\: ipv6 pim
  pim6\-ma\: pim6 ma

Copyright (c) 2013\-2018 by Cisco Systems, Inc.
All rights reserved.

"""
from collections import OrderedDict

from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YError, YModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error



class PimAfi(Enum):
    """
    PimAfi (Enum Class)

    Address family

    .. data:: ipv4_unicast = 0

    	IP v4 unicast

    .. data:: ipv6_unicast = 1

    	IP v6 unicast

    """

    ipv4_unicast = Enum.YLeaf(0, "ipv4-unicast")

    ipv6_unicast = Enum.YLeaf(1, "ipv6-unicast")


class PimClient(Enum):
    """
    PimClient (Enum Class)

    Pim client

    .. data:: none = 0

    	No Client

    .. data:: configured_embedded_rp = 1

    	Embedded RP from configuration

    .. data:: embedded = 2

    	Embedded RP learnt from the Group addr

    .. data:: permanent = 3

    	Permanent

    .. data:: auto_rp = 4

    	AutoRP

    .. data:: bsr = 5

    	BSR

    .. data:: configured = 6

    	Configured

    .. data:: static = 7

    	Static

    """

    none = Enum.YLeaf(0, "none")

    configured_embedded_rp = Enum.YLeaf(1, "configured-embedded-rp")

    embedded = Enum.YLeaf(2, "embedded")

    permanent = Enum.YLeaf(3, "permanent")

    auto_rp = Enum.YLeaf(4, "auto-rp")

    bsr = Enum.YLeaf(5, "bsr")

    configured = Enum.YLeaf(6, "configured")

    static = Enum.YLeaf(7, "static")


class PimInterface(Enum):
    """
    PimInterface (Enum Class)

    Interface Type

    .. data:: encap_interface = 0

    	Encap Interface

    .. data:: decap_interface = 1

    	Decap Interface

    .. data:: mdt_interface = 2

    	MDT Interface

    """

    encap_interface = Enum.YLeaf(0, "encap-interface")

    decap_interface = Enum.YLeaf(1, "decap-interface")

    mdt_interface = Enum.YLeaf(2, "mdt-interface")


class PimInternalInterestInfo(Enum):
    """
    PimInternalInterestInfo (Enum Class)

    Pim internal interest info

    .. data:: null = 21

    	null

    .. data:: ii = 22

    	Internal Interest

    .. data:: id = 23

    	Internal Disinterest

    """

    null = Enum.YLeaf(21, "null")

    ii = Enum.YLeaf(22, "ii")

    id = Enum.YLeaf(23, "id")


class PimProtocol(Enum):
    """
    PimProtocol (Enum Class)

    Pim protocol

    .. data:: non_routable = 0

    	Non Routable

    .. data:: sparse_mode = 1

    	Sparse Mode

    .. data:: dense_mode = 2

    	Dense Mode

    .. data:: bidir = 3

    	Bidirectional Mode

    .. data:: ssm = 4

    	Source Specific Multicast Mode

    .. data:: maximum = 5

    	Maximum

    .. data:: any = 6

    	Any

    """

    non_routable = Enum.YLeaf(0, "non-routable")

    sparse_mode = Enum.YLeaf(1, "sparse-mode")

    dense_mode = Enum.YLeaf(2, "dense-mode")

    bidir = Enum.YLeaf(3, "bidir")

    ssm = Enum.YLeaf(4, "ssm")

    maximum = Enum.YLeaf(5, "maximum")

    any = Enum.YLeaf(6, "any")


class PimSafi(Enum):
    """
    PimSafi (Enum Class)

    Pim safi

    .. data:: unicast = 1

    	SAFI unicast

    .. data:: multicast = 2

    	SAFI Multicast

    .. data:: all = 3

    	SAFI all

    .. data:: default = 4

    	SAFI default

    """

    unicast = Enum.YLeaf(1, "unicast")

    multicast = Enum.YLeaf(2, "multicast")

    all = Enum.YLeaf(3, "all")

    default = Enum.YLeaf(4, "default")


class PimShowLocalInterest(Enum):
    """
    PimShowLocalInterest (Enum Class)

    Pim show local interest

    .. data:: null = 1

    	null

    .. data:: li = 2

    	Local Interest

    .. data:: ld = 3

    	Local Disinterest

    """

    null = Enum.YLeaf(1, "null")

    li = Enum.YLeaf(2, "li")

    ld = Enum.YLeaf(3, "ld")


class PimShowProtocol(Enum):
    """
    PimShowProtocol (Enum Class)

    Pim show protocol

    .. data:: no_route = 0

    	no route

    .. data:: sm = 1

    	sm

    .. data:: dm = 2

    	dm

    .. data:: bidir = 3

    	bidir

    .. data:: ssm = 4

    	ssm

    .. data:: maximum = 5

    	maximum

    .. data:: any = 6

    	any

    """

    no_route = Enum.YLeaf(0, "no-route")

    sm = Enum.YLeaf(1, "sm")

    dm = Enum.YLeaf(2, "dm")

    bidir = Enum.YLeaf(3, "bidir")

    ssm = Enum.YLeaf(4, "ssm")

    maximum = Enum.YLeaf(5, "maximum")

    any = Enum.YLeaf(6, "any")


class PimShowRangeClient(Enum):
    """
    PimShowRangeClient (Enum Class)

    Pim show range client

    .. data:: no_client = 0

    	no client

    .. data:: embedded_config = 1

    	embedded config

    .. data:: embedded = 2

    	embedded

    .. data:: permanent = 3

    	permanent

    .. data:: auto_rp = 4

    	auto rp

    .. data:: bsr = 5

    	bsr

    .. data:: config = 6

    	config

    .. data:: static = 7

    	static

    """

    no_client = Enum.YLeaf(0, "no-client")

    embedded_config = Enum.YLeaf(1, "embedded-config")

    embedded = Enum.YLeaf(2, "embedded")

    permanent = Enum.YLeaf(3, "permanent")

    auto_rp = Enum.YLeaf(4, "auto-rp")

    bsr = Enum.YLeaf(5, "bsr")

    config = Enum.YLeaf(6, "config")

    static = Enum.YLeaf(7, "static")


class PimTopologyEntryFlag(Enum):
    """
    PimTopologyEntryFlag (Enum Class)

    Pim topology entry flag

    .. data:: kat = 0

    	KAT

    .. data:: aa = 1

    	AA

    .. data:: pa = 2

    	PA

    .. data:: ra = 3

    	RA

    .. data:: ia = 4

    	IA

    .. data:: rr = 5

    	RR

    .. data:: lh = 6

    	LH

    .. data:: dss = 7

    	DSS

    .. data:: dcc = 8

    	DCC

    .. data:: sr = 9

    	SR

    .. data:: e = 10

    	E

    .. data:: ex = 11

    	EX

    .. data:: ma = 12

    	MA

    .. data:: mt = 13

    	MT

    .. data:: mfa = 14

    	MFA

    .. data:: mfp = 15

    	MFP

    .. data:: mfb = 16

    	MFB

    """

    kat = Enum.YLeaf(0, "kat")

    aa = Enum.YLeaf(1, "aa")

    pa = Enum.YLeaf(2, "pa")

    ra = Enum.YLeaf(3, "ra")

    ia = Enum.YLeaf(4, "ia")

    rr = Enum.YLeaf(5, "rr")

    lh = Enum.YLeaf(6, "lh")

    dss = Enum.YLeaf(7, "dss")

    dcc = Enum.YLeaf(8, "dcc")

    sr = Enum.YLeaf(9, "sr")

    e = Enum.YLeaf(10, "e")

    ex = Enum.YLeaf(11, "ex")

    ma = Enum.YLeaf(12, "ma")

    mt = Enum.YLeaf(13, "mt")

    mfa = Enum.YLeaf(14, "mfa")

    mfp = Enum.YLeaf(15, "mfp")

    mfb = Enum.YLeaf(16, "mfb")


class PimTopologyInterfaceFlag(Enum):
    """
    PimTopologyInterfaceFlag (Enum Class)

    Pim topology interface flag

    .. data:: lh = 0

    	LH

    .. data:: ld = 1

    	LD

    .. data:: li = 2

    	LI

    .. data:: ii = 3

    	II

    .. data:: id = 4

    	ID

    .. data:: as_ = 5

    	AS

    .. data:: ab = 6

    	AB

    .. data:: ex = 7

    	EX

    """

    lh = Enum.YLeaf(0, "lh")

    ld = Enum.YLeaf(1, "ld")

    li = Enum.YLeaf(2, "li")

    ii = Enum.YLeaf(3, "ii")

    id = Enum.YLeaf(4, "id")

    as_ = Enum.YLeaf(5, "as")

    ab = Enum.YLeaf(6, "ab")

    ex = Enum.YLeaf(7, "ex")



class PimMa(Entity):
    """
    PIM MA operational data
    
    .. attribute:: active
    
    	Active Process
    	**type**\:  :py:class:`Active <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Active>`
    
    .. attribute:: standby
    
    	Standby Process
    	**type**\:  :py:class:`Standby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Standby>`
    
    

    """

    _prefix = 'ipv4-pim-oper'
    _revision = '2017-09-07'

    def __init__(self):
        super(PimMa, self).__init__()
        self._top_entity = None

        self.yang_name = "pim-ma"
        self.yang_parent_name = "Cisco-IOS-XR-ipv4-pim-oper"
        self.is_top_level_class = True
        self.has_list_ancestor = False
        self.ylist_key_names = []
        self._child_classes = OrderedDict([("active", ("active", PimMa.Active)), ("standby", ("standby", PimMa.Standby))])
        self._leafs = OrderedDict()

        self.active = PimMa.Active()
        self.active.parent = self
        self._children_name_map["active"] = "active"

        self.standby = PimMa.Standby()
        self.standby.parent = self
        self._children_name_map["standby"] = "standby"
        self._segment_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim-ma"
        self._is_frozen = True

    def __setattr__(self, name, value):
        self._perform_setattr(PimMa, [], name, value)


    class Active(Entity):
        """
        Active Process
        
        .. attribute:: interface_table
        
        	Interface Table
        	**type**\:  :py:class:`InterfaceTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Active.InterfaceTable>`
        
        .. attribute:: pim_ma_summary
        
        	PIM MA summary
        	**type**\:  :py:class:`PimMaSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Active.PimMaSummary>`
        
        

        """

        _prefix = 'ipv4-pim-oper'
        _revision = '2017-09-07'

        def __init__(self):
            super(PimMa.Active, self).__init__()

            self.yang_name = "active"
            self.yang_parent_name = "pim-ma"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("interface-table", ("interface_table", PimMa.Active.InterfaceTable)), ("pim-ma-summary", ("pim_ma_summary", PimMa.Active.PimMaSummary))])
            self._leafs = OrderedDict()

            self.interface_table = PimMa.Active.InterfaceTable()
            self.interface_table.parent = self
            self._children_name_map["interface_table"] = "interface-table"

            self.pim_ma_summary = PimMa.Active.PimMaSummary()
            self.pim_ma_summary.parent = self
            self._children_name_map["pim_ma_summary"] = "pim-ma-summary"
            self._segment_path = lambda: "active"
            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim-ma/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(PimMa.Active, [], name, value)


        class InterfaceTable(Entity):
            """
            Interface Table
            
            .. attribute:: interface_by_handles
            
            	Table of PIM MA interfaces indexed by handle
            	**type**\:  :py:class:`InterfaceByHandles <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Active.InterfaceTable.InterfaceByHandles>`
            
            .. attribute:: interface_by_names
            
            	Table of PIM MA interfaces indexed by name
            	**type**\:  :py:class:`InterfaceByNames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Active.InterfaceTable.InterfaceByNames>`
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(PimMa.Active.InterfaceTable, self).__init__()

                self.yang_name = "interface-table"
                self.yang_parent_name = "active"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("interface-by-handles", ("interface_by_handles", PimMa.Active.InterfaceTable.InterfaceByHandles)), ("interface-by-names", ("interface_by_names", PimMa.Active.InterfaceTable.InterfaceByNames))])
                self._leafs = OrderedDict()

                self.interface_by_handles = PimMa.Active.InterfaceTable.InterfaceByHandles()
                self.interface_by_handles.parent = self
                self._children_name_map["interface_by_handles"] = "interface-by-handles"

                self.interface_by_names = PimMa.Active.InterfaceTable.InterfaceByNames()
                self.interface_by_names.parent = self
                self._children_name_map["interface_by_names"] = "interface-by-names"
                self._segment_path = lambda: "interface-table"
                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim-ma/active/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(PimMa.Active.InterfaceTable, [], name, value)


            class InterfaceByHandles(Entity):
                """
                Table of PIM MA interfaces indexed by handle
                
                .. attribute:: interface_by_handle
                
                	PIM MA interface referenced by handle
                	**type**\: list of  		 :py:class:`InterfaceByHandle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(PimMa.Active.InterfaceTable.InterfaceByHandles, self).__init__()

                    self.yang_name = "interface-by-handles"
                    self.yang_parent_name = "interface-table"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("interface-by-handle", ("interface_by_handle", PimMa.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle))])
                    self._leafs = OrderedDict()

                    self.interface_by_handle = YList(self)
                    self._segment_path = lambda: "interface-by-handles"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim-ma/active/interface-table/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(PimMa.Active.InterfaceTable.InterfaceByHandles, [], name, value)


                class InterfaceByHandle(Entity):
                    """
                    PIM MA interface referenced by handle
                    
                    .. attribute:: interface_handle  (key)
                    
                    	Interface handle
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rp_address
                    
                    	RP Address
                    	**type**\:  :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress>`
                    
                    .. attribute:: source_address
                    
                    	Source Address
                    	**type**\:  :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress>`
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Name
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: vrf_name
                    
                    	VRF Name
                    	**type**\: str
                    
                    .. attribute:: interface_type
                    
                    	Interface Type
                    	**type**\:  :py:class:`PimInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimInterface>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(PimMa.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle, self).__init__()

                        self.yang_name = "interface-by-handle"
                        self.yang_parent_name = "interface-by-handles"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['interface_handle']
                        self._child_classes = OrderedDict([("rp-address", ("rp_address", PimMa.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress)), ("source-address", ("source_address", PimMa.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress))])
                        self._leafs = OrderedDict([
                            ('interface_handle', (YLeaf(YType.uint32, 'interface-handle'), ['int'])),
                            ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                            ('interface_type', (YLeaf(YType.enumeration, 'interface-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimInterface', '')])),
                        ])
                        self.interface_handle = None
                        self.interface_name_xr = None
                        self.vrf_name = None
                        self.interface_type = None

                        self.rp_address = PimMa.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress()
                        self.rp_address.parent = self
                        self._children_name_map["rp_address"] = "rp-address"

                        self.source_address = PimMa.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress()
                        self.source_address.parent = self
                        self._children_name_map["source_address"] = "source-address"
                        self._segment_path = lambda: "interface-by-handle" + "[interface-handle='" + str(self.interface_handle) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim-ma/active/interface-table/interface-by-handles/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(PimMa.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle, ['interface_handle', u'interface_name_xr', u'vrf_name', u'interface_type'], name, value)


                    class RpAddress(Entity):
                        """
                        RP Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(PimMa.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress, self).__init__()

                            self.yang_name = "rp-address"
                            self.yang_parent_name = "interface-by-handle"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "rp-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(PimMa.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class SourceAddress(Entity):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(PimMa.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress, self).__init__()

                            self.yang_name = "source-address"
                            self.yang_parent_name = "interface-by-handle"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "source-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(PimMa.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class InterfaceByNames(Entity):
                """
                Table of PIM MA interfaces indexed by name
                
                .. attribute:: interface_by_name
                
                	PIM MA interface referenced by name
                	**type**\: list of  		 :py:class:`InterfaceByName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Active.InterfaceTable.InterfaceByNames.InterfaceByName>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(PimMa.Active.InterfaceTable.InterfaceByNames, self).__init__()

                    self.yang_name = "interface-by-names"
                    self.yang_parent_name = "interface-table"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("interface-by-name", ("interface_by_name", PimMa.Active.InterfaceTable.InterfaceByNames.InterfaceByName))])
                    self._leafs = OrderedDict()

                    self.interface_by_name = YList(self)
                    self._segment_path = lambda: "interface-by-names"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim-ma/active/interface-table/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(PimMa.Active.InterfaceTable.InterfaceByNames, [], name, value)


                class InterfaceByName(Entity):
                    """
                    PIM MA interface referenced by name
                    
                    .. attribute:: interface_name  (key)
                    
                    	Interface name
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: rp_address
                    
                    	RP Address
                    	**type**\:  :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Active.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress>`
                    
                    .. attribute:: source_address
                    
                    	Source Address
                    	**type**\:  :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Active.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress>`
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Name
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: vrf_name
                    
                    	VRF Name
                    	**type**\: str
                    
                    .. attribute:: interface_type
                    
                    	Interface Type
                    	**type**\:  :py:class:`PimInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimInterface>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(PimMa.Active.InterfaceTable.InterfaceByNames.InterfaceByName, self).__init__()

                        self.yang_name = "interface-by-name"
                        self.yang_parent_name = "interface-by-names"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['interface_name']
                        self._child_classes = OrderedDict([("rp-address", ("rp_address", PimMa.Active.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress)), ("source-address", ("source_address", PimMa.Active.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress))])
                        self._leafs = OrderedDict([
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                            ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                            ('interface_type', (YLeaf(YType.enumeration, 'interface-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimInterface', '')])),
                        ])
                        self.interface_name = None
                        self.interface_name_xr = None
                        self.vrf_name = None
                        self.interface_type = None

                        self.rp_address = PimMa.Active.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress()
                        self.rp_address.parent = self
                        self._children_name_map["rp_address"] = "rp-address"

                        self.source_address = PimMa.Active.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress()
                        self.source_address.parent = self
                        self._children_name_map["source_address"] = "source-address"
                        self._segment_path = lambda: "interface-by-name" + "[interface-name='" + str(self.interface_name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim-ma/active/interface-table/interface-by-names/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(PimMa.Active.InterfaceTable.InterfaceByNames.InterfaceByName, ['interface_name', u'interface_name_xr', u'vrf_name', u'interface_type'], name, value)


                    class RpAddress(Entity):
                        """
                        RP Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(PimMa.Active.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress, self).__init__()

                            self.yang_name = "rp-address"
                            self.yang_parent_name = "interface-by-name"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "rp-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(PimMa.Active.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class SourceAddress(Entity):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(PimMa.Active.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress, self).__init__()

                            self.yang_name = "source-address"
                            self.yang_parent_name = "interface-by-name"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "source-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(PimMa.Active.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


        class PimMaSummary(Entity):
            """
            PIM MA summary
            
            .. attribute:: is_im_connection_open
            
            	IM Connection Open
            	**type**\: bool
            
            .. attribute:: is_netio_connection_open
            
            	Netio Connection Open
            	**type**\: bool
            
            .. attribute:: is_edm_connection_open
            
            	EDM Connection Open
            	**type**\: bool
            
            .. attribute:: is_standby_edm_connection_open
            
            	Standby EDM Connection Open
            	**type**\: bool
            
            .. attribute:: encap_interface_count
            
            	Encap Interface Count
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: decap_interface_count
            
            	Decap Interface Count
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: mdt_interface_count
            
            	MDT Interface Count
            	**type**\: int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(PimMa.Active.PimMaSummary, self).__init__()

                self.yang_name = "pim-ma-summary"
                self.yang_parent_name = "active"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('is_im_connection_open', (YLeaf(YType.boolean, 'is-im-connection-open'), ['bool'])),
                    ('is_netio_connection_open', (YLeaf(YType.boolean, 'is-netio-connection-open'), ['bool'])),
                    ('is_edm_connection_open', (YLeaf(YType.boolean, 'is-edm-connection-open'), ['bool'])),
                    ('is_standby_edm_connection_open', (YLeaf(YType.boolean, 'is-standby-edm-connection-open'), ['bool'])),
                    ('encap_interface_count', (YLeaf(YType.uint32, 'encap-interface-count'), ['int'])),
                    ('decap_interface_count', (YLeaf(YType.uint32, 'decap-interface-count'), ['int'])),
                    ('mdt_interface_count', (YLeaf(YType.uint32, 'mdt-interface-count'), ['int'])),
                ])
                self.is_im_connection_open = None
                self.is_netio_connection_open = None
                self.is_edm_connection_open = None
                self.is_standby_edm_connection_open = None
                self.encap_interface_count = None
                self.decap_interface_count = None
                self.mdt_interface_count = None
                self._segment_path = lambda: "pim-ma-summary"
                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim-ma/active/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(PimMa.Active.PimMaSummary, [u'is_im_connection_open', u'is_netio_connection_open', u'is_edm_connection_open', u'is_standby_edm_connection_open', u'encap_interface_count', u'decap_interface_count', u'mdt_interface_count'], name, value)


    class Standby(Entity):
        """
        Standby Process
        
        .. attribute:: interface_table
        
        	Interface Table
        	**type**\:  :py:class:`InterfaceTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Standby.InterfaceTable>`
        
        .. attribute:: pim_ma_summary
        
        	PIM MA summary
        	**type**\:  :py:class:`PimMaSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Standby.PimMaSummary>`
        
        

        """

        _prefix = 'ipv4-pim-oper'
        _revision = '2017-09-07'

        def __init__(self):
            super(PimMa.Standby, self).__init__()

            self.yang_name = "standby"
            self.yang_parent_name = "pim-ma"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("interface-table", ("interface_table", PimMa.Standby.InterfaceTable)), ("pim-ma-summary", ("pim_ma_summary", PimMa.Standby.PimMaSummary))])
            self._leafs = OrderedDict()

            self.interface_table = PimMa.Standby.InterfaceTable()
            self.interface_table.parent = self
            self._children_name_map["interface_table"] = "interface-table"

            self.pim_ma_summary = PimMa.Standby.PimMaSummary()
            self.pim_ma_summary.parent = self
            self._children_name_map["pim_ma_summary"] = "pim-ma-summary"
            self._segment_path = lambda: "standby"
            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim-ma/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(PimMa.Standby, [], name, value)


        class InterfaceTable(Entity):
            """
            Interface Table
            
            .. attribute:: interface_by_handles
            
            	Table of PIM MA interfaces indexed by handle
            	**type**\:  :py:class:`InterfaceByHandles <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Standby.InterfaceTable.InterfaceByHandles>`
            
            .. attribute:: interface_by_names
            
            	Table of PIM MA interfaces indexed by name
            	**type**\:  :py:class:`InterfaceByNames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Standby.InterfaceTable.InterfaceByNames>`
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(PimMa.Standby.InterfaceTable, self).__init__()

                self.yang_name = "interface-table"
                self.yang_parent_name = "standby"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("interface-by-handles", ("interface_by_handles", PimMa.Standby.InterfaceTable.InterfaceByHandles)), ("interface-by-names", ("interface_by_names", PimMa.Standby.InterfaceTable.InterfaceByNames))])
                self._leafs = OrderedDict()

                self.interface_by_handles = PimMa.Standby.InterfaceTable.InterfaceByHandles()
                self.interface_by_handles.parent = self
                self._children_name_map["interface_by_handles"] = "interface-by-handles"

                self.interface_by_names = PimMa.Standby.InterfaceTable.InterfaceByNames()
                self.interface_by_names.parent = self
                self._children_name_map["interface_by_names"] = "interface-by-names"
                self._segment_path = lambda: "interface-table"
                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim-ma/standby/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(PimMa.Standby.InterfaceTable, [], name, value)


            class InterfaceByHandles(Entity):
                """
                Table of PIM MA interfaces indexed by handle
                
                .. attribute:: interface_by_handle
                
                	PIM MA interface referenced by handle
                	**type**\: list of  		 :py:class:`InterfaceByHandle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(PimMa.Standby.InterfaceTable.InterfaceByHandles, self).__init__()

                    self.yang_name = "interface-by-handles"
                    self.yang_parent_name = "interface-table"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("interface-by-handle", ("interface_by_handle", PimMa.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle))])
                    self._leafs = OrderedDict()

                    self.interface_by_handle = YList(self)
                    self._segment_path = lambda: "interface-by-handles"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim-ma/standby/interface-table/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(PimMa.Standby.InterfaceTable.InterfaceByHandles, [], name, value)


                class InterfaceByHandle(Entity):
                    """
                    PIM MA interface referenced by handle
                    
                    .. attribute:: interface_handle  (key)
                    
                    	Interface handle
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rp_address
                    
                    	RP Address
                    	**type**\:  :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress>`
                    
                    .. attribute:: source_address
                    
                    	Source Address
                    	**type**\:  :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress>`
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Name
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: vrf_name
                    
                    	VRF Name
                    	**type**\: str
                    
                    .. attribute:: interface_type
                    
                    	Interface Type
                    	**type**\:  :py:class:`PimInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimInterface>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(PimMa.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle, self).__init__()

                        self.yang_name = "interface-by-handle"
                        self.yang_parent_name = "interface-by-handles"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['interface_handle']
                        self._child_classes = OrderedDict([("rp-address", ("rp_address", PimMa.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress)), ("source-address", ("source_address", PimMa.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress))])
                        self._leafs = OrderedDict([
                            ('interface_handle', (YLeaf(YType.uint32, 'interface-handle'), ['int'])),
                            ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                            ('interface_type', (YLeaf(YType.enumeration, 'interface-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimInterface', '')])),
                        ])
                        self.interface_handle = None
                        self.interface_name_xr = None
                        self.vrf_name = None
                        self.interface_type = None

                        self.rp_address = PimMa.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress()
                        self.rp_address.parent = self
                        self._children_name_map["rp_address"] = "rp-address"

                        self.source_address = PimMa.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress()
                        self.source_address.parent = self
                        self._children_name_map["source_address"] = "source-address"
                        self._segment_path = lambda: "interface-by-handle" + "[interface-handle='" + str(self.interface_handle) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim-ma/standby/interface-table/interface-by-handles/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(PimMa.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle, ['interface_handle', u'interface_name_xr', u'vrf_name', u'interface_type'], name, value)


                    class RpAddress(Entity):
                        """
                        RP Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(PimMa.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress, self).__init__()

                            self.yang_name = "rp-address"
                            self.yang_parent_name = "interface-by-handle"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "rp-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(PimMa.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class SourceAddress(Entity):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(PimMa.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress, self).__init__()

                            self.yang_name = "source-address"
                            self.yang_parent_name = "interface-by-handle"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "source-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(PimMa.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class InterfaceByNames(Entity):
                """
                Table of PIM MA interfaces indexed by name
                
                .. attribute:: interface_by_name
                
                	PIM MA interface referenced by name
                	**type**\: list of  		 :py:class:`InterfaceByName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Standby.InterfaceTable.InterfaceByNames.InterfaceByName>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(PimMa.Standby.InterfaceTable.InterfaceByNames, self).__init__()

                    self.yang_name = "interface-by-names"
                    self.yang_parent_name = "interface-table"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("interface-by-name", ("interface_by_name", PimMa.Standby.InterfaceTable.InterfaceByNames.InterfaceByName))])
                    self._leafs = OrderedDict()

                    self.interface_by_name = YList(self)
                    self._segment_path = lambda: "interface-by-names"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim-ma/standby/interface-table/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(PimMa.Standby.InterfaceTable.InterfaceByNames, [], name, value)


                class InterfaceByName(Entity):
                    """
                    PIM MA interface referenced by name
                    
                    .. attribute:: interface_name  (key)
                    
                    	Interface name
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: rp_address
                    
                    	RP Address
                    	**type**\:  :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress>`
                    
                    .. attribute:: source_address
                    
                    	Source Address
                    	**type**\:  :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress>`
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Name
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: vrf_name
                    
                    	VRF Name
                    	**type**\: str
                    
                    .. attribute:: interface_type
                    
                    	Interface Type
                    	**type**\:  :py:class:`PimInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimInterface>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(PimMa.Standby.InterfaceTable.InterfaceByNames.InterfaceByName, self).__init__()

                        self.yang_name = "interface-by-name"
                        self.yang_parent_name = "interface-by-names"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['interface_name']
                        self._child_classes = OrderedDict([("rp-address", ("rp_address", PimMa.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress)), ("source-address", ("source_address", PimMa.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress))])
                        self._leafs = OrderedDict([
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                            ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                            ('interface_type', (YLeaf(YType.enumeration, 'interface-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimInterface', '')])),
                        ])
                        self.interface_name = None
                        self.interface_name_xr = None
                        self.vrf_name = None
                        self.interface_type = None

                        self.rp_address = PimMa.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress()
                        self.rp_address.parent = self
                        self._children_name_map["rp_address"] = "rp-address"

                        self.source_address = PimMa.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress()
                        self.source_address.parent = self
                        self._children_name_map["source_address"] = "source-address"
                        self._segment_path = lambda: "interface-by-name" + "[interface-name='" + str(self.interface_name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim-ma/standby/interface-table/interface-by-names/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(PimMa.Standby.InterfaceTable.InterfaceByNames.InterfaceByName, ['interface_name', u'interface_name_xr', u'vrf_name', u'interface_type'], name, value)


                    class RpAddress(Entity):
                        """
                        RP Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(PimMa.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress, self).__init__()

                            self.yang_name = "rp-address"
                            self.yang_parent_name = "interface-by-name"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "rp-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(PimMa.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class SourceAddress(Entity):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(PimMa.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress, self).__init__()

                            self.yang_name = "source-address"
                            self.yang_parent_name = "interface-by-name"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "source-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(PimMa.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


        class PimMaSummary(Entity):
            """
            PIM MA summary
            
            .. attribute:: is_im_connection_open
            
            	IM Connection Open
            	**type**\: bool
            
            .. attribute:: is_netio_connection_open
            
            	Netio Connection Open
            	**type**\: bool
            
            .. attribute:: is_edm_connection_open
            
            	EDM Connection Open
            	**type**\: bool
            
            .. attribute:: is_standby_edm_connection_open
            
            	Standby EDM Connection Open
            	**type**\: bool
            
            .. attribute:: encap_interface_count
            
            	Encap Interface Count
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: decap_interface_count
            
            	Decap Interface Count
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: mdt_interface_count
            
            	MDT Interface Count
            	**type**\: int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(PimMa.Standby.PimMaSummary, self).__init__()

                self.yang_name = "pim-ma-summary"
                self.yang_parent_name = "standby"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('is_im_connection_open', (YLeaf(YType.boolean, 'is-im-connection-open'), ['bool'])),
                    ('is_netio_connection_open', (YLeaf(YType.boolean, 'is-netio-connection-open'), ['bool'])),
                    ('is_edm_connection_open', (YLeaf(YType.boolean, 'is-edm-connection-open'), ['bool'])),
                    ('is_standby_edm_connection_open', (YLeaf(YType.boolean, 'is-standby-edm-connection-open'), ['bool'])),
                    ('encap_interface_count', (YLeaf(YType.uint32, 'encap-interface-count'), ['int'])),
                    ('decap_interface_count', (YLeaf(YType.uint32, 'decap-interface-count'), ['int'])),
                    ('mdt_interface_count', (YLeaf(YType.uint32, 'mdt-interface-count'), ['int'])),
                ])
                self.is_im_connection_open = None
                self.is_netio_connection_open = None
                self.is_edm_connection_open = None
                self.is_standby_edm_connection_open = None
                self.encap_interface_count = None
                self.decap_interface_count = None
                self.mdt_interface_count = None
                self._segment_path = lambda: "pim-ma-summary"
                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim-ma/standby/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(PimMa.Standby.PimMaSummary, [u'is_im_connection_open', u'is_netio_connection_open', u'is_edm_connection_open', u'is_standby_edm_connection_open', u'encap_interface_count', u'decap_interface_count', u'mdt_interface_count'], name, value)

    def clone_ptr(self):
        self._top_entity = PimMa()
        return self._top_entity

class Pim(Entity):
    """
    pim
    
    .. attribute:: standby
    
    	Standby Process
    	**type**\:  :py:class:`Standby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby>`
    
    .. attribute:: active
    
    	Active Process
    	**type**\:  :py:class:`Active <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active>`
    
    

    """

    _prefix = 'ipv4-pim-oper'
    _revision = '2017-09-07'

    def __init__(self):
        super(Pim, self).__init__()
        self._top_entity = None

        self.yang_name = "pim"
        self.yang_parent_name = "Cisco-IOS-XR-ipv4-pim-oper"
        self.is_top_level_class = True
        self.has_list_ancestor = False
        self.ylist_key_names = []
        self._child_classes = OrderedDict([("standby", ("standby", Pim.Standby)), ("active", ("active", Pim.Active))])
        self._leafs = OrderedDict()

        self.standby = Pim.Standby()
        self.standby.parent = self
        self._children_name_map["standby"] = "standby"

        self.active = Pim.Active()
        self.active.parent = self
        self._children_name_map["active"] = "active"
        self._segment_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim"
        self._is_frozen = True

    def __setattr__(self, name, value):
        self._perform_setattr(Pim, [], name, value)


    class Standby(Entity):
        """
        Standby Process
        
        .. attribute:: default_context
        
        	Default Context
        	**type**\:  :py:class:`DefaultContext <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext>`
        
        .. attribute:: process
        
        	Process
        	**type**\:  :py:class:`Process <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Process>`
        
        .. attribute:: vrfs
        
        	VRF Table
        	**type**\:  :py:class:`Vrfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs>`
        
        

        """

        _prefix = 'ipv4-pim-oper'
        _revision = '2017-09-07'

        def __init__(self):
            super(Pim.Standby, self).__init__()

            self.yang_name = "standby"
            self.yang_parent_name = "pim"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("default-context", ("default_context", Pim.Standby.DefaultContext)), ("process", ("process", Pim.Standby.Process)), ("vrfs", ("vrfs", Pim.Standby.Vrfs))])
            self._leafs = OrderedDict()

            self.default_context = Pim.Standby.DefaultContext()
            self.default_context.parent = self
            self._children_name_map["default_context"] = "default-context"

            self.process = Pim.Standby.Process()
            self.process.parent = self
            self._children_name_map["process"] = "process"

            self.vrfs = Pim.Standby.Vrfs()
            self.vrfs.parent = self
            self._children_name_map["vrfs"] = "vrfs"
            self._segment_path = lambda: "standby"
            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Pim.Standby, [], name, value)


        class DefaultContext(Entity):
            """
            Default Context
            
            .. attribute:: global_interfaces
            
            	PIM global interface table
            	**type**\:  :py:class:`GlobalInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GlobalInterfaces>`
            
            .. attribute:: ifrs_interfaces
            
            	PIM interfaces in forward reference store table
            	**type**\:  :py:class:`IfrsInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.IfrsInterfaces>`
            
            .. attribute:: safs
            
            	SAFI table and type
            	**type**\:  :py:class:`Safs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Safs>`
            
            .. attribute:: interface_statistics
            
            	PIM interface statistics
            	**type**\:  :py:class:`InterfaceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.InterfaceStatistics>`
            
            .. attribute:: topology_route_count
            
            	Topology route count information from PIM topology table
            	**type**\:  :py:class:`TopologyRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.TopologyRouteCount>`
            
            .. attribute:: jp_statistics
            
            	PIM join prune statistics table
            	**type**\:  :py:class:`JpStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.JpStatistics>`
            
            .. attribute:: mib_databases
            
            	PIM group database for mroute mibs table
            	**type**\:  :py:class:`MibDatabases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.MibDatabases>`
            
            .. attribute:: neighbor_old_formats
            
            	PIM neighbor table old format
            	**type**\:  :py:class:`NeighborOldFormats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.NeighborOldFormats>`
            
            .. attribute:: ifrs_summary
            
            	PIM interfaces in forward reference store summary
            	**type**\:  :py:class:`IfrsSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.IfrsSummary>`
            
            .. attribute:: ranges
            
            	PIM range list information
            	**type**\:  :py:class:`Ranges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Ranges>`
            
            .. attribute:: interface_old_formats
            
            	PIM interfaces in old format
            	**type**\:  :py:class:`InterfaceOldFormats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.InterfaceOldFormats>`
            
            .. attribute:: bsr
            
            	PIM BSR information
            	**type**\:  :py:class:`Bsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Bsr>`
            
            .. attribute:: route_policy
            
            	PIM route policy
            	**type**\:  :py:class:`RoutePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.RoutePolicy>`
            
            .. attribute:: rpf_summary
            
            	PIM RPF registration summary
            	**type**\:  :py:class:`RpfSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.RpfSummary>`
            
            .. attribute:: interfaces
            
            	PIM interfaces
            	**type**\:  :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Interfaces>`
            
            .. attribute:: net_io_tunnels
            
            	Tunnel information that NETIO has 
            	**type**\:  :py:class:`NetIoTunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.NetIoTunnels>`
            
            .. attribute:: bidir_df_states
            
            	Bidirectional PIM DF election state table
            	**type**\:  :py:class:`BidirDfStates <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.BidirDfStates>`
            
            .. attribute:: topologies
            
            	PIM topology table
            	**type**\:  :py:class:`Topologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Topologies>`
            
            .. attribute:: bgp_afs
            
            	PIM BGP SAFI table
            	**type**\:  :py:class:`BgpAfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.BgpAfs>`
            
            .. attribute:: auto_rp
            
            	PIM Auto\-RP information
            	**type**\:  :py:class:`AutoRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.AutoRp>`
            
            .. attribute:: topology_interface_flag_route_counts
            
            	Route count for topology with interface flag set
            	**type**\:  :py:class:`TopologyInterfaceFlagRouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts>`
            
            .. attribute:: group_map_sources
            
            	PIM group\-mapping with source information
            	**type**\:  :py:class:`GroupMapSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapSources>`
            
            .. attribute:: traffic_counters
            
            	PIM message traffic counters
            	**type**\:  :py:class:`TrafficCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.TrafficCounters>`
            
            .. attribute:: group_map_rpfs
            
            	PIM group mapping information
            	**type**\:  :py:class:`GroupMapRpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapRpfs>`
            
            .. attribute:: summary
            
            	PIM summary
            	**type**\:  :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Summary>`
            
            .. attribute:: gre
            
            	GRE information
            	**type**\:  :py:class:`Gre <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Gre>`
            
            .. attribute:: bidir_df_winners
            
            	Bidirectional PIM DF election winner table
            	**type**\:  :py:class:`BidirDfWinners <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.BidirDfWinners>`
            
            .. attribute:: table_contexts
            
            	PIM table context list
            	**type**\:  :py:class:`TableContexts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.TableContexts>`
            
            .. attribute:: neighbor_summaries
            
            	PIM neighbor summary table
            	**type**\:  :py:class:`NeighborSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.NeighborSummaries>`
            
            .. attribute:: context
            
            	PIM context information
            	**type**\:  :py:class:`Context <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Context>`
            
            .. attribute:: topology_entry_flag_route_counts
            
            	Route count for topology with entry flag set
            	**type**\:  :py:class:`TopologyEntryFlagRouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts>`
            
            .. attribute:: rpf_redirect
            
            	PIM ECMP RPF\-redirect bundle
            	**type**\:  :py:class:`RpfRedirect <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.RpfRedirect>`
            
            .. attribute:: tunnels
            
            	Tunnels information that PIM has
            	**type**\:  :py:class:`Tunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Tunnels>`
            
            .. attribute:: multicast_static_routes
            
            	PIM multicast static route table
            	**type**\:  :py:class:`MulticastStaticRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.MulticastStaticRoutes>`
            
            .. attribute:: neighbors
            
            	PIM neighbor table
            	**type**\:  :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Neighbors>`
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(Pim.Standby.DefaultContext, self).__init__()

                self.yang_name = "default-context"
                self.yang_parent_name = "standby"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("global-interfaces", ("global_interfaces", Pim.Standby.DefaultContext.GlobalInterfaces)), ("ifrs-interfaces", ("ifrs_interfaces", Pim.Standby.DefaultContext.IfrsInterfaces)), ("safs", ("safs", Pim.Standby.DefaultContext.Safs)), ("interface-statistics", ("interface_statistics", Pim.Standby.DefaultContext.InterfaceStatistics)), ("topology-route-count", ("topology_route_count", Pim.Standby.DefaultContext.TopologyRouteCount)), ("jp-statistics", ("jp_statistics", Pim.Standby.DefaultContext.JpStatistics)), ("mib-databases", ("mib_databases", Pim.Standby.DefaultContext.MibDatabases)), ("neighbor-old-formats", ("neighbor_old_formats", Pim.Standby.DefaultContext.NeighborOldFormats)), ("ifrs-summary", ("ifrs_summary", Pim.Standby.DefaultContext.IfrsSummary)), ("ranges", ("ranges", Pim.Standby.DefaultContext.Ranges)), ("interface-old-formats", ("interface_old_formats", Pim.Standby.DefaultContext.InterfaceOldFormats)), ("bsr", ("bsr", Pim.Standby.DefaultContext.Bsr)), ("route-policy", ("route_policy", Pim.Standby.DefaultContext.RoutePolicy)), ("rpf-summary", ("rpf_summary", Pim.Standby.DefaultContext.RpfSummary)), ("interfaces", ("interfaces", Pim.Standby.DefaultContext.Interfaces)), ("net-io-tunnels", ("net_io_tunnels", Pim.Standby.DefaultContext.NetIoTunnels)), ("bidir-df-states", ("bidir_df_states", Pim.Standby.DefaultContext.BidirDfStates)), ("topologies", ("topologies", Pim.Standby.DefaultContext.Topologies)), ("bgp-afs", ("bgp_afs", Pim.Standby.DefaultContext.BgpAfs)), ("auto-rp", ("auto_rp", Pim.Standby.DefaultContext.AutoRp)), ("topology-interface-flag-route-counts", ("topology_interface_flag_route_counts", Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts)), ("group-map-sources", ("group_map_sources", Pim.Standby.DefaultContext.GroupMapSources)), ("traffic-counters", ("traffic_counters", Pim.Standby.DefaultContext.TrafficCounters)), ("group-map-rpfs", ("group_map_rpfs", Pim.Standby.DefaultContext.GroupMapRpfs)), ("summary", ("summary", Pim.Standby.DefaultContext.Summary)), ("gre", ("gre", Pim.Standby.DefaultContext.Gre)), ("bidir-df-winners", ("bidir_df_winners", Pim.Standby.DefaultContext.BidirDfWinners)), ("table-contexts", ("table_contexts", Pim.Standby.DefaultContext.TableContexts)), ("neighbor-summaries", ("neighbor_summaries", Pim.Standby.DefaultContext.NeighborSummaries)), ("context", ("context", Pim.Standby.DefaultContext.Context)), ("topology-entry-flag-route-counts", ("topology_entry_flag_route_counts", Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts)), ("rpf-redirect", ("rpf_redirect", Pim.Standby.DefaultContext.RpfRedirect)), ("tunnels", ("tunnels", Pim.Standby.DefaultContext.Tunnels)), ("multicast-static-routes", ("multicast_static_routes", Pim.Standby.DefaultContext.MulticastStaticRoutes)), ("neighbors", ("neighbors", Pim.Standby.DefaultContext.Neighbors))])
                self._leafs = OrderedDict()

                self.global_interfaces = Pim.Standby.DefaultContext.GlobalInterfaces()
                self.global_interfaces.parent = self
                self._children_name_map["global_interfaces"] = "global-interfaces"

                self.ifrs_interfaces = Pim.Standby.DefaultContext.IfrsInterfaces()
                self.ifrs_interfaces.parent = self
                self._children_name_map["ifrs_interfaces"] = "ifrs-interfaces"

                self.safs = Pim.Standby.DefaultContext.Safs()
                self.safs.parent = self
                self._children_name_map["safs"] = "safs"

                self.interface_statistics = Pim.Standby.DefaultContext.InterfaceStatistics()
                self.interface_statistics.parent = self
                self._children_name_map["interface_statistics"] = "interface-statistics"

                self.topology_route_count = Pim.Standby.DefaultContext.TopologyRouteCount()
                self.topology_route_count.parent = self
                self._children_name_map["topology_route_count"] = "topology-route-count"

                self.jp_statistics = Pim.Standby.DefaultContext.JpStatistics()
                self.jp_statistics.parent = self
                self._children_name_map["jp_statistics"] = "jp-statistics"

                self.mib_databases = Pim.Standby.DefaultContext.MibDatabases()
                self.mib_databases.parent = self
                self._children_name_map["mib_databases"] = "mib-databases"

                self.neighbor_old_formats = Pim.Standby.DefaultContext.NeighborOldFormats()
                self.neighbor_old_formats.parent = self
                self._children_name_map["neighbor_old_formats"] = "neighbor-old-formats"

                self.ifrs_summary = Pim.Standby.DefaultContext.IfrsSummary()
                self.ifrs_summary.parent = self
                self._children_name_map["ifrs_summary"] = "ifrs-summary"

                self.ranges = Pim.Standby.DefaultContext.Ranges()
                self.ranges.parent = self
                self._children_name_map["ranges"] = "ranges"

                self.interface_old_formats = Pim.Standby.DefaultContext.InterfaceOldFormats()
                self.interface_old_formats.parent = self
                self._children_name_map["interface_old_formats"] = "interface-old-formats"

                self.bsr = Pim.Standby.DefaultContext.Bsr()
                self.bsr.parent = self
                self._children_name_map["bsr"] = "bsr"

                self.route_policy = Pim.Standby.DefaultContext.RoutePolicy()
                self.route_policy.parent = self
                self._children_name_map["route_policy"] = "route-policy"

                self.rpf_summary = Pim.Standby.DefaultContext.RpfSummary()
                self.rpf_summary.parent = self
                self._children_name_map["rpf_summary"] = "rpf-summary"

                self.interfaces = Pim.Standby.DefaultContext.Interfaces()
                self.interfaces.parent = self
                self._children_name_map["interfaces"] = "interfaces"

                self.net_io_tunnels = Pim.Standby.DefaultContext.NetIoTunnels()
                self.net_io_tunnels.parent = self
                self._children_name_map["net_io_tunnels"] = "net-io-tunnels"

                self.bidir_df_states = Pim.Standby.DefaultContext.BidirDfStates()
                self.bidir_df_states.parent = self
                self._children_name_map["bidir_df_states"] = "bidir-df-states"

                self.topologies = Pim.Standby.DefaultContext.Topologies()
                self.topologies.parent = self
                self._children_name_map["topologies"] = "topologies"

                self.bgp_afs = Pim.Standby.DefaultContext.BgpAfs()
                self.bgp_afs.parent = self
                self._children_name_map["bgp_afs"] = "bgp-afs"

                self.auto_rp = Pim.Standby.DefaultContext.AutoRp()
                self.auto_rp.parent = self
                self._children_name_map["auto_rp"] = "auto-rp"

                self.topology_interface_flag_route_counts = Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts()
                self.topology_interface_flag_route_counts.parent = self
                self._children_name_map["topology_interface_flag_route_counts"] = "topology-interface-flag-route-counts"

                self.group_map_sources = Pim.Standby.DefaultContext.GroupMapSources()
                self.group_map_sources.parent = self
                self._children_name_map["group_map_sources"] = "group-map-sources"

                self.traffic_counters = Pim.Standby.DefaultContext.TrafficCounters()
                self.traffic_counters.parent = self
                self._children_name_map["traffic_counters"] = "traffic-counters"

                self.group_map_rpfs = Pim.Standby.DefaultContext.GroupMapRpfs()
                self.group_map_rpfs.parent = self
                self._children_name_map["group_map_rpfs"] = "group-map-rpfs"

                self.summary = Pim.Standby.DefaultContext.Summary()
                self.summary.parent = self
                self._children_name_map["summary"] = "summary"

                self.gre = Pim.Standby.DefaultContext.Gre()
                self.gre.parent = self
                self._children_name_map["gre"] = "gre"

                self.bidir_df_winners = Pim.Standby.DefaultContext.BidirDfWinners()
                self.bidir_df_winners.parent = self
                self._children_name_map["bidir_df_winners"] = "bidir-df-winners"

                self.table_contexts = Pim.Standby.DefaultContext.TableContexts()
                self.table_contexts.parent = self
                self._children_name_map["table_contexts"] = "table-contexts"

                self.neighbor_summaries = Pim.Standby.DefaultContext.NeighborSummaries()
                self.neighbor_summaries.parent = self
                self._children_name_map["neighbor_summaries"] = "neighbor-summaries"

                self.context = Pim.Standby.DefaultContext.Context()
                self.context.parent = self
                self._children_name_map["context"] = "context"

                self.topology_entry_flag_route_counts = Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts()
                self.topology_entry_flag_route_counts.parent = self
                self._children_name_map["topology_entry_flag_route_counts"] = "topology-entry-flag-route-counts"

                self.rpf_redirect = Pim.Standby.DefaultContext.RpfRedirect()
                self.rpf_redirect.parent = self
                self._children_name_map["rpf_redirect"] = "rpf-redirect"

                self.tunnels = Pim.Standby.DefaultContext.Tunnels()
                self.tunnels.parent = self
                self._children_name_map["tunnels"] = "tunnels"

                self.multicast_static_routes = Pim.Standby.DefaultContext.MulticastStaticRoutes()
                self.multicast_static_routes.parent = self
                self._children_name_map["multicast_static_routes"] = "multicast-static-routes"

                self.neighbors = Pim.Standby.DefaultContext.Neighbors()
                self.neighbors.parent = self
                self._children_name_map["neighbors"] = "neighbors"
                self._segment_path = lambda: "default-context"
                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Pim.Standby.DefaultContext, [], name, value)


            class GlobalInterfaces(Entity):
                """
                PIM global interface table
                
                .. attribute:: global_interface
                
                	PIM interface name
                	**type**\: list of  		 :py:class:`GlobalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.GlobalInterfaces, self).__init__()

                    self.yang_name = "global-interfaces"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("global-interface", ("global_interface", Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface))])
                    self._leafs = OrderedDict()

                    self.global_interface = YList(self)
                    self._segment_path = lambda: "global-interfaces"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.DefaultContext.GlobalInterfaces, [], name, value)


                class GlobalInterface(Entity):
                    """
                    PIM interface name
                    
                    .. attribute:: interface_name  (key)
                    
                    	Interface name
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: dr_address
                    
                    	PIM Designated Router
                    	**type**\:  :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress>`
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identfier
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: interface_address_mask
                    
                    	Interface IP Address Mask
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: is_enabled
                    
                    	Is PIM enabled on this IF ?
                    	**type**\: bool
                    
                    .. attribute:: neighbor_count
                    
                    	No. of neighbors on this IF
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: external_neighbor_count
                    
                    	No. of external neighbors on this IF
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: hello_interval
                    
                    	Hello Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dr_priority
                    
                    	DR Priority
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_expiry
                    
                    	Hello Timer Expiry
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: are_we_dr
                    
                    	Are we the DR on this IF ?
                    	**type**\: bool
                    
                    .. attribute:: bfd_enabled
                    
                    	BFD state
                    	**type**\: bool
                    
                    .. attribute:: bfd_interval
                    
                    	BFD Interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bfd_multiplier
                    
                    	BFD Multiplier
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_interface
                    
                    	 is this a Virtual Interfaces ?
                    	**type**\: bool
                    
                    .. attribute:: passive_interface
                    
                    	Passive PIM interface
                    	**type**\: bool
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\: str
                    
                    .. attribute:: join_prune_interval
                    
                    	Join\-Prune Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: prune_delay_enabled
                    
                    	Prune Delay Enabled
                    	**type**\: bool
                    
                    .. attribute:: configured_propagation_delay
                    
                    	Configured Propagation Delay
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_override_interval
                    
                    	Configured Override Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: generation_id
                    
                    	Generation Identifier
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Bidir Capable
                    	**type**\: bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Proxy Capable
                    	**type**\: bool
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Batch Asserts Capable
                    	**type**\: bool
                    
                    .. attribute:: idb_oor_enabled
                    
                    	Interface oor enabled
                    	**type**\: bool
                    
                    .. attribute:: idb_acl_provided
                    
                    	ACL name provided
                    	**type**\: bool
                    
                    .. attribute:: idb_max_count
                    
                    	Interface ole max count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_threshold_count
                    
                    	Interface ole threshold count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_current_count
                    
                    	Interface ole current count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_acl_name
                    
                    	Interface ole ACL Name
                    	**type**\: str
                    
                    	**length:** 0..64
                    
                    .. attribute:: interface_address
                    
                    	List of Interface IP Addresses
                    	**type**\: list of  		 :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.InterfaceAddress>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface, self).__init__()

                        self.yang_name = "global-interface"
                        self.yang_parent_name = "global-interfaces"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['interface_name']
                        self._child_classes = OrderedDict([("dr-address", ("dr_address", Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress)), ("interface-address", ("interface_address", Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.InterfaceAddress))])
                        self._leafs = OrderedDict([
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                            ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                            ('interface_address_mask', (YLeaf(YType.uint8, 'interface-address-mask'), ['int'])),
                            ('is_enabled', (YLeaf(YType.boolean, 'is-enabled'), ['bool'])),
                            ('neighbor_count', (YLeaf(YType.uint16, 'neighbor-count'), ['int'])),
                            ('external_neighbor_count', (YLeaf(YType.uint16, 'external-neighbor-count'), ['int'])),
                            ('hello_interval', (YLeaf(YType.uint16, 'hello-interval'), ['int'])),
                            ('dr_priority', (YLeaf(YType.uint32, 'dr-priority'), ['int'])),
                            ('hello_expiry', (YLeaf(YType.uint64, 'hello-expiry'), ['int'])),
                            ('are_we_dr', (YLeaf(YType.boolean, 'are-we-dr'), ['bool'])),
                            ('bfd_enabled', (YLeaf(YType.boolean, 'bfd-enabled'), ['bool'])),
                            ('bfd_interval', (YLeaf(YType.uint32, 'bfd-interval'), ['int'])),
                            ('bfd_multiplier', (YLeaf(YType.uint32, 'bfd-multiplier'), ['int'])),
                            ('virtual_interface', (YLeaf(YType.boolean, 'virtual-interface'), ['bool'])),
                            ('passive_interface', (YLeaf(YType.boolean, 'passive-interface'), ['bool'])),
                            ('neighbor_filter_name', (YLeaf(YType.str, 'neighbor-filter-name'), ['str'])),
                            ('join_prune_interval', (YLeaf(YType.uint16, 'join-prune-interval'), ['int'])),
                            ('prune_delay_enabled', (YLeaf(YType.boolean, 'prune-delay-enabled'), ['bool'])),
                            ('configured_propagation_delay', (YLeaf(YType.uint16, 'configured-propagation-delay'), ['int'])),
                            ('propagation_delay', (YLeaf(YType.uint16, 'propagation-delay'), ['int'])),
                            ('configured_override_interval', (YLeaf(YType.uint16, 'configured-override-interval'), ['int'])),
                            ('override_interval', (YLeaf(YType.uint16, 'override-interval'), ['int'])),
                            ('generation_id', (YLeaf(YType.uint32, 'generation-id'), ['int'])),
                            ('is_bidirectional_capable', (YLeaf(YType.boolean, 'is-bidirectional-capable'), ['bool'])),
                            ('is_proxy_capable', (YLeaf(YType.boolean, 'is-proxy-capable'), ['bool'])),
                            ('is_batch_asserts_capable', (YLeaf(YType.boolean, 'is-batch-asserts-capable'), ['bool'])),
                            ('idb_oor_enabled', (YLeaf(YType.boolean, 'idb-oor-enabled'), ['bool'])),
                            ('idb_acl_provided', (YLeaf(YType.boolean, 'idb-acl-provided'), ['bool'])),
                            ('idb_max_count', (YLeaf(YType.uint32, 'idb-max-count'), ['int'])),
                            ('idb_threshold_count', (YLeaf(YType.uint32, 'idb-threshold-count'), ['int'])),
                            ('idb_current_count', (YLeaf(YType.uint32, 'idb-current-count'), ['int'])),
                            ('idb_acl_name', (YLeaf(YType.str, 'idb-acl-name'), ['str'])),
                        ])
                        self.interface_name = None
                        self.interface_name_xr = None
                        self.interface_address_mask = None
                        self.is_enabled = None
                        self.neighbor_count = None
                        self.external_neighbor_count = None
                        self.hello_interval = None
                        self.dr_priority = None
                        self.hello_expiry = None
                        self.are_we_dr = None
                        self.bfd_enabled = None
                        self.bfd_interval = None
                        self.bfd_multiplier = None
                        self.virtual_interface = None
                        self.passive_interface = None
                        self.neighbor_filter_name = None
                        self.join_prune_interval = None
                        self.prune_delay_enabled = None
                        self.configured_propagation_delay = None
                        self.propagation_delay = None
                        self.configured_override_interval = None
                        self.override_interval = None
                        self.generation_id = None
                        self.is_bidirectional_capable = None
                        self.is_proxy_capable = None
                        self.is_batch_asserts_capable = None
                        self.idb_oor_enabled = None
                        self.idb_acl_provided = None
                        self.idb_max_count = None
                        self.idb_threshold_count = None
                        self.idb_current_count = None
                        self.idb_acl_name = None

                        self.dr_address = Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress()
                        self.dr_address.parent = self
                        self._children_name_map["dr_address"] = "dr-address"

                        self.interface_address = YList(self)
                        self._segment_path = lambda: "global-interface" + "[interface-name='" + str(self.interface_name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/global-interfaces/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface, ['interface_name', 'interface_name_xr', 'interface_address_mask', 'is_enabled', 'neighbor_count', 'external_neighbor_count', 'hello_interval', 'dr_priority', 'hello_expiry', 'are_we_dr', 'bfd_enabled', 'bfd_interval', 'bfd_multiplier', 'virtual_interface', 'passive_interface', 'neighbor_filter_name', 'join_prune_interval', 'prune_delay_enabled', 'configured_propagation_delay', 'propagation_delay', 'configured_override_interval', 'override_interval', 'generation_id', 'is_bidirectional_capable', 'is_proxy_capable', 'is_batch_asserts_capable', 'idb_oor_enabled', 'idb_acl_provided', 'idb_max_count', 'idb_threshold_count', 'idb_current_count', 'idb_acl_name'], name, value)


                    class DrAddress(Entity):
                        """
                        PIM Designated Router
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress, self).__init__()

                            self.yang_name = "dr-address"
                            self.yang_parent_name = "global-interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "dr-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class InterfaceAddress(Entity):
                        """
                        List of Interface IP Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.InterfaceAddress, self).__init__()

                            self.yang_name = "interface-address"
                            self.yang_parent_name = "global-interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "interface-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.InterfaceAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class IfrsInterfaces(Entity):
                """
                PIM interfaces in forward reference store table
                
                .. attribute:: ifrs_interface
                
                	PIM IFRS interface information
                	**type**\: list of  		 :py:class:`IfrsInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.IfrsInterfaces, self).__init__()

                    self.yang_name = "ifrs-interfaces"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ifrs-interface", ("ifrs_interface", Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface))])
                    self._leafs = OrderedDict()

                    self.ifrs_interface = YList(self)
                    self._segment_path = lambda: "ifrs-interfaces"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.DefaultContext.IfrsInterfaces, [], name, value)


                class IfrsInterface(Entity):
                    """
                    PIM IFRS interface information
                    
                    .. attribute:: interface_name  (key)
                    
                    	Interface name
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: dr_address
                    
                    	PIM Designated Router
                    	**type**\:  :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress>`
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identfier
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: interface_address_mask
                    
                    	Interface IP Address Mask
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: is_enabled
                    
                    	Is PIM enabled on this IF ?
                    	**type**\: bool
                    
                    .. attribute:: neighbor_count
                    
                    	No. of neighbors on this IF
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: external_neighbor_count
                    
                    	No. of external neighbors on this IF
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: hello_interval
                    
                    	Hello Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dr_priority
                    
                    	DR Priority
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_expiry
                    
                    	Hello Timer Expiry
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: are_we_dr
                    
                    	Are we the DR on this IF ?
                    	**type**\: bool
                    
                    .. attribute:: bfd_enabled
                    
                    	BFD state
                    	**type**\: bool
                    
                    .. attribute:: bfd_interval
                    
                    	BFD Interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bfd_multiplier
                    
                    	BFD Multiplier
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_interface
                    
                    	 is this a Virtual Interfaces ?
                    	**type**\: bool
                    
                    .. attribute:: passive_interface
                    
                    	Passive PIM interface
                    	**type**\: bool
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\: str
                    
                    .. attribute:: join_prune_interval
                    
                    	Join\-Prune Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: prune_delay_enabled
                    
                    	Prune Delay Enabled
                    	**type**\: bool
                    
                    .. attribute:: configured_propagation_delay
                    
                    	Configured Propagation Delay
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_override_interval
                    
                    	Configured Override Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: generation_id
                    
                    	Generation Identifier
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Bidir Capable
                    	**type**\: bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Proxy Capable
                    	**type**\: bool
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Batch Asserts Capable
                    	**type**\: bool
                    
                    .. attribute:: idb_oor_enabled
                    
                    	Interface oor enabled
                    	**type**\: bool
                    
                    .. attribute:: idb_acl_provided
                    
                    	ACL name provided
                    	**type**\: bool
                    
                    .. attribute:: idb_max_count
                    
                    	Interface ole max count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_threshold_count
                    
                    	Interface ole threshold count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_current_count
                    
                    	Interface ole current count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_acl_name
                    
                    	Interface ole ACL Name
                    	**type**\: str
                    
                    	**length:** 0..64
                    
                    .. attribute:: interface_address
                    
                    	List of Interface IP Addresses
                    	**type**\: list of  		 :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.InterfaceAddress>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface, self).__init__()

                        self.yang_name = "ifrs-interface"
                        self.yang_parent_name = "ifrs-interfaces"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['interface_name']
                        self._child_classes = OrderedDict([("dr-address", ("dr_address", Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress)), ("interface-address", ("interface_address", Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.InterfaceAddress))])
                        self._leafs = OrderedDict([
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                            ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                            ('interface_address_mask', (YLeaf(YType.uint8, 'interface-address-mask'), ['int'])),
                            ('is_enabled', (YLeaf(YType.boolean, 'is-enabled'), ['bool'])),
                            ('neighbor_count', (YLeaf(YType.uint16, 'neighbor-count'), ['int'])),
                            ('external_neighbor_count', (YLeaf(YType.uint16, 'external-neighbor-count'), ['int'])),
                            ('hello_interval', (YLeaf(YType.uint16, 'hello-interval'), ['int'])),
                            ('dr_priority', (YLeaf(YType.uint32, 'dr-priority'), ['int'])),
                            ('hello_expiry', (YLeaf(YType.uint64, 'hello-expiry'), ['int'])),
                            ('are_we_dr', (YLeaf(YType.boolean, 'are-we-dr'), ['bool'])),
                            ('bfd_enabled', (YLeaf(YType.boolean, 'bfd-enabled'), ['bool'])),
                            ('bfd_interval', (YLeaf(YType.uint32, 'bfd-interval'), ['int'])),
                            ('bfd_multiplier', (YLeaf(YType.uint32, 'bfd-multiplier'), ['int'])),
                            ('virtual_interface', (YLeaf(YType.boolean, 'virtual-interface'), ['bool'])),
                            ('passive_interface', (YLeaf(YType.boolean, 'passive-interface'), ['bool'])),
                            ('neighbor_filter_name', (YLeaf(YType.str, 'neighbor-filter-name'), ['str'])),
                            ('join_prune_interval', (YLeaf(YType.uint16, 'join-prune-interval'), ['int'])),
                            ('prune_delay_enabled', (YLeaf(YType.boolean, 'prune-delay-enabled'), ['bool'])),
                            ('configured_propagation_delay', (YLeaf(YType.uint16, 'configured-propagation-delay'), ['int'])),
                            ('propagation_delay', (YLeaf(YType.uint16, 'propagation-delay'), ['int'])),
                            ('configured_override_interval', (YLeaf(YType.uint16, 'configured-override-interval'), ['int'])),
                            ('override_interval', (YLeaf(YType.uint16, 'override-interval'), ['int'])),
                            ('generation_id', (YLeaf(YType.uint32, 'generation-id'), ['int'])),
                            ('is_bidirectional_capable', (YLeaf(YType.boolean, 'is-bidirectional-capable'), ['bool'])),
                            ('is_proxy_capable', (YLeaf(YType.boolean, 'is-proxy-capable'), ['bool'])),
                            ('is_batch_asserts_capable', (YLeaf(YType.boolean, 'is-batch-asserts-capable'), ['bool'])),
                            ('idb_oor_enabled', (YLeaf(YType.boolean, 'idb-oor-enabled'), ['bool'])),
                            ('idb_acl_provided', (YLeaf(YType.boolean, 'idb-acl-provided'), ['bool'])),
                            ('idb_max_count', (YLeaf(YType.uint32, 'idb-max-count'), ['int'])),
                            ('idb_threshold_count', (YLeaf(YType.uint32, 'idb-threshold-count'), ['int'])),
                            ('idb_current_count', (YLeaf(YType.uint32, 'idb-current-count'), ['int'])),
                            ('idb_acl_name', (YLeaf(YType.str, 'idb-acl-name'), ['str'])),
                        ])
                        self.interface_name = None
                        self.interface_name_xr = None
                        self.interface_address_mask = None
                        self.is_enabled = None
                        self.neighbor_count = None
                        self.external_neighbor_count = None
                        self.hello_interval = None
                        self.dr_priority = None
                        self.hello_expiry = None
                        self.are_we_dr = None
                        self.bfd_enabled = None
                        self.bfd_interval = None
                        self.bfd_multiplier = None
                        self.virtual_interface = None
                        self.passive_interface = None
                        self.neighbor_filter_name = None
                        self.join_prune_interval = None
                        self.prune_delay_enabled = None
                        self.configured_propagation_delay = None
                        self.propagation_delay = None
                        self.configured_override_interval = None
                        self.override_interval = None
                        self.generation_id = None
                        self.is_bidirectional_capable = None
                        self.is_proxy_capable = None
                        self.is_batch_asserts_capable = None
                        self.idb_oor_enabled = None
                        self.idb_acl_provided = None
                        self.idb_max_count = None
                        self.idb_threshold_count = None
                        self.idb_current_count = None
                        self.idb_acl_name = None

                        self.dr_address = Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress()
                        self.dr_address.parent = self
                        self._children_name_map["dr_address"] = "dr-address"

                        self.interface_address = YList(self)
                        self._segment_path = lambda: "ifrs-interface" + "[interface-name='" + str(self.interface_name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/ifrs-interfaces/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface, ['interface_name', 'interface_name_xr', 'interface_address_mask', 'is_enabled', 'neighbor_count', 'external_neighbor_count', 'hello_interval', 'dr_priority', 'hello_expiry', 'are_we_dr', 'bfd_enabled', 'bfd_interval', 'bfd_multiplier', 'virtual_interface', 'passive_interface', 'neighbor_filter_name', 'join_prune_interval', 'prune_delay_enabled', 'configured_propagation_delay', 'propagation_delay', 'configured_override_interval', 'override_interval', 'generation_id', 'is_bidirectional_capable', 'is_proxy_capable', 'is_batch_asserts_capable', 'idb_oor_enabled', 'idb_acl_provided', 'idb_max_count', 'idb_threshold_count', 'idb_current_count', 'idb_acl_name'], name, value)


                    class DrAddress(Entity):
                        """
                        PIM Designated Router
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress, self).__init__()

                            self.yang_name = "dr-address"
                            self.yang_parent_name = "ifrs-interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "dr-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class InterfaceAddress(Entity):
                        """
                        List of Interface IP Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.InterfaceAddress, self).__init__()

                            self.yang_name = "interface-address"
                            self.yang_parent_name = "ifrs-interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "interface-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.InterfaceAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class Safs(Entity):
                """
                SAFI table and type
                
                .. attribute:: saf
                
                	SAF name 
                	**type**\: list of  		 :py:class:`Saf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Safs.Saf>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.Safs, self).__init__()

                    self.yang_name = "safs"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("saf", ("saf", Pim.Standby.DefaultContext.Safs.Saf))])
                    self._leafs = OrderedDict()

                    self.saf = YList(self)
                    self._segment_path = lambda: "safs"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.DefaultContext.Safs, [], name, value)


                class Saf(Entity):
                    """
                    SAF name 
                    
                    .. attribute:: rpf_hash_source_groups
                    
                    	PIM RPF multipath hash outcome
                    	**type**\:  :py:class:`RpfHashSourceGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups>`
                    
                    .. attribute:: rpf_hash_sources
                    
                    	PIM RPF multipath hash outcome
                    	**type**\:  :py:class:`RpfHashSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources>`
                    
                    .. attribute:: rpfs
                    
                    	PIM RPF information table
                    	**type**\:  :py:class:`Rpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Safs.Saf.Rpfs>`
                    
                    .. attribute:: saf_name
                    
                    	SAF name 
                    	**type**\:  :py:class:`PimSafi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimSafi>`
                    
                    .. attribute:: topology_name
                    
                    	Topology name 
                    	**type**\: str
                    
                    	**length:** 1..32
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.Safs.Saf, self).__init__()

                        self.yang_name = "saf"
                        self.yang_parent_name = "safs"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("rpf-hash-source-groups", ("rpf_hash_source_groups", Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups)), ("rpf-hash-sources", ("rpf_hash_sources", Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources)), ("rpfs", ("rpfs", Pim.Standby.DefaultContext.Safs.Saf.Rpfs))])
                        self._leafs = OrderedDict([
                            ('saf_name', (YLeaf(YType.enumeration, 'saf-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimSafi', '')])),
                            ('topology_name', (YLeaf(YType.str, 'topology-name'), ['str'])),
                        ])
                        self.saf_name = None
                        self.topology_name = None

                        self.rpf_hash_source_groups = Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups()
                        self.rpf_hash_source_groups.parent = self
                        self._children_name_map["rpf_hash_source_groups"] = "rpf-hash-source-groups"

                        self.rpf_hash_sources = Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources()
                        self.rpf_hash_sources.parent = self
                        self._children_name_map["rpf_hash_sources"] = "rpf-hash-sources"

                        self.rpfs = Pim.Standby.DefaultContext.Safs.Saf.Rpfs()
                        self.rpfs.parent = self
                        self._children_name_map["rpfs"] = "rpfs"
                        self._segment_path = lambda: "saf"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/safs/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.Safs.Saf, ['saf_name', 'topology_name'], name, value)


                    class RpfHashSourceGroups(Entity):
                        """
                        PIM RPF multipath hash outcome
                        
                        .. attribute:: rpf_hash_source_group
                        
                        	PIM RPF hash outcome for S,G
                        	**type**\: list of  		 :py:class:`RpfHashSourceGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups, self).__init__()

                            self.yang_name = "rpf-hash-source-groups"
                            self.yang_parent_name = "saf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rpf-hash-source-group", ("rpf_hash_source_group", Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup))])
                            self._leafs = OrderedDict()

                            self.rpf_hash_source_group = YList(self)
                            self._segment_path = lambda: "rpf-hash-source-groups"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/safs/saf/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups, [], name, value)


                        class RpfHashSourceGroup(Entity):
                            """
                            PIM RPF hash outcome for S,G
                            
                            .. attribute:: source_address
                            
                            	Source address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: group_address
                            
                            	Group address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: mask_length
                            
                            	Hash mask length
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mofrr
                            
                            	MOFRR
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: next_hop_address
                            
                            	Next hop neighbor address
                            	**type**\:  :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress>`
                            
                            .. attribute:: secondary_next_hop_address
                            
                            	Secondary Next hop neighbor address
                            	**type**\:  :py:class:`SecondaryNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress>`
                            
                            .. attribute:: next_hop_multipath_enabled
                            
                            	Next hop multipath enabled?
                            	**type**\: bool
                            
                            .. attribute:: next_hop_interface
                            
                            	Next hop neighbor interface
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: secondary_next_hop_interface
                            
                            	Secondary Next hop neighbor interface
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup, self).__init__()

                                self.yang_name = "rpf-hash-source-group"
                                self.yang_parent_name = "rpf-hash-source-groups"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("next-hop-address", ("next_hop_address", Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress)), ("secondary-next-hop-address", ("secondary_next_hop_address", Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress))])
                                self._leafs = OrderedDict([
                                    ('source_address', (YLeaf(YType.str, 'source-address'), ['str','str'])),
                                    ('group_address', (YLeaf(YType.str, 'group-address'), ['str','str'])),
                                    ('mask_length', (YLeaf(YType.uint32, 'mask-length'), ['int'])),
                                    ('mofrr', (YLeaf(YType.uint32, 'mofrr'), ['int'])),
                                    ('next_hop_multipath_enabled', (YLeaf(YType.boolean, 'next-hop-multipath-enabled'), ['bool'])),
                                    ('next_hop_interface', (YLeaf(YType.str, 'next-hop-interface'), ['str'])),
                                    ('secondary_next_hop_interface', (YLeaf(YType.str, 'secondary-next-hop-interface'), ['str'])),
                                ])
                                self.source_address = None
                                self.group_address = None
                                self.mask_length = None
                                self.mofrr = None
                                self.next_hop_multipath_enabled = None
                                self.next_hop_interface = None
                                self.secondary_next_hop_interface = None

                                self.next_hop_address = Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress()
                                self.next_hop_address.parent = self
                                self._children_name_map["next_hop_address"] = "next-hop-address"

                                self.secondary_next_hop_address = Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress()
                                self.secondary_next_hop_address.parent = self
                                self._children_name_map["secondary_next_hop_address"] = "secondary-next-hop-address"
                                self._segment_path = lambda: "rpf-hash-source-group"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/safs/saf/rpf-hash-source-groups/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup, ['source_address', 'group_address', 'mask_length', 'mofrr', 'next_hop_multipath_enabled', 'next_hop_interface', 'secondary_next_hop_interface'], name, value)


                            class NextHopAddress(Entity):
                                """
                                Next hop neighbor address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress, self).__init__()

                                    self.yang_name = "next-hop-address"
                                    self.yang_parent_name = "rpf-hash-source-group"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "next-hop-address"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/safs/saf/rpf-hash-source-groups/rpf-hash-source-group/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                            class SecondaryNextHopAddress(Entity):
                                """
                                Secondary Next hop neighbor address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress, self).__init__()

                                    self.yang_name = "secondary-next-hop-address"
                                    self.yang_parent_name = "rpf-hash-source-group"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "secondary-next-hop-address"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/safs/saf/rpf-hash-source-groups/rpf-hash-source-group/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class RpfHashSources(Entity):
                        """
                        PIM RPF multipath hash outcome
                        
                        .. attribute:: rpf_hash_source
                        
                        	PIM RPF hash outcome for S,G
                        	**type**\: list of  		 :py:class:`RpfHashSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources, self).__init__()

                            self.yang_name = "rpf-hash-sources"
                            self.yang_parent_name = "saf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rpf-hash-source", ("rpf_hash_source", Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource))])
                            self._leafs = OrderedDict()

                            self.rpf_hash_source = YList(self)
                            self._segment_path = lambda: "rpf-hash-sources"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/safs/saf/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources, [], name, value)


                        class RpfHashSource(Entity):
                            """
                            PIM RPF hash outcome for S,G
                            
                            .. attribute:: source_address
                            
                            	Source address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: mofrr
                            
                            	MOFRR
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: next_hop_address
                            
                            	Next hop neighbor address
                            	**type**\:  :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress>`
                            
                            .. attribute:: secondary_next_hop_address
                            
                            	Secondary Next hop neighbor address
                            	**type**\:  :py:class:`SecondaryNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress>`
                            
                            .. attribute:: next_hop_multipath_enabled
                            
                            	Next hop multipath enabled?
                            	**type**\: bool
                            
                            .. attribute:: next_hop_interface
                            
                            	Next hop neighbor interface
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: secondary_next_hop_interface
                            
                            	Secondary Next hop neighbor interface
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource, self).__init__()

                                self.yang_name = "rpf-hash-source"
                                self.yang_parent_name = "rpf-hash-sources"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("next-hop-address", ("next_hop_address", Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress)), ("secondary-next-hop-address", ("secondary_next_hop_address", Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress))])
                                self._leafs = OrderedDict([
                                    ('source_address', (YLeaf(YType.str, 'source-address'), ['str','str'])),
                                    ('mofrr', (YLeaf(YType.uint32, 'mofrr'), ['int'])),
                                    ('next_hop_multipath_enabled', (YLeaf(YType.boolean, 'next-hop-multipath-enabled'), ['bool'])),
                                    ('next_hop_interface', (YLeaf(YType.str, 'next-hop-interface'), ['str'])),
                                    ('secondary_next_hop_interface', (YLeaf(YType.str, 'secondary-next-hop-interface'), ['str'])),
                                ])
                                self.source_address = None
                                self.mofrr = None
                                self.next_hop_multipath_enabled = None
                                self.next_hop_interface = None
                                self.secondary_next_hop_interface = None

                                self.next_hop_address = Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress()
                                self.next_hop_address.parent = self
                                self._children_name_map["next_hop_address"] = "next-hop-address"

                                self.secondary_next_hop_address = Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress()
                                self.secondary_next_hop_address.parent = self
                                self._children_name_map["secondary_next_hop_address"] = "secondary-next-hop-address"
                                self._segment_path = lambda: "rpf-hash-source"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/safs/saf/rpf-hash-sources/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource, ['source_address', 'mofrr', 'next_hop_multipath_enabled', 'next_hop_interface', 'secondary_next_hop_interface'], name, value)


                            class NextHopAddress(Entity):
                                """
                                Next hop neighbor address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress, self).__init__()

                                    self.yang_name = "next-hop-address"
                                    self.yang_parent_name = "rpf-hash-source"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "next-hop-address"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/safs/saf/rpf-hash-sources/rpf-hash-source/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                            class SecondaryNextHopAddress(Entity):
                                """
                                Secondary Next hop neighbor address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress, self).__init__()

                                    self.yang_name = "secondary-next-hop-address"
                                    self.yang_parent_name = "rpf-hash-source"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "secondary-next-hop-address"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/safs/saf/rpf-hash-sources/rpf-hash-source/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class Rpfs(Entity):
                        """
                        PIM RPF information table
                        
                        .. attribute:: rpf
                        
                        	PIM RPF information
                        	**type**\: list of  		 :py:class:`Rpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Safs.Saf.Rpfs, self).__init__()

                            self.yang_name = "rpfs"
                            self.yang_parent_name = "saf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rpf", ("rpf", Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf))])
                            self._leafs = OrderedDict()

                            self.rpf = YList(self)
                            self._segment_path = lambda: "rpfs"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/safs/saf/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.Safs.Saf.Rpfs, [], name, value)


                        class Rpf(Entity):
                            """
                            PIM RPF information
                            
                            .. attribute:: registered_address  (key)
                            
                            	Address for which RPF lookup
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: registered_address_xr
                            
                            	Address registered
                            	**type**\:  :py:class:`RegisteredAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr>`
                            
                            .. attribute:: metric
                            
                            	Metric
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_preference
                            
                            	Metric preference
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_connected
                            
                            	Are we connected ?
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: is_rpf_bgp_route
                            
                            	Is RPF through BGP route
                            	**type**\: bool
                            
                            .. attribute:: rpf_path
                            
                            	RPF Paths list
                            	**type**\: list of  		 :py:class:`RpfPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf, self).__init__()

                                self.yang_name = "rpf"
                                self.yang_parent_name = "rpfs"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['registered_address']
                                self._child_classes = OrderedDict([("registered-address-xr", ("registered_address_xr", Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr)), ("rpf-path", ("rpf_path", Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath))])
                                self._leafs = OrderedDict([
                                    ('registered_address', (YLeaf(YType.str, 'registered-address'), ['str','str'])),
                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                    ('metric_preference', (YLeaf(YType.uint32, 'metric-preference'), ['int'])),
                                    ('is_connected', (YLeaf(YType.uint8, 'is-connected'), ['int'])),
                                    ('is_rpf_bgp_route', (YLeaf(YType.boolean, 'is-rpf-bgp-route'), ['bool'])),
                                ])
                                self.registered_address = None
                                self.metric = None
                                self.metric_preference = None
                                self.is_connected = None
                                self.is_rpf_bgp_route = None

                                self.registered_address_xr = Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr()
                                self.registered_address_xr.parent = self
                                self._children_name_map["registered_address_xr"] = "registered-address-xr"

                                self.rpf_path = YList(self)
                                self._segment_path = lambda: "rpf" + "[registered-address='" + str(self.registered_address) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/safs/saf/rpfs/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf, ['registered_address', 'metric', 'metric_preference', 'is_connected', 'is_rpf_bgp_route'], name, value)


                            class RegisteredAddressXr(Entity):
                                """
                                Address registered
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr, self).__init__()

                                    self.yang_name = "registered-address-xr"
                                    self.yang_parent_name = "rpf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "registered-address-xr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                            class RpfPath(Entity):
                                """
                                RPF Paths list
                                
                                .. attribute:: rpf_neighbor
                                
                                	RPF neighbor
                                	**type**\:  :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor>`
                                
                                .. attribute:: rpf_nexthop
                                
                                	RPF nexthop
                                	**type**\:  :py:class:`RpfNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop>`
                                
                                .. attribute:: rpf_interface_name
                                
                                	RPF Interface
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                .. attribute:: is_rpf_interface_disabled
                                
                                	Is the rpf interface disabled ?
                                	**type**\: bool
                                
                                .. attribute:: is_via_lsm
                                
                                	Via LSM
                                	**type**\: bool
                                
                                .. attribute:: is_via_mlsm
                                
                                	Via Mstatic LSM
                                	**type**\: bool
                                
                                .. attribute:: is_connector_attribute_present
                                
                                	Connector attribute present
                                	**type**\: bool
                                
                                .. attribute:: connector
                                
                                	Connector Attribute
                                	**type**\: str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                .. attribute:: extranet_vrf_name
                                
                                	Extranet VRF name
                                	**type**\: str
                                
                                	**length:** 0..33
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath, self).__init__()

                                    self.yang_name = "rpf-path"
                                    self.yang_parent_name = "rpf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("rpf-neighbor", ("rpf_neighbor", Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor)), ("rpf-nexthop", ("rpf_nexthop", Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop))])
                                    self._leafs = OrderedDict([
                                        ('rpf_interface_name', (YLeaf(YType.str, 'rpf-interface-name'), ['str'])),
                                        ('is_rpf_interface_disabled', (YLeaf(YType.boolean, 'is-rpf-interface-disabled'), ['bool'])),
                                        ('is_via_lsm', (YLeaf(YType.boolean, 'is-via-lsm'), ['bool'])),
                                        ('is_via_mlsm', (YLeaf(YType.boolean, 'is-via-mlsm'), ['bool'])),
                                        ('is_connector_attribute_present', (YLeaf(YType.boolean, 'is-connector-attribute-present'), ['bool'])),
                                        ('connector', (YLeaf(YType.str, 'connector'), ['str'])),
                                        ('extranet_vrf_name', (YLeaf(YType.str, 'extranet-vrf-name'), ['str'])),
                                    ])
                                    self.rpf_interface_name = None
                                    self.is_rpf_interface_disabled = None
                                    self.is_via_lsm = None
                                    self.is_via_mlsm = None
                                    self.is_connector_attribute_present = None
                                    self.connector = None
                                    self.extranet_vrf_name = None

                                    self.rpf_neighbor = Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor()
                                    self.rpf_neighbor.parent = self
                                    self._children_name_map["rpf_neighbor"] = "rpf-neighbor"

                                    self.rpf_nexthop = Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop()
                                    self.rpf_nexthop.parent = self
                                    self._children_name_map["rpf_nexthop"] = "rpf-nexthop"
                                    self._segment_path = lambda: "rpf-path"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath, ['rpf_interface_name', 'is_rpf_interface_disabled', 'is_via_lsm', 'is_via_mlsm', 'is_connector_attribute_present', 'connector', 'extranet_vrf_name'], name, value)


                                class RpfNeighbor(Entity):
                                    """
                                    RPF neighbor
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor, self).__init__()

                                        self.yang_name = "rpf-neighbor"
                                        self.yang_parent_name = "rpf-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ])
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None
                                        self._segment_path = lambda: "rpf-neighbor"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                                class RpfNexthop(Entity):
                                    """
                                    RPF nexthop
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop, self).__init__()

                                        self.yang_name = "rpf-nexthop"
                                        self.yang_parent_name = "rpf-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ])
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None
                                        self._segment_path = lambda: "rpf-nexthop"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class InterfaceStatistics(Entity):
                """
                PIM interface statistics
                
                .. attribute:: interface_statistic
                
                	PIM interface statistics
                	**type**\: list of  		 :py:class:`InterfaceStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.InterfaceStatistics.InterfaceStatistic>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.InterfaceStatistics, self).__init__()

                    self.yang_name = "interface-statistics"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("interface-statistic", ("interface_statistic", Pim.Standby.DefaultContext.InterfaceStatistics.InterfaceStatistic))])
                    self._leafs = OrderedDict()

                    self.interface_statistic = YList(self)
                    self._segment_path = lambda: "interface-statistics"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.DefaultContext.InterfaceStatistics, [], name, value)


                class InterfaceStatistic(Entity):
                    """
                    PIM interface statistics
                    
                    .. attribute:: interface_name  (key)
                    
                    	Interface name
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: input_hello
                    
                    	Hello packets in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_hello
                    
                    	Hello packets out
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_register
                    
                    	Register packets in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_register
                    
                    	Register packets out
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_register_stop
                    
                    	Register Stop packets in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_register_stop
                    
                    	Register Stop packets out
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_jp
                    
                    	Join Prune packets in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_jp
                    
                    	Join Prune packets out
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_bsr_message
                    
                    	Input BSR Messages
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_bsr_message
                    
                    	Output BSR Messages
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_assert
                    
                    	Assert packets in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_assert
                    
                    	Assert packets out
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_graft_message
                    
                    	Input Graft Messages
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_graft_message
                    
                    	Output Graft Messages
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_graft_ack_message
                    
                    	Input Graft Ack Messages
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_graft_ack_message
                    
                    	Output Graft Ack Messages
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_candidate_rp_advertisement
                    
                    	Input Candidate\-RP Advertisment
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_candidate_rp_advertisement
                    
                    	Output Candidate\-RP Advertisment
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_df_election
                    
                    	DF Election packets in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_df_election
                    
                    	DF Election packets out
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_miscellaneous
                    
                    	Miscellaneous packet in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.InterfaceStatistics.InterfaceStatistic, self).__init__()

                        self.yang_name = "interface-statistic"
                        self.yang_parent_name = "interface-statistics"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['interface_name']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                            ('input_hello', (YLeaf(YType.uint32, 'input-hello'), ['int'])),
                            ('output_hello', (YLeaf(YType.uint32, 'output-hello'), ['int'])),
                            ('input_register', (YLeaf(YType.uint32, 'input-register'), ['int'])),
                            ('output_register', (YLeaf(YType.uint32, 'output-register'), ['int'])),
                            ('input_register_stop', (YLeaf(YType.uint32, 'input-register-stop'), ['int'])),
                            ('output_register_stop', (YLeaf(YType.uint32, 'output-register-stop'), ['int'])),
                            ('input_jp', (YLeaf(YType.uint32, 'input-jp'), ['int'])),
                            ('output_jp', (YLeaf(YType.uint32, 'output-jp'), ['int'])),
                            ('input_bsr_message', (YLeaf(YType.uint32, 'input-bsr-message'), ['int'])),
                            ('output_bsr_message', (YLeaf(YType.uint32, 'output-bsr-message'), ['int'])),
                            ('input_assert', (YLeaf(YType.uint32, 'input-assert'), ['int'])),
                            ('output_assert', (YLeaf(YType.uint32, 'output-assert'), ['int'])),
                            ('input_graft_message', (YLeaf(YType.uint32, 'input-graft-message'), ['int'])),
                            ('output_graft_message', (YLeaf(YType.uint32, 'output-graft-message'), ['int'])),
                            ('input_graft_ack_message', (YLeaf(YType.uint32, 'input-graft-ack-message'), ['int'])),
                            ('output_graft_ack_message', (YLeaf(YType.uint32, 'output-graft-ack-message'), ['int'])),
                            ('input_candidate_rp_advertisement', (YLeaf(YType.uint32, 'input-candidate-rp-advertisement'), ['int'])),
                            ('output_candidate_rp_advertisement', (YLeaf(YType.uint32, 'output-candidate-rp-advertisement'), ['int'])),
                            ('input_df_election', (YLeaf(YType.uint32, 'input-df-election'), ['int'])),
                            ('output_df_election', (YLeaf(YType.uint32, 'output-df-election'), ['int'])),
                            ('input_miscellaneous', (YLeaf(YType.uint32, 'input-miscellaneous'), ['int'])),
                        ])
                        self.interface_name = None
                        self.input_hello = None
                        self.output_hello = None
                        self.input_register = None
                        self.output_register = None
                        self.input_register_stop = None
                        self.output_register_stop = None
                        self.input_jp = None
                        self.output_jp = None
                        self.input_bsr_message = None
                        self.output_bsr_message = None
                        self.input_assert = None
                        self.output_assert = None
                        self.input_graft_message = None
                        self.output_graft_message = None
                        self.input_graft_ack_message = None
                        self.output_graft_ack_message = None
                        self.input_candidate_rp_advertisement = None
                        self.output_candidate_rp_advertisement = None
                        self.input_df_election = None
                        self.output_df_election = None
                        self.input_miscellaneous = None
                        self._segment_path = lambda: "interface-statistic" + "[interface-name='" + str(self.interface_name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/interface-statistics/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.InterfaceStatistics.InterfaceStatistic, ['interface_name', 'input_hello', 'output_hello', 'input_register', 'output_register', 'input_register_stop', 'output_register_stop', 'input_jp', 'output_jp', 'input_bsr_message', 'output_bsr_message', 'input_assert', 'output_assert', 'input_graft_message', 'output_graft_message', 'input_graft_ack_message', 'output_graft_ack_message', 'input_candidate_rp_advertisement', 'output_candidate_rp_advertisement', 'input_df_election', 'output_df_election', 'input_miscellaneous'], name, value)


            class TopologyRouteCount(Entity):
                """
                Topology route count information from PIM
                topology table
                
                .. attribute:: group_ranges
                
                	No. of (\*,G/M) routes
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: active_group_ranges
                
                	No. of (\*,G/M) routes active in mrib
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: groute_count
                
                	No. of (\*,G) routes
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: sg_route_count
                
                	No. of (S,G) routes
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: sgr_route_count
                
                	No. of (S,G)RPT routes
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_node_low_memory
                
                	Is node in low memory condition
                	**type**\: bool
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.TopologyRouteCount, self).__init__()

                    self.yang_name = "topology-route-count"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('group_ranges', (YLeaf(YType.uint32, 'group-ranges'), ['int'])),
                        ('active_group_ranges', (YLeaf(YType.uint32, 'active-group-ranges'), ['int'])),
                        ('groute_count', (YLeaf(YType.uint32, 'groute-count'), ['int'])),
                        ('sg_route_count', (YLeaf(YType.uint32, 'sg-route-count'), ['int'])),
                        ('sgr_route_count', (YLeaf(YType.uint32, 'sgr-route-count'), ['int'])),
                        ('is_node_low_memory', (YLeaf(YType.boolean, 'is-node-low-memory'), ['bool'])),
                    ])
                    self.group_ranges = None
                    self.active_group_ranges = None
                    self.groute_count = None
                    self.sg_route_count = None
                    self.sgr_route_count = None
                    self.is_node_low_memory = None
                    self._segment_path = lambda: "topology-route-count"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.DefaultContext.TopologyRouteCount, ['group_ranges', 'active_group_ranges', 'groute_count', 'sg_route_count', 'sgr_route_count', 'is_node_low_memory'], name, value)


            class JpStatistics(Entity):
                """
                PIM join prune statistics table
                
                .. attribute:: jp_statistic
                
                	PIM Join Prune Statistics
                	**type**\: list of  		 :py:class:`JpStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.JpStatistics.JpStatistic>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.JpStatistics, self).__init__()

                    self.yang_name = "jp-statistics"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("jp-statistic", ("jp_statistic", Pim.Standby.DefaultContext.JpStatistics.JpStatistic))])
                    self._leafs = OrderedDict()

                    self.jp_statistic = YList(self)
                    self._segment_path = lambda: "jp-statistics"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.DefaultContext.JpStatistics, [], name, value)


                class JpStatistic(Entity):
                    """
                    PIM Join Prune Statistics
                    
                    .. attribute:: interface_name  (key)
                    
                    	Interface name
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identifier
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: mtu
                    
                    	Interface MTU
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: transmitted
                    
                    	Transmitted
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: transmitted100
                    
                    	Transmitted 100 average
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: transmitted_1k
                    
                    	Transmitted 1K average
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: transmitted_10k
                    
                    	Transmitted 10K average
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: transmitted_50k
                    
                    	Deprecated by Transmitted100
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: received
                    
                    	Received
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: received100
                    
                    	Received 100 average
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: received_1k
                    
                    	Received 1K average
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: received_10k
                    
                    	Received 10K average
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: received_50k
                    
                    	Deprecated by Received100
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.JpStatistics.JpStatistic, self).__init__()

                        self.yang_name = "jp-statistic"
                        self.yang_parent_name = "jp-statistics"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['interface_name']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                            ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                            ('mtu', (YLeaf(YType.uint32, 'mtu'), ['int'])),
                            ('transmitted', (YLeaf(YType.uint32, 'transmitted'), ['int'])),
                            ('transmitted100', (YLeaf(YType.uint16, 'transmitted100'), ['int'])),
                            ('transmitted_1k', (YLeaf(YType.uint16, 'transmitted-1k'), ['int'])),
                            ('transmitted_10k', (YLeaf(YType.uint16, 'transmitted-10k'), ['int'])),
                            ('transmitted_50k', (YLeaf(YType.uint16, 'transmitted-50k'), ['int'])),
                            ('received', (YLeaf(YType.uint32, 'received'), ['int'])),
                            ('received100', (YLeaf(YType.uint16, 'received100'), ['int'])),
                            ('received_1k', (YLeaf(YType.uint16, 'received-1k'), ['int'])),
                            ('received_10k', (YLeaf(YType.uint16, 'received-10k'), ['int'])),
                            ('received_50k', (YLeaf(YType.uint16, 'received-50k'), ['int'])),
                        ])
                        self.interface_name = None
                        self.interface_name_xr = None
                        self.mtu = None
                        self.transmitted = None
                        self.transmitted100 = None
                        self.transmitted_1k = None
                        self.transmitted_10k = None
                        self.transmitted_50k = None
                        self.received = None
                        self.received100 = None
                        self.received_1k = None
                        self.received_10k = None
                        self.received_50k = None
                        self._segment_path = lambda: "jp-statistic" + "[interface-name='" + str(self.interface_name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/jp-statistics/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.JpStatistics.JpStatistic, ['interface_name', 'interface_name_xr', 'mtu', 'transmitted', 'transmitted100', 'transmitted_1k', 'transmitted_10k', 'transmitted_50k', 'received', 'received100', 'received_1k', 'received_10k', 'received_50k'], name, value)


            class MibDatabases(Entity):
                """
                PIM group database for mroute mibs table
                
                .. attribute:: mib_database
                
                	PIM multicast static route information
                	**type**\: list of  		 :py:class:`MibDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.MibDatabases.MibDatabase>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.MibDatabases, self).__init__()

                    self.yang_name = "mib-databases"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("mib-database", ("mib_database", Pim.Standby.DefaultContext.MibDatabases.MibDatabase))])
                    self._leafs = OrderedDict()

                    self.mib_database = YList(self)
                    self._segment_path = lambda: "mib-databases"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.DefaultContext.MibDatabases, [], name, value)


                class MibDatabase(Entity):
                    """
                    PIM multicast static route information
                    
                    .. attribute:: source_address
                    
                    	Multicast static route source address
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: group_address
                    
                    	Multicast satic route group address
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: source_netmask
                    
                    	Source mask
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: source_address_xr
                    
                    	Source Address
                    	**type**\:  :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr>`
                    
                    .. attribute:: group_address_xr
                    
                    	Group Address
                    	**type**\:  :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr>`
                    
                    .. attribute:: rpf_neighbor
                    
                    	The RPF Neighbor
                    	**type**\:  :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor>`
                    
                    .. attribute:: rpf_root
                    
                    	Root of this mcast tree
                    	**type**\:  :py:class:`RpfRoot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfRoot>`
                    
                    .. attribute:: upstream_assert_timer
                    
                    	Upstream Assert Timer
                    	**type**\: int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: assert_metric
                    
                    	Assert Metric
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: assert_metric_preference
                    
                    	Assert Metric Preference
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: assert_rpt_bit
                    
                    	Assert RPT Bit
                    	**type**\: bool
                    
                    .. attribute:: spt_bit
                    
                    	Is SPT bit set ?
                    	**type**\: bool
                    
                    .. attribute:: rpf_mask
                    
                    	Mask of the multicast root
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rpf_safi
                    
                    	Unicast or mcast
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: rpf_table_name
                    
                    	RPF Table name
                    	**type**\: str
                    
                    .. attribute:: rpf_drop
                    
                    	RPF route\-policy drop
                    	**type**\: bool
                    
                    .. attribute:: rpf_extranet
                    
                    	Extranet RPF route\-policy
                    	**type**\: bool
                    
                    .. attribute:: rpf_interface_name
                    
                    	RPF interface name 
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: rpf_vrf_name
                    
                    	RPF VRF Name
                    	**type**\: str
                    
                    	**length:** 0..33
                    
                    .. attribute:: bidirectional_route
                    
                    	Is this Bidir ?
                    	**type**\: bool
                    
                    .. attribute:: uptime
                    
                    	Uptime of route
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: protocol
                    
                    	The PIM protocol
                    	**type**\:  :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.MibDatabases.MibDatabase, self).__init__()

                        self.yang_name = "mib-database"
                        self.yang_parent_name = "mib-databases"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("source-address-xr", ("source_address_xr", Pim.Standby.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr)), ("group-address-xr", ("group_address_xr", Pim.Standby.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr)), ("rpf-neighbor", ("rpf_neighbor", Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor)), ("rpf-root", ("rpf_root", Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfRoot))])
                        self._leafs = OrderedDict([
                            ('source_address', (YLeaf(YType.str, 'source-address'), ['str','str'])),
                            ('group_address', (YLeaf(YType.str, 'group-address'), ['str','str'])),
                            ('source_netmask', (YLeaf(YType.uint32, 'source-netmask'), ['int'])),
                            ('upstream_assert_timer', (YLeaf(YType.int32, 'upstream-assert-timer'), ['int'])),
                            ('assert_metric', (YLeaf(YType.uint32, 'assert-metric'), ['int'])),
                            ('assert_metric_preference', (YLeaf(YType.uint32, 'assert-metric-preference'), ['int'])),
                            ('assert_rpt_bit', (YLeaf(YType.boolean, 'assert-rpt-bit'), ['bool'])),
                            ('spt_bit', (YLeaf(YType.boolean, 'spt-bit'), ['bool'])),
                            ('rpf_mask', (YLeaf(YType.uint32, 'rpf-mask'), ['int'])),
                            ('rpf_safi', (YLeaf(YType.uint8, 'rpf-safi'), ['int'])),
                            ('rpf_table_name', (YLeaf(YType.str, 'rpf-table-name'), ['str'])),
                            ('rpf_drop', (YLeaf(YType.boolean, 'rpf-drop'), ['bool'])),
                            ('rpf_extranet', (YLeaf(YType.boolean, 'rpf-extranet'), ['bool'])),
                            ('rpf_interface_name', (YLeaf(YType.str, 'rpf-interface-name'), ['str'])),
                            ('rpf_vrf_name', (YLeaf(YType.str, 'rpf-vrf-name'), ['str'])),
                            ('bidirectional_route', (YLeaf(YType.boolean, 'bidirectional-route'), ['bool'])),
                            ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                            ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowProtocol', '')])),
                        ])
                        self.source_address = None
                        self.group_address = None
                        self.source_netmask = None
                        self.upstream_assert_timer = None
                        self.assert_metric = None
                        self.assert_metric_preference = None
                        self.assert_rpt_bit = None
                        self.spt_bit = None
                        self.rpf_mask = None
                        self.rpf_safi = None
                        self.rpf_table_name = None
                        self.rpf_drop = None
                        self.rpf_extranet = None
                        self.rpf_interface_name = None
                        self.rpf_vrf_name = None
                        self.bidirectional_route = None
                        self.uptime = None
                        self.protocol = None

                        self.source_address_xr = Pim.Standby.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr()
                        self.source_address_xr.parent = self
                        self._children_name_map["source_address_xr"] = "source-address-xr"

                        self.group_address_xr = Pim.Standby.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr()
                        self.group_address_xr.parent = self
                        self._children_name_map["group_address_xr"] = "group-address-xr"

                        self.rpf_neighbor = Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor()
                        self.rpf_neighbor.parent = self
                        self._children_name_map["rpf_neighbor"] = "rpf-neighbor"

                        self.rpf_root = Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfRoot()
                        self.rpf_root.parent = self
                        self._children_name_map["rpf_root"] = "rpf-root"
                        self._segment_path = lambda: "mib-database"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/mib-databases/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.MibDatabases.MibDatabase, ['source_address', 'group_address', 'source_netmask', 'upstream_assert_timer', 'assert_metric', 'assert_metric_preference', 'assert_rpt_bit', 'spt_bit', 'rpf_mask', 'rpf_safi', 'rpf_table_name', 'rpf_drop', 'rpf_extranet', 'rpf_interface_name', 'rpf_vrf_name', 'bidirectional_route', 'uptime', 'protocol'], name, value)


                    class SourceAddressXr(Entity):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr, self).__init__()

                            self.yang_name = "source-address-xr"
                            self.yang_parent_name = "mib-database"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "source-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/mib-databases/mib-database/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class GroupAddressXr(Entity):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr, self).__init__()

                            self.yang_name = "group-address-xr"
                            self.yang_parent_name = "mib-database"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "group-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/mib-databases/mib-database/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class RpfNeighbor(Entity):
                        """
                        The RPF Neighbor
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor, self).__init__()

                            self.yang_name = "rpf-neighbor"
                            self.yang_parent_name = "mib-database"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "rpf-neighbor"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/mib-databases/mib-database/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class RpfRoot(Entity):
                        """
                        Root of this mcast tree
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfRoot, self).__init__()

                            self.yang_name = "rpf-root"
                            self.yang_parent_name = "mib-database"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "rpf-root"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/mib-databases/mib-database/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfRoot, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class NeighborOldFormats(Entity):
                """
                PIM neighbor table old format
                
                .. attribute:: neighbor_old_format
                
                	PIM neighbor information
                	**type**\: list of  		 :py:class:`NeighborOldFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.NeighborOldFormats.NeighborOldFormat>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.NeighborOldFormats, self).__init__()

                    self.yang_name = "neighbor-old-formats"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("neighbor-old-format", ("neighbor_old_format", Pim.Standby.DefaultContext.NeighborOldFormats.NeighborOldFormat))])
                    self._leafs = OrderedDict()

                    self.neighbor_old_format = YList(self)
                    self._segment_path = lambda: "neighbor-old-formats"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.DefaultContext.NeighborOldFormats, [], name, value)


                class NeighborOldFormat(Entity):
                    """
                    PIM neighbor information
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: neighbor_address
                    
                    	Neighbor address
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identifier
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: expires
                    
                    	Neighbor expiry in seconds
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: expiry_timer
                    
                    	Expiry timer in seconds
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: is_this_neighbor_us
                    
                    	Is this neighbor us ?
                    	**type**\: bool
                    
                    .. attribute:: is_this_neighbor_dr
                    
                    	Is this neighbor the DR
                    	**type**\: bool
                    
                    .. attribute:: is_dr_priority_capable
                    
                    	Is this neighbor DR priority capable ?
                    	**type**\: bool
                    
                    .. attribute:: dr_priority
                    
                    	DR priority
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Is this neighbor bidir capable ?
                    	**type**\: bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Is this neighbor proxy capable?
                    	**type**\: bool
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Is this neighbor capable of batching asserts?
                    	**type**\: bool
                    
                    .. attribute:: is_ecmp_redirect_capable
                    
                    	Is this neighbor capable of Ecmp Redirect?
                    	**type**\: bool
                    
                    .. attribute:: is_bfd_state
                    
                    	Is the neighbor bfd session created
                    	**type**\: bool
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_address_xr
                    
                    	List of Neighbor Addresses
                    	**type**\: list of  		 :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.NeighborOldFormats.NeighborOldFormat, self).__init__()

                        self.yang_name = "neighbor-old-format"
                        self.yang_parent_name = "neighbor-old-formats"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("neighbor-address-xr", ("neighbor_address_xr", Pim.Standby.DefaultContext.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr))])
                        self._leafs = OrderedDict([
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                            ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                            ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                            ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                            ('expires', (YLeaf(YType.uint64, 'expires'), ['int'])),
                            ('expiry_timer', (YLeaf(YType.uint64, 'expiry-timer'), ['int'])),
                            ('is_this_neighbor_us', (YLeaf(YType.boolean, 'is-this-neighbor-us'), ['bool'])),
                            ('is_this_neighbor_dr', (YLeaf(YType.boolean, 'is-this-neighbor-dr'), ['bool'])),
                            ('is_dr_priority_capable', (YLeaf(YType.boolean, 'is-dr-priority-capable'), ['bool'])),
                            ('dr_priority', (YLeaf(YType.uint32, 'dr-priority'), ['int'])),
                            ('is_bidirectional_capable', (YLeaf(YType.boolean, 'is-bidirectional-capable'), ['bool'])),
                            ('is_proxy_capable', (YLeaf(YType.boolean, 'is-proxy-capable'), ['bool'])),
                            ('is_batch_asserts_capable', (YLeaf(YType.boolean, 'is-batch-asserts-capable'), ['bool'])),
                            ('is_ecmp_redirect_capable', (YLeaf(YType.boolean, 'is-ecmp-redirect-capable'), ['bool'])),
                            ('is_bfd_state', (YLeaf(YType.boolean, 'is-bfd-state'), ['bool'])),
                            ('propagation_delay', (YLeaf(YType.uint16, 'propagation-delay'), ['int'])),
                            ('override_interval', (YLeaf(YType.uint16, 'override-interval'), ['int'])),
                        ])
                        self.interface_name = None
                        self.neighbor_address = None
                        self.interface_name_xr = None
                        self.uptime = None
                        self.expires = None
                        self.expiry_timer = None
                        self.is_this_neighbor_us = None
                        self.is_this_neighbor_dr = None
                        self.is_dr_priority_capable = None
                        self.dr_priority = None
                        self.is_bidirectional_capable = None
                        self.is_proxy_capable = None
                        self.is_batch_asserts_capable = None
                        self.is_ecmp_redirect_capable = None
                        self.is_bfd_state = None
                        self.propagation_delay = None
                        self.override_interval = None

                        self.neighbor_address_xr = YList(self)
                        self._segment_path = lambda: "neighbor-old-format"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/neighbor-old-formats/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.NeighborOldFormats.NeighborOldFormat, ['interface_name', 'neighbor_address', 'interface_name_xr', 'uptime', 'expires', 'expiry_timer', 'is_this_neighbor_us', 'is_this_neighbor_dr', 'is_dr_priority_capable', 'dr_priority', 'is_bidirectional_capable', 'is_proxy_capable', 'is_batch_asserts_capable', 'is_ecmp_redirect_capable', 'is_bfd_state', 'propagation_delay', 'override_interval'], name, value)


                    class NeighborAddressXr(Entity):
                        """
                        List of Neighbor Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr, self).__init__()

                            self.yang_name = "neighbor-address-xr"
                            self.yang_parent_name = "neighbor-old-format"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "neighbor-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/neighbor-old-formats/neighbor-old-format/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class IfrsSummary(Entity):
                """
                PIM interfaces in forward reference store
                summary
                
                .. attribute:: interface_count
                
                	Number of interfaces
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: configuration_count
                
                	Configuration counts
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.IfrsSummary, self).__init__()

                    self.yang_name = "ifrs-summary"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('interface_count', (YLeaf(YType.uint32, 'interface-count'), ['int'])),
                        ('configuration_count', (YLeaf(YType.uint32, 'configuration-count'), ['int'])),
                    ])
                    self.interface_count = None
                    self.configuration_count = None
                    self._segment_path = lambda: "ifrs-summary"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.DefaultContext.IfrsSummary, ['interface_count', 'configuration_count'], name, value)


            class Ranges(Entity):
                """
                PIM range list information
                
                .. attribute:: range
                
                	PIM range list information
                	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Ranges.Range>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.Ranges, self).__init__()

                    self.yang_name = "ranges"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("range", ("range", Pim.Standby.DefaultContext.Ranges.Range))])
                    self._leafs = OrderedDict()

                    self.range = YList(self)
                    self._segment_path = lambda: "ranges"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.DefaultContext.Ranges, [], name, value)


                class Range(Entity):
                    """
                    PIM range list information
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: client
                    
                    	Client
                    	**type**\:  :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                    
                    .. attribute:: rp_address_xr
                    
                    	Rendezvous point address
                    	**type**\:  :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Ranges.Range.RpAddressXr>`
                    
                    .. attribute:: source_of_information
                    
                    	Source of information
                    	**type**\:  :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Ranges.Range.SourceOfInformation>`
                    
                    .. attribute:: protocol
                    
                    	PIM protocol
                    	**type**\:  :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                    
                    .. attribute:: client_xr
                    
                    	Client mapping learnt via
                    	**type**\:  :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                    
                    .. attribute:: expires
                    
                    	When mapping expires
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: group_range
                    
                    	List of group ranges
                    	**type**\: list of  		 :py:class:`GroupRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Ranges.Range.GroupRange>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.Ranges.Range, self).__init__()

                        self.yang_name = "range"
                        self.yang_parent_name = "ranges"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("rp-address-xr", ("rp_address_xr", Pim.Standby.DefaultContext.Ranges.Range.RpAddressXr)), ("source-of-information", ("source_of_information", Pim.Standby.DefaultContext.Ranges.Range.SourceOfInformation)), ("group-range", ("group_range", Pim.Standby.DefaultContext.Ranges.Range.GroupRange))])
                        self._leafs = OrderedDict([
                            ('rp_address', (YLeaf(YType.str, 'rp-address'), ['str','str'])),
                            ('client', (YLeaf(YType.enumeration, 'client'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimClient', '')])),
                            ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowProtocol', '')])),
                            ('client_xr', (YLeaf(YType.enumeration, 'client-xr'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowRangeClient', '')])),
                            ('expires', (YLeaf(YType.uint64, 'expires'), ['int'])),
                        ])
                        self.rp_address = None
                        self.client = None
                        self.protocol = None
                        self.client_xr = None
                        self.expires = None

                        self.rp_address_xr = Pim.Standby.DefaultContext.Ranges.Range.RpAddressXr()
                        self.rp_address_xr.parent = self
                        self._children_name_map["rp_address_xr"] = "rp-address-xr"

                        self.source_of_information = Pim.Standby.DefaultContext.Ranges.Range.SourceOfInformation()
                        self.source_of_information.parent = self
                        self._children_name_map["source_of_information"] = "source-of-information"

                        self.group_range = YList(self)
                        self._segment_path = lambda: "range"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/ranges/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.Ranges.Range, ['rp_address', 'client', 'protocol', 'client_xr', 'expires'], name, value)


                    class RpAddressXr(Entity):
                        """
                        Rendezvous point address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Ranges.Range.RpAddressXr, self).__init__()

                            self.yang_name = "rp-address-xr"
                            self.yang_parent_name = "range"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "rp-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/ranges/range/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.Ranges.Range.RpAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class SourceOfInformation(Entity):
                        """
                        Source of information
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Ranges.Range.SourceOfInformation, self).__init__()

                            self.yang_name = "source-of-information"
                            self.yang_parent_name = "range"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "source-of-information"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/ranges/range/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.Ranges.Range.SourceOfInformation, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class GroupRange(Entity):
                        """
                        List of group ranges
                        
                        .. attribute:: prefix
                        
                        	Group range prefix
                        	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Ranges.Range.GroupRange.Prefix>`
                        
                        .. attribute:: source_of_information
                        
                        	Source of information
                        	**type**\:  :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation>`
                        
                        .. attribute:: prefix_length
                        
                        	Group range prefix length
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: expires
                        
                        	When mapping expires
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Ranges.Range.GroupRange, self).__init__()

                            self.yang_name = "group-range"
                            self.yang_parent_name = "range"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("prefix", ("prefix", Pim.Standby.DefaultContext.Ranges.Range.GroupRange.Prefix)), ("source-of-information", ("source_of_information", Pim.Standby.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation))])
                            self._leafs = OrderedDict([
                                ('prefix_length', (YLeaf(YType.int32, 'prefix-length'), ['int'])),
                                ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                                ('expires', (YLeaf(YType.uint64, 'expires'), ['int'])),
                            ])
                            self.prefix_length = None
                            self.uptime = None
                            self.expires = None

                            self.prefix = Pim.Standby.DefaultContext.Ranges.Range.GroupRange.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"

                            self.source_of_information = Pim.Standby.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation()
                            self.source_of_information.parent = self
                            self._children_name_map["source_of_information"] = "source-of-information"
                            self._segment_path = lambda: "group-range"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/ranges/range/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.Ranges.Range.GroupRange, ['prefix_length', 'uptime', 'expires'], name, value)


                        class Prefix(Entity):
                            """
                            Group range prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.Ranges.Range.GroupRange.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "group-range"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "prefix"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/ranges/range/group-range/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.DefaultContext.Ranges.Range.GroupRange.Prefix, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class SourceOfInformation(Entity):
                            """
                            Source of information
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation, self).__init__()

                                self.yang_name = "source-of-information"
                                self.yang_parent_name = "group-range"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "source-of-information"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/ranges/range/group-range/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class InterfaceOldFormats(Entity):
                """
                PIM interfaces in old format
                
                .. attribute:: interface_old_format
                
                	PIM interface name
                	**type**\: list of  		 :py:class:`InterfaceOldFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.InterfaceOldFormats, self).__init__()

                    self.yang_name = "interface-old-formats"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("interface-old-format", ("interface_old_format", Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat))])
                    self._leafs = OrderedDict()

                    self.interface_old_format = YList(self)
                    self._segment_path = lambda: "interface-old-formats"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.DefaultContext.InterfaceOldFormats, [], name, value)


                class InterfaceOldFormat(Entity):
                    """
                    PIM interface name
                    
                    .. attribute:: interface_name  (key)
                    
                    	Interface name
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: dr_address
                    
                    	PIM Designated Router
                    	**type**\:  :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress>`
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identfier
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: interface_address_mask
                    
                    	Interface IP Address Mask
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: is_enabled
                    
                    	Is PIM enabled on this IF ?
                    	**type**\: bool
                    
                    .. attribute:: neighbor_count
                    
                    	No. of neighbors on this IF
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: external_neighbor_count
                    
                    	No. of external neighbors on this IF
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: hello_interval
                    
                    	Hello Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dr_priority
                    
                    	DR Priority
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_expiry
                    
                    	Hello Timer Expiry
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: are_we_dr
                    
                    	Are we the DR on this IF ?
                    	**type**\: bool
                    
                    .. attribute:: bfd_enabled
                    
                    	BFD state
                    	**type**\: bool
                    
                    .. attribute:: bfd_interval
                    
                    	BFD Interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bfd_multiplier
                    
                    	BFD Multiplier
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_interface
                    
                    	 is this a Virtual Interfaces ?
                    	**type**\: bool
                    
                    .. attribute:: passive_interface
                    
                    	Passive PIM interface
                    	**type**\: bool
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\: str
                    
                    .. attribute:: join_prune_interval
                    
                    	Join\-Prune Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: prune_delay_enabled
                    
                    	Prune Delay Enabled
                    	**type**\: bool
                    
                    .. attribute:: configured_propagation_delay
                    
                    	Configured Propagation Delay
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_override_interval
                    
                    	Configured Override Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: generation_id
                    
                    	Generation Identifier
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Bidir Capable
                    	**type**\: bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Proxy Capable
                    	**type**\: bool
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Batch Asserts Capable
                    	**type**\: bool
                    
                    .. attribute:: idb_oor_enabled
                    
                    	Interface oor enabled
                    	**type**\: bool
                    
                    .. attribute:: idb_acl_provided
                    
                    	ACL name provided
                    	**type**\: bool
                    
                    .. attribute:: idb_max_count
                    
                    	Interface ole max count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_threshold_count
                    
                    	Interface ole threshold count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_current_count
                    
                    	Interface ole current count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_acl_name
                    
                    	Interface ole ACL Name
                    	**type**\: str
                    
                    	**length:** 0..64
                    
                    .. attribute:: interface_address
                    
                    	List of Interface IP Addresses
                    	**type**\: list of  		 :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat, self).__init__()

                        self.yang_name = "interface-old-format"
                        self.yang_parent_name = "interface-old-formats"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['interface_name']
                        self._child_classes = OrderedDict([("dr-address", ("dr_address", Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress)), ("interface-address", ("interface_address", Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress))])
                        self._leafs = OrderedDict([
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                            ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                            ('interface_address_mask', (YLeaf(YType.uint8, 'interface-address-mask'), ['int'])),
                            ('is_enabled', (YLeaf(YType.boolean, 'is-enabled'), ['bool'])),
                            ('neighbor_count', (YLeaf(YType.uint16, 'neighbor-count'), ['int'])),
                            ('external_neighbor_count', (YLeaf(YType.uint16, 'external-neighbor-count'), ['int'])),
                            ('hello_interval', (YLeaf(YType.uint16, 'hello-interval'), ['int'])),
                            ('dr_priority', (YLeaf(YType.uint32, 'dr-priority'), ['int'])),
                            ('hello_expiry', (YLeaf(YType.uint64, 'hello-expiry'), ['int'])),
                            ('are_we_dr', (YLeaf(YType.boolean, 'are-we-dr'), ['bool'])),
                            ('bfd_enabled', (YLeaf(YType.boolean, 'bfd-enabled'), ['bool'])),
                            ('bfd_interval', (YLeaf(YType.uint32, 'bfd-interval'), ['int'])),
                            ('bfd_multiplier', (YLeaf(YType.uint32, 'bfd-multiplier'), ['int'])),
                            ('virtual_interface', (YLeaf(YType.boolean, 'virtual-interface'), ['bool'])),
                            ('passive_interface', (YLeaf(YType.boolean, 'passive-interface'), ['bool'])),
                            ('neighbor_filter_name', (YLeaf(YType.str, 'neighbor-filter-name'), ['str'])),
                            ('join_prune_interval', (YLeaf(YType.uint16, 'join-prune-interval'), ['int'])),
                            ('prune_delay_enabled', (YLeaf(YType.boolean, 'prune-delay-enabled'), ['bool'])),
                            ('configured_propagation_delay', (YLeaf(YType.uint16, 'configured-propagation-delay'), ['int'])),
                            ('propagation_delay', (YLeaf(YType.uint16, 'propagation-delay'), ['int'])),
                            ('configured_override_interval', (YLeaf(YType.uint16, 'configured-override-interval'), ['int'])),
                            ('override_interval', (YLeaf(YType.uint16, 'override-interval'), ['int'])),
                            ('generation_id', (YLeaf(YType.uint32, 'generation-id'), ['int'])),
                            ('is_bidirectional_capable', (YLeaf(YType.boolean, 'is-bidirectional-capable'), ['bool'])),
                            ('is_proxy_capable', (YLeaf(YType.boolean, 'is-proxy-capable'), ['bool'])),
                            ('is_batch_asserts_capable', (YLeaf(YType.boolean, 'is-batch-asserts-capable'), ['bool'])),
                            ('idb_oor_enabled', (YLeaf(YType.boolean, 'idb-oor-enabled'), ['bool'])),
                            ('idb_acl_provided', (YLeaf(YType.boolean, 'idb-acl-provided'), ['bool'])),
                            ('idb_max_count', (YLeaf(YType.uint32, 'idb-max-count'), ['int'])),
                            ('idb_threshold_count', (YLeaf(YType.uint32, 'idb-threshold-count'), ['int'])),
                            ('idb_current_count', (YLeaf(YType.uint32, 'idb-current-count'), ['int'])),
                            ('idb_acl_name', (YLeaf(YType.str, 'idb-acl-name'), ['str'])),
                        ])
                        self.interface_name = None
                        self.interface_name_xr = None
                        self.interface_address_mask = None
                        self.is_enabled = None
                        self.neighbor_count = None
                        self.external_neighbor_count = None
                        self.hello_interval = None
                        self.dr_priority = None
                        self.hello_expiry = None
                        self.are_we_dr = None
                        self.bfd_enabled = None
                        self.bfd_interval = None
                        self.bfd_multiplier = None
                        self.virtual_interface = None
                        self.passive_interface = None
                        self.neighbor_filter_name = None
                        self.join_prune_interval = None
                        self.prune_delay_enabled = None
                        self.configured_propagation_delay = None
                        self.propagation_delay = None
                        self.configured_override_interval = None
                        self.override_interval = None
                        self.generation_id = None
                        self.is_bidirectional_capable = None
                        self.is_proxy_capable = None
                        self.is_batch_asserts_capable = None
                        self.idb_oor_enabled = None
                        self.idb_acl_provided = None
                        self.idb_max_count = None
                        self.idb_threshold_count = None
                        self.idb_current_count = None
                        self.idb_acl_name = None

                        self.dr_address = Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress()
                        self.dr_address.parent = self
                        self._children_name_map["dr_address"] = "dr-address"

                        self.interface_address = YList(self)
                        self._segment_path = lambda: "interface-old-format" + "[interface-name='" + str(self.interface_name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/interface-old-formats/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat, ['interface_name', 'interface_name_xr', 'interface_address_mask', 'is_enabled', 'neighbor_count', 'external_neighbor_count', 'hello_interval', 'dr_priority', 'hello_expiry', 'are_we_dr', 'bfd_enabled', 'bfd_interval', 'bfd_multiplier', 'virtual_interface', 'passive_interface', 'neighbor_filter_name', 'join_prune_interval', 'prune_delay_enabled', 'configured_propagation_delay', 'propagation_delay', 'configured_override_interval', 'override_interval', 'generation_id', 'is_bidirectional_capable', 'is_proxy_capable', 'is_batch_asserts_capable', 'idb_oor_enabled', 'idb_acl_provided', 'idb_max_count', 'idb_threshold_count', 'idb_current_count', 'idb_acl_name'], name, value)


                    class DrAddress(Entity):
                        """
                        PIM Designated Router
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress, self).__init__()

                            self.yang_name = "dr-address"
                            self.yang_parent_name = "interface-old-format"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "dr-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class InterfaceAddress(Entity):
                        """
                        List of Interface IP Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress, self).__init__()

                            self.yang_name = "interface-address"
                            self.yang_parent_name = "interface-old-format"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "interface-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class Bsr(Entity):
                """
                PIM BSR information
                
                .. attribute:: rp_caches
                
                	PIM BSR RP cache table
                	**type**\:  :py:class:`RpCaches <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Bsr.RpCaches>`
                
                .. attribute:: candidate_rps
                
                	PIM candidate\-RP
                	**type**\:  :py:class:`CandidateRps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Bsr.CandidateRps>`
                
                .. attribute:: bsr_elections
                
                	PIM BSR election state
                	**type**\:  :py:class:`BsrElections <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Bsr.BsrElections>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.Bsr, self).__init__()

                    self.yang_name = "bsr"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("rp-caches", ("rp_caches", Pim.Standby.DefaultContext.Bsr.RpCaches)), ("candidate-rps", ("candidate_rps", Pim.Standby.DefaultContext.Bsr.CandidateRps)), ("bsr-elections", ("bsr_elections", Pim.Standby.DefaultContext.Bsr.BsrElections))])
                    self._leafs = OrderedDict()

                    self.rp_caches = Pim.Standby.DefaultContext.Bsr.RpCaches()
                    self.rp_caches.parent = self
                    self._children_name_map["rp_caches"] = "rp-caches"

                    self.candidate_rps = Pim.Standby.DefaultContext.Bsr.CandidateRps()
                    self.candidate_rps.parent = self
                    self._children_name_map["candidate_rps"] = "candidate-rps"

                    self.bsr_elections = Pim.Standby.DefaultContext.Bsr.BsrElections()
                    self.bsr_elections.parent = self
                    self._children_name_map["bsr_elections"] = "bsr-elections"
                    self._segment_path = lambda: "bsr"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.DefaultContext.Bsr, [], name, value)


                class RpCaches(Entity):
                    """
                    PIM BSR RP cache table
                    
                    .. attribute:: rp_cache
                    
                    	PIM BSR RP cache
                    	**type**\: list of  		 :py:class:`RpCache <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.Bsr.RpCaches, self).__init__()

                        self.yang_name = "rp-caches"
                        self.yang_parent_name = "bsr"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("rp-cache", ("rp_cache", Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache))])
                        self._leafs = OrderedDict()

                        self.rp_cache = YList(self)
                        self._segment_path = lambda: "rp-caches"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/bsr/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.Bsr.RpCaches, [], name, value)


                    class RpCache(Entity):
                        """
                        PIM BSR RP cache
                        
                        .. attribute:: group_prefix  (key)
                        
                        	Group prefix
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: group_prefix_xr
                        
                        	Group Prefix
                        	**type**\:  :py:class:`GroupPrefixXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr>`
                        
                        .. attribute:: candidate_rp_list
                        
                        	C\-RP list for this prefix
                        	**type**\:  :py:class:`CandidateRpList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList>`
                        
                        .. attribute:: group_prefix_length
                        
                        	Group Prefix Length
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: candidate_rp_group_count
                        
                        	C\-RP count for this Prefix
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache, self).__init__()

                            self.yang_name = "rp-cache"
                            self.yang_parent_name = "rp-caches"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['group_prefix']
                            self._child_classes = OrderedDict([("group-prefix-xr", ("group_prefix_xr", Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr)), ("candidate-rp-list", ("candidate_rp_list", Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList))])
                            self._leafs = OrderedDict([
                                ('group_prefix', (YLeaf(YType.str, 'group-prefix'), ['str','str'])),
                                ('group_prefix_length', (YLeaf(YType.uint32, 'group-prefix-length'), ['int'])),
                                ('candidate_rp_group_count', (YLeaf(YType.uint32, 'candidate-rp-group-count'), ['int'])),
                            ])
                            self.group_prefix = None
                            self.group_prefix_length = None
                            self.candidate_rp_group_count = None

                            self.group_prefix_xr = Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr()
                            self.group_prefix_xr.parent = self
                            self._children_name_map["group_prefix_xr"] = "group-prefix-xr"

                            self.candidate_rp_list = Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList()
                            self.candidate_rp_list.parent = self
                            self._children_name_map["candidate_rp_list"] = "candidate-rp-list"
                            self._segment_path = lambda: "rp-cache" + "[group-prefix='" + str(self.group_prefix) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/bsr/rp-caches/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache, ['group_prefix', 'group_prefix_length', 'candidate_rp_group_count'], name, value)


                        class GroupPrefixXr(Entity):
                            """
                            Group Prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr, self).__init__()

                                self.yang_name = "group-prefix-xr"
                                self.yang_parent_name = "rp-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "group-prefix-xr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class CandidateRpList(Entity):
                            """
                            C\-RP list for this prefix
                            
                            .. attribute:: pim_bsr_crp_bag
                            
                            	pim bsr crp bag
                            	**type**\: list of  		 :py:class:`PimBsrCrpBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList, self).__init__()

                                self.yang_name = "candidate-rp-list"
                                self.yang_parent_name = "rp-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("pim-bsr-crp-bag", ("pim_bsr_crp_bag", Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag))])
                                self._leafs = OrderedDict()

                                self.pim_bsr_crp_bag = YList(self)
                                self._segment_path = lambda: "candidate-rp-list"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList, [], name, value)


                            class PimBsrCrpBag(Entity):
                                """
                                pim bsr crp bag
                                
                                .. attribute:: candidate_rp_address
                                
                                	C\-RP address
                                	**type**\:  :py:class:`CandidateRpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress>`
                                
                                .. attribute:: candidate_rp_holdtime
                                
                                	C\-RP Holdtime
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: candidate_rp_priority
                                
                                	C\-RP Priority
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: candidate_rp_up_time
                                
                                	C\-RP Uptime
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: candidate_rp_expires
                                
                                	C\-RP Expires
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: protocol
                                
                                	PIM Protocol
                                	**type**\:  :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag, self).__init__()

                                    self.yang_name = "pim-bsr-crp-bag"
                                    self.yang_parent_name = "candidate-rp-list"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("candidate-rp-address", ("candidate_rp_address", Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress))])
                                    self._leafs = OrderedDict([
                                        ('candidate_rp_holdtime', (YLeaf(YType.uint16, 'candidate-rp-holdtime'), ['int'])),
                                        ('candidate_rp_priority', (YLeaf(YType.uint8, 'candidate-rp-priority'), ['int'])),
                                        ('candidate_rp_up_time', (YLeaf(YType.uint16, 'candidate-rp-up-time'), ['int'])),
                                        ('candidate_rp_expires', (YLeaf(YType.uint16, 'candidate-rp-expires'), ['int'])),
                                        ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowProtocol', '')])),
                                    ])
                                    self.candidate_rp_holdtime = None
                                    self.candidate_rp_priority = None
                                    self.candidate_rp_up_time = None
                                    self.candidate_rp_expires = None
                                    self.protocol = None

                                    self.candidate_rp_address = Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress()
                                    self.candidate_rp_address.parent = self
                                    self._children_name_map["candidate_rp_address"] = "candidate-rp-address"
                                    self._segment_path = lambda: "pim-bsr-crp-bag"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag, ['candidate_rp_holdtime', 'candidate_rp_priority', 'candidate_rp_up_time', 'candidate_rp_expires', 'protocol'], name, value)


                                class CandidateRpAddress(Entity):
                                    """
                                    C\-RP address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress, self).__init__()

                                        self.yang_name = "candidate-rp-address"
                                        self.yang_parent_name = "pim-bsr-crp-bag"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ])
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None
                                        self._segment_path = lambda: "candidate-rp-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class CandidateRps(Entity):
                    """
                    PIM candidate\-RP
                    
                    .. attribute:: candidate_rp
                    
                    	PIM BSR candidate RP information
                    	**type**\: list of  		 :py:class:`CandidateRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.Bsr.CandidateRps, self).__init__()

                        self.yang_name = "candidate-rps"
                        self.yang_parent_name = "bsr"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("candidate-rp", ("candidate_rp", Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp))])
                        self._leafs = OrderedDict()

                        self.candidate_rp = YList(self)
                        self._segment_path = lambda: "candidate-rps"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/bsr/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.Bsr.CandidateRps, [], name, value)


                    class CandidateRp(Entity):
                        """
                        PIM BSR candidate RP information
                        
                        .. attribute:: rp_address  (key)
                        
                        	Candidate\-RP address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: candidate_rp
                        
                        	Cand\-RP Address
                        	**type**\:  :py:class:`CandidateRp_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp_>`
                        
                        .. attribute:: candidate_rp_mode
                        
                        	Cand\-RP Mode
                        	**type**\:  :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: candidate_rp_scope
                        
                        	Cand\-RP Scope
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: crp_priority
                        
                        	Cand\-RP Priority
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: crp_holdtime
                        
                        	Cand\-RP Holdtime
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: candidate_rp_advance_interval
                        
                        	Cand\-RP Adv Interval in seconds
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        	**units**\: second
                        
                        .. attribute:: candidate_rp_uptime
                        
                        	Cand\-RP uptime
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: acl_name
                        
                        	Group Access\-List Name
                        	**type**\: str
                        
                        	**length:** 0..33
                        
                        .. attribute:: crp_access
                        
                        	Group Ranges Using this Cand\-RP
                        	**type**\: list of  		 :py:class:`CrpAccess <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CrpAccess>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp, self).__init__()

                            self.yang_name = "candidate-rp"
                            self.yang_parent_name = "candidate-rps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['rp_address']
                            self._child_classes = OrderedDict([("candidate-rp", ("candidate_rp", Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp_)), ("crp-access", ("crp_access", Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CrpAccess))])
                            self._leafs = OrderedDict([
                                ('rp_address', (YLeaf(YType.str, 'rp-address'), ['str','str'])),
                                ('candidate_rp_mode', (YLeaf(YType.enumeration, 'candidate-rp-mode'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowProtocol', '')])),
                                ('candidate_rp_scope', (YLeaf(YType.int32, 'candidate-rp-scope'), ['int'])),
                                ('crp_priority', (YLeaf(YType.uint8, 'crp-priority'), ['int'])),
                                ('crp_holdtime', (YLeaf(YType.uint16, 'crp-holdtime'), ['int'])),
                                ('candidate_rp_advance_interval', (YLeaf(YType.uint16, 'candidate-rp-advance-interval'), ['int'])),
                                ('candidate_rp_uptime', (YLeaf(YType.uint16, 'candidate-rp-uptime'), ['int'])),
                                ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                            ])
                            self.rp_address = None
                            self.candidate_rp_mode = None
                            self.candidate_rp_scope = None
                            self.crp_priority = None
                            self.crp_holdtime = None
                            self.candidate_rp_advance_interval = None
                            self.candidate_rp_uptime = None
                            self.acl_name = None

                            self.candidate_rp = Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp_()
                            self.candidate_rp.parent = self
                            self._children_name_map["candidate_rp"] = "candidate-rp"

                            self.crp_access = YList(self)
                            self._segment_path = lambda: "candidate-rp" + "[rp-address='" + str(self.rp_address) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/bsr/candidate-rps/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp, ['rp_address', 'candidate_rp_mode', 'candidate_rp_scope', 'crp_priority', 'crp_holdtime', 'candidate_rp_advance_interval', 'candidate_rp_uptime', 'acl_name'], name, value)


                        class CandidateRp_(Entity):
                            """
                            Cand\-RP Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp_, self).__init__()

                                self.yang_name = "candidate-rp"
                                self.yang_parent_name = "candidate-rp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "candidate-rp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp_, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class CrpAccess(Entity):
                            """
                            Group Ranges Using this Cand\-RP
                            
                            .. attribute:: candidate_rp_mode
                            
                            	Cand\-RP Mode
                            	**type**\:  :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                            
                            .. attribute:: acl_name
                            
                            	Group Access\-List Name
                            	**type**\: str
                            
                            	**length:** 0..33
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CrpAccess, self).__init__()

                                self.yang_name = "crp-access"
                                self.yang_parent_name = "candidate-rp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('candidate_rp_mode', (YLeaf(YType.enumeration, 'candidate-rp-mode'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowProtocol', '')])),
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                                ])
                                self.candidate_rp_mode = None
                                self.acl_name = None
                                self._segment_path = lambda: "crp-access"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CrpAccess, ['candidate_rp_mode', 'acl_name'], name, value)


                class BsrElections(Entity):
                    """
                    PIM BSR election state
                    
                    .. attribute:: bsr_election
                    
                    	PIM BSR information
                    	**type**\: list of  		 :py:class:`BsrElection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.Bsr.BsrElections, self).__init__()

                        self.yang_name = "bsr-elections"
                        self.yang_parent_name = "bsr"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("bsr-election", ("bsr_election", Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection))])
                        self._leafs = OrderedDict()

                        self.bsr_election = YList(self)
                        self._segment_path = lambda: "bsr-elections"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/bsr/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.Bsr.BsrElections, [], name, value)


                    class BsrElection(Entity):
                        """
                        PIM BSR information
                        
                        .. attribute:: pim_scope  (key)
                        
                        	BSR information
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bsr_address
                        
                        	BSR address
                        	**type**\:  :py:class:`BsrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress>`
                        
                        .. attribute:: candidate_bsr_address
                        
                        	C\-BSR address
                        	**type**\:  :py:class:`CandidateBsrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress>`
                        
                        .. attribute:: bsr_priority
                        
                        	BSR Priority
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: bsr_mask_length
                        
                        	Hash Function Mask Length
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: bsr_up_time
                        
                        	BSR Uptime
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: bootstrap_timeout
                        
                        	Bootstrap Timeout
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: candidate_bsr_state
                        
                        	BSR Candidate State
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bsr_election_state
                        
                        	BSR Election State
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bsr_scope
                        
                        	BSR Scope
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: candidate_bsr_flag
                        
                        	BSR Candidate Config Flag
                        	**type**\: bool
                        
                        .. attribute:: candidate_bsr_priority
                        
                        	C\-BSR Priority
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: candidate_bsr_mask_length
                        
                        	C\-BSR Hash Func. Mask Len
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection, self).__init__()

                            self.yang_name = "bsr-election"
                            self.yang_parent_name = "bsr-elections"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['pim_scope']
                            self._child_classes = OrderedDict([("bsr-address", ("bsr_address", Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress)), ("candidate-bsr-address", ("candidate_bsr_address", Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress))])
                            self._leafs = OrderedDict([
                                ('pim_scope', (YLeaf(YType.uint32, 'pim-scope'), ['int'])),
                                ('bsr_priority', (YLeaf(YType.uint8, 'bsr-priority'), ['int'])),
                                ('bsr_mask_length', (YLeaf(YType.uint8, 'bsr-mask-length'), ['int'])),
                                ('bsr_up_time', (YLeaf(YType.uint16, 'bsr-up-time'), ['int'])),
                                ('bootstrap_timeout', (YLeaf(YType.uint16, 'bootstrap-timeout'), ['int'])),
                                ('candidate_bsr_state', (YLeaf(YType.uint32, 'candidate-bsr-state'), ['int'])),
                                ('bsr_election_state', (YLeaf(YType.uint32, 'bsr-election-state'), ['int'])),
                                ('bsr_scope', (YLeaf(YType.uint16, 'bsr-scope'), ['int'])),
                                ('candidate_bsr_flag', (YLeaf(YType.boolean, 'candidate-bsr-flag'), ['bool'])),
                                ('candidate_bsr_priority', (YLeaf(YType.uint8, 'candidate-bsr-priority'), ['int'])),
                                ('candidate_bsr_mask_length', (YLeaf(YType.uint8, 'candidate-bsr-mask-length'), ['int'])),
                            ])
                            self.pim_scope = None
                            self.bsr_priority = None
                            self.bsr_mask_length = None
                            self.bsr_up_time = None
                            self.bootstrap_timeout = None
                            self.candidate_bsr_state = None
                            self.bsr_election_state = None
                            self.bsr_scope = None
                            self.candidate_bsr_flag = None
                            self.candidate_bsr_priority = None
                            self.candidate_bsr_mask_length = None

                            self.bsr_address = Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress()
                            self.bsr_address.parent = self
                            self._children_name_map["bsr_address"] = "bsr-address"

                            self.candidate_bsr_address = Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress()
                            self.candidate_bsr_address.parent = self
                            self._children_name_map["candidate_bsr_address"] = "candidate-bsr-address"
                            self._segment_path = lambda: "bsr-election" + "[pim-scope='" + str(self.pim_scope) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/bsr/bsr-elections/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection, ['pim_scope', 'bsr_priority', 'bsr_mask_length', 'bsr_up_time', 'bootstrap_timeout', 'candidate_bsr_state', 'bsr_election_state', 'bsr_scope', 'candidate_bsr_flag', 'candidate_bsr_priority', 'candidate_bsr_mask_length'], name, value)


                        class BsrAddress(Entity):
                            """
                            BSR address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress, self).__init__()

                                self.yang_name = "bsr-address"
                                self.yang_parent_name = "bsr-election"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "bsr-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class CandidateBsrAddress(Entity):
                            """
                            C\-BSR address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress, self).__init__()

                                self.yang_name = "candidate-bsr-address"
                                self.yang_parent_name = "bsr-election"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "candidate-bsr-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class RoutePolicy(Entity):
                """
                PIM route policy
                
                .. attribute:: route_policy_statistics
                
                	PIM route policy statistics
                	**type**\:  :py:class:`RoutePolicyStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyStatistics>`
                
                .. attribute:: route_policy_tests
                
                	PIM route policy test run table
                	**type**\:  :py:class:`RoutePolicyTests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.RoutePolicy, self).__init__()

                    self.yang_name = "route-policy"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("route-policy-statistics", ("route_policy_statistics", Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyStatistics)), ("route-policy-tests", ("route_policy_tests", Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests))])
                    self._leafs = OrderedDict()

                    self.route_policy_statistics = Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyStatistics()
                    self.route_policy_statistics.parent = self
                    self._children_name_map["route_policy_statistics"] = "route-policy-statistics"

                    self.route_policy_tests = Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests()
                    self.route_policy_tests.parent = self
                    self._children_name_map["route_policy_tests"] = "route-policy-tests"
                    self._segment_path = lambda: "route-policy"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.DefaultContext.RoutePolicy, [], name, value)


                class RoutePolicyStatistics(Entity):
                    """
                    PIM route policy statistics
                    
                    .. attribute:: policy_name
                    
                    	RPF policy name
                    	**type**\: str
                    
                    .. attribute:: requests
                    
                    	Number of RPF lookup requests
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pass_
                    
                    	Number of RPF pass
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: drop
                    
                    	Number of RPF drops
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: default_table
                    
                    	Number of RPF lookup in default\-only Table
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: any_table
                    
                    	Number of RPF lookup in any Table
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyStatistics, self).__init__()

                        self.yang_name = "route-policy-statistics"
                        self.yang_parent_name = "route-policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('policy_name', (YLeaf(YType.str, 'policy-name'), ['str'])),
                            ('requests', (YLeaf(YType.uint32, 'requests'), ['int'])),
                            ('pass_', (YLeaf(YType.uint32, 'pass'), ['int'])),
                            ('drop', (YLeaf(YType.uint32, 'drop'), ['int'])),
                            ('default_table', (YLeaf(YType.uint32, 'default-table'), ['int'])),
                            ('any_table', (YLeaf(YType.uint32, 'any-table'), ['int'])),
                        ])
                        self.policy_name = None
                        self.requests = None
                        self.pass_ = None
                        self.drop = None
                        self.default_table = None
                        self.any_table = None
                        self._segment_path = lambda: "route-policy-statistics"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/route-policy/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyStatistics, ['policy_name', 'requests', 'pass_', 'drop', 'default_table', 'any_table'], name, value)


                class RoutePolicyTests(Entity):
                    """
                    PIM route policy test run table
                    
                    .. attribute:: route_policy_test
                    
                    	PIM route policy test run
                    	**type**\: list of  		 :py:class:`RoutePolicyTest <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests, self).__init__()

                        self.yang_name = "route-policy-tests"
                        self.yang_parent_name = "route-policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("route-policy-test", ("route_policy_test", Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest))])
                        self._leafs = OrderedDict()

                        self.route_policy_test = YList(self)
                        self._segment_path = lambda: "route-policy-tests"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/route-policy/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests, [], name, value)


                    class RoutePolicyTest(Entity):
                        """
                        PIM route policy test run
                        
                        .. attribute:: source_address
                        
                        	Source IP address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: group_address
                        
                        	Group IP address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ext_comm
                        
                        	Extended Community
                        	**type**\: str
                        
                        	**length:** 1..8
                        
                        .. attribute:: source_address_xr
                        
                        	Source address
                        	**type**\:  :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr>`
                        
                        .. attribute:: group_address_xr
                        
                        	Source address
                        	**type**\:  :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr>`
                        
                        .. attribute:: policy_name
                        
                        	RPF policy name
                        	**type**\: str
                        
                        .. attribute:: extended_community_rt
                        
                        	Route Target
                        	**type**\: str
                        
                        	**length:** 0..33
                        
                        .. attribute:: pass_
                        
                        	Pass
                        	**type**\: bool
                        
                        .. attribute:: default_table
                        
                        	Default table selected
                        	**type**\: bool
                        
                        .. attribute:: vrf_name
                        
                        	VRF name
                        	**type**\: str
                        
                        	**length:** 0..33
                        
                        .. attribute:: afi
                        
                        	AFI
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: safi
                        
                        	SAFI
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_name
                        
                        	Table name
                        	**type**\: str
                        
                        .. attribute:: table_exists
                        
                        	Table exists
                        	**type**\: bool
                        
                        .. attribute:: table_active
                        
                        	Table active
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest, self).__init__()

                            self.yang_name = "route-policy-test"
                            self.yang_parent_name = "route-policy-tests"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("source-address-xr", ("source_address_xr", Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr)), ("group-address-xr", ("group_address_xr", Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr))])
                            self._leafs = OrderedDict([
                                ('source_address', (YLeaf(YType.str, 'source-address'), ['str','str'])),
                                ('group_address', (YLeaf(YType.str, 'group-address'), ['str','str'])),
                                ('ext_comm', (YLeaf(YType.str, 'ext-comm'), ['str'])),
                                ('policy_name', (YLeaf(YType.str, 'policy-name'), ['str'])),
                                ('extended_community_rt', (YLeaf(YType.str, 'extended-community-rt'), ['str'])),
                                ('pass_', (YLeaf(YType.boolean, 'pass'), ['bool'])),
                                ('default_table', (YLeaf(YType.boolean, 'default-table'), ['bool'])),
                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                ('afi', (YLeaf(YType.uint32, 'afi'), ['int'])),
                                ('safi', (YLeaf(YType.uint32, 'safi'), ['int'])),
                                ('table_name', (YLeaf(YType.str, 'table-name'), ['str'])),
                                ('table_exists', (YLeaf(YType.boolean, 'table-exists'), ['bool'])),
                                ('table_active', (YLeaf(YType.boolean, 'table-active'), ['bool'])),
                            ])
                            self.source_address = None
                            self.group_address = None
                            self.ext_comm = None
                            self.policy_name = None
                            self.extended_community_rt = None
                            self.pass_ = None
                            self.default_table = None
                            self.vrf_name = None
                            self.afi = None
                            self.safi = None
                            self.table_name = None
                            self.table_exists = None
                            self.table_active = None

                            self.source_address_xr = Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr()
                            self.source_address_xr.parent = self
                            self._children_name_map["source_address_xr"] = "source-address-xr"

                            self.group_address_xr = Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._segment_path = lambda: "route-policy-test"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/route-policy/route-policy-tests/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest, ['source_address', 'group_address', 'ext_comm', 'policy_name', 'extended_community_rt', 'pass_', 'default_table', 'vrf_name', 'afi', 'safi', 'table_name', 'table_exists', 'table_active'], name, value)


                        class SourceAddressXr(Entity):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr, self).__init__()

                                self.yang_name = "source-address-xr"
                                self.yang_parent_name = "route-policy-test"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "source-address-xr"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/route-policy/route-policy-tests/route-policy-test/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class GroupAddressXr(Entity):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "route-policy-test"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "group-address-xr"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/route-policy/route-policy-tests/route-policy-test/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class RpfSummary(Entity):
                """
                PIM RPF registration summary
                
                .. attribute:: default_safi
                
                	Default RPF Table SAFI
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: default_table_name
                
                	Default RPF Table Name
                	**type**\: str
                
                .. attribute:: is_mbgp_configured
                
                	Is MBGP configured?
                	**type**\: bool
                
                .. attribute:: is_ospf_te_configured
                
                	Is OSPF TE configured?
                	**type**\: bool
                
                .. attribute:: is_isis_te_configured
                
                	Is ISIS TE configured?
                	**type**\: bool
                
                .. attribute:: is_isis_mtr_configured
                
                	Is ISIS MTR configured?
                	**type**\: bool
                
                .. attribute:: mo_frr_configured
                
                	Is MoFRR configured?
                	**type**\: bool
                
                .. attribute:: rib_mo_frr_configured
                
                	Is MoFRR RIB configured?
                	**type**\: bool
                
                .. attribute:: rump_enabled
                
                	Is RUMP MuRIB enabled?
                	**type**\: bool
                
                .. attribute:: rib_convergence_timeout
                
                	RIB convergence timeout in seconds
                	**type**\: int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: rib_convergence_time_left
                
                	RIB convergence time left in seconds
                	**type**\: int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: is_multipath_enabled
                
                	Is Multipath Enabled ?
                	**type**\: bool
                
                .. attribute:: is_multipath_interface_hash_enabled
                
                	Is Multipath Interface Hash Extension Enabled ?
                	**type**\: bool
                
                .. attribute:: is_multipath_source_hash_enabled
                
                	Is Multipath Source based Hash Enabled ?
                	**type**\: bool
                
                .. attribute:: is_multipath_source_next_hop_hash_enabled
                
                	Is Multipath Source\-Nexthop Hash Enabled ?
                	**type**\: bool
                
                .. attribute:: rpf_registrations
                
                	RPF Registration count
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_rib_convergence
                
                	RIB Convergence status
                	**type**\: bool
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.RpfSummary, self).__init__()

                    self.yang_name = "rpf-summary"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('default_safi', (YLeaf(YType.uint32, 'default-safi'), ['int'])),
                        ('default_table_name', (YLeaf(YType.str, 'default-table-name'), ['str'])),
                        ('is_mbgp_configured', (YLeaf(YType.boolean, 'is-mbgp-configured'), ['bool'])),
                        ('is_ospf_te_configured', (YLeaf(YType.boolean, 'is-ospf-te-configured'), ['bool'])),
                        ('is_isis_te_configured', (YLeaf(YType.boolean, 'is-isis-te-configured'), ['bool'])),
                        ('is_isis_mtr_configured', (YLeaf(YType.boolean, 'is-isis-mtr-configured'), ['bool'])),
                        ('mo_frr_configured', (YLeaf(YType.boolean, 'mo-frr-configured'), ['bool'])),
                        ('rib_mo_frr_configured', (YLeaf(YType.boolean, 'rib-mo-frr-configured'), ['bool'])),
                        ('rump_enabled', (YLeaf(YType.boolean, 'rump-enabled'), ['bool'])),
                        ('rib_convergence_timeout', (YLeaf(YType.uint32, 'rib-convergence-timeout'), ['int'])),
                        ('rib_convergence_time_left', (YLeaf(YType.uint32, 'rib-convergence-time-left'), ['int'])),
                        ('is_multipath_enabled', (YLeaf(YType.boolean, 'is-multipath-enabled'), ['bool'])),
                        ('is_multipath_interface_hash_enabled', (YLeaf(YType.boolean, 'is-multipath-interface-hash-enabled'), ['bool'])),
                        ('is_multipath_source_hash_enabled', (YLeaf(YType.boolean, 'is-multipath-source-hash-enabled'), ['bool'])),
                        ('is_multipath_source_next_hop_hash_enabled', (YLeaf(YType.boolean, 'is-multipath-source-next-hop-hash-enabled'), ['bool'])),
                        ('rpf_registrations', (YLeaf(YType.uint32, 'rpf-registrations'), ['int'])),
                        ('is_rib_convergence', (YLeaf(YType.boolean, 'is-rib-convergence'), ['bool'])),
                    ])
                    self.default_safi = None
                    self.default_table_name = None
                    self.is_mbgp_configured = None
                    self.is_ospf_te_configured = None
                    self.is_isis_te_configured = None
                    self.is_isis_mtr_configured = None
                    self.mo_frr_configured = None
                    self.rib_mo_frr_configured = None
                    self.rump_enabled = None
                    self.rib_convergence_timeout = None
                    self.rib_convergence_time_left = None
                    self.is_multipath_enabled = None
                    self.is_multipath_interface_hash_enabled = None
                    self.is_multipath_source_hash_enabled = None
                    self.is_multipath_source_next_hop_hash_enabled = None
                    self.rpf_registrations = None
                    self.is_rib_convergence = None
                    self._segment_path = lambda: "rpf-summary"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.DefaultContext.RpfSummary, ['default_safi', 'default_table_name', 'is_mbgp_configured', 'is_ospf_te_configured', 'is_isis_te_configured', 'is_isis_mtr_configured', 'mo_frr_configured', 'rib_mo_frr_configured', 'rump_enabled', 'rib_convergence_timeout', 'rib_convergence_time_left', 'is_multipath_enabled', 'is_multipath_interface_hash_enabled', 'is_multipath_source_hash_enabled', 'is_multipath_source_next_hop_hash_enabled', 'rpf_registrations', 'is_rib_convergence'], name, value)


            class Interfaces(Entity):
                """
                PIM interfaces
                
                .. attribute:: interface
                
                	PIM interface name
                	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Interfaces.Interface>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.Interfaces, self).__init__()

                    self.yang_name = "interfaces"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("interface", ("interface", Pim.Standby.DefaultContext.Interfaces.Interface))])
                    self._leafs = OrderedDict()

                    self.interface = YList(self)
                    self._segment_path = lambda: "interfaces"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.DefaultContext.Interfaces, [], name, value)


                class Interface(Entity):
                    """
                    PIM interface name
                    
                    .. attribute:: interface_name  (key)
                    
                    	Interface name
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: dr_address
                    
                    	PIM Designated Router
                    	**type**\:  :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Interfaces.Interface.DrAddress>`
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identfier
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: interface_address_mask
                    
                    	Interface IP Address Mask
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: is_enabled
                    
                    	Is PIM enabled on this IF ?
                    	**type**\: bool
                    
                    .. attribute:: neighbor_count
                    
                    	No. of neighbors on this IF
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: external_neighbor_count
                    
                    	No. of external neighbors on this IF
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: hello_interval
                    
                    	Hello Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dr_priority
                    
                    	DR Priority
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_expiry
                    
                    	Hello Timer Expiry
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: are_we_dr
                    
                    	Are we the DR on this IF ?
                    	**type**\: bool
                    
                    .. attribute:: bfd_enabled
                    
                    	BFD state
                    	**type**\: bool
                    
                    .. attribute:: bfd_interval
                    
                    	BFD Interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bfd_multiplier
                    
                    	BFD Multiplier
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_interface
                    
                    	 is this a Virtual Interfaces ?
                    	**type**\: bool
                    
                    .. attribute:: passive_interface
                    
                    	Passive PIM interface
                    	**type**\: bool
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\: str
                    
                    .. attribute:: join_prune_interval
                    
                    	Join\-Prune Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: prune_delay_enabled
                    
                    	Prune Delay Enabled
                    	**type**\: bool
                    
                    .. attribute:: configured_propagation_delay
                    
                    	Configured Propagation Delay
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_override_interval
                    
                    	Configured Override Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: generation_id
                    
                    	Generation Identifier
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Bidir Capable
                    	**type**\: bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Proxy Capable
                    	**type**\: bool
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Batch Asserts Capable
                    	**type**\: bool
                    
                    .. attribute:: idb_oor_enabled
                    
                    	Interface oor enabled
                    	**type**\: bool
                    
                    .. attribute:: idb_acl_provided
                    
                    	ACL name provided
                    	**type**\: bool
                    
                    .. attribute:: idb_max_count
                    
                    	Interface ole max count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_threshold_count
                    
                    	Interface ole threshold count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_current_count
                    
                    	Interface ole current count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_acl_name
                    
                    	Interface ole ACL Name
                    	**type**\: str
                    
                    	**length:** 0..64
                    
                    .. attribute:: interface_address
                    
                    	List of Interface IP Addresses
                    	**type**\: list of  		 :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Interfaces.Interface.InterfaceAddress>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.Interfaces.Interface, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "interfaces"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['interface_name']
                        self._child_classes = OrderedDict([("dr-address", ("dr_address", Pim.Standby.DefaultContext.Interfaces.Interface.DrAddress)), ("interface-address", ("interface_address", Pim.Standby.DefaultContext.Interfaces.Interface.InterfaceAddress))])
                        self._leafs = OrderedDict([
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                            ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                            ('interface_address_mask', (YLeaf(YType.uint8, 'interface-address-mask'), ['int'])),
                            ('is_enabled', (YLeaf(YType.boolean, 'is-enabled'), ['bool'])),
                            ('neighbor_count', (YLeaf(YType.uint16, 'neighbor-count'), ['int'])),
                            ('external_neighbor_count', (YLeaf(YType.uint16, 'external-neighbor-count'), ['int'])),
                            ('hello_interval', (YLeaf(YType.uint16, 'hello-interval'), ['int'])),
                            ('dr_priority', (YLeaf(YType.uint32, 'dr-priority'), ['int'])),
                            ('hello_expiry', (YLeaf(YType.uint64, 'hello-expiry'), ['int'])),
                            ('are_we_dr', (YLeaf(YType.boolean, 'are-we-dr'), ['bool'])),
                            ('bfd_enabled', (YLeaf(YType.boolean, 'bfd-enabled'), ['bool'])),
                            ('bfd_interval', (YLeaf(YType.uint32, 'bfd-interval'), ['int'])),
                            ('bfd_multiplier', (YLeaf(YType.uint32, 'bfd-multiplier'), ['int'])),
                            ('virtual_interface', (YLeaf(YType.boolean, 'virtual-interface'), ['bool'])),
                            ('passive_interface', (YLeaf(YType.boolean, 'passive-interface'), ['bool'])),
                            ('neighbor_filter_name', (YLeaf(YType.str, 'neighbor-filter-name'), ['str'])),
                            ('join_prune_interval', (YLeaf(YType.uint16, 'join-prune-interval'), ['int'])),
                            ('prune_delay_enabled', (YLeaf(YType.boolean, 'prune-delay-enabled'), ['bool'])),
                            ('configured_propagation_delay', (YLeaf(YType.uint16, 'configured-propagation-delay'), ['int'])),
                            ('propagation_delay', (YLeaf(YType.uint16, 'propagation-delay'), ['int'])),
                            ('configured_override_interval', (YLeaf(YType.uint16, 'configured-override-interval'), ['int'])),
                            ('override_interval', (YLeaf(YType.uint16, 'override-interval'), ['int'])),
                            ('generation_id', (YLeaf(YType.uint32, 'generation-id'), ['int'])),
                            ('is_bidirectional_capable', (YLeaf(YType.boolean, 'is-bidirectional-capable'), ['bool'])),
                            ('is_proxy_capable', (YLeaf(YType.boolean, 'is-proxy-capable'), ['bool'])),
                            ('is_batch_asserts_capable', (YLeaf(YType.boolean, 'is-batch-asserts-capable'), ['bool'])),
                            ('idb_oor_enabled', (YLeaf(YType.boolean, 'idb-oor-enabled'), ['bool'])),
                            ('idb_acl_provided', (YLeaf(YType.boolean, 'idb-acl-provided'), ['bool'])),
                            ('idb_max_count', (YLeaf(YType.uint32, 'idb-max-count'), ['int'])),
                            ('idb_threshold_count', (YLeaf(YType.uint32, 'idb-threshold-count'), ['int'])),
                            ('idb_current_count', (YLeaf(YType.uint32, 'idb-current-count'), ['int'])),
                            ('idb_acl_name', (YLeaf(YType.str, 'idb-acl-name'), ['str'])),
                        ])
                        self.interface_name = None
                        self.interface_name_xr = None
                        self.interface_address_mask = None
                        self.is_enabled = None
                        self.neighbor_count = None
                        self.external_neighbor_count = None
                        self.hello_interval = None
                        self.dr_priority = None
                        self.hello_expiry = None
                        self.are_we_dr = None
                        self.bfd_enabled = None
                        self.bfd_interval = None
                        self.bfd_multiplier = None
                        self.virtual_interface = None
                        self.passive_interface = None
                        self.neighbor_filter_name = None
                        self.join_prune_interval = None
                        self.prune_delay_enabled = None
                        self.configured_propagation_delay = None
                        self.propagation_delay = None
                        self.configured_override_interval = None
                        self.override_interval = None
                        self.generation_id = None
                        self.is_bidirectional_capable = None
                        self.is_proxy_capable = None
                        self.is_batch_asserts_capable = None
                        self.idb_oor_enabled = None
                        self.idb_acl_provided = None
                        self.idb_max_count = None
                        self.idb_threshold_count = None
                        self.idb_current_count = None
                        self.idb_acl_name = None

                        self.dr_address = Pim.Standby.DefaultContext.Interfaces.Interface.DrAddress()
                        self.dr_address.parent = self
                        self._children_name_map["dr_address"] = "dr-address"

                        self.interface_address = YList(self)
                        self._segment_path = lambda: "interface" + "[interface-name='" + str(self.interface_name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/interfaces/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.Interfaces.Interface, ['interface_name', 'interface_name_xr', 'interface_address_mask', 'is_enabled', 'neighbor_count', 'external_neighbor_count', 'hello_interval', 'dr_priority', 'hello_expiry', 'are_we_dr', 'bfd_enabled', 'bfd_interval', 'bfd_multiplier', 'virtual_interface', 'passive_interface', 'neighbor_filter_name', 'join_prune_interval', 'prune_delay_enabled', 'configured_propagation_delay', 'propagation_delay', 'configured_override_interval', 'override_interval', 'generation_id', 'is_bidirectional_capable', 'is_proxy_capable', 'is_batch_asserts_capable', 'idb_oor_enabled', 'idb_acl_provided', 'idb_max_count', 'idb_threshold_count', 'idb_current_count', 'idb_acl_name'], name, value)


                    class DrAddress(Entity):
                        """
                        PIM Designated Router
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Interfaces.Interface.DrAddress, self).__init__()

                            self.yang_name = "dr-address"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "dr-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.Interfaces.Interface.DrAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class InterfaceAddress(Entity):
                        """
                        List of Interface IP Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Interfaces.Interface.InterfaceAddress, self).__init__()

                            self.yang_name = "interface-address"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "interface-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.Interfaces.Interface.InterfaceAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class NetIoTunnels(Entity):
                """
                Tunnel information that NETIO has 
                
                .. attribute:: net_io_tunnel
                
                	PIM netio tunnel information
                	**type**\: list of  		 :py:class:`NetIoTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.NetIoTunnels, self).__init__()

                    self.yang_name = "net-io-tunnels"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("net-io-tunnel", ("net_io_tunnel", Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel))])
                    self._leafs = OrderedDict()

                    self.net_io_tunnel = YList(self)
                    self._segment_path = lambda: "net-io-tunnels"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.DefaultContext.NetIoTunnels, [], name, value)


                class NetIoTunnel(Entity):
                    """
                    PIM netio tunnel information
                    
                    .. attribute:: tunnel_name  (key)
                    
                    	Tunnel name
                    	**type**\: str
                    
                    	**length:** 1..64
                    
                    .. attribute:: source_address
                    
                    	Source addr known to PIM
                    	**type**\:  :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress>`
                    
                    .. attribute:: rp_address
                    
                    	RP addr known to PIM
                    	**type**\:  :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress>`
                    
                    .. attribute:: source_address_netio
                    
                    	Source addr from netio
                    	**type**\:  :py:class:`SourceAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio>`
                    
                    .. attribute:: group_address_netio
                    
                    	Group addr from netio
                    	**type**\:  :py:class:`GroupAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio>`
                    
                    .. attribute:: vrf_name
                    
                    	VRF Name
                    	**type**\: str
                    
                    	**length:** 0..33
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel, self).__init__()

                        self.yang_name = "net-io-tunnel"
                        self.yang_parent_name = "net-io-tunnels"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['tunnel_name']
                        self._child_classes = OrderedDict([("source-address", ("source_address", Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress)), ("rp-address", ("rp_address", Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress)), ("source-address-netio", ("source_address_netio", Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio)), ("group-address-netio", ("group_address_netio", Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio))])
                        self._leafs = OrderedDict([
                            ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                        ])
                        self.tunnel_name = None
                        self.vrf_name = None

                        self.source_address = Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress()
                        self.source_address.parent = self
                        self._children_name_map["source_address"] = "source-address"

                        self.rp_address = Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress()
                        self.rp_address.parent = self
                        self._children_name_map["rp_address"] = "rp-address"

                        self.source_address_netio = Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio()
                        self.source_address_netio.parent = self
                        self._children_name_map["source_address_netio"] = "source-address-netio"

                        self.group_address_netio = Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio()
                        self.group_address_netio.parent = self
                        self._children_name_map["group_address_netio"] = "group-address-netio"
                        self._segment_path = lambda: "net-io-tunnel" + "[tunnel-name='" + str(self.tunnel_name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/net-io-tunnels/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel, ['tunnel_name', 'vrf_name'], name, value)


                    class SourceAddress(Entity):
                        """
                        Source addr known to PIM
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress, self).__init__()

                            self.yang_name = "source-address"
                            self.yang_parent_name = "net-io-tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "source-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class RpAddress(Entity):
                        """
                        RP addr known to PIM
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress, self).__init__()

                            self.yang_name = "rp-address"
                            self.yang_parent_name = "net-io-tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "rp-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class SourceAddressNetio(Entity):
                        """
                        Source addr from netio
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio, self).__init__()

                            self.yang_name = "source-address-netio"
                            self.yang_parent_name = "net-io-tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "source-address-netio"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class GroupAddressNetio(Entity):
                        """
                        Group addr from netio
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio, self).__init__()

                            self.yang_name = "group-address-netio"
                            self.yang_parent_name = "net-io-tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "group-address-netio"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class BidirDfStates(Entity):
                """
                Bidirectional PIM DF election state table
                
                .. attribute:: bidir_df_state
                
                	Bidirectional PIM DF Election Table Entry
                	**type**\: list of  		 :py:class:`BidirDfState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.BidirDfStates.BidirDfState>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.BidirDfStates, self).__init__()

                    self.yang_name = "bidir-df-states"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("bidir-df-state", ("bidir_df_state", Pim.Standby.DefaultContext.BidirDfStates.BidirDfState))])
                    self._leafs = OrderedDict()

                    self.bidir_df_state = YList(self)
                    self._segment_path = lambda: "bidir-df-states"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.DefaultContext.BidirDfStates, [], name, value)


                class BidirDfState(Entity):
                    """
                    Bidirectional PIM DF Election Table Entry
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: rp_address_xr
                    
                    	RP Address
                    	**type**\:  :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr>`
                    
                    .. attribute:: pim_interface_name
                    
                    	Interface Name
                    	**type**\: str
                    
                    .. attribute:: election_state
                    
                    	DF Election State
                    	**type**\: str
                    
                    .. attribute:: time_seconds
                    
                    	Timer expires (seconds)
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: time_nano_seconds
                    
                    	Timer expires (nseconds)
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: nanosecond
                    
                    .. attribute:: our_metric
                    
                    	Metric
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: our_metric_preference
                    
                    	MetricPreference
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.BidirDfStates.BidirDfState, self).__init__()

                        self.yang_name = "bidir-df-state"
                        self.yang_parent_name = "bidir-df-states"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("rp-address-xr", ("rp_address_xr", Pim.Standby.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr))])
                        self._leafs = OrderedDict([
                            ('rp_address', (YLeaf(YType.str, 'rp-address'), ['str','str'])),
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                            ('pim_interface_name', (YLeaf(YType.str, 'pim-interface-name'), ['str'])),
                            ('election_state', (YLeaf(YType.str, 'election-state'), ['str'])),
                            ('time_seconds', (YLeaf(YType.uint64, 'time-seconds'), ['int'])),
                            ('time_nano_seconds', (YLeaf(YType.uint64, 'time-nano-seconds'), ['int'])),
                            ('our_metric', (YLeaf(YType.uint32, 'our-metric'), ['int'])),
                            ('our_metric_preference', (YLeaf(YType.uint32, 'our-metric-preference'), ['int'])),
                        ])
                        self.rp_address = None
                        self.interface_name = None
                        self.pim_interface_name = None
                        self.election_state = None
                        self.time_seconds = None
                        self.time_nano_seconds = None
                        self.our_metric = None
                        self.our_metric_preference = None

                        self.rp_address_xr = Pim.Standby.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr()
                        self.rp_address_xr.parent = self
                        self._children_name_map["rp_address_xr"] = "rp-address-xr"
                        self._segment_path = lambda: "bidir-df-state"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/bidir-df-states/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.BidirDfStates.BidirDfState, ['rp_address', 'interface_name', 'pim_interface_name', 'election_state', 'time_seconds', 'time_nano_seconds', 'our_metric', 'our_metric_preference'], name, value)


                    class RpAddressXr(Entity):
                        """
                        RP Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr, self).__init__()

                            self.yang_name = "rp-address-xr"
                            self.yang_parent_name = "bidir-df-state"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "rp-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/bidir-df-states/bidir-df-state/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class Topologies(Entity):
                """
                PIM topology table
                
                .. attribute:: topology
                
                	PIM topology information
                	**type**\: list of  		 :py:class:`Topology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Topologies.Topology>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.Topologies, self).__init__()

                    self.yang_name = "topologies"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("topology", ("topology", Pim.Standby.DefaultContext.Topologies.Topology))])
                    self._leafs = OrderedDict()

                    self.topology = YList(self)
                    self._segment_path = lambda: "topologies"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.DefaultContext.Topologies, [], name, value)


                class Topology(Entity):
                    """
                    PIM topology information
                    
                    .. attribute:: source_address
                    
                    	Source address
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: group_address
                    
                    	Group address
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: rpt
                    
                    	RPT bit
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_address_xr
                    
                    	Group Address
                    	**type**\:  :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Topologies.Topology.GroupAddressXr>`
                    
                    .. attribute:: source_address_xr
                    
                    	Source Address
                    	**type**\:  :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Topologies.Topology.SourceAddressXr>`
                    
                    .. attribute:: rp_address
                    
                    	RP Address (If rpt)
                    	**type**\:  :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Topologies.Topology.RpAddress>`
                    
                    .. attribute:: rpf_neighbor
                    
                    	RPF Neighbor
                    	**type**\:  :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Topologies.Topology.RpfNeighbor>`
                    
                    .. attribute:: secondary_rpf_neighbor
                    
                    	Secondary RPF Neighbor
                    	**type**\:  :py:class:`SecondaryRpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor>`
                    
                    .. attribute:: rpf_root
                    
                    	Root of this mcast tree
                    	**type**\:  :py:class:`RpfRoot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Topologies.Topology.RpfRoot>`
                    
                    .. attribute:: proxy_address
                    
                    	RPF Proxy address
                    	**type**\:  :py:class:`ProxyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Topologies.Topology.ProxyAddress>`
                    
                    .. attribute:: orig_src_address
                    
                    	Orig Src Address
                    	**type**\:  :py:class:`OrigSrcAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Topologies.Topology.OrigSrcAddress>`
                    
                    .. attribute:: limit_reached
                    
                    	Have we throttled the creation of routes or interfaces ?
                    	**type**\: bool
                    
                    .. attribute:: low_memory
                    
                    	Node is running low on memory
                    	**type**\: bool
                    
                    .. attribute:: protocol
                    
                    	The PIM protocol
                    	**type**\:  :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                    
                    .. attribute:: wildcard
                    
                    	WC \-Wildcard
                    	**type**\: bool
                    
                    .. attribute:: rpt_xr
                    
                    	Is this on the RPT ?
                    	**type**\: bool
                    
                    .. attribute:: spt
                    
                    	Is this on the SPT ?
                    	**type**\: bool
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: expiry
                    
                    	When this entry expires
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: alive
                    
                    	Alive time in seconds (\-1 if never)
                    	**type**\: int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    .. attribute:: register_received_timer
                    
                    	Register Received Timer in seconds (\-1 if never)
                    	**type**\: int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    .. attribute:: remote_source
                    
                    	MSDP told us
                    	**type**\: bool
                    
                    .. attribute:: crossed_threshold
                    
                    	Incoming traffic crossed threshold. MT flag set
                    	**type**\: bool
                    
                    .. attribute:: data_mdt_addr_assigned
                    
                    	PIM has assigned a Data MDT Address
                    	**type**\: bool
                    
                    .. attribute:: rpf_interface_name
                    
                    	Interface Identifier
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: rpf_vrf_name
                    
                    	RPF VRF Name
                    	**type**\: str
                    
                    	**length:** 0..33
                    
                    .. attribute:: rpf_safi
                    
                    	Unicast or mcast
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: rpf_table_name
                    
                    	RPF Table name
                    	**type**\: str
                    
                    .. attribute:: rpf_drop
                    
                    	RPF route\-policy drop
                    	**type**\: bool
                    
                    .. attribute:: rpf_extranet
                    
                    	Extranet RPF route\-policy
                    	**type**\: bool
                    
                    .. attribute:: is_via_lsm
                    
                    	Via LSM
                    	**type**\: bool
                    
                    .. attribute:: secondary_rpf_interface_name
                    
                    	Secondary Interface Identifier
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: connected
                    
                    	Is Connected ?
                    	**type**\: bool
                    
                    .. attribute:: proxy
                    
                    	Is the RPF target a proxy?
                    	**type**\: bool
                    
                    .. attribute:: rpf_proxy_enabled
                    
                    	Is rpf if proxy enabled?
                    	**type**\: bool
                    
                    .. attribute:: mofrr_enabled
                    
                    	Is this SG MoFRR enabled?
                    	**type**\: bool
                    
                    .. attribute:: rib_mo_frr_enabled
                    
                    	Is this SG MoFRR enabled?
                    	**type**\: bool
                    
                    .. attribute:: jp_timer
                    
                    	Join\-Prune Timer
                    	**type**\: int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: jp_status
                    
                    	Join\-Prune Status
                    	**type**\: int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: suppress_registers
                    
                    	When the Null register probe expires
                    	**type**\: int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: assume_alive
                    
                    	The Assume Alive Bit
                    	**type**\: bool
                    
                    .. attribute:: probe_alive
                    
                    	The Probe Alive Bit
                    	**type**\: bool
                    
                    .. attribute:: really_alive
                    
                    	The Really Alive Bit
                    	**type**\: bool
                    
                    .. attribute:: inherit_alive
                    
                    	The Inherit Alive Bit
                    	**type**\: bool
                    
                    .. attribute:: inherit_spt
                    
                    	The Inherit SPT Bit
                    	**type**\: bool
                    
                    .. attribute:: signal_sources
                    
                    	Signal Sources on route?
                    	**type**\: bool
                    
                    .. attribute:: dont_check_connected
                    
                    	Do we need to make the connected check on this route ?
                    	**type**\: bool
                    
                    .. attribute:: register_received
                    
                    	Have registers been received for this source ?
                    	**type**\: bool
                    
                    .. attribute:: last_hop
                    
                    	Are we last hop ?
                    	**type**\: bool
                    
                    .. attribute:: sending_registers
                    
                    	Are we sending registers for this route ?
                    	**type**\: bool
                    
                    .. attribute:: sending_null_registers
                    
                    	Are we sending null registers for this route ?
                    	**type**\: bool
                    
                    .. attribute:: sa_sent
                    
                    	BGP SA sent
                    	**type**\: bool
                    
                    .. attribute:: sa_received
                    
                    	BGP SA received
                    	**type**\: bool
                    
                    .. attribute:: sa_joined
                    
                    	BGP SA join
                    	**type**\: bool
                    
                    .. attribute:: anycast_rp_match
                    
                    	Group matches Anycast\-RP policy
                    	**type**\: bool
                    
                    .. attribute:: anycast_rp_route_target
                    
                    	Anycast\-RP RT
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: bgp_join
                    
                    	BGP C JOIN
                    	**type**\: bool
                    
                    .. attribute:: bgp_jp_time
                    
                    	BGP C JP Time
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: customer_routing_type
                    
                    	Type of Customer Routing in the MVPN
                    	**type**\: int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: extranet_route
                    
                    	Is a Extranet route ?
                    	**type**\: bool
                    
                    .. attribute:: mofrr_active
                    
                    	Is MoFRR Active?
                    	**type**\: bool
                    
                    .. attribute:: mofrr_primary
                    
                    	Is this Mofrr Primary?
                    	**type**\: bool
                    
                    .. attribute:: mofrr_backup
                    
                    	Is this Mofrr Backup?
                    	**type**\: bool
                    
                    .. attribute:: vxlan
                    
                    	Is this VXLAN?
                    	**type**\: bool
                    
                    .. attribute:: kat_state
                    
                    	Keep Alive Timer State
                    	**type**\: bool
                    
                    .. attribute:: outgoing_interface
                    
                    	Outgoing interface list
                    	**type**\: list of  		 :py:class:`OutgoingInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.Topologies.Topology, self).__init__()

                        self.yang_name = "topology"
                        self.yang_parent_name = "topologies"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("group-address-xr", ("group_address_xr", Pim.Standby.DefaultContext.Topologies.Topology.GroupAddressXr)), ("source-address-xr", ("source_address_xr", Pim.Standby.DefaultContext.Topologies.Topology.SourceAddressXr)), ("rp-address", ("rp_address", Pim.Standby.DefaultContext.Topologies.Topology.RpAddress)), ("rpf-neighbor", ("rpf_neighbor", Pim.Standby.DefaultContext.Topologies.Topology.RpfNeighbor)), ("secondary-rpf-neighbor", ("secondary_rpf_neighbor", Pim.Standby.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor)), ("rpf-root", ("rpf_root", Pim.Standby.DefaultContext.Topologies.Topology.RpfRoot)), ("proxy-address", ("proxy_address", Pim.Standby.DefaultContext.Topologies.Topology.ProxyAddress)), ("orig-src-address", ("orig_src_address", Pim.Standby.DefaultContext.Topologies.Topology.OrigSrcAddress)), ("outgoing-interface", ("outgoing_interface", Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface))])
                        self._leafs = OrderedDict([
                            ('source_address', (YLeaf(YType.str, 'source-address'), ['str','str'])),
                            ('group_address', (YLeaf(YType.str, 'group-address'), ['str','str'])),
                            ('rpt', (YLeaf(YType.uint32, 'rpt'), ['int'])),
                            ('limit_reached', (YLeaf(YType.boolean, 'limit-reached'), ['bool'])),
                            ('low_memory', (YLeaf(YType.boolean, 'low-memory'), ['bool'])),
                            ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowProtocol', '')])),
                            ('wildcard', (YLeaf(YType.boolean, 'wildcard'), ['bool'])),
                            ('rpt_xr', (YLeaf(YType.boolean, 'rpt-xr'), ['bool'])),
                            ('spt', (YLeaf(YType.boolean, 'spt'), ['bool'])),
                            ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                            ('expiry', (YLeaf(YType.uint64, 'expiry'), ['int'])),
                            ('alive', (YLeaf(YType.int32, 'alive'), ['int'])),
                            ('register_received_timer', (YLeaf(YType.int32, 'register-received-timer'), ['int'])),
                            ('remote_source', (YLeaf(YType.boolean, 'remote-source'), ['bool'])),
                            ('crossed_threshold', (YLeaf(YType.boolean, 'crossed-threshold'), ['bool'])),
                            ('data_mdt_addr_assigned', (YLeaf(YType.boolean, 'data-mdt-addr-assigned'), ['bool'])),
                            ('rpf_interface_name', (YLeaf(YType.str, 'rpf-interface-name'), ['str'])),
                            ('rpf_vrf_name', (YLeaf(YType.str, 'rpf-vrf-name'), ['str'])),
                            ('rpf_safi', (YLeaf(YType.uint8, 'rpf-safi'), ['int'])),
                            ('rpf_table_name', (YLeaf(YType.str, 'rpf-table-name'), ['str'])),
                            ('rpf_drop', (YLeaf(YType.boolean, 'rpf-drop'), ['bool'])),
                            ('rpf_extranet', (YLeaf(YType.boolean, 'rpf-extranet'), ['bool'])),
                            ('is_via_lsm', (YLeaf(YType.boolean, 'is-via-lsm'), ['bool'])),
                            ('secondary_rpf_interface_name', (YLeaf(YType.str, 'secondary-rpf-interface-name'), ['str'])),
                            ('connected', (YLeaf(YType.boolean, 'connected'), ['bool'])),
                            ('proxy', (YLeaf(YType.boolean, 'proxy'), ['bool'])),
                            ('rpf_proxy_enabled', (YLeaf(YType.boolean, 'rpf-proxy-enabled'), ['bool'])),
                            ('mofrr_enabled', (YLeaf(YType.boolean, 'mofrr-enabled'), ['bool'])),
                            ('rib_mo_frr_enabled', (YLeaf(YType.boolean, 'rib-mo-frr-enabled'), ['bool'])),
                            ('jp_timer', (YLeaf(YType.int32, 'jp-timer'), ['int'])),
                            ('jp_status', (YLeaf(YType.int32, 'jp-status'), ['int'])),
                            ('suppress_registers', (YLeaf(YType.int32, 'suppress-registers'), ['int'])),
                            ('assume_alive', (YLeaf(YType.boolean, 'assume-alive'), ['bool'])),
                            ('probe_alive', (YLeaf(YType.boolean, 'probe-alive'), ['bool'])),
                            ('really_alive', (YLeaf(YType.boolean, 'really-alive'), ['bool'])),
                            ('inherit_alive', (YLeaf(YType.boolean, 'inherit-alive'), ['bool'])),
                            ('inherit_spt', (YLeaf(YType.boolean, 'inherit-spt'), ['bool'])),
                            ('signal_sources', (YLeaf(YType.boolean, 'signal-sources'), ['bool'])),
                            ('dont_check_connected', (YLeaf(YType.boolean, 'dont-check-connected'), ['bool'])),
                            ('register_received', (YLeaf(YType.boolean, 'register-received'), ['bool'])),
                            ('last_hop', (YLeaf(YType.boolean, 'last-hop'), ['bool'])),
                            ('sending_registers', (YLeaf(YType.boolean, 'sending-registers'), ['bool'])),
                            ('sending_null_registers', (YLeaf(YType.boolean, 'sending-null-registers'), ['bool'])),
                            ('sa_sent', (YLeaf(YType.boolean, 'sa-sent'), ['bool'])),
                            ('sa_received', (YLeaf(YType.boolean, 'sa-received'), ['bool'])),
                            ('sa_joined', (YLeaf(YType.boolean, 'sa-joined'), ['bool'])),
                            ('anycast_rp_match', (YLeaf(YType.boolean, 'anycast-rp-match'), ['bool'])),
                            ('anycast_rp_route_target', (YLeaf(YType.str, 'anycast-rp-route-target'), ['str'])),
                            ('bgp_join', (YLeaf(YType.boolean, 'bgp-join'), ['bool'])),
                            ('bgp_jp_time', (YLeaf(YType.uint64, 'bgp-jp-time'), ['int'])),
                            ('customer_routing_type', (YLeaf(YType.int32, 'customer-routing-type'), ['int'])),
                            ('extranet_route', (YLeaf(YType.boolean, 'extranet-route'), ['bool'])),
                            ('mofrr_active', (YLeaf(YType.boolean, 'mofrr-active'), ['bool'])),
                            ('mofrr_primary', (YLeaf(YType.boolean, 'mofrr-primary'), ['bool'])),
                            ('mofrr_backup', (YLeaf(YType.boolean, 'mofrr-backup'), ['bool'])),
                            ('vxlan', (YLeaf(YType.boolean, 'vxlan'), ['bool'])),
                            ('kat_state', (YLeaf(YType.boolean, 'kat-state'), ['bool'])),
                        ])
                        self.source_address = None
                        self.group_address = None
                        self.rpt = None
                        self.limit_reached = None
                        self.low_memory = None
                        self.protocol = None
                        self.wildcard = None
                        self.rpt_xr = None
                        self.spt = None
                        self.uptime = None
                        self.expiry = None
                        self.alive = None
                        self.register_received_timer = None
                        self.remote_source = None
                        self.crossed_threshold = None
                        self.data_mdt_addr_assigned = None
                        self.rpf_interface_name = None
                        self.rpf_vrf_name = None
                        self.rpf_safi = None
                        self.rpf_table_name = None
                        self.rpf_drop = None
                        self.rpf_extranet = None
                        self.is_via_lsm = None
                        self.secondary_rpf_interface_name = None
                        self.connected = None
                        self.proxy = None
                        self.rpf_proxy_enabled = None
                        self.mofrr_enabled = None
                        self.rib_mo_frr_enabled = None
                        self.jp_timer = None
                        self.jp_status = None
                        self.suppress_registers = None
                        self.assume_alive = None
                        self.probe_alive = None
                        self.really_alive = None
                        self.inherit_alive = None
                        self.inherit_spt = None
                        self.signal_sources = None
                        self.dont_check_connected = None
                        self.register_received = None
                        self.last_hop = None
                        self.sending_registers = None
                        self.sending_null_registers = None
                        self.sa_sent = None
                        self.sa_received = None
                        self.sa_joined = None
                        self.anycast_rp_match = None
                        self.anycast_rp_route_target = None
                        self.bgp_join = None
                        self.bgp_jp_time = None
                        self.customer_routing_type = None
                        self.extranet_route = None
                        self.mofrr_active = None
                        self.mofrr_primary = None
                        self.mofrr_backup = None
                        self.vxlan = None
                        self.kat_state = None

                        self.group_address_xr = Pim.Standby.DefaultContext.Topologies.Topology.GroupAddressXr()
                        self.group_address_xr.parent = self
                        self._children_name_map["group_address_xr"] = "group-address-xr"

                        self.source_address_xr = Pim.Standby.DefaultContext.Topologies.Topology.SourceAddressXr()
                        self.source_address_xr.parent = self
                        self._children_name_map["source_address_xr"] = "source-address-xr"

                        self.rp_address = Pim.Standby.DefaultContext.Topologies.Topology.RpAddress()
                        self.rp_address.parent = self
                        self._children_name_map["rp_address"] = "rp-address"

                        self.rpf_neighbor = Pim.Standby.DefaultContext.Topologies.Topology.RpfNeighbor()
                        self.rpf_neighbor.parent = self
                        self._children_name_map["rpf_neighbor"] = "rpf-neighbor"

                        self.secondary_rpf_neighbor = Pim.Standby.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor()
                        self.secondary_rpf_neighbor.parent = self
                        self._children_name_map["secondary_rpf_neighbor"] = "secondary-rpf-neighbor"

                        self.rpf_root = Pim.Standby.DefaultContext.Topologies.Topology.RpfRoot()
                        self.rpf_root.parent = self
                        self._children_name_map["rpf_root"] = "rpf-root"

                        self.proxy_address = Pim.Standby.DefaultContext.Topologies.Topology.ProxyAddress()
                        self.proxy_address.parent = self
                        self._children_name_map["proxy_address"] = "proxy-address"

                        self.orig_src_address = Pim.Standby.DefaultContext.Topologies.Topology.OrigSrcAddress()
                        self.orig_src_address.parent = self
                        self._children_name_map["orig_src_address"] = "orig-src-address"

                        self.outgoing_interface = YList(self)
                        self._segment_path = lambda: "topology"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/topologies/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.Topologies.Topology, ['source_address', 'group_address', 'rpt', 'limit_reached', 'low_memory', 'protocol', 'wildcard', 'rpt_xr', 'spt', 'uptime', 'expiry', 'alive', 'register_received_timer', 'remote_source', 'crossed_threshold', 'data_mdt_addr_assigned', 'rpf_interface_name', 'rpf_vrf_name', 'rpf_safi', 'rpf_table_name', 'rpf_drop', 'rpf_extranet', 'is_via_lsm', 'secondary_rpf_interface_name', 'connected', 'proxy', 'rpf_proxy_enabled', 'mofrr_enabled', 'rib_mo_frr_enabled', 'jp_timer', 'jp_status', 'suppress_registers', 'assume_alive', 'probe_alive', 'really_alive', 'inherit_alive', 'inherit_spt', 'signal_sources', 'dont_check_connected', 'register_received', 'last_hop', 'sending_registers', 'sending_null_registers', 'sa_sent', 'sa_received', 'sa_joined', 'anycast_rp_match', 'anycast_rp_route_target', 'bgp_join', 'bgp_jp_time', 'customer_routing_type', 'extranet_route', 'mofrr_active', 'mofrr_primary', 'mofrr_backup', 'vxlan', 'kat_state'], name, value)


                    class GroupAddressXr(Entity):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Topologies.Topology.GroupAddressXr, self).__init__()

                            self.yang_name = "group-address-xr"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "group-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/topologies/topology/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.Topologies.Topology.GroupAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class SourceAddressXr(Entity):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Topologies.Topology.SourceAddressXr, self).__init__()

                            self.yang_name = "source-address-xr"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "source-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/topologies/topology/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.Topologies.Topology.SourceAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class RpAddress(Entity):
                        """
                        RP Address (If rpt)
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Topologies.Topology.RpAddress, self).__init__()

                            self.yang_name = "rp-address"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "rp-address"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/topologies/topology/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.Topologies.Topology.RpAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class RpfNeighbor(Entity):
                        """
                        RPF Neighbor
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Topologies.Topology.RpfNeighbor, self).__init__()

                            self.yang_name = "rpf-neighbor"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "rpf-neighbor"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/topologies/topology/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.Topologies.Topology.RpfNeighbor, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class SecondaryRpfNeighbor(Entity):
                        """
                        Secondary RPF Neighbor
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor, self).__init__()

                            self.yang_name = "secondary-rpf-neighbor"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "secondary-rpf-neighbor"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/topologies/topology/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class RpfRoot(Entity):
                        """
                        Root of this mcast tree
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Topologies.Topology.RpfRoot, self).__init__()

                            self.yang_name = "rpf-root"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "rpf-root"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/topologies/topology/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.Topologies.Topology.RpfRoot, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class ProxyAddress(Entity):
                        """
                        RPF Proxy address.
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Topologies.Topology.ProxyAddress, self).__init__()

                            self.yang_name = "proxy-address"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "proxy-address"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/topologies/topology/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.Topologies.Topology.ProxyAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class OrigSrcAddress(Entity):
                        """
                        Orig Src Address.
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Topologies.Topology.OrigSrcAddress, self).__init__()

                            self.yang_name = "orig-src-address"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "orig-src-address"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/topologies/topology/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.Topologies.Topology.OrigSrcAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class OutgoingInterface(Entity):
                        """
                        Outgoing interface list
                        
                        .. attribute:: assert_winner
                        
                        	Assert Winner
                        	**type**\:  :py:class:`AssertWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner>`
                        
                        .. attribute:: interface_name
                        
                        	Interface Identifier
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: expiry
                        
                        	Expiry in seconds
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: bgp_c_mcast_prune_delay_timer
                        
                        	BGP C\-MCAST Prune Suppression in seconds
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: jp_timer
                        
                        	Join\-Prune Timer (secs)
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: jp_state
                        
                        	Join\-Prune State
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: assert_timer
                        
                        	Assert Timer in seconds
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: local_members
                        
                        	Local Information. Deprecated \- use 'local\-members\-information' instead
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: internal_interest_info
                        
                        	Internal Interest. Deprecated \- use 'internal\-interest\-information' instead
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: forwarding_state
                        
                        	Forward or Prune
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: immediate_state
                        
                        	Immediate fwding state
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: last_hop
                        
                        	Are we last hop ?
                        	**type**\: bool
                        
                        .. attribute:: mldp_inband_mdt
                        
                        	MLDP Inband MDT interface
                        	**type**\: bool
                        
                        .. attribute:: mldp_stale
                        
                        	OLE is stale
                        	**type**\: bool
                        
                        .. attribute:: sa_prune
                        
                        	BGP SA Prune state
                        	**type**\: bool
                        
                        .. attribute:: admin_boundary
                        
                        	Is this an administrative boundary ?
                        	**type**\: bool
                        
                        .. attribute:: igmp_membership
                        
                        	IGMP membership
                        	**type**\: bool
                        
                        .. attribute:: mdt_safi_join
                        
                        	MDT Safi join
                        	**type**\: bool
                        
                        .. attribute:: mvpn_safi_join
                        
                        	MVPN Safi join
                        	**type**\: bool
                        
                        .. attribute:: local_mdt_join
                        
                        	Default MDT Join
                        	**type**\: bool
                        
                        .. attribute:: data_mdt_join
                        
                        	Data MDT join
                        	**type**\: bool
                        
                        .. attribute:: mvpnv6_safi_join
                        
                        	MVPN IPv6 Safi join
                        	**type**\: bool
                        
                        .. attribute:: bgp_c_mcast_join
                        
                        	BGP C\-Mcast join
                        	**type**\: bool
                        
                        .. attribute:: vrf_name
                        
                        	VRF which physically owns
                        	**type**\: str
                        
                        	**length:** 0..33
                        
                        .. attribute:: extranet_interface
                        
                        	Is this an Extranet Interface ?
                        	**type**\: bool
                        
                        .. attribute:: internal_interest_information
                        
                        	Internal Interest. Replaces internal\-interest\-info
                        	**type**\:  :py:class:`PimInternalInterestInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimInternalInterestInfo>`
                        
                        .. attribute:: local_members_information
                        
                        	Local Information. Replaces local\-members
                        	**type**\:  :py:class:`PimShowLocalInterest <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowLocalInterest>`
                        
                        .. attribute:: assert_state
                        
                        	Assert State
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface, self).__init__()

                            self.yang_name = "outgoing-interface"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("assert-winner", ("assert_winner", Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner))])
                            self._leafs = OrderedDict([
                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                                ('expiry', (YLeaf(YType.uint64, 'expiry'), ['int'])),
                                ('bgp_c_mcast_prune_delay_timer', (YLeaf(YType.uint64, 'bgp-c-mcast-prune-delay-timer'), ['int'])),
                                ('jp_timer', (YLeaf(YType.int32, 'jp-timer'), ['int'])),
                                ('jp_state', (YLeaf(YType.int32, 'jp-state'), ['int'])),
                                ('assert_timer', (YLeaf(YType.int32, 'assert-timer'), ['int'])),
                                ('local_members', (YLeaf(YType.int32, 'local-members'), ['int'])),
                                ('internal_interest_info', (YLeaf(YType.int32, 'internal-interest-info'), ['int'])),
                                ('forwarding_state', (YLeaf(YType.int32, 'forwarding-state'), ['int'])),
                                ('immediate_state', (YLeaf(YType.int32, 'immediate-state'), ['int'])),
                                ('last_hop', (YLeaf(YType.boolean, 'last-hop'), ['bool'])),
                                ('mldp_inband_mdt', (YLeaf(YType.boolean, 'mldp-inband-mdt'), ['bool'])),
                                ('mldp_stale', (YLeaf(YType.boolean, 'mldp-stale'), ['bool'])),
                                ('sa_prune', (YLeaf(YType.boolean, 'sa-prune'), ['bool'])),
                                ('admin_boundary', (YLeaf(YType.boolean, 'admin-boundary'), ['bool'])),
                                ('igmp_membership', (YLeaf(YType.boolean, 'igmp-membership'), ['bool'])),
                                ('mdt_safi_join', (YLeaf(YType.boolean, 'mdt-safi-join'), ['bool'])),
                                ('mvpn_safi_join', (YLeaf(YType.boolean, 'mvpn-safi-join'), ['bool'])),
                                ('local_mdt_join', (YLeaf(YType.boolean, 'local-mdt-join'), ['bool'])),
                                ('data_mdt_join', (YLeaf(YType.boolean, 'data-mdt-join'), ['bool'])),
                                ('mvpnv6_safi_join', (YLeaf(YType.boolean, 'mvpnv6-safi-join'), ['bool'])),
                                ('bgp_c_mcast_join', (YLeaf(YType.boolean, 'bgp-c-mcast-join'), ['bool'])),
                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                ('extranet_interface', (YLeaf(YType.boolean, 'extranet-interface'), ['bool'])),
                                ('internal_interest_information', (YLeaf(YType.enumeration, 'internal-interest-information'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimInternalInterestInfo', '')])),
                                ('local_members_information', (YLeaf(YType.enumeration, 'local-members-information'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowLocalInterest', '')])),
                                ('assert_state', (YLeaf(YType.boolean, 'assert-state'), ['bool'])),
                            ])
                            self.interface_name = None
                            self.uptime = None
                            self.expiry = None
                            self.bgp_c_mcast_prune_delay_timer = None
                            self.jp_timer = None
                            self.jp_state = None
                            self.assert_timer = None
                            self.local_members = None
                            self.internal_interest_info = None
                            self.forwarding_state = None
                            self.immediate_state = None
                            self.last_hop = None
                            self.mldp_inband_mdt = None
                            self.mldp_stale = None
                            self.sa_prune = None
                            self.admin_boundary = None
                            self.igmp_membership = None
                            self.mdt_safi_join = None
                            self.mvpn_safi_join = None
                            self.local_mdt_join = None
                            self.data_mdt_join = None
                            self.mvpnv6_safi_join = None
                            self.bgp_c_mcast_join = None
                            self.vrf_name = None
                            self.extranet_interface = None
                            self.internal_interest_information = None
                            self.local_members_information = None
                            self.assert_state = None

                            self.assert_winner = Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner()
                            self.assert_winner.parent = self
                            self._children_name_map["assert_winner"] = "assert-winner"
                            self._segment_path = lambda: "outgoing-interface"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/topologies/topology/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface, ['interface_name', 'uptime', 'expiry', 'bgp_c_mcast_prune_delay_timer', 'jp_timer', 'jp_state', 'assert_timer', 'local_members', 'internal_interest_info', 'forwarding_state', 'immediate_state', 'last_hop', 'mldp_inband_mdt', 'mldp_stale', 'sa_prune', 'admin_boundary', 'igmp_membership', 'mdt_safi_join', 'mvpn_safi_join', 'local_mdt_join', 'data_mdt_join', 'mvpnv6_safi_join', 'bgp_c_mcast_join', 'vrf_name', 'extranet_interface', 'internal_interest_information', 'local_members_information', 'assert_state'], name, value)


                        class AssertWinner(Entity):
                            """
                            Assert Winner
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner, self).__init__()

                                self.yang_name = "assert-winner"
                                self.yang_parent_name = "outgoing-interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "assert-winner"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/topologies/topology/outgoing-interface/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class BgpAfs(Entity):
                """
                PIM BGP SAFI table
                
                .. attribute:: bgp_af
                
                	PIM BGP SAFI information
                	**type**\: list of  		 :py:class:`BgpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.BgpAfs.BgpAf>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.BgpAfs, self).__init__()

                    self.yang_name = "bgp-afs"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("bgp-af", ("bgp_af", Pim.Standby.DefaultContext.BgpAfs.BgpAf))])
                    self._leafs = OrderedDict()

                    self.bgp_af = YList(self)
                    self._segment_path = lambda: "bgp-afs"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.DefaultContext.BgpAfs, [], name, value)


                class BgpAf(Entity):
                    """
                    PIM BGP SAFI information
                    
                    .. attribute:: source_address
                    
                    	Source IP address
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: group_address
                    
                    	Group IP address
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: source
                    
                    	Source address
                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.BgpAfs.BgpAf.Source>`
                    
                    .. attribute:: group
                    
                    	Group address
                    	**type**\:  :py:class:`Group <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.BgpAfs.BgpAf.Group>`
                    
                    .. attribute:: next_hop
                    
                    	Next hop address
                    	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.BgpAfs.BgpAf.NextHop>`
                    
                    .. attribute:: route_distinguisher
                    
                    	Router ID
                    	**type**\: str
                    
                    	**length:** 0..256
                    
                    .. attribute:: extranet_path_count
                    
                    	Count of dependent extranet paths
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_bgp_added
                    
                    	SAFI learnt from BGP
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.BgpAfs.BgpAf, self).__init__()

                        self.yang_name = "bgp-af"
                        self.yang_parent_name = "bgp-afs"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("source", ("source", Pim.Standby.DefaultContext.BgpAfs.BgpAf.Source)), ("group", ("group", Pim.Standby.DefaultContext.BgpAfs.BgpAf.Group)), ("next-hop", ("next_hop", Pim.Standby.DefaultContext.BgpAfs.BgpAf.NextHop))])
                        self._leafs = OrderedDict([
                            ('source_address', (YLeaf(YType.str, 'source-address'), ['str','str'])),
                            ('group_address', (YLeaf(YType.str, 'group-address'), ['str','str'])),
                            ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                            ('extranet_path_count', (YLeaf(YType.uint32, 'extranet-path-count'), ['int'])),
                            ('is_bgp_added', (YLeaf(YType.boolean, 'is-bgp-added'), ['bool'])),
                        ])
                        self.source_address = None
                        self.group_address = None
                        self.route_distinguisher = None
                        self.extranet_path_count = None
                        self.is_bgp_added = None

                        self.source = Pim.Standby.DefaultContext.BgpAfs.BgpAf.Source()
                        self.source.parent = self
                        self._children_name_map["source"] = "source"

                        self.group = Pim.Standby.DefaultContext.BgpAfs.BgpAf.Group()
                        self.group.parent = self
                        self._children_name_map["group"] = "group"

                        self.next_hop = Pim.Standby.DefaultContext.BgpAfs.BgpAf.NextHop()
                        self.next_hop.parent = self
                        self._children_name_map["next_hop"] = "next-hop"
                        self._segment_path = lambda: "bgp-af"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/bgp-afs/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.BgpAfs.BgpAf, ['source_address', 'group_address', 'route_distinguisher', 'extranet_path_count', 'is_bgp_added'], name, value)


                    class Source(Entity):
                        """
                        Source address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.BgpAfs.BgpAf.Source, self).__init__()

                            self.yang_name = "source"
                            self.yang_parent_name = "bgp-af"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "source"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/bgp-afs/bgp-af/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.BgpAfs.BgpAf.Source, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class Group(Entity):
                        """
                        Group address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.BgpAfs.BgpAf.Group, self).__init__()

                            self.yang_name = "group"
                            self.yang_parent_name = "bgp-af"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "group"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/bgp-afs/bgp-af/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.BgpAfs.BgpAf.Group, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class NextHop(Entity):
                        """
                        Next hop address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.BgpAfs.BgpAf.NextHop, self).__init__()

                            self.yang_name = "next-hop"
                            self.yang_parent_name = "bgp-af"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "next-hop"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/bgp-afs/bgp-af/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.BgpAfs.BgpAf.NextHop, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class AutoRp(Entity):
                """
                PIM Auto\-RP information
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.AutoRp, self).__init__()

                    self.yang_name = "auto-rp"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "auto-rp"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True


            class TopologyInterfaceFlagRouteCounts(Entity):
                """
                Route count for topology with interface flag set
                
                .. attribute:: topology_interface_flag_route_count
                
                	Route count for topology with interface flag set
                	**type**\: list of  		 :py:class:`TopologyInterfaceFlagRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts, self).__init__()

                    self.yang_name = "topology-interface-flag-route-counts"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("topology-interface-flag-route-count", ("topology_interface_flag_route_count", Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount))])
                    self._leafs = OrderedDict()

                    self.topology_interface_flag_route_count = YList(self)
                    self._segment_path = lambda: "topology-interface-flag-route-counts"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts, [], name, value)


                class TopologyInterfaceFlagRouteCount(Entity):
                    """
                    Route count for topology with interface flag
                    set
                    
                    .. attribute:: interface_flag  (key)
                    
                    	Interface flag
                    	**type**\:  :py:class:`PimTopologyInterfaceFlag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimTopologyInterfaceFlag>`
                    
                    .. attribute:: group_ranges
                    
                    	No. of (\*,G/M) routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: active_group_ranges
                    
                    	No. of (\*,G/M) routes active in mrib
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: groute_count
                    
                    	No. of (\*,G) routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sg_route_count
                    
                    	No. of (S,G) routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sgr_route_count
                    
                    	No. of (S,G)RPT routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount, self).__init__()

                        self.yang_name = "topology-interface-flag-route-count"
                        self.yang_parent_name = "topology-interface-flag-route-counts"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['interface_flag']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('interface_flag', (YLeaf(YType.enumeration, 'interface-flag'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimTopologyInterfaceFlag', '')])),
                            ('group_ranges', (YLeaf(YType.uint32, 'group-ranges'), ['int'])),
                            ('active_group_ranges', (YLeaf(YType.uint32, 'active-group-ranges'), ['int'])),
                            ('groute_count', (YLeaf(YType.uint32, 'groute-count'), ['int'])),
                            ('sg_route_count', (YLeaf(YType.uint32, 'sg-route-count'), ['int'])),
                            ('sgr_route_count', (YLeaf(YType.uint32, 'sgr-route-count'), ['int'])),
                            ('is_node_low_memory', (YLeaf(YType.boolean, 'is-node-low-memory'), ['bool'])),
                        ])
                        self.interface_flag = None
                        self.group_ranges = None
                        self.active_group_ranges = None
                        self.groute_count = None
                        self.sg_route_count = None
                        self.sgr_route_count = None
                        self.is_node_low_memory = None
                        self._segment_path = lambda: "topology-interface-flag-route-count" + "[interface-flag='" + str(self.interface_flag) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/topology-interface-flag-route-counts/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount, ['interface_flag', 'group_ranges', 'active_group_ranges', 'groute_count', 'sg_route_count', 'sgr_route_count', 'is_node_low_memory'], name, value)


            class GroupMapSources(Entity):
                """
                PIM group\-mapping with source information
                
                .. attribute:: group_map_source
                
                	PIM Group Mapping Entry with source information
                	**type**\: list of  		 :py:class:`GroupMapSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.GroupMapSources, self).__init__()

                    self.yang_name = "group-map-sources"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("group-map-source", ("group_map_source", Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource))])
                    self._leafs = OrderedDict()

                    self.group_map_source = YList(self)
                    self._segment_path = lambda: "group-map-sources"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.DefaultContext.GroupMapSources, [], name, value)


                class GroupMapSource(Entity):
                    """
                    PIM Group Mapping Entry with source information
                    
                    .. attribute:: prefix
                    
                    	Prefix
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: client
                    
                    	Client
                    	**type**\:  :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                    
                    .. attribute:: protocol
                    
                    	Protocol
                    	**type**\:  :py:class:`PimProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimProtocol>`
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: priority
                    
                    	RP Priority
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: source_of_information
                    
                    	The source of information
                    	**type**\:  :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation>`
                    
                    .. attribute:: group_map_information
                    
                    	Group Mapping information
                    	**type**\:  :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation>`
                    
                    .. attribute:: holdtime
                    
                    	Holdtime in seconds
                    	**type**\: int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    .. attribute:: expires
                    
                    	Mapping expiry time in seconds
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: uptime
                    
                    	Mapping uptime in seconds
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource, self).__init__()

                        self.yang_name = "group-map-source"
                        self.yang_parent_name = "group-map-sources"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("source-of-information", ("source_of_information", Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation)), ("group-map-information", ("group_map_information", Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation))])
                        self._leafs = OrderedDict([
                            ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                            ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                            ('client', (YLeaf(YType.enumeration, 'client'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimClient', '')])),
                            ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimProtocol', '')])),
                            ('rp_address', (YLeaf(YType.str, 'rp-address'), ['str','str'])),
                            ('priority', (YLeaf(YType.uint32, 'priority'), ['int'])),
                            ('holdtime', (YLeaf(YType.int32, 'holdtime'), ['int'])),
                            ('expires', (YLeaf(YType.uint64, 'expires'), ['int'])),
                            ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                        ])
                        self.prefix = None
                        self.prefix_length = None
                        self.client = None
                        self.protocol = None
                        self.rp_address = None
                        self.priority = None
                        self.holdtime = None
                        self.expires = None
                        self.uptime = None

                        self.source_of_information = Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation()
                        self.source_of_information.parent = self
                        self._children_name_map["source_of_information"] = "source-of-information"

                        self.group_map_information = Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation()
                        self.group_map_information.parent = self
                        self._children_name_map["group_map_information"] = "group-map-information"
                        self._segment_path = lambda: "group-map-source"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/group-map-sources/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource, ['prefix', 'prefix_length', 'client', 'protocol', 'rp_address', 'priority', 'holdtime', 'expires', 'uptime'], name, value)


                    class SourceOfInformation(Entity):
                        """
                        The source of information
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation, self).__init__()

                            self.yang_name = "source-of-information"
                            self.yang_parent_name = "group-map-source"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "source-of-information"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/group-map-sources/group-map-source/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class GroupMapInformation(Entity):
                        """
                        Group Mapping information
                        
                        .. attribute:: prefix
                        
                        	Group range prefix
                        	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix>`
                        
                        .. attribute:: rp_address
                        
                        	Rendezvous Point Address
                        	**type**\:  :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress>`
                        
                        .. attribute:: prefix_length
                        
                        	Group range prefix length
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: client
                        
                        	Client mapping learnt from
                        	**type**\:  :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                        
                        .. attribute:: protocol
                        
                        	Protocol mode of the range
                        	**type**\:  :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: group_count
                        
                        	No. of groups in this range
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_used
                        
                        	Is this mapping being used?
                        	**type**\: bool
                        
                        .. attribute:: mrib_active
                        
                        	Is this mapping active in MRIB?
                        	**type**\: bool
                        
                        .. attribute:: is_override
                        
                        	Is this the override range?
                        	**type**\: bool
                        
                        .. attribute:: priority
                        
                        	Bootstrap priority
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation, self).__init__()

                            self.yang_name = "group-map-information"
                            self.yang_parent_name = "group-map-source"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("prefix", ("prefix", Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix)), ("rp-address", ("rp_address", Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress))])
                            self._leafs = OrderedDict([
                                ('prefix_length', (YLeaf(YType.int32, 'prefix-length'), ['int'])),
                                ('client', (YLeaf(YType.enumeration, 'client'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowRangeClient', '')])),
                                ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowProtocol', '')])),
                                ('group_count', (YLeaf(YType.uint32, 'group-count'), ['int'])),
                                ('is_used', (YLeaf(YType.boolean, 'is-used'), ['bool'])),
                                ('mrib_active', (YLeaf(YType.boolean, 'mrib-active'), ['bool'])),
                                ('is_override', (YLeaf(YType.boolean, 'is-override'), ['bool'])),
                                ('priority', (YLeaf(YType.uint32, 'priority'), ['int'])),
                            ])
                            self.prefix_length = None
                            self.client = None
                            self.protocol = None
                            self.group_count = None
                            self.is_used = None
                            self.mrib_active = None
                            self.is_override = None
                            self.priority = None

                            self.prefix = Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"

                            self.rp_address = Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"
                            self._segment_path = lambda: "group-map-information"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/group-map-sources/group-map-source/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation, ['prefix_length', 'client', 'protocol', 'group_count', 'is_used', 'mrib_active', 'is_override', 'priority'], name, value)


                        class Prefix(Entity):
                            """
                            Group range prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "group-map-information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "prefix"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/group-map-sources/group-map-source/group-map-information/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class RpAddress(Entity):
                            """
                            Rendezvous Point Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "group-map-information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "rp-address"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/group-map-sources/group-map-source/group-map-information/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class TrafficCounters(Entity):
                """
                PIM message traffic counters
                
                .. attribute:: elapsed_time
                
                	Running time for counters in seconds
                	**type**\: int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: inputs
                
                	Packets in
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: outputs
                
                	Packets out
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: format_error
                
                	Malformed packets in
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: pakman_error
                
                	Pakman packets dropped
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: standby_packets_error
                
                	Packets received in standby state
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: checksum_error
                
                	Checksum errors
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: socket_error
                
                	Socket errors
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: send_queue_full
                
                	Packets dropped since send queue was full
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: boundary_acl_rx_drop
                
                	Inc. JP dropped since boundary ACL confg
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: boundary_acl_tx_drop
                
                	Out JP dropped since boundary ACL confg
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: no_socket_connection
                
                	Packets dropped since no socket connection
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: no_source_address
                
                	Packets dropped since no source address
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_hello
                
                	Hello packets in
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_hello
                
                	Hello packets out
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_jp
                
                	Join Prune packets in
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_jp
                
                	Join Prune packets out
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_data_register
                
                	Data Register packets in
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_null_register
                
                	Null Register packets in
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_null_register
                
                	Null Register packets out
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_register_stop
                
                	Register Stop packets in
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_register_stop
                
                	Register Stop packets out
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_assert
                
                	Assert packets in
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_assert_batched
                
                	Batched Assert packets in
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_assert
                
                	Assert packets out
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_assert_batched
                
                	Batched Assert packets out
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_df_election
                
                	DF Election packets in
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_df_election
                
                	DF Election packets out
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_bsr_message
                
                	Input BSR Messages
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_bsr_message
                
                	Output BSR Messages
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_candidate_rp_advertisement
                
                	Input Candidate\-RP Advertisment
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_candidate_rp_advertisement
                
                	Output Candidate\-RP Advertisment
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_ecmp_redirect
                
                	Input Ecmp Redirect
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_ecmp_redirect
                
                	Output Ecmp Redirect
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_loop_error
                
                	Output on loopback error
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_invalid_lsm_identifier
                
                	 Invalid LSM ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_idb_error
                
                	No IDB for intf error
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_vrf_error
                
                	No VRF for idb error
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_pim_error
                
                	PIM Disabled on intf error
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_pim_version_error
                
                	Invalid PIM version error
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_join_group
                
                	Output Join Groups
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_prune_group
                
                	Output Prune Groups
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_join_prune_bytes
                
                	Output JP Bytes
                	**type**\: int
                
                	**range:** 0..4294967295
                
                	**units**\: byte
                
                .. attribute:: output_hello_bytes
                
                	Output Hello Bytes
                	**type**\: int
                
                	**range:** 0..4294967295
                
                	**units**\: byte
                
                .. attribute:: non_supported_packets
                
                	PIM non supported pckets
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: invalid_registers
                
                	PIM invalid registers received
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: invalid_join_prunes
                
                	PIM invalid Join/Prunes received
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_packman_error
                
                	Packets Dropped due to Pakman Error
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_read_socket_error
                
                	Packet Read Socket Error
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_queue_last_clear
                
                	Time in seconds since the last clear of all packet queues stats
                	**type**\: int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: packets_standby
                
                	Packets Dropped due to Standby Error
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: no_mdt_socket_connection
                
                	Packets dropped since no mdt socket connection
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_send_queue_full
                
                	Packets dropped since mdt send queue was full
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_socket_error
                
                	MDT Socket errors
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_join_tlv_sent
                
                	Data MDT Join Msgs sent
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_join_tlv_received
                
                	Data MDT Join Msgs received
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_join_bad_type
                
                	Data MDT TLV bad type
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_drop_local_source_address
                
                	Data MDT Join msgs dropped due to local source addr
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_drop_null_local_address
                
                	Data MDT Join msgs dropped due to null local addr
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_drop_no_idb
                
                	Data MDT Join msgs dropped due to idb missing
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_drop_no_vrf
                
                	Data MDT Join msgs dropped due to vrf missing
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: invalid_destination_packets
                
                	Control Packets with Invalid Destination
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_joins_drop_multiple_encapsulation
                
                	MDT Join msgs dropped due to multiple Encap limitation
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: truncated_pim_packets
                
                	Packets dropped due to truncated Joins or Prunes
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: invalid_source_encodings
                
                	Number of invalid source encodings received
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: invalid_hello_options
                
                	Number of invalid hello options received
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_queue
                
                	Packet queue state and statistics
                	**type**\: list of  		 :py:class:`PacketQueue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.TrafficCounters.PacketQueue>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.TrafficCounters, self).__init__()

                    self.yang_name = "traffic-counters"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("packet-queue", ("packet_queue", Pim.Standby.DefaultContext.TrafficCounters.PacketQueue))])
                    self._leafs = OrderedDict([
                        ('elapsed_time', (YLeaf(YType.uint32, 'elapsed-time'), ['int'])),
                        ('inputs', (YLeaf(YType.uint32, 'inputs'), ['int'])),
                        ('outputs', (YLeaf(YType.uint32, 'outputs'), ['int'])),
                        ('format_error', (YLeaf(YType.uint32, 'format-error'), ['int'])),
                        ('pakman_error', (YLeaf(YType.uint32, 'pakman-error'), ['int'])),
                        ('standby_packets_error', (YLeaf(YType.uint32, 'standby-packets-error'), ['int'])),
                        ('checksum_error', (YLeaf(YType.uint32, 'checksum-error'), ['int'])),
                        ('socket_error', (YLeaf(YType.uint32, 'socket-error'), ['int'])),
                        ('send_queue_full', (YLeaf(YType.uint32, 'send-queue-full'), ['int'])),
                        ('boundary_acl_rx_drop', (YLeaf(YType.uint32, 'boundary-acl-rx-drop'), ['int'])),
                        ('boundary_acl_tx_drop', (YLeaf(YType.uint32, 'boundary-acl-tx-drop'), ['int'])),
                        ('no_socket_connection', (YLeaf(YType.uint32, 'no-socket-connection'), ['int'])),
                        ('no_source_address', (YLeaf(YType.uint32, 'no-source-address'), ['int'])),
                        ('input_hello', (YLeaf(YType.uint32, 'input-hello'), ['int'])),
                        ('output_hello', (YLeaf(YType.uint32, 'output-hello'), ['int'])),
                        ('input_jp', (YLeaf(YType.uint32, 'input-jp'), ['int'])),
                        ('output_jp', (YLeaf(YType.uint32, 'output-jp'), ['int'])),
                        ('input_data_register', (YLeaf(YType.uint32, 'input-data-register'), ['int'])),
                        ('input_null_register', (YLeaf(YType.uint32, 'input-null-register'), ['int'])),
                        ('output_null_register', (YLeaf(YType.uint32, 'output-null-register'), ['int'])),
                        ('input_register_stop', (YLeaf(YType.uint32, 'input-register-stop'), ['int'])),
                        ('output_register_stop', (YLeaf(YType.uint32, 'output-register-stop'), ['int'])),
                        ('input_assert', (YLeaf(YType.uint32, 'input-assert'), ['int'])),
                        ('input_assert_batched', (YLeaf(YType.uint32, 'input-assert-batched'), ['int'])),
                        ('output_assert', (YLeaf(YType.uint32, 'output-assert'), ['int'])),
                        ('output_assert_batched', (YLeaf(YType.uint32, 'output-assert-batched'), ['int'])),
                        ('input_df_election', (YLeaf(YType.uint32, 'input-df-election'), ['int'])),
                        ('output_df_election', (YLeaf(YType.uint32, 'output-df-election'), ['int'])),
                        ('input_bsr_message', (YLeaf(YType.uint32, 'input-bsr-message'), ['int'])),
                        ('output_bsr_message', (YLeaf(YType.uint32, 'output-bsr-message'), ['int'])),
                        ('input_candidate_rp_advertisement', (YLeaf(YType.uint32, 'input-candidate-rp-advertisement'), ['int'])),
                        ('output_candidate_rp_advertisement', (YLeaf(YType.uint32, 'output-candidate-rp-advertisement'), ['int'])),
                        ('input_ecmp_redirect', (YLeaf(YType.uint32, 'input-ecmp-redirect'), ['int'])),
                        ('output_ecmp_redirect', (YLeaf(YType.uint32, 'output-ecmp-redirect'), ['int'])),
                        ('output_loop_error', (YLeaf(YType.uint32, 'output-loop-error'), ['int'])),
                        ('mldp_mdt_invalid_lsm_identifier', (YLeaf(YType.uint32, 'mldp-mdt-invalid-lsm-identifier'), ['int'])),
                        ('input_no_idb_error', (YLeaf(YType.uint32, 'input-no-idb-error'), ['int'])),
                        ('input_no_vrf_error', (YLeaf(YType.uint32, 'input-no-vrf-error'), ['int'])),
                        ('input_no_pim_error', (YLeaf(YType.uint32, 'input-no-pim-error'), ['int'])),
                        ('input_pim_version_error', (YLeaf(YType.uint32, 'input-pim-version-error'), ['int'])),
                        ('output_join_group', (YLeaf(YType.uint32, 'output-join-group'), ['int'])),
                        ('output_prune_group', (YLeaf(YType.uint32, 'output-prune-group'), ['int'])),
                        ('output_join_prune_bytes', (YLeaf(YType.uint32, 'output-join-prune-bytes'), ['int'])),
                        ('output_hello_bytes', (YLeaf(YType.uint32, 'output-hello-bytes'), ['int'])),
                        ('non_supported_packets', (YLeaf(YType.uint32, 'non-supported-packets'), ['int'])),
                        ('invalid_registers', (YLeaf(YType.uint32, 'invalid-registers'), ['int'])),
                        ('invalid_join_prunes', (YLeaf(YType.uint32, 'invalid-join-prunes'), ['int'])),
                        ('packet_packman_error', (YLeaf(YType.uint32, 'packet-packman-error'), ['int'])),
                        ('packet_read_socket_error', (YLeaf(YType.uint32, 'packet-read-socket-error'), ['int'])),
                        ('packet_queue_last_clear', (YLeaf(YType.uint32, 'packet-queue-last-clear'), ['int'])),
                        ('packets_standby', (YLeaf(YType.uint32, 'packets-standby'), ['int'])),
                        ('no_mdt_socket_connection', (YLeaf(YType.uint32, 'no-mdt-socket-connection'), ['int'])),
                        ('mdt_send_queue_full', (YLeaf(YType.uint32, 'mdt-send-queue-full'), ['int'])),
                        ('mdt_socket_error', (YLeaf(YType.uint32, 'mdt-socket-error'), ['int'])),
                        ('mdt_join_tlv_sent', (YLeaf(YType.uint32, 'mdt-join-tlv-sent'), ['int'])),
                        ('mdt_join_tlv_received', (YLeaf(YType.uint32, 'mdt-join-tlv-received'), ['int'])),
                        ('mdt_join_bad_type', (YLeaf(YType.uint32, 'mdt-join-bad-type'), ['int'])),
                        ('mdt_drop_local_source_address', (YLeaf(YType.uint32, 'mdt-drop-local-source-address'), ['int'])),
                        ('mdt_drop_null_local_address', (YLeaf(YType.uint32, 'mdt-drop-null-local-address'), ['int'])),
                        ('mdt_drop_no_idb', (YLeaf(YType.uint32, 'mdt-drop-no-idb'), ['int'])),
                        ('mdt_drop_no_vrf', (YLeaf(YType.uint32, 'mdt-drop-no-vrf'), ['int'])),
                        ('invalid_destination_packets', (YLeaf(YType.uint32, 'invalid-destination-packets'), ['int'])),
                        ('mdt_joins_drop_multiple_encapsulation', (YLeaf(YType.uint32, 'mdt-joins-drop-multiple-encapsulation'), ['int'])),
                        ('truncated_pim_packets', (YLeaf(YType.uint32, 'truncated-pim-packets'), ['int'])),
                        ('invalid_source_encodings', (YLeaf(YType.uint32, 'invalid-source-encodings'), ['int'])),
                        ('invalid_hello_options', (YLeaf(YType.uint32, 'invalid-hello-options'), ['int'])),
                    ])
                    self.elapsed_time = None
                    self.inputs = None
                    self.outputs = None
                    self.format_error = None
                    self.pakman_error = None
                    self.standby_packets_error = None
                    self.checksum_error = None
                    self.socket_error = None
                    self.send_queue_full = None
                    self.boundary_acl_rx_drop = None
                    self.boundary_acl_tx_drop = None
                    self.no_socket_connection = None
                    self.no_source_address = None
                    self.input_hello = None
                    self.output_hello = None
                    self.input_jp = None
                    self.output_jp = None
                    self.input_data_register = None
                    self.input_null_register = None
                    self.output_null_register = None
                    self.input_register_stop = None
                    self.output_register_stop = None
                    self.input_assert = None
                    self.input_assert_batched = None
                    self.output_assert = None
                    self.output_assert_batched = None
                    self.input_df_election = None
                    self.output_df_election = None
                    self.input_bsr_message = None
                    self.output_bsr_message = None
                    self.input_candidate_rp_advertisement = None
                    self.output_candidate_rp_advertisement = None
                    self.input_ecmp_redirect = None
                    self.output_ecmp_redirect = None
                    self.output_loop_error = None
                    self.mldp_mdt_invalid_lsm_identifier = None
                    self.input_no_idb_error = None
                    self.input_no_vrf_error = None
                    self.input_no_pim_error = None
                    self.input_pim_version_error = None
                    self.output_join_group = None
                    self.output_prune_group = None
                    self.output_join_prune_bytes = None
                    self.output_hello_bytes = None
                    self.non_supported_packets = None
                    self.invalid_registers = None
                    self.invalid_join_prunes = None
                    self.packet_packman_error = None
                    self.packet_read_socket_error = None
                    self.packet_queue_last_clear = None
                    self.packets_standby = None
                    self.no_mdt_socket_connection = None
                    self.mdt_send_queue_full = None
                    self.mdt_socket_error = None
                    self.mdt_join_tlv_sent = None
                    self.mdt_join_tlv_received = None
                    self.mdt_join_bad_type = None
                    self.mdt_drop_local_source_address = None
                    self.mdt_drop_null_local_address = None
                    self.mdt_drop_no_idb = None
                    self.mdt_drop_no_vrf = None
                    self.invalid_destination_packets = None
                    self.mdt_joins_drop_multiple_encapsulation = None
                    self.truncated_pim_packets = None
                    self.invalid_source_encodings = None
                    self.invalid_hello_options = None

                    self.packet_queue = YList(self)
                    self._segment_path = lambda: "traffic-counters"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.DefaultContext.TrafficCounters, ['elapsed_time', 'inputs', 'outputs', 'format_error', 'pakman_error', 'standby_packets_error', 'checksum_error', 'socket_error', 'send_queue_full', 'boundary_acl_rx_drop', 'boundary_acl_tx_drop', 'no_socket_connection', 'no_source_address', 'input_hello', 'output_hello', 'input_jp', 'output_jp', 'input_data_register', 'input_null_register', 'output_null_register', 'input_register_stop', 'output_register_stop', 'input_assert', 'input_assert_batched', 'output_assert', 'output_assert_batched', 'input_df_election', 'output_df_election', 'input_bsr_message', 'output_bsr_message', 'input_candidate_rp_advertisement', 'output_candidate_rp_advertisement', 'input_ecmp_redirect', 'output_ecmp_redirect', 'output_loop_error', 'mldp_mdt_invalid_lsm_identifier', 'input_no_idb_error', 'input_no_vrf_error', 'input_no_pim_error', 'input_pim_version_error', 'output_join_group', 'output_prune_group', 'output_join_prune_bytes', 'output_hello_bytes', 'non_supported_packets', 'invalid_registers', 'invalid_join_prunes', 'packet_packman_error', 'packet_read_socket_error', 'packet_queue_last_clear', 'packets_standby', 'no_mdt_socket_connection', 'mdt_send_queue_full', 'mdt_socket_error', 'mdt_join_tlv_sent', 'mdt_join_tlv_received', 'mdt_join_bad_type', 'mdt_drop_local_source_address', 'mdt_drop_null_local_address', 'mdt_drop_no_idb', 'mdt_drop_no_vrf', 'invalid_destination_packets', 'mdt_joins_drop_multiple_encapsulation', 'truncated_pim_packets', 'invalid_source_encodings', 'invalid_hello_options'], name, value)


                class PacketQueue(Entity):
                    """
                    Packet queue state and statistics
                    
                    .. attribute:: packet_queue_state
                    
                    	State of the queue
                    	**type**\:  :py:class:`PacketQueueState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState>`
                    
                    .. attribute:: packet_queue_stats
                    
                    	Statistics about the queue
                    	**type**\:  :py:class:`PacketQueueStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats>`
                    
                    .. attribute:: packet_queue_priority
                    
                    	Priority of this packet queue
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.TrafficCounters.PacketQueue, self).__init__()

                        self.yang_name = "packet-queue"
                        self.yang_parent_name = "traffic-counters"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("packet-queue-state", ("packet_queue_state", Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState)), ("packet-queue-stats", ("packet_queue_stats", Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats))])
                        self._leafs = OrderedDict([
                            ('packet_queue_priority', (YLeaf(YType.uint32, 'packet-queue-priority'), ['int'])),
                        ])
                        self.packet_queue_priority = None

                        self.packet_queue_state = Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState()
                        self.packet_queue_state.parent = self
                        self._children_name_map["packet_queue_state"] = "packet-queue-state"

                        self.packet_queue_stats = Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats()
                        self.packet_queue_stats.parent = self
                        self._children_name_map["packet_queue_stats"] = "packet-queue-stats"
                        self._segment_path = lambda: "packet-queue"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/traffic-counters/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.TrafficCounters.PacketQueue, ['packet_queue_priority'], name, value)


                    class PacketQueueState(Entity):
                        """
                        State of the queue
                        
                        .. attribute:: max_queue_size
                        
                        	Maximum size of queue in bytes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: byte
                        
                        .. attribute:: queue_size_bytes
                        
                        	Size of queue in bytes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: byte
                        
                        .. attribute:: queue_size_packets
                        
                        	Size of queue in number of packets
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState, self).__init__()

                            self.yang_name = "packet-queue-state"
                            self.yang_parent_name = "packet-queue"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('max_queue_size', (YLeaf(YType.uint32, 'max-queue-size'), ['int'])),
                                ('queue_size_bytes', (YLeaf(YType.uint32, 'queue-size-bytes'), ['int'])),
                                ('queue_size_packets', (YLeaf(YType.uint32, 'queue-size-packets'), ['int'])),
                            ])
                            self.max_queue_size = None
                            self.queue_size_bytes = None
                            self.queue_size_packets = None
                            self._segment_path = lambda: "packet-queue-state"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/traffic-counters/packet-queue/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState, ['max_queue_size', 'queue_size_bytes', 'queue_size_packets'], name, value)


                    class PacketQueueStats(Entity):
                        """
                        Statistics about the queue
                        
                        .. attribute:: enqueued_packets
                        
                        	Total number of packets enqueued to this queue
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: dequeued_packets
                        
                        	Total number of packets dequeued from this queue
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: high_water_mark_packets
                        
                        	Highest number of packets enqueued in this queue
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: high_water_mark_bytes
                        
                        	Highest number of bytes enqueued in this queue
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: byte
                        
                        .. attribute:: tail_drops
                        
                        	Number packets dropped from this queue due to max size
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats, self).__init__()

                            self.yang_name = "packet-queue-stats"
                            self.yang_parent_name = "packet-queue"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('enqueued_packets', (YLeaf(YType.uint32, 'enqueued-packets'), ['int'])),
                                ('dequeued_packets', (YLeaf(YType.uint32, 'dequeued-packets'), ['int'])),
                                ('high_water_mark_packets', (YLeaf(YType.uint32, 'high-water-mark-packets'), ['int'])),
                                ('high_water_mark_bytes', (YLeaf(YType.uint32, 'high-water-mark-bytes'), ['int'])),
                                ('tail_drops', (YLeaf(YType.uint32, 'tail-drops'), ['int'])),
                            ])
                            self.enqueued_packets = None
                            self.dequeued_packets = None
                            self.high_water_mark_packets = None
                            self.high_water_mark_bytes = None
                            self.tail_drops = None
                            self._segment_path = lambda: "packet-queue-stats"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/traffic-counters/packet-queue/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats, ['enqueued_packets', 'dequeued_packets', 'high_water_mark_packets', 'high_water_mark_bytes', 'tail_drops'], name, value)


            class GroupMapRpfs(Entity):
                """
                PIM group mapping information
                
                .. attribute:: group_map_rpf
                
                	PIM group mapping entry
                	**type**\: list of  		 :py:class:`GroupMapRpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.GroupMapRpfs, self).__init__()

                    self.yang_name = "group-map-rpfs"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("group-map-rpf", ("group_map_rpf", Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf))])
                    self._leafs = OrderedDict()

                    self.group_map_rpf = YList(self)
                    self._segment_path = lambda: "group-map-rpfs"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.DefaultContext.GroupMapRpfs, [], name, value)


                class GroupMapRpf(Entity):
                    """
                    PIM group mapping entry
                    
                    .. attribute:: prefix
                    
                    	Prefix
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: client
                    
                    	Client
                    	**type**\:  :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                    
                    .. attribute:: protocol
                    
                    	Protocol
                    	**type**\:  :py:class:`PimProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimProtocol>`
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: rp_priority
                    
                    	RP priority
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rpf_neighbor
                    
                    	RPF neighbor to the RP
                    	**type**\:  :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor>`
                    
                    .. attribute:: group_map_information
                    
                    	Group Mapping information
                    	**type**\:  :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation>`
                    
                    .. attribute:: are_we_rp
                    
                    	Are we the RP?
                    	**type**\: bool
                    
                    .. attribute:: rpf_interface_name
                    
                    	RPF interface to the RP
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: rpf_vrf_name
                    
                    	RPF VRF Name
                    	**type**\: str
                    
                    	**length:** 0..33
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf, self).__init__()

                        self.yang_name = "group-map-rpf"
                        self.yang_parent_name = "group-map-rpfs"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("rpf-neighbor", ("rpf_neighbor", Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor)), ("group-map-information", ("group_map_information", Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation))])
                        self._leafs = OrderedDict([
                            ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                            ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                            ('client', (YLeaf(YType.enumeration, 'client'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimClient', '')])),
                            ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimProtocol', '')])),
                            ('rp_address', (YLeaf(YType.str, 'rp-address'), ['str','str'])),
                            ('rp_priority', (YLeaf(YType.uint32, 'rp-priority'), ['int'])),
                            ('are_we_rp', (YLeaf(YType.boolean, 'are-we-rp'), ['bool'])),
                            ('rpf_interface_name', (YLeaf(YType.str, 'rpf-interface-name'), ['str'])),
                            ('rpf_vrf_name', (YLeaf(YType.str, 'rpf-vrf-name'), ['str'])),
                        ])
                        self.prefix = None
                        self.prefix_length = None
                        self.client = None
                        self.protocol = None
                        self.rp_address = None
                        self.rp_priority = None
                        self.are_we_rp = None
                        self.rpf_interface_name = None
                        self.rpf_vrf_name = None

                        self.rpf_neighbor = Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor()
                        self.rpf_neighbor.parent = self
                        self._children_name_map["rpf_neighbor"] = "rpf-neighbor"

                        self.group_map_information = Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation()
                        self.group_map_information.parent = self
                        self._children_name_map["group_map_information"] = "group-map-information"
                        self._segment_path = lambda: "group-map-rpf"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/group-map-rpfs/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf, ['prefix', 'prefix_length', 'client', 'protocol', 'rp_address', 'rp_priority', 'are_we_rp', 'rpf_interface_name', 'rpf_vrf_name'], name, value)


                    class RpfNeighbor(Entity):
                        """
                        RPF neighbor to the RP
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor, self).__init__()

                            self.yang_name = "rpf-neighbor"
                            self.yang_parent_name = "group-map-rpf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "rpf-neighbor"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/group-map-rpfs/group-map-rpf/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class GroupMapInformation(Entity):
                        """
                        Group Mapping information
                        
                        .. attribute:: prefix
                        
                        	Group range prefix
                        	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix>`
                        
                        .. attribute:: rp_address
                        
                        	Rendezvous Point Address
                        	**type**\:  :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress>`
                        
                        .. attribute:: prefix_length
                        
                        	Group range prefix length
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: client
                        
                        	Client mapping learnt from
                        	**type**\:  :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                        
                        .. attribute:: protocol
                        
                        	Protocol mode of the range
                        	**type**\:  :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: group_count
                        
                        	No. of groups in this range
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_used
                        
                        	Is this mapping being used?
                        	**type**\: bool
                        
                        .. attribute:: mrib_active
                        
                        	Is this mapping active in MRIB?
                        	**type**\: bool
                        
                        .. attribute:: is_override
                        
                        	Is this the override range?
                        	**type**\: bool
                        
                        .. attribute:: priority
                        
                        	Bootstrap priority
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation, self).__init__()

                            self.yang_name = "group-map-information"
                            self.yang_parent_name = "group-map-rpf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("prefix", ("prefix", Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix)), ("rp-address", ("rp_address", Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress))])
                            self._leafs = OrderedDict([
                                ('prefix_length', (YLeaf(YType.int32, 'prefix-length'), ['int'])),
                                ('client', (YLeaf(YType.enumeration, 'client'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowRangeClient', '')])),
                                ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowProtocol', '')])),
                                ('group_count', (YLeaf(YType.uint32, 'group-count'), ['int'])),
                                ('is_used', (YLeaf(YType.boolean, 'is-used'), ['bool'])),
                                ('mrib_active', (YLeaf(YType.boolean, 'mrib-active'), ['bool'])),
                                ('is_override', (YLeaf(YType.boolean, 'is-override'), ['bool'])),
                                ('priority', (YLeaf(YType.uint32, 'priority'), ['int'])),
                            ])
                            self.prefix_length = None
                            self.client = None
                            self.protocol = None
                            self.group_count = None
                            self.is_used = None
                            self.mrib_active = None
                            self.is_override = None
                            self.priority = None

                            self.prefix = Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"

                            self.rp_address = Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"
                            self._segment_path = lambda: "group-map-information"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/group-map-rpfs/group-map-rpf/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation, ['prefix_length', 'client', 'protocol', 'group_count', 'is_used', 'mrib_active', 'is_override', 'priority'], name, value)


                        class Prefix(Entity):
                            """
                            Group range prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "group-map-information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "prefix"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/group-map-rpfs/group-map-rpf/group-map-information/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class RpAddress(Entity):
                            """
                            Rendezvous Point Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "group-map-information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "rp-address"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/group-map-rpfs/group-map-rpf/group-map-information/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class Summary(Entity):
                """
                PIM summary
                
                .. attribute:: route_limit
                
                	Maximum routes
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_count
                
                	Current routes
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_low_water_mark
                
                	The number of routes below which the throttle on route creation will be lifted
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_route_limit_reached
                
                	Is route creation throttled
                	**type**\: bool
                
                .. attribute:: topology_interface_state_limit
                
                	Maximum Topology Interface State count
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_count
                
                	Current Topology Interface State count
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: rxi_low_water_mark
                
                	The rxi below which the throttle on interface creation will be lifted
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: rxi_limit_reached
                
                	Is interface creation throttled
                	**type**\: bool
                
                .. attribute:: register_limit
                
                	Maximum registers
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_count
                
                	Current registers
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_limit_reached
                
                	Is PIM SM register handling throttled
                	**type**\: bool
                
                .. attribute:: ranges_limit
                
                	Maximum group ranges from Autorp
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: ranges_count
                
                	Current group ranges from Autorp
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: ranges_threshold
                
                	OOR theshold of grange ranges from AutoRP
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_ranges_limit_reached
                
                	Is Auto\-RP group\-to\-RP mapping range creation throttled
                	**type**\: bool
                
                .. attribute:: bsr_ranges_limit
                
                	Maximum group ranges from BSR
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_ranges_count
                
                	Current group ranges from BSR
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_range_threshold
                
                	Threshold group range from BSR
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_bsr_ranges_threshold_reached
                
                	Is VRF\-specific BSR group\-to\-RP mapping range creation throttled
                	**type**\: bool
                
                .. attribute:: bsr_candidate_rp_set_limit
                
                	Maximum crp\-set from BSR
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_candidate_rp_set_count
                
                	Current crp\-set count from BSR
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_candidate_rp_set_threshold
                
                	Threshold crp\-set from BSR
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_maximum_enforcement_disabled
                
                	Is maximum enforcement disabled
                	**type**\: bool
                
                .. attribute:: is_node_low_memory
                
                	Is node in low memory condition
                	**type**\: bool
                
                .. attribute:: route_threshold
                
                	Threshold routes
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_auto_rp_ranges_limit
                
                	Global Auto\-RP maximum group ranges
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_global_auto_rp_ranges_limit_reached
                
                	Is global AutoRP group\-to\-RP mapping range creation throttled
                	**type**\: bool
                
                .. attribute:: global_bsr_ranges_limit
                
                	Global BSR maximum group ranges
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_count
                
                	Global BSR current group ranges
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_threshold
                
                	Global BSR Threshold group ranges
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_global_bsr_ranges_limit_reached
                
                	Is global BSR group\-to\-RP mapping range creation throttled
                	**type**\: bool
                
                .. attribute:: global_bsr_candidate_rp_set_limit
                
                	Global BSR maximum crp\-set
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_count
                
                	Global BSR current crp\-set count
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_threshold
                
                	Global BSR Threshold crp\-set
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_global_route_limit_reached
                
                	Is global route creation throttled
                	**type**\: bool
                
                .. attribute:: topology_interface_state_threshold
                
                	Topology Interface State threshold
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_global_rxi_limit_reached
                
                	Is global interface creation throttled
                	**type**\: bool
                
                .. attribute:: register_threshold
                
                	Threshold registers
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_register_limit
                
                	Maximum global registers
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_global_register_limit_reached
                
                	Is global PIM SM register handling throttled
                	**type**\: bool
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.Summary, self).__init__()

                    self.yang_name = "summary"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('route_limit', (YLeaf(YType.uint32, 'route-limit'), ['int'])),
                        ('route_count', (YLeaf(YType.uint32, 'route-count'), ['int'])),
                        ('route_low_water_mark', (YLeaf(YType.uint32, 'route-low-water-mark'), ['int'])),
                        ('is_route_limit_reached', (YLeaf(YType.boolean, 'is-route-limit-reached'), ['bool'])),
                        ('topology_interface_state_limit', (YLeaf(YType.uint32, 'topology-interface-state-limit'), ['int'])),
                        ('topology_interface_state_count', (YLeaf(YType.uint32, 'topology-interface-state-count'), ['int'])),
                        ('rxi_low_water_mark', (YLeaf(YType.uint32, 'rxi-low-water-mark'), ['int'])),
                        ('rxi_limit_reached', (YLeaf(YType.boolean, 'rxi-limit-reached'), ['bool'])),
                        ('register_limit', (YLeaf(YType.uint32, 'register-limit'), ['int'])),
                        ('register_count', (YLeaf(YType.uint32, 'register-count'), ['int'])),
                        ('register_limit_reached', (YLeaf(YType.boolean, 'register-limit-reached'), ['bool'])),
                        ('ranges_limit', (YLeaf(YType.uint32, 'ranges-limit'), ['int'])),
                        ('ranges_count', (YLeaf(YType.uint32, 'ranges-count'), ['int'])),
                        ('ranges_threshold', (YLeaf(YType.uint32, 'ranges-threshold'), ['int'])),
                        ('is_ranges_limit_reached', (YLeaf(YType.boolean, 'is-ranges-limit-reached'), ['bool'])),
                        ('bsr_ranges_limit', (YLeaf(YType.uint32, 'bsr-ranges-limit'), ['int'])),
                        ('bsr_ranges_count', (YLeaf(YType.uint32, 'bsr-ranges-count'), ['int'])),
                        ('bsr_range_threshold', (YLeaf(YType.uint32, 'bsr-range-threshold'), ['int'])),
                        ('is_bsr_ranges_threshold_reached', (YLeaf(YType.boolean, 'is-bsr-ranges-threshold-reached'), ['bool'])),
                        ('bsr_candidate_rp_set_limit', (YLeaf(YType.uint32, 'bsr-candidate-rp-set-limit'), ['int'])),
                        ('bsr_candidate_rp_set_count', (YLeaf(YType.uint32, 'bsr-candidate-rp-set-count'), ['int'])),
                        ('bsr_candidate_rp_set_threshold', (YLeaf(YType.uint32, 'bsr-candidate-rp-set-threshold'), ['int'])),
                        ('is_maximum_enforcement_disabled', (YLeaf(YType.boolean, 'is-maximum-enforcement-disabled'), ['bool'])),
                        ('is_node_low_memory', (YLeaf(YType.boolean, 'is-node-low-memory'), ['bool'])),
                        ('route_threshold', (YLeaf(YType.uint32, 'route-threshold'), ['int'])),
                        ('global_auto_rp_ranges_limit', (YLeaf(YType.uint32, 'global-auto-rp-ranges-limit'), ['int'])),
                        ('is_global_auto_rp_ranges_limit_reached', (YLeaf(YType.boolean, 'is-global-auto-rp-ranges-limit-reached'), ['bool'])),
                        ('global_bsr_ranges_limit', (YLeaf(YType.uint32, 'global-bsr-ranges-limit'), ['int'])),
                        ('global_bsr_ranges_count', (YLeaf(YType.uint32, 'global-bsr-ranges-count'), ['int'])),
                        ('global_bsr_ranges_threshold', (YLeaf(YType.uint32, 'global-bsr-ranges-threshold'), ['int'])),
                        ('is_global_bsr_ranges_limit_reached', (YLeaf(YType.boolean, 'is-global-bsr-ranges-limit-reached'), ['bool'])),
                        ('global_bsr_candidate_rp_set_limit', (YLeaf(YType.uint32, 'global-bsr-candidate-rp-set-limit'), ['int'])),
                        ('global_bsr_candidate_rp_set_count', (YLeaf(YType.uint32, 'global-bsr-candidate-rp-set-count'), ['int'])),
                        ('global_bsr_candidate_rp_set_threshold', (YLeaf(YType.uint32, 'global-bsr-candidate-rp-set-threshold'), ['int'])),
                        ('is_global_route_limit_reached', (YLeaf(YType.boolean, 'is-global-route-limit-reached'), ['bool'])),
                        ('topology_interface_state_threshold', (YLeaf(YType.uint32, 'topology-interface-state-threshold'), ['int'])),
                        ('is_global_rxi_limit_reached', (YLeaf(YType.boolean, 'is-global-rxi-limit-reached'), ['bool'])),
                        ('register_threshold', (YLeaf(YType.uint32, 'register-threshold'), ['int'])),
                        ('global_register_limit', (YLeaf(YType.uint32, 'global-register-limit'), ['int'])),
                        ('is_global_register_limit_reached', (YLeaf(YType.boolean, 'is-global-register-limit-reached'), ['bool'])),
                    ])
                    self.route_limit = None
                    self.route_count = None
                    self.route_low_water_mark = None
                    self.is_route_limit_reached = None
                    self.topology_interface_state_limit = None
                    self.topology_interface_state_count = None
                    self.rxi_low_water_mark = None
                    self.rxi_limit_reached = None
                    self.register_limit = None
                    self.register_count = None
                    self.register_limit_reached = None
                    self.ranges_limit = None
                    self.ranges_count = None
                    self.ranges_threshold = None
                    self.is_ranges_limit_reached = None
                    self.bsr_ranges_limit = None
                    self.bsr_ranges_count = None
                    self.bsr_range_threshold = None
                    self.is_bsr_ranges_threshold_reached = None
                    self.bsr_candidate_rp_set_limit = None
                    self.bsr_candidate_rp_set_count = None
                    self.bsr_candidate_rp_set_threshold = None
                    self.is_maximum_enforcement_disabled = None
                    self.is_node_low_memory = None
                    self.route_threshold = None
                    self.global_auto_rp_ranges_limit = None
                    self.is_global_auto_rp_ranges_limit_reached = None
                    self.global_bsr_ranges_limit = None
                    self.global_bsr_ranges_count = None
                    self.global_bsr_ranges_threshold = None
                    self.is_global_bsr_ranges_limit_reached = None
                    self.global_bsr_candidate_rp_set_limit = None
                    self.global_bsr_candidate_rp_set_count = None
                    self.global_bsr_candidate_rp_set_threshold = None
                    self.is_global_route_limit_reached = None
                    self.topology_interface_state_threshold = None
                    self.is_global_rxi_limit_reached = None
                    self.register_threshold = None
                    self.global_register_limit = None
                    self.is_global_register_limit_reached = None
                    self._segment_path = lambda: "summary"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.DefaultContext.Summary, ['route_limit', 'route_count', 'route_low_water_mark', 'is_route_limit_reached', 'topology_interface_state_limit', 'topology_interface_state_count', 'rxi_low_water_mark', 'rxi_limit_reached', 'register_limit', 'register_count', 'register_limit_reached', 'ranges_limit', 'ranges_count', 'ranges_threshold', 'is_ranges_limit_reached', 'bsr_ranges_limit', 'bsr_ranges_count', 'bsr_range_threshold', 'is_bsr_ranges_threshold_reached', 'bsr_candidate_rp_set_limit', 'bsr_candidate_rp_set_count', 'bsr_candidate_rp_set_threshold', 'is_maximum_enforcement_disabled', 'is_node_low_memory', 'route_threshold', 'global_auto_rp_ranges_limit', 'is_global_auto_rp_ranges_limit_reached', 'global_bsr_ranges_limit', 'global_bsr_ranges_count', 'global_bsr_ranges_threshold', 'is_global_bsr_ranges_limit_reached', 'global_bsr_candidate_rp_set_limit', 'global_bsr_candidate_rp_set_count', 'global_bsr_candidate_rp_set_threshold', 'is_global_route_limit_reached', 'topology_interface_state_threshold', 'is_global_rxi_limit_reached', 'register_threshold', 'global_register_limit', 'is_global_register_limit_reached'], name, value)


            class Gre(Entity):
                """
                GRE information
                
                .. attribute:: gre_hashes
                
                	GRE hash
                	**type**\:  :py:class:`GreHashes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Gre.GreHashes>`
                
                .. attribute:: gre_next_hops
                
                	GRE destination neighbor table
                	**type**\:  :py:class:`GreNextHops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Gre.GreNextHops>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.Gre, self).__init__()

                    self.yang_name = "gre"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("gre-hashes", ("gre_hashes", Pim.Standby.DefaultContext.Gre.GreHashes)), ("gre-next-hops", ("gre_next_hops", Pim.Standby.DefaultContext.Gre.GreNextHops))])
                    self._leafs = OrderedDict()

                    self.gre_hashes = Pim.Standby.DefaultContext.Gre.GreHashes()
                    self.gre_hashes.parent = self
                    self._children_name_map["gre_hashes"] = "gre-hashes"

                    self.gre_next_hops = Pim.Standby.DefaultContext.Gre.GreNextHops()
                    self.gre_next_hops.parent = self
                    self._children_name_map["gre_next_hops"] = "gre-next-hops"
                    self._segment_path = lambda: "gre"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.DefaultContext.Gre, [], name, value)


                class GreHashes(Entity):
                    """
                    GRE hash
                    
                    .. attribute:: gre_hash
                    
                    	PIM GRE Hashed Underlying Interface
                    	**type**\: list of  		 :py:class:`GreHash <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Gre.GreHashes.GreHash>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.Gre.GreHashes, self).__init__()

                        self.yang_name = "gre-hashes"
                        self.yang_parent_name = "gre"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("gre-hash", ("gre_hash", Pim.Standby.DefaultContext.Gre.GreHashes.GreHash))])
                        self._leafs = OrderedDict()

                        self.gre_hash = YList(self)
                        self._segment_path = lambda: "gre-hashes"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/gre/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.Gre.GreHashes, [], name, value)


                    class GreHash(Entity):
                        """
                        PIM GRE Hashed Underlying Interface
                        
                        .. attribute:: source_address  (key)
                        
                        	Source address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: destination_address  (key)
                        
                        	Destination address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ifname  (key)
                        
                        	GRE Tunnel Interface
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: next_hop_interface
                        
                        	Next hop neighbor interface
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Gre.GreHashes.GreHash, self).__init__()

                            self.yang_name = "gre-hash"
                            self.yang_parent_name = "gre-hashes"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['source_address','destination_address','ifname']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('source_address', (YLeaf(YType.str, 'source-address'), ['str','str'])),
                                ('destination_address', (YLeaf(YType.str, 'destination-address'), ['str','str'])),
                                ('ifname', (YLeaf(YType.str, 'ifname'), ['str'])),
                                ('next_hop_interface', (YLeaf(YType.str, 'next-hop-interface'), ['str'])),
                            ])
                            self.source_address = None
                            self.destination_address = None
                            self.ifname = None
                            self.next_hop_interface = None
                            self._segment_path = lambda: "gre-hash" + "[source-address='" + str(self.source_address) + "']" + "[destination-address='" + str(self.destination_address) + "']" + "[ifname='" + str(self.ifname) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/gre/gre-hashes/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.Gre.GreHashes.GreHash, ['source_address', 'destination_address', 'ifname', 'next_hop_interface'], name, value)


                class GreNextHops(Entity):
                    """
                    GRE destination neighbor table
                    
                    .. attribute:: gre_next_hop
                    
                    	PIM GRE address next\-hop information
                    	**type**\: list of  		 :py:class:`GreNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.Gre.GreNextHops, self).__init__()

                        self.yang_name = "gre-next-hops"
                        self.yang_parent_name = "gre"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("gre-next-hop", ("gre_next_hop", Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop))])
                        self._leafs = OrderedDict()

                        self.gre_next_hop = YList(self)
                        self._segment_path = lambda: "gre-next-hops"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/gre/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.Gre.GreNextHops, [], name, value)


                    class GreNextHop(Entity):
                        """
                        PIM GRE address next\-hop information
                        
                        .. attribute:: destination_address  (key)
                        
                        	GRE destination address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: registered_address
                        
                        	Address registered
                        	**type**\:  :py:class:`RegisteredAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress>`
                        
                        .. attribute:: metric
                        
                        	Metric
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: metric_preference
                        
                        	Metric preference
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_connected
                        
                        	Are we connected ?
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: gre_path
                        
                        	GRE Paths list
                        	**type**\: list of  		 :py:class:`GrePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop, self).__init__()

                            self.yang_name = "gre-next-hop"
                            self.yang_parent_name = "gre-next-hops"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['destination_address']
                            self._child_classes = OrderedDict([("registered-address", ("registered_address", Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress)), ("gre-path", ("gre_path", Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath))])
                            self._leafs = OrderedDict([
                                ('destination_address', (YLeaf(YType.str, 'destination-address'), ['str','str'])),
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                ('metric_preference', (YLeaf(YType.uint32, 'metric-preference'), ['int'])),
                                ('is_connected', (YLeaf(YType.uint8, 'is-connected'), ['int'])),
                            ])
                            self.destination_address = None
                            self.metric = None
                            self.metric_preference = None
                            self.is_connected = None

                            self.registered_address = Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress()
                            self.registered_address.parent = self
                            self._children_name_map["registered_address"] = "registered-address"

                            self.gre_path = YList(self)
                            self._segment_path = lambda: "gre-next-hop" + "[destination-address='" + str(self.destination_address) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/gre/gre-next-hops/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop, ['destination_address', 'metric', 'metric_preference', 'is_connected'], name, value)


                        class RegisteredAddress(Entity):
                            """
                            Address registered
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress, self).__init__()

                                self.yang_name = "registered-address"
                                self.yang_parent_name = "gre-next-hop"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "registered-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class GrePath(Entity):
                            """
                            GRE Paths list
                            
                            .. attribute:: gre_neighbor
                            
                            	GRE neighbor
                            	**type**\:  :py:class:`GreNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor>`
                            
                            .. attribute:: gre_next_hop
                            
                            	GRE nexthop
                            	**type**\:  :py:class:`GreNextHop_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop_>`
                            
                            .. attribute:: gre_interface_name
                            
                            	GRE Interface
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: is_gre_interface_disabled
                            
                            	Is the gre interface disabled ?
                            	**type**\: bool
                            
                            .. attribute:: is_via_lsm
                            
                            	Via LSM
                            	**type**\: bool
                            
                            .. attribute:: is_connector_attribute_present
                            
                            	Connector attribute present
                            	**type**\: bool
                            
                            .. attribute:: extranet_vrf_name
                            
                            	Extranet VRF name
                            	**type**\: str
                            
                            	**length:** 0..33
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath, self).__init__()

                                self.yang_name = "gre-path"
                                self.yang_parent_name = "gre-next-hop"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("gre-neighbor", ("gre_neighbor", Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor)), ("gre-next-hop", ("gre_next_hop", Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop_))])
                                self._leafs = OrderedDict([
                                    ('gre_interface_name', (YLeaf(YType.str, 'gre-interface-name'), ['str'])),
                                    ('is_gre_interface_disabled', (YLeaf(YType.boolean, 'is-gre-interface-disabled'), ['bool'])),
                                    ('is_via_lsm', (YLeaf(YType.boolean, 'is-via-lsm'), ['bool'])),
                                    ('is_connector_attribute_present', (YLeaf(YType.boolean, 'is-connector-attribute-present'), ['bool'])),
                                    ('extranet_vrf_name', (YLeaf(YType.str, 'extranet-vrf-name'), ['str'])),
                                ])
                                self.gre_interface_name = None
                                self.is_gre_interface_disabled = None
                                self.is_via_lsm = None
                                self.is_connector_attribute_present = None
                                self.extranet_vrf_name = None

                                self.gre_neighbor = Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor()
                                self.gre_neighbor.parent = self
                                self._children_name_map["gre_neighbor"] = "gre-neighbor"

                                self.gre_next_hop = Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop_()
                                self.gre_next_hop.parent = self
                                self._children_name_map["gre_next_hop"] = "gre-next-hop"
                                self._segment_path = lambda: "gre-path"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath, ['gre_interface_name', 'is_gre_interface_disabled', 'is_via_lsm', 'is_connector_attribute_present', 'extranet_vrf_name'], name, value)


                            class GreNeighbor(Entity):
                                """
                                GRE neighbor
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor, self).__init__()

                                    self.yang_name = "gre-neighbor"
                                    self.yang_parent_name = "gre-path"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "gre-neighbor"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                            class GreNextHop_(Entity):
                                """
                                GRE nexthop
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop_, self).__init__()

                                    self.yang_name = "gre-next-hop"
                                    self.yang_parent_name = "gre-path"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "gre-next-hop"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop_, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class BidirDfWinners(Entity):
                """
                Bidirectional PIM DF election winner table
                
                .. attribute:: bidir_df_winner
                
                	Bidirectional PIM DF election table entry
                	**type**\: list of  		 :py:class:`BidirDfWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.BidirDfWinners, self).__init__()

                    self.yang_name = "bidir-df-winners"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("bidir-df-winner", ("bidir_df_winner", Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner))])
                    self._leafs = OrderedDict()

                    self.bidir_df_winner = YList(self)
                    self._segment_path = lambda: "bidir-df-winners"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.DefaultContext.BidirDfWinners, [], name, value)


                class BidirDfWinner(Entity):
                    """
                    Bidirectional PIM DF election table entry
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: rp_address_xr
                    
                    	RP Address
                    	**type**\:  :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr>`
                    
                    .. attribute:: df_winner
                    
                    	DF Winner
                    	**type**\:  :py:class:`DfWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner>`
                    
                    .. attribute:: pim_interface_name
                    
                    	Interface Name
                    	**type**\: str
                    
                    .. attribute:: are_we_df
                    
                    	Are we DF
                    	**type**\: bool
                    
                    .. attribute:: rp_lan
                    
                    	Is this the RP LAN
                    	**type**\: bool
                    
                    .. attribute:: metric
                    
                    	Metric
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: metric_preference
                    
                    	Metric Preference
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner, self).__init__()

                        self.yang_name = "bidir-df-winner"
                        self.yang_parent_name = "bidir-df-winners"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("rp-address-xr", ("rp_address_xr", Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr)), ("df-winner", ("df_winner", Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner))])
                        self._leafs = OrderedDict([
                            ('rp_address', (YLeaf(YType.str, 'rp-address'), ['str','str'])),
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                            ('pim_interface_name', (YLeaf(YType.str, 'pim-interface-name'), ['str'])),
                            ('are_we_df', (YLeaf(YType.boolean, 'are-we-df'), ['bool'])),
                            ('rp_lan', (YLeaf(YType.boolean, 'rp-lan'), ['bool'])),
                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                            ('metric_preference', (YLeaf(YType.uint32, 'metric-preference'), ['int'])),
                            ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                        ])
                        self.rp_address = None
                        self.interface_name = None
                        self.pim_interface_name = None
                        self.are_we_df = None
                        self.rp_lan = None
                        self.metric = None
                        self.metric_preference = None
                        self.uptime = None

                        self.rp_address_xr = Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr()
                        self.rp_address_xr.parent = self
                        self._children_name_map["rp_address_xr"] = "rp-address-xr"

                        self.df_winner = Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner()
                        self.df_winner.parent = self
                        self._children_name_map["df_winner"] = "df-winner"
                        self._segment_path = lambda: "bidir-df-winner"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/bidir-df-winners/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner, ['rp_address', 'interface_name', 'pim_interface_name', 'are_we_df', 'rp_lan', 'metric', 'metric_preference', 'uptime'], name, value)


                    class RpAddressXr(Entity):
                        """
                        RP Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr, self).__init__()

                            self.yang_name = "rp-address-xr"
                            self.yang_parent_name = "bidir-df-winner"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "rp-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/bidir-df-winners/bidir-df-winner/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class DfWinner(Entity):
                        """
                        DF Winner
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner, self).__init__()

                            self.yang_name = "df-winner"
                            self.yang_parent_name = "bidir-df-winner"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "df-winner"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/bidir-df-winners/bidir-df-winner/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class TableContexts(Entity):
                """
                PIM table context list
                
                .. attribute:: table_context
                
                	PIM table context information
                	**type**\: list of  		 :py:class:`TableContext <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.TableContexts.TableContext>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.TableContexts, self).__init__()

                    self.yang_name = "table-contexts"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("table-context", ("table_context", Pim.Standby.DefaultContext.TableContexts.TableContext))])
                    self._leafs = OrderedDict()

                    self.table_context = YList(self)
                    self._segment_path = lambda: "table-contexts"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.DefaultContext.TableContexts, [], name, value)


                class TableContext(Entity):
                    """
                    PIM table context information
                    
                    .. attribute:: saf_name
                    
                    	SAF name
                    	**type**\:  :py:class:`PimSafi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimSafi>`
                    
                    .. attribute:: topology_name
                    
                    	Topology name
                    	**type**\: str
                    
                    	**length:** 1..32
                    
                    .. attribute:: afi
                    
                    	AFI
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: safi
                    
                    	SAFI
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_name
                    
                    	Table name
                    	**type**\: str
                    
                    .. attribute:: vrf_id
                    
                    	VRF ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_id
                    
                    	Table ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_active
                    
                    	Active status
                    	**type**\: bool
                    
                    .. attribute:: is_ital_registration_done
                    
                    	ITAL reg status
                    	**type**\: bool
                    
                    .. attribute:: is_rib_registration_done
                    
                    	RIB reg status
                    	**type**\: bool
                    
                    .. attribute:: is_rib_convergence_received
                    
                    	RIB Convergence receive status
                    	**type**\: bool
                    
                    .. attribute:: is_rib_convergence
                    
                    	RIB Convergence status
                    	**type**\: bool
                    
                    .. attribute:: rpf_registrations
                    
                    	RPF Registration count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.TableContexts.TableContext, self).__init__()

                        self.yang_name = "table-context"
                        self.yang_parent_name = "table-contexts"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('saf_name', (YLeaf(YType.enumeration, 'saf-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimSafi', '')])),
                            ('topology_name', (YLeaf(YType.str, 'topology-name'), ['str'])),
                            ('afi', (YLeaf(YType.uint32, 'afi'), ['int'])),
                            ('safi', (YLeaf(YType.uint32, 'safi'), ['int'])),
                            ('table_name', (YLeaf(YType.str, 'table-name'), ['str'])),
                            ('vrf_id', (YLeaf(YType.uint32, 'vrf-id'), ['int'])),
                            ('table_id', (YLeaf(YType.uint32, 'table-id'), ['int'])),
                            ('is_active', (YLeaf(YType.boolean, 'is-active'), ['bool'])),
                            ('is_ital_registration_done', (YLeaf(YType.boolean, 'is-ital-registration-done'), ['bool'])),
                            ('is_rib_registration_done', (YLeaf(YType.boolean, 'is-rib-registration-done'), ['bool'])),
                            ('is_rib_convergence_received', (YLeaf(YType.boolean, 'is-rib-convergence-received'), ['bool'])),
                            ('is_rib_convergence', (YLeaf(YType.boolean, 'is-rib-convergence'), ['bool'])),
                            ('rpf_registrations', (YLeaf(YType.uint32, 'rpf-registrations'), ['int'])),
                        ])
                        self.saf_name = None
                        self.topology_name = None
                        self.afi = None
                        self.safi = None
                        self.table_name = None
                        self.vrf_id = None
                        self.table_id = None
                        self.is_active = None
                        self.is_ital_registration_done = None
                        self.is_rib_registration_done = None
                        self.is_rib_convergence_received = None
                        self.is_rib_convergence = None
                        self.rpf_registrations = None
                        self._segment_path = lambda: "table-context"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/table-contexts/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.TableContexts.TableContext, ['saf_name', 'topology_name', 'afi', 'safi', 'table_name', 'vrf_id', 'table_id', 'is_active', 'is_ital_registration_done', 'is_rib_registration_done', 'is_rib_convergence_received', 'is_rib_convergence', 'rpf_registrations'], name, value)


            class NeighborSummaries(Entity):
                """
                PIM neighbor summary table
                
                .. attribute:: neighbor_summary
                
                	PIM neighbor summary information
                	**type**\: list of  		 :py:class:`NeighborSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.NeighborSummaries.NeighborSummary>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.NeighborSummaries, self).__init__()

                    self.yang_name = "neighbor-summaries"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("neighbor-summary", ("neighbor_summary", Pim.Standby.DefaultContext.NeighborSummaries.NeighborSummary))])
                    self._leafs = OrderedDict()

                    self.neighbor_summary = YList(self)
                    self._segment_path = lambda: "neighbor-summaries"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.DefaultContext.NeighborSummaries, [], name, value)


                class NeighborSummary(Entity):
                    """
                    PIM neighbor summary information
                    
                    .. attribute:: interface_name  (key)
                    
                    	Interface name
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: number_of_neighbors
                    
                    	Number of neighbors
                    	**type**\: int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: number_of_external_neighbors
                    
                    	Number of external neighbors
                    	**type**\: int
                    
                    	**range:** \-2147483648..2147483647
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.NeighborSummaries.NeighborSummary, self).__init__()

                        self.yang_name = "neighbor-summary"
                        self.yang_parent_name = "neighbor-summaries"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['interface_name']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                            ('number_of_neighbors', (YLeaf(YType.int32, 'number-of-neighbors'), ['int'])),
                            ('number_of_external_neighbors', (YLeaf(YType.int32, 'number-of-external-neighbors'), ['int'])),
                        ])
                        self.interface_name = None
                        self.number_of_neighbors = None
                        self.number_of_external_neighbors = None
                        self._segment_path = lambda: "neighbor-summary" + "[interface-name='" + str(self.interface_name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/neighbor-summaries/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.NeighborSummaries.NeighborSummary, ['interface_name', 'number_of_neighbors', 'number_of_external_neighbors'], name, value)


            class Context(Entity):
                """
                PIM context information
                
                .. attribute:: remote_default_group
                
                	Remote Default Group
                	**type**\:  :py:class:`RemoteDefaultGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Context.RemoteDefaultGroup>`
                
                .. attribute:: rpf_default_table
                
                	RPF Default Table
                	**type**\:  :py:class:`RpfDefaultTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Context.RpfDefaultTable>`
                
                .. attribute:: vrf_id
                
                	VRF ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: table_id
                
                	Table ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: murib_id
                
                	MURIB ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: rpf_id
                
                	RPF ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: remote_table_id
                
                	Remote Table ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_default_group
                
                	MDT Default group
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: mdt_source
                
                	MDT source
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: mdt_source_interface
                
                	MDT Source Interface Name
                	**type**\: str
                
                .. attribute:: mdt_interface
                
                	MDT handle
                	**type**\: str
                
                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                
                .. attribute:: mdt_gre_rpf_identifier
                
                	GRE\-MDT RPF Identifier
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_gre_remote_rpf_identifier
                
                	GRE\-MDT Remote RPF Identifier
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_unicast_rib_registration
                
                	Ucast RIB Registration
                	**type**\: bool
                
                .. attribute:: is_multicast_rib_registration
                
                	Mcast RIB Registration
                	**type**\: bool
                
                .. attribute:: is_active
                
                	Active
                	**type**\: bool
                
                .. attribute:: is_active_ital
                
                	Active ITAL
                	**type**\: bool
                
                .. attribute:: is_mrib_register
                
                	MRIB Register
                	**type**\: bool
                
                .. attribute:: is_mdt_owner
                
                	MDT Owner
                	**type**\: bool
                
                .. attribute:: is_routing_enabled
                
                	Routing Enabled
                	**type**\: bool
                
                .. attribute:: is_socket_add_required
                
                	VRF required on Socket
                	**type**\: bool
                
                .. attribute:: is_socket_added
                
                	VRF added on Socket
                	**type**\: bool
                
                .. attribute:: is_lpts_socket_add_required
                
                	VRF LPTS filter required on Socket
                	**type**\: bool
                
                .. attribute:: is_lpts_socket_added
                
                	VRF LPTS filter added on Socket
                	**type**\: bool
                
                .. attribute:: is_udp_socket_add_required
                
                	VRF added on UDP Socket
                	**type**\: bool
                
                .. attribute:: is_udp_socket_added
                
                	VRF added on UDP Socket
                	**type**\: bool
                
                .. attribute:: is_udp_socket_bind_required
                
                	VRF bind required on UDP Socket
                	**type**\: bool
                
                .. attribute:: is_udp_socket_bind
                
                	VRF bound on UDP Socket
                	**type**\: bool
                
                .. attribute:: is_register_injection_socket_add_required
                
                	VRF required on Register Injection Socket
                	**type**\: bool
                
                .. attribute:: is_register_injection_socket_added
                
                	VRF added on Register Injection Socket
                	**type**\: bool
                
                .. attribute:: is_register_injection_lpts_socket_add_required
                
                	VRF LPTS filter required on Register Injection Socket
                	**type**\: bool
                
                .. attribute:: is_register_injection_lpts_socket_added
                
                	VRF LPTS filter added on Register Injection Socket
                	**type**\: bool
                
                .. attribute:: is_m_host_publish_pending
                
                	Publish pending for MHost Default interface
                	**type**\: bool
                
                .. attribute:: mhost_interface
                
                	MHost handle
                	**type**\: str
                
                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                
                .. attribute:: mhost_default_interface_config
                
                	Configured Mhost Defint
                	**type**\: str
                
                .. attribute:: mdt_mtu
                
                	MDT MTU
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: maximum_mdt_aggregation
                
                	MDT max aggregation
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_data_switchover_interval
                
                	Data MDT Switchover interval
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_data_announce_interval
                
                	Data MDT Announce interval
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: non_default_vrf_count_on_socket
                
                	Count of non\-default vrfs on raw socket
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: neighbor_filter_name
                
                	Neighbor Filter Name
                	**type**\: str
                
                .. attribute:: mdt_neighbor_filter_name
                
                	MDT Neighbor Filter Name
                	**type**\: str
                
                .. attribute:: allow_rp_configured
                
                	Allow RP Configured
                	**type**\: bool
                
                .. attribute:: allow_rp_group_list
                
                	Allow RP Group\-List ACL Name
                	**type**\: str
                
                	**length:** 0..64
                
                .. attribute:: allow_rp_rp_list
                
                	Allow RP RP\-list ACL Name
                	**type**\: str
                
                	**length:** 0..64
                
                .. attribute:: sg_expiry_timer_configured
                
                	S,G Expiry Timer Configured
                	**type**\: bool
                
                .. attribute:: sg_expiry_time
                
                	S,G Expiry Time Configured, in seconds
                	**type**\: int
                
                	**range:** 0..65535
                
                	**units**\: second
                
                .. attribute:: sg_expiry_timer_sg_list
                
                	S,G expiry timer ACL name
                	**type**\: str
                
                	**length:** 0..64
                
                .. attribute:: mldp_mdt_name
                
                	MLDP MDT Name
                	**type**\: str
                
                .. attribute:: mldp_mdt_interface
                
                	MLDP MDT handle
                	**type**\: str
                
                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                
                .. attribute:: mldp_mdt_mtu
                
                	MLDP MDT MTU
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_maximum_mdt_aggregation
                
                	MLDP MDT max aggregation
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_data_switchover_interval
                
                	MLDP Data MDT Switchover interval
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_data_announce_interval
                
                	MLDP Data MDT Announce interval
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_rpf_identifier
                
                	MLDP RPF\-ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_remote_rpf_identifier
                
                	MLDP Remote RPF\-ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_create_mldp_mdt_interface
                
                	Create MLDP MDT interface
                	**type**\: bool
                
                .. attribute:: is_mldp_mdt_owner
                
                	MLDP MDT Owner
                	**type**\: bool
                
                .. attribute:: mldp_root_count
                
                	MLDP Root count
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_head_lsm_identifier
                
                	MLDP Head LSM\-ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_remote_head_lsm_identifier
                
                	MLDP Remote Head LSM\-ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: organization_unique_identifier
                
                	OUI for VPN\-ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: vpn_index
                
                	VPN Index
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_partitioned_mdt_configured
                
                	MLDP Partitioned MDT
                	**type**\: bool
                
                .. attribute:: mldp_remote_partitioned_mdt_configured
                
                	MLDP Remote Partitioned MDT
                	**type**\: bool
                
                .. attribute:: mldp_partioned_mp2m_ptree
                
                	MP2MP Partitioned MDT tree
                	**type**\: bool
                
                .. attribute:: mldp_partitioned_head_lsm_identifier
                
                	Partitioned MDT Head LSM\-ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_head_local_label
                
                	Partitioned MDT Head local label
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_partitioned_mdt_identifier
                
                	MLDP Partitioned MDT Identifier
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: bgp_auto_discovery_configured
                
                	BGP Auto\-Discovery configured
                	**type**\: bool
                
                .. attribute:: suppress_pim_data_mdt_tlv
                
                	Suppress PIM Data\-MDT TLV Announcements
                	**type**\: bool
                
                .. attribute:: inter_autonomous_system_enabled
                
                	Inter\-AS Enabled
                	**type**\: bool
                
                .. attribute:: bgp_source_active_announce
                
                	Send BGP Source\-Active Announcements
                	**type**\: bool
                
                .. attribute:: bgp_i_pmsi_added
                
                	BGP I\-PMSI Added
                	**type**\: bool
                
                .. attribute:: mldp_bsr_control_tree_added
                
                	MLDP BSR Control tree added
                	**type**\: bool
                
                .. attribute:: mldp_auto_rp_discovery_tree_added
                
                	MLDP Autorp Discovery Control tree added
                	**type**\: bool
                
                .. attribute:: mldp_auto_rp_announce_tree_added
                
                	MLDP Autorp Announce Control tree added
                	**type**\: bool
                
                .. attribute:: bgp_auto_discovery_type
                
                	BGP Auto Discovery Type
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_partitioned_mdt_control_identifier
                
                	Partitioned MDT Control Identifier
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_partitioned_ir_control_identifier
                
                	Partitioned IR MDT Control Identifier
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_control_head_lsm_identifier
                
                	MLDP MVPN Identifier
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: umh
                
                	Join UMH Core\-Tree
                	**type**\: bool
                
                .. attribute:: suppress_shared_tree_join
                
                	Suppress Shared\-Tree Joins
                	**type**\: bool
                
                .. attribute:: rsvp_te_mdt_name
                
                	RSVP\-TE MDT Name
                	**type**\: str
                
                .. attribute:: rsvp_te_mdt_interface
                
                	RSVP\-TEMDT handle
                	**type**\: str
                
                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                
                .. attribute:: rsvp_te_mdt_mtu
                
                	RSVP\-TEMDT MTU
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_maximum_mdt_aggregation
                
                	RSVP\-TE MDT max aggregation
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_data_switchover_interval
                
                	RSVP\-TE Data MDT Switchover interval
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_data_announce_interval
                
                	RSVP\-TE Data MDT Announce interval
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_rpf_identifier
                
                	RSVP\-TE RPF\-ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_create_rsvp_te_mdt_interface
                
                	Create RSVP\-TE MDT interface
                	**type**\: bool
                
                .. attribute:: is_rsvp_te_mdt_owner
                
                	RSVP\-TE MDT Owner
                	**type**\: bool
                
                .. attribute:: rsvp_te_mdt_static_p2mp_count
                
                	Number of Static P2MP\-TE MDT
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: p2mpte_li_drop
                
                	Route LI updates dropped for P2MP
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_name
                
                	IR MDT Name
                	**type**\: str
                
                .. attribute:: ir_mdt_interface
                
                	IRMDT handle
                	**type**\: str
                
                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                
                .. attribute:: ir_mdt_mtu
                
                	IRMDT MTU
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_maximum_mdt_aggregation
                
                	IR MDT max aggregation
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_data_switchover_interval
                
                	IR Data MDT Switchover interval
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_data_announce_interval
                
                	IR Data MDT Announce interval
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_rpf_identifier
                
                	IR RPF\-ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_tail_label
                
                	IR Tail Label
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_create_ir_mdt_interface
                
                	Create IR MDT interface
                	**type**\: bool
                
                .. attribute:: is_ir_mdt_owner
                
                	IR MDT Owner
                	**type**\: bool
                
                .. attribute:: in_b_and_mdt_name
                
                	Inband MDT Name
                	**type**\: str
                
                .. attribute:: in_b_and_mdt_interface
                
                	Inband MDT handle
                	**type**\: str
                
                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                
                .. attribute:: in_b_and_mdt_mtu
                
                	Inband MDT MTU
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_band_maximum_mdt_aggregation
                
                	Inband MDT max aggregation
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_b_and_mdt_data_switchover_interval
                
                	Inband Data MDT Switchover interval
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_b_and_mdt_data_announce_interval
                
                	Inband Data MDT Announce interval
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_b_and_mdt_rpf_identifier
                
                	Inband RPF\-ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_create_in_b_and_mdt_interface
                
                	Create Inband MDT interface
                	**type**\: bool
                
                .. attribute:: is_in_b_and_mdt_owner
                
                	Inband MDT Owner
                	**type**\: bool
                
                .. attribute:: in_band_signaling_local_enabled
                
                	Inband signaling Local enabled
                	**type**\: bool
                
                .. attribute:: in_band_signaling_remote_enabled
                
                	Inband signaling Remote enabled
                	**type**\: bool
                
                .. attribute:: valid_rd_present
                
                	RD is valid
                	**type**\: bool
                
                .. attribute:: stale_rd_present
                
                	RD is stale
                	**type**\: bool
                
                .. attribute:: route_distinguisher
                
                	RD value
                	**type**\: str
                
                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                
                .. attribute:: gin_b_and_mdt_name
                
                	Inband MDT Name
                	**type**\: str
                
                .. attribute:: gin_b_and_mdt_interface
                
                	Inband MDT handle
                	**type**\: str
                
                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                
                .. attribute:: gin_b_and_mdt_mtu
                
                	Inband MDT MTU
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: gin_band_maximum_mdt_aggregation
                
                	Inband MDT max aggregation
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: gin_b_and_mdt_data_switchover_interval
                
                	Inband Data MDT Switchover interval
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: gin_b_and_mdt_data_announce_interval
                
                	Inband Data MDT Announce interval
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: gin_b_and_mdt_rpf_identifier
                
                	Inband RPF\-ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_create_gin_b_and_mdt_interface
                
                	Create Inband MDT interface
                	**type**\: bool
                
                .. attribute:: is_gin_b_and_mdt_owner
                
                	Inband MDT Owner
                	**type**\: bool
                
                .. attribute:: is_pim_nsf_rib_converged
                
                	PIM NSF RIB converged
                	**type**\: bool
                
                .. attribute:: is_pim_nsf_rib_converge_received
                
                	PIM NSF RIB converge received
                	**type**\: bool
                
                .. attribute:: is_rib_multipath_enabled
                
                	PIM RIB multiplath enabled
                	**type**\: bool
                
                .. attribute:: is_rib_multipath_interface_hash
                
                	PIM RIB multipath interface hash
                	**type**\: bool
                
                .. attribute:: is_rib_multipath_source_hash
                
                	PIM RIB multipath source based hash
                	**type**\: bool
                
                .. attribute:: is_rib_multipath_source_next_hop_hash
                
                	PIM RIB multipath source\-nexthop hash
                	**type**\: bool
                
                .. attribute:: rump_enabled
                
                	PIM is using MuRIB
                	**type**\: bool
                
                .. attribute:: is_create_mdt_interface
                
                	Create MDT interface
                	**type**\: bool
                
                .. attribute:: is_auto_rp_listen_enabled
                
                	Auto RP Listen Enabled
                	**type**\: bool
                
                .. attribute:: is_all_interface_disable_operation
                
                	PIM all interface disable operation
                	**type**\: bool
                
                .. attribute:: is_default_granges
                
                	Default granges
                	**type**\: bool
                
                .. attribute:: is_auto_rp_listen_sock_add
                
                	Auto RP listen sock add
                	**type**\: bool
                
                .. attribute:: is_redistribution_reset
                
                	Pending redist reset
                	**type**\: bool
                
                .. attribute:: redistribution_reset_count
                
                	Redist reset count
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: rpf_policy_name
                
                	RPF topology selection route\-policy name
                	**type**\: str
                
                .. attribute:: table_count
                
                	Number of configured Tables
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: active_table_count
                
                	Number of active Tables
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: anycast_rp_policy_name
                
                	Anycast\-RP Policy Name
                	**type**\: str
                
                .. attribute:: anycast_rp_configured
                
                	Anycast\-RP config
                	**type**\: bool
                
                .. attribute:: bgp_remote_on
                
                	BGP remote interface status
                	**type**\: bool
                
                .. attribute:: bgp_remote_interface_name
                
                	BGP remote interface name
                	**type**\: str
                
                .. attribute:: bgp_remote_interface
                
                	BGP remote interface handle
                	**type**\: str
                
                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                
                .. attribute:: bgp_remote_address
                
                	BGP remote interface address
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: bgp_remote_state
                
                	BGP remote interface state
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: physical_interface_count
                
                	Enabled Physical Interface Count
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: virtual_interface_count
                
                	Enabled Virtual Interface Count
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: virtual_mlc_interface_name
                
                	Virtual master line card Interface
                	**type**\: str
                
                .. attribute:: mdt_immediate_switch
                
                	MDT Immediate Switch
                	**type**\: bool
                
                .. attribute:: mldp_root_address
                
                	MLDP Root addresses
                	**type**\: list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: export_route_target
                
                	Export Route Targets
                	**type**\: list of  		 :py:class:`ExportRouteTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Context.ExportRouteTarget>`
                
                .. attribute:: import_route_target
                
                	Import Route Targets
                	**type**\: list of  		 :py:class:`ImportRouteTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Context.ImportRouteTarget>`
                
                .. attribute:: anycast_rp_range
                
                	Anycast\-RP Ranges
                	**type**\: list of  		 :py:class:`AnycastRpRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Context.AnycastRpRange>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.Context, self).__init__()

                    self.yang_name = "context"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("remote-default-group", ("remote_default_group", Pim.Standby.DefaultContext.Context.RemoteDefaultGroup)), ("rpf-default-table", ("rpf_default_table", Pim.Standby.DefaultContext.Context.RpfDefaultTable)), ("export-route-target", ("export_route_target", Pim.Standby.DefaultContext.Context.ExportRouteTarget)), ("import-route-target", ("import_route_target", Pim.Standby.DefaultContext.Context.ImportRouteTarget)), ("anycast-rp-range", ("anycast_rp_range", Pim.Standby.DefaultContext.Context.AnycastRpRange))])
                    self._leafs = OrderedDict([
                        ('vrf_id', (YLeaf(YType.uint32, 'vrf-id'), ['int'])),
                        ('table_id', (YLeaf(YType.uint32, 'table-id'), ['int'])),
                        ('murib_id', (YLeaf(YType.uint32, 'murib-id'), ['int'])),
                        ('rpf_id', (YLeaf(YType.uint32, 'rpf-id'), ['int'])),
                        ('remote_table_id', (YLeaf(YType.uint32, 'remote-table-id'), ['int'])),
                        ('mdt_default_group', (YLeaf(YType.str, 'mdt-default-group'), ['str'])),
                        ('mdt_source', (YLeaf(YType.str, 'mdt-source'), ['str'])),
                        ('mdt_source_interface', (YLeaf(YType.str, 'mdt-source-interface'), ['str'])),
                        ('mdt_interface', (YLeaf(YType.str, 'mdt-interface'), ['str'])),
                        ('mdt_gre_rpf_identifier', (YLeaf(YType.uint32, 'mdt-gre-rpf-identifier'), ['int'])),
                        ('mdt_gre_remote_rpf_identifier', (YLeaf(YType.uint32, 'mdt-gre-remote-rpf-identifier'), ['int'])),
                        ('is_unicast_rib_registration', (YLeaf(YType.boolean, 'is-unicast-rib-registration'), ['bool'])),
                        ('is_multicast_rib_registration', (YLeaf(YType.boolean, 'is-multicast-rib-registration'), ['bool'])),
                        ('is_active', (YLeaf(YType.boolean, 'is-active'), ['bool'])),
                        ('is_active_ital', (YLeaf(YType.boolean, 'is-active-ital'), ['bool'])),
                        ('is_mrib_register', (YLeaf(YType.boolean, 'is-mrib-register'), ['bool'])),
                        ('is_mdt_owner', (YLeaf(YType.boolean, 'is-mdt-owner'), ['bool'])),
                        ('is_routing_enabled', (YLeaf(YType.boolean, 'is-routing-enabled'), ['bool'])),
                        ('is_socket_add_required', (YLeaf(YType.boolean, 'is-socket-add-required'), ['bool'])),
                        ('is_socket_added', (YLeaf(YType.boolean, 'is-socket-added'), ['bool'])),
                        ('is_lpts_socket_add_required', (YLeaf(YType.boolean, 'is-lpts-socket-add-required'), ['bool'])),
                        ('is_lpts_socket_added', (YLeaf(YType.boolean, 'is-lpts-socket-added'), ['bool'])),
                        ('is_udp_socket_add_required', (YLeaf(YType.boolean, 'is-udp-socket-add-required'), ['bool'])),
                        ('is_udp_socket_added', (YLeaf(YType.boolean, 'is-udp-socket-added'), ['bool'])),
                        ('is_udp_socket_bind_required', (YLeaf(YType.boolean, 'is-udp-socket-bind-required'), ['bool'])),
                        ('is_udp_socket_bind', (YLeaf(YType.boolean, 'is-udp-socket-bind'), ['bool'])),
                        ('is_register_injection_socket_add_required', (YLeaf(YType.boolean, 'is-register-injection-socket-add-required'), ['bool'])),
                        ('is_register_injection_socket_added', (YLeaf(YType.boolean, 'is-register-injection-socket-added'), ['bool'])),
                        ('is_register_injection_lpts_socket_add_required', (YLeaf(YType.boolean, 'is-register-injection-lpts-socket-add-required'), ['bool'])),
                        ('is_register_injection_lpts_socket_added', (YLeaf(YType.boolean, 'is-register-injection-lpts-socket-added'), ['bool'])),
                        ('is_m_host_publish_pending', (YLeaf(YType.boolean, 'is-m-host-publish-pending'), ['bool'])),
                        ('mhost_interface', (YLeaf(YType.str, 'mhost-interface'), ['str'])),
                        ('mhost_default_interface_config', (YLeaf(YType.str, 'mhost-default-interface-config'), ['str'])),
                        ('mdt_mtu', (YLeaf(YType.uint32, 'mdt-mtu'), ['int'])),
                        ('maximum_mdt_aggregation', (YLeaf(YType.uint32, 'maximum-mdt-aggregation'), ['int'])),
                        ('mdt_data_switchover_interval', (YLeaf(YType.uint32, 'mdt-data-switchover-interval'), ['int'])),
                        ('mdt_data_announce_interval', (YLeaf(YType.uint32, 'mdt-data-announce-interval'), ['int'])),
                        ('non_default_vrf_count_on_socket', (YLeaf(YType.uint32, 'non-default-vrf-count-on-socket'), ['int'])),
                        ('neighbor_filter_name', (YLeaf(YType.str, 'neighbor-filter-name'), ['str'])),
                        ('mdt_neighbor_filter_name', (YLeaf(YType.str, 'mdt-neighbor-filter-name'), ['str'])),
                        ('allow_rp_configured', (YLeaf(YType.boolean, 'allow-rp-configured'), ['bool'])),
                        ('allow_rp_group_list', (YLeaf(YType.str, 'allow-rp-group-list'), ['str'])),
                        ('allow_rp_rp_list', (YLeaf(YType.str, 'allow-rp-rp-list'), ['str'])),
                        ('sg_expiry_timer_configured', (YLeaf(YType.boolean, 'sg-expiry-timer-configured'), ['bool'])),
                        ('sg_expiry_time', (YLeaf(YType.uint16, 'sg-expiry-time'), ['int'])),
                        ('sg_expiry_timer_sg_list', (YLeaf(YType.str, 'sg-expiry-timer-sg-list'), ['str'])),
                        ('mldp_mdt_name', (YLeaf(YType.str, 'mldp-mdt-name'), ['str'])),
                        ('mldp_mdt_interface', (YLeaf(YType.str, 'mldp-mdt-interface'), ['str'])),
                        ('mldp_mdt_mtu', (YLeaf(YType.uint32, 'mldp-mdt-mtu'), ['int'])),
                        ('mldp_maximum_mdt_aggregation', (YLeaf(YType.uint32, 'mldp-maximum-mdt-aggregation'), ['int'])),
                        ('mldp_mdt_data_switchover_interval', (YLeaf(YType.uint32, 'mldp-mdt-data-switchover-interval'), ['int'])),
                        ('mldp_mdt_data_announce_interval', (YLeaf(YType.uint32, 'mldp-mdt-data-announce-interval'), ['int'])),
                        ('mldp_mdt_rpf_identifier', (YLeaf(YType.uint32, 'mldp-mdt-rpf-identifier'), ['int'])),
                        ('mldp_mdt_remote_rpf_identifier', (YLeaf(YType.uint32, 'mldp-mdt-remote-rpf-identifier'), ['int'])),
                        ('is_create_mldp_mdt_interface', (YLeaf(YType.boolean, 'is-create-mldp-mdt-interface'), ['bool'])),
                        ('is_mldp_mdt_owner', (YLeaf(YType.boolean, 'is-mldp-mdt-owner'), ['bool'])),
                        ('mldp_root_count', (YLeaf(YType.uint32, 'mldp-root-count'), ['int'])),
                        ('mldp_head_lsm_identifier', (YLeaf(YType.uint32, 'mldp-head-lsm-identifier'), ['int'])),
                        ('mldp_remote_head_lsm_identifier', (YLeaf(YType.uint32, 'mldp-remote-head-lsm-identifier'), ['int'])),
                        ('organization_unique_identifier', (YLeaf(YType.uint32, 'organization-unique-identifier'), ['int'])),
                        ('vpn_index', (YLeaf(YType.uint32, 'vpn-index'), ['int'])),
                        ('mldp_partitioned_mdt_configured', (YLeaf(YType.boolean, 'mldp-partitioned-mdt-configured'), ['bool'])),
                        ('mldp_remote_partitioned_mdt_configured', (YLeaf(YType.boolean, 'mldp-remote-partitioned-mdt-configured'), ['bool'])),
                        ('mldp_partioned_mp2m_ptree', (YLeaf(YType.boolean, 'mldp-partioned-mp2m-ptree'), ['bool'])),
                        ('mldp_partitioned_head_lsm_identifier', (YLeaf(YType.uint32, 'mldp-partitioned-head-lsm-identifier'), ['int'])),
                        ('mldp_head_local_label', (YLeaf(YType.uint32, 'mldp-head-local-label'), ['int'])),
                        ('mldp_partitioned_mdt_identifier', (YLeaf(YType.uint32, 'mldp-partitioned-mdt-identifier'), ['int'])),
                        ('bgp_auto_discovery_configured', (YLeaf(YType.boolean, 'bgp-auto-discovery-configured'), ['bool'])),
                        ('suppress_pim_data_mdt_tlv', (YLeaf(YType.boolean, 'suppress-pim-data-mdt-tlv'), ['bool'])),
                        ('inter_autonomous_system_enabled', (YLeaf(YType.boolean, 'inter-autonomous-system-enabled'), ['bool'])),
                        ('bgp_source_active_announce', (YLeaf(YType.boolean, 'bgp-source-active-announce'), ['bool'])),
                        ('bgp_i_pmsi_added', (YLeaf(YType.boolean, 'bgp-i-pmsi-added'), ['bool'])),
                        ('mldp_bsr_control_tree_added', (YLeaf(YType.boolean, 'mldp-bsr-control-tree-added'), ['bool'])),
                        ('mldp_auto_rp_discovery_tree_added', (YLeaf(YType.boolean, 'mldp-auto-rp-discovery-tree-added'), ['bool'])),
                        ('mldp_auto_rp_announce_tree_added', (YLeaf(YType.boolean, 'mldp-auto-rp-announce-tree-added'), ['bool'])),
                        ('bgp_auto_discovery_type', (YLeaf(YType.uint32, 'bgp-auto-discovery-type'), ['int'])),
                        ('mdt_partitioned_mdt_control_identifier', (YLeaf(YType.uint32, 'mdt-partitioned-mdt-control-identifier'), ['int'])),
                        ('mdt_partitioned_ir_control_identifier', (YLeaf(YType.uint32, 'mdt-partitioned-ir-control-identifier'), ['int'])),
                        ('mldp_control_head_lsm_identifier', (YLeaf(YType.uint32, 'mldp-control-head-lsm-identifier'), ['int'])),
                        ('umh', (YLeaf(YType.boolean, 'umh'), ['bool'])),
                        ('suppress_shared_tree_join', (YLeaf(YType.boolean, 'suppress-shared-tree-join'), ['bool'])),
                        ('rsvp_te_mdt_name', (YLeaf(YType.str, 'rsvp-te-mdt-name'), ['str'])),
                        ('rsvp_te_mdt_interface', (YLeaf(YType.str, 'rsvp-te-mdt-interface'), ['str'])),
                        ('rsvp_te_mdt_mtu', (YLeaf(YType.uint32, 'rsvp-te-mdt-mtu'), ['int'])),
                        ('rsvp_te_maximum_mdt_aggregation', (YLeaf(YType.uint32, 'rsvp-te-maximum-mdt-aggregation'), ['int'])),
                        ('rsvp_te_mdt_data_switchover_interval', (YLeaf(YType.uint32, 'rsvp-te-mdt-data-switchover-interval'), ['int'])),
                        ('rsvp_te_mdt_data_announce_interval', (YLeaf(YType.uint32, 'rsvp-te-mdt-data-announce-interval'), ['int'])),
                        ('rsvp_te_mdt_rpf_identifier', (YLeaf(YType.uint32, 'rsvp-te-mdt-rpf-identifier'), ['int'])),
                        ('is_create_rsvp_te_mdt_interface', (YLeaf(YType.boolean, 'is-create-rsvp-te-mdt-interface'), ['bool'])),
                        ('is_rsvp_te_mdt_owner', (YLeaf(YType.boolean, 'is-rsvp-te-mdt-owner'), ['bool'])),
                        ('rsvp_te_mdt_static_p2mp_count', (YLeaf(YType.uint32, 'rsvp-te-mdt-static-p2mp-count'), ['int'])),
                        ('p2mpte_li_drop', (YLeaf(YType.uint32, 'p2mpte-li-drop'), ['int'])),
                        ('ir_mdt_name', (YLeaf(YType.str, 'ir-mdt-name'), ['str'])),
                        ('ir_mdt_interface', (YLeaf(YType.str, 'ir-mdt-interface'), ['str'])),
                        ('ir_mdt_mtu', (YLeaf(YType.uint32, 'ir-mdt-mtu'), ['int'])),
                        ('ir_maximum_mdt_aggregation', (YLeaf(YType.uint32, 'ir-maximum-mdt-aggregation'), ['int'])),
                        ('ir_mdt_data_switchover_interval', (YLeaf(YType.uint32, 'ir-mdt-data-switchover-interval'), ['int'])),
                        ('ir_mdt_data_announce_interval', (YLeaf(YType.uint32, 'ir-mdt-data-announce-interval'), ['int'])),
                        ('ir_mdt_rpf_identifier', (YLeaf(YType.uint32, 'ir-mdt-rpf-identifier'), ['int'])),
                        ('ir_mdt_tail_label', (YLeaf(YType.uint32, 'ir-mdt-tail-label'), ['int'])),
                        ('is_create_ir_mdt_interface', (YLeaf(YType.boolean, 'is-create-ir-mdt-interface'), ['bool'])),
                        ('is_ir_mdt_owner', (YLeaf(YType.boolean, 'is-ir-mdt-owner'), ['bool'])),
                        ('in_b_and_mdt_name', (YLeaf(YType.str, 'in-b-and-mdt-name'), ['str'])),
                        ('in_b_and_mdt_interface', (YLeaf(YType.str, 'in-b-and-mdt-interface'), ['str'])),
                        ('in_b_and_mdt_mtu', (YLeaf(YType.uint32, 'in-b-and-mdt-mtu'), ['int'])),
                        ('in_band_maximum_mdt_aggregation', (YLeaf(YType.uint32, 'in-band-maximum-mdt-aggregation'), ['int'])),
                        ('in_b_and_mdt_data_switchover_interval', (YLeaf(YType.uint32, 'in-b-and-mdt-data-switchover-interval'), ['int'])),
                        ('in_b_and_mdt_data_announce_interval', (YLeaf(YType.uint32, 'in-b-and-mdt-data-announce-interval'), ['int'])),
                        ('in_b_and_mdt_rpf_identifier', (YLeaf(YType.uint32, 'in-b-and-mdt-rpf-identifier'), ['int'])),
                        ('is_create_in_b_and_mdt_interface', (YLeaf(YType.boolean, 'is-create-in-b-and-mdt-interface'), ['bool'])),
                        ('is_in_b_and_mdt_owner', (YLeaf(YType.boolean, 'is-in-b-and-mdt-owner'), ['bool'])),
                        ('in_band_signaling_local_enabled', (YLeaf(YType.boolean, 'in-band-signaling-local-enabled'), ['bool'])),
                        ('in_band_signaling_remote_enabled', (YLeaf(YType.boolean, 'in-band-signaling-remote-enabled'), ['bool'])),
                        ('valid_rd_present', (YLeaf(YType.boolean, 'valid-rd-present'), ['bool'])),
                        ('stale_rd_present', (YLeaf(YType.boolean, 'stale-rd-present'), ['bool'])),
                        ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                        ('gin_b_and_mdt_name', (YLeaf(YType.str, 'gin-b-and-mdt-name'), ['str'])),
                        ('gin_b_and_mdt_interface', (YLeaf(YType.str, 'gin-b-and-mdt-interface'), ['str'])),
                        ('gin_b_and_mdt_mtu', (YLeaf(YType.uint32, 'gin-b-and-mdt-mtu'), ['int'])),
                        ('gin_band_maximum_mdt_aggregation', (YLeaf(YType.uint32, 'gin-band-maximum-mdt-aggregation'), ['int'])),
                        ('gin_b_and_mdt_data_switchover_interval', (YLeaf(YType.uint32, 'gin-b-and-mdt-data-switchover-interval'), ['int'])),
                        ('gin_b_and_mdt_data_announce_interval', (YLeaf(YType.uint32, 'gin-b-and-mdt-data-announce-interval'), ['int'])),
                        ('gin_b_and_mdt_rpf_identifier', (YLeaf(YType.uint32, 'gin-b-and-mdt-rpf-identifier'), ['int'])),
                        ('is_create_gin_b_and_mdt_interface', (YLeaf(YType.boolean, 'is-create-gin-b-and-mdt-interface'), ['bool'])),
                        ('is_gin_b_and_mdt_owner', (YLeaf(YType.boolean, 'is-gin-b-and-mdt-owner'), ['bool'])),
                        ('is_pim_nsf_rib_converged', (YLeaf(YType.boolean, 'is-pim-nsf-rib-converged'), ['bool'])),
                        ('is_pim_nsf_rib_converge_received', (YLeaf(YType.boolean, 'is-pim-nsf-rib-converge-received'), ['bool'])),
                        ('is_rib_multipath_enabled', (YLeaf(YType.boolean, 'is-rib-multipath-enabled'), ['bool'])),
                        ('is_rib_multipath_interface_hash', (YLeaf(YType.boolean, 'is-rib-multipath-interface-hash'), ['bool'])),
                        ('is_rib_multipath_source_hash', (YLeaf(YType.boolean, 'is-rib-multipath-source-hash'), ['bool'])),
                        ('is_rib_multipath_source_next_hop_hash', (YLeaf(YType.boolean, 'is-rib-multipath-source-next-hop-hash'), ['bool'])),
                        ('rump_enabled', (YLeaf(YType.boolean, 'rump-enabled'), ['bool'])),
                        ('is_create_mdt_interface', (YLeaf(YType.boolean, 'is-create-mdt-interface'), ['bool'])),
                        ('is_auto_rp_listen_enabled', (YLeaf(YType.boolean, 'is-auto-rp-listen-enabled'), ['bool'])),
                        ('is_all_interface_disable_operation', (YLeaf(YType.boolean, 'is-all-interface-disable-operation'), ['bool'])),
                        ('is_default_granges', (YLeaf(YType.boolean, 'is-default-granges'), ['bool'])),
                        ('is_auto_rp_listen_sock_add', (YLeaf(YType.boolean, 'is-auto-rp-listen-sock-add'), ['bool'])),
                        ('is_redistribution_reset', (YLeaf(YType.boolean, 'is-redistribution-reset'), ['bool'])),
                        ('redistribution_reset_count', (YLeaf(YType.uint32, 'redistribution-reset-count'), ['int'])),
                        ('rpf_policy_name', (YLeaf(YType.str, 'rpf-policy-name'), ['str'])),
                        ('table_count', (YLeaf(YType.uint32, 'table-count'), ['int'])),
                        ('active_table_count', (YLeaf(YType.uint32, 'active-table-count'), ['int'])),
                        ('anycast_rp_policy_name', (YLeaf(YType.str, 'anycast-rp-policy-name'), ['str'])),
                        ('anycast_rp_configured', (YLeaf(YType.boolean, 'anycast-rp-configured'), ['bool'])),
                        ('bgp_remote_on', (YLeaf(YType.boolean, 'bgp-remote-on'), ['bool'])),
                        ('bgp_remote_interface_name', (YLeaf(YType.str, 'bgp-remote-interface-name'), ['str'])),
                        ('bgp_remote_interface', (YLeaf(YType.str, 'bgp-remote-interface'), ['str'])),
                        ('bgp_remote_address', (YLeaf(YType.str, 'bgp-remote-address'), ['str'])),
                        ('bgp_remote_state', (YLeaf(YType.uint32, 'bgp-remote-state'), ['int'])),
                        ('physical_interface_count', (YLeaf(YType.uint64, 'physical-interface-count'), ['int'])),
                        ('virtual_interface_count', (YLeaf(YType.uint64, 'virtual-interface-count'), ['int'])),
                        ('virtual_mlc_interface_name', (YLeaf(YType.str, 'virtual-mlc-interface-name'), ['str'])),
                        ('mdt_immediate_switch', (YLeaf(YType.boolean, 'mdt-immediate-switch'), ['bool'])),
                        ('mldp_root_address', (YLeafList(YType.uint32, 'mldp-root-address'), ['int'])),
                    ])
                    self.vrf_id = None
                    self.table_id = None
                    self.murib_id = None
                    self.rpf_id = None
                    self.remote_table_id = None
                    self.mdt_default_group = None
                    self.mdt_source = None
                    self.mdt_source_interface = None
                    self.mdt_interface = None
                    self.mdt_gre_rpf_identifier = None
                    self.mdt_gre_remote_rpf_identifier = None
                    self.is_unicast_rib_registration = None
                    self.is_multicast_rib_registration = None
                    self.is_active = None
                    self.is_active_ital = None
                    self.is_mrib_register = None
                    self.is_mdt_owner = None
                    self.is_routing_enabled = None
                    self.is_socket_add_required = None
                    self.is_socket_added = None
                    self.is_lpts_socket_add_required = None
                    self.is_lpts_socket_added = None
                    self.is_udp_socket_add_required = None
                    self.is_udp_socket_added = None
                    self.is_udp_socket_bind_required = None
                    self.is_udp_socket_bind = None
                    self.is_register_injection_socket_add_required = None
                    self.is_register_injection_socket_added = None
                    self.is_register_injection_lpts_socket_add_required = None
                    self.is_register_injection_lpts_socket_added = None
                    self.is_m_host_publish_pending = None
                    self.mhost_interface = None
                    self.mhost_default_interface_config = None
                    self.mdt_mtu = None
                    self.maximum_mdt_aggregation = None
                    self.mdt_data_switchover_interval = None
                    self.mdt_data_announce_interval = None
                    self.non_default_vrf_count_on_socket = None
                    self.neighbor_filter_name = None
                    self.mdt_neighbor_filter_name = None
                    self.allow_rp_configured = None
                    self.allow_rp_group_list = None
                    self.allow_rp_rp_list = None
                    self.sg_expiry_timer_configured = None
                    self.sg_expiry_time = None
                    self.sg_expiry_timer_sg_list = None
                    self.mldp_mdt_name = None
                    self.mldp_mdt_interface = None
                    self.mldp_mdt_mtu = None
                    self.mldp_maximum_mdt_aggregation = None
                    self.mldp_mdt_data_switchover_interval = None
                    self.mldp_mdt_data_announce_interval = None
                    self.mldp_mdt_rpf_identifier = None
                    self.mldp_mdt_remote_rpf_identifier = None
                    self.is_create_mldp_mdt_interface = None
                    self.is_mldp_mdt_owner = None
                    self.mldp_root_count = None
                    self.mldp_head_lsm_identifier = None
                    self.mldp_remote_head_lsm_identifier = None
                    self.organization_unique_identifier = None
                    self.vpn_index = None
                    self.mldp_partitioned_mdt_configured = None
                    self.mldp_remote_partitioned_mdt_configured = None
                    self.mldp_partioned_mp2m_ptree = None
                    self.mldp_partitioned_head_lsm_identifier = None
                    self.mldp_head_local_label = None
                    self.mldp_partitioned_mdt_identifier = None
                    self.bgp_auto_discovery_configured = None
                    self.suppress_pim_data_mdt_tlv = None
                    self.inter_autonomous_system_enabled = None
                    self.bgp_source_active_announce = None
                    self.bgp_i_pmsi_added = None
                    self.mldp_bsr_control_tree_added = None
                    self.mldp_auto_rp_discovery_tree_added = None
                    self.mldp_auto_rp_announce_tree_added = None
                    self.bgp_auto_discovery_type = None
                    self.mdt_partitioned_mdt_control_identifier = None
                    self.mdt_partitioned_ir_control_identifier = None
                    self.mldp_control_head_lsm_identifier = None
                    self.umh = None
                    self.suppress_shared_tree_join = None
                    self.rsvp_te_mdt_name = None
                    self.rsvp_te_mdt_interface = None
                    self.rsvp_te_mdt_mtu = None
                    self.rsvp_te_maximum_mdt_aggregation = None
                    self.rsvp_te_mdt_data_switchover_interval = None
                    self.rsvp_te_mdt_data_announce_interval = None
                    self.rsvp_te_mdt_rpf_identifier = None
                    self.is_create_rsvp_te_mdt_interface = None
                    self.is_rsvp_te_mdt_owner = None
                    self.rsvp_te_mdt_static_p2mp_count = None
                    self.p2mpte_li_drop = None
                    self.ir_mdt_name = None
                    self.ir_mdt_interface = None
                    self.ir_mdt_mtu = None
                    self.ir_maximum_mdt_aggregation = None
                    self.ir_mdt_data_switchover_interval = None
                    self.ir_mdt_data_announce_interval = None
                    self.ir_mdt_rpf_identifier = None
                    self.ir_mdt_tail_label = None
                    self.is_create_ir_mdt_interface = None
                    self.is_ir_mdt_owner = None
                    self.in_b_and_mdt_name = None
                    self.in_b_and_mdt_interface = None
                    self.in_b_and_mdt_mtu = None
                    self.in_band_maximum_mdt_aggregation = None
                    self.in_b_and_mdt_data_switchover_interval = None
                    self.in_b_and_mdt_data_announce_interval = None
                    self.in_b_and_mdt_rpf_identifier = None
                    self.is_create_in_b_and_mdt_interface = None
                    self.is_in_b_and_mdt_owner = None
                    self.in_band_signaling_local_enabled = None
                    self.in_band_signaling_remote_enabled = None
                    self.valid_rd_present = None
                    self.stale_rd_present = None
                    self.route_distinguisher = None
                    self.gin_b_and_mdt_name = None
                    self.gin_b_and_mdt_interface = None
                    self.gin_b_and_mdt_mtu = None
                    self.gin_band_maximum_mdt_aggregation = None
                    self.gin_b_and_mdt_data_switchover_interval = None
                    self.gin_b_and_mdt_data_announce_interval = None
                    self.gin_b_and_mdt_rpf_identifier = None
                    self.is_create_gin_b_and_mdt_interface = None
                    self.is_gin_b_and_mdt_owner = None
                    self.is_pim_nsf_rib_converged = None
                    self.is_pim_nsf_rib_converge_received = None
                    self.is_rib_multipath_enabled = None
                    self.is_rib_multipath_interface_hash = None
                    self.is_rib_multipath_source_hash = None
                    self.is_rib_multipath_source_next_hop_hash = None
                    self.rump_enabled = None
                    self.is_create_mdt_interface = None
                    self.is_auto_rp_listen_enabled = None
                    self.is_all_interface_disable_operation = None
                    self.is_default_granges = None
                    self.is_auto_rp_listen_sock_add = None
                    self.is_redistribution_reset = None
                    self.redistribution_reset_count = None
                    self.rpf_policy_name = None
                    self.table_count = None
                    self.active_table_count = None
                    self.anycast_rp_policy_name = None
                    self.anycast_rp_configured = None
                    self.bgp_remote_on = None
                    self.bgp_remote_interface_name = None
                    self.bgp_remote_interface = None
                    self.bgp_remote_address = None
                    self.bgp_remote_state = None
                    self.physical_interface_count = None
                    self.virtual_interface_count = None
                    self.virtual_mlc_interface_name = None
                    self.mdt_immediate_switch = None
                    self.mldp_root_address = []

                    self.remote_default_group = Pim.Standby.DefaultContext.Context.RemoteDefaultGroup()
                    self.remote_default_group.parent = self
                    self._children_name_map["remote_default_group"] = "remote-default-group"

                    self.rpf_default_table = Pim.Standby.DefaultContext.Context.RpfDefaultTable()
                    self.rpf_default_table.parent = self
                    self._children_name_map["rpf_default_table"] = "rpf-default-table"

                    self.export_route_target = YList(self)
                    self.import_route_target = YList(self)
                    self.anycast_rp_range = YList(self)
                    self._segment_path = lambda: "context"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.DefaultContext.Context, ['vrf_id', 'table_id', 'murib_id', 'rpf_id', 'remote_table_id', 'mdt_default_group', 'mdt_source', 'mdt_source_interface', 'mdt_interface', 'mdt_gre_rpf_identifier', 'mdt_gre_remote_rpf_identifier', 'is_unicast_rib_registration', 'is_multicast_rib_registration', 'is_active', 'is_active_ital', 'is_mrib_register', 'is_mdt_owner', 'is_routing_enabled', 'is_socket_add_required', 'is_socket_added', 'is_lpts_socket_add_required', 'is_lpts_socket_added', 'is_udp_socket_add_required', 'is_udp_socket_added', 'is_udp_socket_bind_required', 'is_udp_socket_bind', 'is_register_injection_socket_add_required', 'is_register_injection_socket_added', 'is_register_injection_lpts_socket_add_required', 'is_register_injection_lpts_socket_added', 'is_m_host_publish_pending', 'mhost_interface', 'mhost_default_interface_config', 'mdt_mtu', 'maximum_mdt_aggregation', 'mdt_data_switchover_interval', 'mdt_data_announce_interval', 'non_default_vrf_count_on_socket', 'neighbor_filter_name', 'mdt_neighbor_filter_name', 'allow_rp_configured', 'allow_rp_group_list', 'allow_rp_rp_list', 'sg_expiry_timer_configured', 'sg_expiry_time', 'sg_expiry_timer_sg_list', 'mldp_mdt_name', 'mldp_mdt_interface', 'mldp_mdt_mtu', 'mldp_maximum_mdt_aggregation', 'mldp_mdt_data_switchover_interval', 'mldp_mdt_data_announce_interval', 'mldp_mdt_rpf_identifier', 'mldp_mdt_remote_rpf_identifier', 'is_create_mldp_mdt_interface', 'is_mldp_mdt_owner', 'mldp_root_count', 'mldp_head_lsm_identifier', 'mldp_remote_head_lsm_identifier', 'organization_unique_identifier', 'vpn_index', 'mldp_partitioned_mdt_configured', 'mldp_remote_partitioned_mdt_configured', 'mldp_partioned_mp2m_ptree', 'mldp_partitioned_head_lsm_identifier', 'mldp_head_local_label', 'mldp_partitioned_mdt_identifier', 'bgp_auto_discovery_configured', 'suppress_pim_data_mdt_tlv', 'inter_autonomous_system_enabled', 'bgp_source_active_announce', 'bgp_i_pmsi_added', 'mldp_bsr_control_tree_added', 'mldp_auto_rp_discovery_tree_added', 'mldp_auto_rp_announce_tree_added', 'bgp_auto_discovery_type', 'mdt_partitioned_mdt_control_identifier', 'mdt_partitioned_ir_control_identifier', 'mldp_control_head_lsm_identifier', 'umh', 'suppress_shared_tree_join', 'rsvp_te_mdt_name', 'rsvp_te_mdt_interface', 'rsvp_te_mdt_mtu', 'rsvp_te_maximum_mdt_aggregation', 'rsvp_te_mdt_data_switchover_interval', 'rsvp_te_mdt_data_announce_interval', 'rsvp_te_mdt_rpf_identifier', 'is_create_rsvp_te_mdt_interface', 'is_rsvp_te_mdt_owner', 'rsvp_te_mdt_static_p2mp_count', 'p2mpte_li_drop', 'ir_mdt_name', 'ir_mdt_interface', 'ir_mdt_mtu', 'ir_maximum_mdt_aggregation', 'ir_mdt_data_switchover_interval', 'ir_mdt_data_announce_interval', 'ir_mdt_rpf_identifier', 'ir_mdt_tail_label', 'is_create_ir_mdt_interface', 'is_ir_mdt_owner', 'in_b_and_mdt_name', 'in_b_and_mdt_interface', 'in_b_and_mdt_mtu', 'in_band_maximum_mdt_aggregation', 'in_b_and_mdt_data_switchover_interval', 'in_b_and_mdt_data_announce_interval', 'in_b_and_mdt_rpf_identifier', 'is_create_in_b_and_mdt_interface', 'is_in_b_and_mdt_owner', 'in_band_signaling_local_enabled', 'in_band_signaling_remote_enabled', 'valid_rd_present', 'stale_rd_present', 'route_distinguisher', 'gin_b_and_mdt_name', 'gin_b_and_mdt_interface', 'gin_b_and_mdt_mtu', 'gin_band_maximum_mdt_aggregation', 'gin_b_and_mdt_data_switchover_interval', 'gin_b_and_mdt_data_announce_interval', 'gin_b_and_mdt_rpf_identifier', 'is_create_gin_b_and_mdt_interface', 'is_gin_b_and_mdt_owner', 'is_pim_nsf_rib_converged', 'is_pim_nsf_rib_converge_received', 'is_rib_multipath_enabled', 'is_rib_multipath_interface_hash', 'is_rib_multipath_source_hash', 'is_rib_multipath_source_next_hop_hash', 'rump_enabled', 'is_create_mdt_interface', 'is_auto_rp_listen_enabled', 'is_all_interface_disable_operation', 'is_default_granges', 'is_auto_rp_listen_sock_add', 'is_redistribution_reset', 'redistribution_reset_count', 'rpf_policy_name', 'table_count', 'active_table_count', 'anycast_rp_policy_name', 'anycast_rp_configured', 'bgp_remote_on', 'bgp_remote_interface_name', 'bgp_remote_interface', 'bgp_remote_address', 'bgp_remote_state', 'physical_interface_count', 'virtual_interface_count', 'virtual_mlc_interface_name', 'mdt_immediate_switch', 'mldp_root_address'], name, value)


                class RemoteDefaultGroup(Entity):
                    """
                    Remote Default Group
                    
                    .. attribute:: af_name
                    
                    	AFName
                    	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                    
                    .. attribute:: ipv4_address
                    
                    	IPv4 Address
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: ipv6_address
                    
                    	IPV6 Address
                    	**type**\: str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.Context.RemoteDefaultGroup, self).__init__()

                        self.yang_name = "remote-default-group"
                        self.yang_parent_name = "context"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                        ])
                        self.af_name = None
                        self.ipv4_address = None
                        self.ipv6_address = None
                        self._segment_path = lambda: "remote-default-group"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/context/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.Context.RemoteDefaultGroup, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class RpfDefaultTable(Entity):
                    """
                    RPF Default Table
                    
                    .. attribute:: afi
                    
                    	AFI
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: safi
                    
                    	SAFI
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_name
                    
                    	Table name
                    	**type**\: str
                    
                    .. attribute:: vrf_id
                    
                    	VRF ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_id
                    
                    	Table ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_active
                    
                    	Active status
                    	**type**\: bool
                    
                    .. attribute:: is_ital_registration_done
                    
                    	ITAL reg status
                    	**type**\: bool
                    
                    .. attribute:: is_rib_registration_done
                    
                    	RIB reg status
                    	**type**\: bool
                    
                    .. attribute:: is_rib_convergence_received
                    
                    	RIB Convergence receive status
                    	**type**\: bool
                    
                    .. attribute:: is_rib_convergence
                    
                    	RIB Convergence status
                    	**type**\: bool
                    
                    .. attribute:: rpf_registrations
                    
                    	RPF Registration count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.Context.RpfDefaultTable, self).__init__()

                        self.yang_name = "rpf-default-table"
                        self.yang_parent_name = "context"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('afi', (YLeaf(YType.uint32, 'afi'), ['int'])),
                            ('safi', (YLeaf(YType.uint32, 'safi'), ['int'])),
                            ('table_name', (YLeaf(YType.str, 'table-name'), ['str'])),
                            ('vrf_id', (YLeaf(YType.uint32, 'vrf-id'), ['int'])),
                            ('table_id', (YLeaf(YType.uint32, 'table-id'), ['int'])),
                            ('is_active', (YLeaf(YType.boolean, 'is-active'), ['bool'])),
                            ('is_ital_registration_done', (YLeaf(YType.boolean, 'is-ital-registration-done'), ['bool'])),
                            ('is_rib_registration_done', (YLeaf(YType.boolean, 'is-rib-registration-done'), ['bool'])),
                            ('is_rib_convergence_received', (YLeaf(YType.boolean, 'is-rib-convergence-received'), ['bool'])),
                            ('is_rib_convergence', (YLeaf(YType.boolean, 'is-rib-convergence'), ['bool'])),
                            ('rpf_registrations', (YLeaf(YType.uint32, 'rpf-registrations'), ['int'])),
                        ])
                        self.afi = None
                        self.safi = None
                        self.table_name = None
                        self.vrf_id = None
                        self.table_id = None
                        self.is_active = None
                        self.is_ital_registration_done = None
                        self.is_rib_registration_done = None
                        self.is_rib_convergence_received = None
                        self.is_rib_convergence = None
                        self.rpf_registrations = None
                        self._segment_path = lambda: "rpf-default-table"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/context/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.Context.RpfDefaultTable, ['afi', 'safi', 'table_name', 'vrf_id', 'table_id', 'is_active', 'is_ital_registration_done', 'is_rib_registration_done', 'is_rib_convergence_received', 'is_rib_convergence', 'rpf_registrations'], name, value)


                class ExportRouteTarget(Entity):
                    """
                    Export Route Targets
                    
                    .. attribute:: route_target
                    
                    	Route Target Extended community value
                    	**type**\: str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: configured
                    
                    	Configured Route Target
                    	**type**\: bool
                    
                    .. attribute:: anycast_rp
                    
                    	Anycast\-RP Group
                    	**type**\: bool
                    
                    .. attribute:: anycast_rp_marked
                    
                    	Anycast\-RP Group marked
                    	**type**\: bool
                    
                    .. attribute:: update_pending
                    
                    	Update Pending to BGP
                    	**type**\: bool
                    
                    .. attribute:: bgp_auto_discovery
                    
                    	BGP Auto Discovery
                    	**type**\: bool
                    
                    .. attribute:: segment_border
                    
                    	Segment Border
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.Context.ExportRouteTarget, self).__init__()

                        self.yang_name = "export-route-target"
                        self.yang_parent_name = "context"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_target', (YLeaf(YType.str, 'route-target'), ['str'])),
                            ('configured', (YLeaf(YType.boolean, 'configured'), ['bool'])),
                            ('anycast_rp', (YLeaf(YType.boolean, 'anycast-rp'), ['bool'])),
                            ('anycast_rp_marked', (YLeaf(YType.boolean, 'anycast-rp-marked'), ['bool'])),
                            ('update_pending', (YLeaf(YType.boolean, 'update-pending'), ['bool'])),
                            ('bgp_auto_discovery', (YLeaf(YType.boolean, 'bgp-auto-discovery'), ['bool'])),
                            ('segment_border', (YLeaf(YType.boolean, 'segment-border'), ['bool'])),
                        ])
                        self.route_target = None
                        self.configured = None
                        self.anycast_rp = None
                        self.anycast_rp_marked = None
                        self.update_pending = None
                        self.bgp_auto_discovery = None
                        self.segment_border = None
                        self._segment_path = lambda: "export-route-target"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/context/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.Context.ExportRouteTarget, ['route_target', 'configured', 'anycast_rp', 'anycast_rp_marked', 'update_pending', 'bgp_auto_discovery', 'segment_border'], name, value)


                class ImportRouteTarget(Entity):
                    """
                    Import Route Targets
                    
                    .. attribute:: route_target
                    
                    	Route Target Extended community value
                    	**type**\: str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: configured
                    
                    	Configured Route Target
                    	**type**\: bool
                    
                    .. attribute:: anycast_rp
                    
                    	Anycast\-RP Group
                    	**type**\: bool
                    
                    .. attribute:: anycast_rp_marked
                    
                    	Anycast\-RP Group marked
                    	**type**\: bool
                    
                    .. attribute:: update_pending
                    
                    	Update Pending to BGP
                    	**type**\: bool
                    
                    .. attribute:: bgp_auto_discovery
                    
                    	BGP Auto Discovery
                    	**type**\: bool
                    
                    .. attribute:: segment_border
                    
                    	Segment Border
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.Context.ImportRouteTarget, self).__init__()

                        self.yang_name = "import-route-target"
                        self.yang_parent_name = "context"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_target', (YLeaf(YType.str, 'route-target'), ['str'])),
                            ('configured', (YLeaf(YType.boolean, 'configured'), ['bool'])),
                            ('anycast_rp', (YLeaf(YType.boolean, 'anycast-rp'), ['bool'])),
                            ('anycast_rp_marked', (YLeaf(YType.boolean, 'anycast-rp-marked'), ['bool'])),
                            ('update_pending', (YLeaf(YType.boolean, 'update-pending'), ['bool'])),
                            ('bgp_auto_discovery', (YLeaf(YType.boolean, 'bgp-auto-discovery'), ['bool'])),
                            ('segment_border', (YLeaf(YType.boolean, 'segment-border'), ['bool'])),
                        ])
                        self.route_target = None
                        self.configured = None
                        self.anycast_rp = None
                        self.anycast_rp_marked = None
                        self.update_pending = None
                        self.bgp_auto_discovery = None
                        self.segment_border = None
                        self._segment_path = lambda: "import-route-target"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/context/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.Context.ImportRouteTarget, ['route_target', 'configured', 'anycast_rp', 'anycast_rp_marked', 'update_pending', 'bgp_auto_discovery', 'segment_border'], name, value)


                class AnycastRpRange(Entity):
                    """
                    Anycast\-RP Ranges
                    
                    .. attribute:: prefix
                    
                    	Anycast\-RP Range Prefix
                    	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Context.AnycastRpRange.Prefix>`
                    
                    .. attribute:: prefix_length
                    
                    	Anycast\-RP Range Prefix Length
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: ancast_rp_marked
                    
                    	Anycast\-RP Range marked
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.Context.AnycastRpRange, self).__init__()

                        self.yang_name = "anycast-rp-range"
                        self.yang_parent_name = "context"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("prefix", ("prefix", Pim.Standby.DefaultContext.Context.AnycastRpRange.Prefix))])
                        self._leafs = OrderedDict([
                            ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                            ('ancast_rp_marked', (YLeaf(YType.boolean, 'ancast-rp-marked'), ['bool'])),
                        ])
                        self.prefix_length = None
                        self.ancast_rp_marked = None

                        self.prefix = Pim.Standby.DefaultContext.Context.AnycastRpRange.Prefix()
                        self.prefix.parent = self
                        self._children_name_map["prefix"] = "prefix"
                        self._segment_path = lambda: "anycast-rp-range"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/context/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.Context.AnycastRpRange, ['prefix_length', 'ancast_rp_marked'], name, value)


                    class Prefix(Entity):
                        """
                        Anycast\-RP Range Prefix
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Context.AnycastRpRange.Prefix, self).__init__()

                            self.yang_name = "prefix"
                            self.yang_parent_name = "anycast-rp-range"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "prefix"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/context/anycast-rp-range/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.Context.AnycastRpRange.Prefix, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class TopologyEntryFlagRouteCounts(Entity):
                """
                Route count for topology with entry flag set
                
                .. attribute:: topology_entry_flag_route_count
                
                	Route count for topology with entry flag set
                	**type**\: list of  		 :py:class:`TopologyEntryFlagRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts, self).__init__()

                    self.yang_name = "topology-entry-flag-route-counts"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("topology-entry-flag-route-count", ("topology_entry_flag_route_count", Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount))])
                    self._leafs = OrderedDict()

                    self.topology_entry_flag_route_count = YList(self)
                    self._segment_path = lambda: "topology-entry-flag-route-counts"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts, [], name, value)


                class TopologyEntryFlagRouteCount(Entity):
                    """
                    Route count for topology with entry flag set
                    
                    .. attribute:: entry_flag  (key)
                    
                    	entry flag
                    	**type**\:  :py:class:`PimTopologyEntryFlag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimTopologyEntryFlag>`
                    
                    .. attribute:: group_ranges
                    
                    	No. of (\*,G/M) routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: active_group_ranges
                    
                    	No. of (\*,G/M) routes active in mrib
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: groute_count
                    
                    	No. of (\*,G) routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sg_route_count
                    
                    	No. of (S,G) routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sgr_route_count
                    
                    	No. of (S,G)RPT routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount, self).__init__()

                        self.yang_name = "topology-entry-flag-route-count"
                        self.yang_parent_name = "topology-entry-flag-route-counts"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['entry_flag']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('entry_flag', (YLeaf(YType.enumeration, 'entry-flag'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimTopologyEntryFlag', '')])),
                            ('group_ranges', (YLeaf(YType.uint32, 'group-ranges'), ['int'])),
                            ('active_group_ranges', (YLeaf(YType.uint32, 'active-group-ranges'), ['int'])),
                            ('groute_count', (YLeaf(YType.uint32, 'groute-count'), ['int'])),
                            ('sg_route_count', (YLeaf(YType.uint32, 'sg-route-count'), ['int'])),
                            ('sgr_route_count', (YLeaf(YType.uint32, 'sgr-route-count'), ['int'])),
                            ('is_node_low_memory', (YLeaf(YType.boolean, 'is-node-low-memory'), ['bool'])),
                        ])
                        self.entry_flag = None
                        self.group_ranges = None
                        self.active_group_ranges = None
                        self.groute_count = None
                        self.sg_route_count = None
                        self.sgr_route_count = None
                        self.is_node_low_memory = None
                        self._segment_path = lambda: "topology-entry-flag-route-count" + "[entry-flag='" + str(self.entry_flag) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/topology-entry-flag-route-counts/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount, ['entry_flag', 'group_ranges', 'active_group_ranges', 'groute_count', 'sg_route_count', 'sgr_route_count', 'is_node_low_memory'], name, value)


            class RpfRedirect(Entity):
                """
                PIM ECMP RPF\-redirect bundle
                
                .. attribute:: redirect_route_databases
                
                	PIM ECMP RPF\-redirect route database
                	**type**\:  :py:class:`RedirectRouteDatabases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases>`
                
                .. attribute:: bundle_interfaces
                
                	PIM ECMP RPF\-redirect bundle information
                	**type**\:  :py:class:`BundleInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.RpfRedirect, self).__init__()

                    self.yang_name = "rpf-redirect"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("redirect-route-databases", ("redirect_route_databases", Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases)), ("bundle-interfaces", ("bundle_interfaces", Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces))])
                    self._leafs = OrderedDict()

                    self.redirect_route_databases = Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases()
                    self.redirect_route_databases.parent = self
                    self._children_name_map["redirect_route_databases"] = "redirect-route-databases"

                    self.bundle_interfaces = Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces()
                    self.bundle_interfaces.parent = self
                    self._children_name_map["bundle_interfaces"] = "bundle-interfaces"
                    self._segment_path = lambda: "rpf-redirect"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.DefaultContext.RpfRedirect, [], name, value)


                class RedirectRouteDatabases(Entity):
                    """
                    PIM ECMP RPF\-redirect route database
                    
                    .. attribute:: redirect_route_database
                    
                    	PIM ECMP RPF\-redirect route information
                    	**type**\: list of  		 :py:class:`RedirectRouteDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases, self).__init__()

                        self.yang_name = "redirect-route-databases"
                        self.yang_parent_name = "rpf-redirect"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("redirect-route-database", ("redirect_route_database", Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase))])
                        self._leafs = OrderedDict()

                        self.redirect_route_database = YList(self)
                        self._segment_path = lambda: "redirect-route-databases"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/rpf-redirect/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases, [], name, value)


                    class RedirectRouteDatabase(Entity):
                        """
                        PIM ECMP RPF\-redirect route information
                        
                        .. attribute:: source_address
                        
                        	Source address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: group_address
                        
                        	Group address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: group_address_xr
                        
                        	Group ddress
                        	**type**\:  :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr>`
                        
                        .. attribute:: source_address_xr
                        
                        	Source address
                        	**type**\:  :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr>`
                        
                        .. attribute:: bandwidth
                        
                        	Bandwidth in Kbps
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: interface
                        
                        	Outgoing interface list
                        	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase, self).__init__()

                            self.yang_name = "redirect-route-database"
                            self.yang_parent_name = "redirect-route-databases"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("group-address-xr", ("group_address_xr", Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr)), ("source-address-xr", ("source_address_xr", Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr)), ("interface", ("interface", Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface))])
                            self._leafs = OrderedDict([
                                ('source_address', (YLeaf(YType.str, 'source-address'), ['str','str'])),
                                ('group_address', (YLeaf(YType.str, 'group-address'), ['str','str'])),
                                ('bandwidth', (YLeaf(YType.uint32, 'bandwidth'), ['int'])),
                                ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                            ])
                            self.source_address = None
                            self.group_address = None
                            self.bandwidth = None
                            self.uptime = None

                            self.group_address_xr = Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"

                            self.source_address_xr = Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr()
                            self.source_address_xr.parent = self
                            self._children_name_map["source_address_xr"] = "source-address-xr"

                            self.interface = YList(self)
                            self._segment_path = lambda: "redirect-route-database"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/rpf-redirect/redirect-route-databases/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase, ['source_address', 'group_address', 'bandwidth', 'uptime'], name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group ddress
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "redirect-route-database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "group-address-xr"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/rpf-redirect/redirect-route-databases/redirect-route-database/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class SourceAddressXr(Entity):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr, self).__init__()

                                self.yang_name = "source-address-xr"
                                self.yang_parent_name = "redirect-route-database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "source-address-xr"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/rpf-redirect/redirect-route-databases/redirect-route-database/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class Interface(Entity):
                            """
                            Outgoing interface list
                            
                            .. attribute:: rpf_address
                            
                            	RPF Address
                            	**type**\:  :py:class:`RpfAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress>`
                            
                            .. attribute:: interface_name
                            
                            	Interface name
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: expiry
                            
                            	Expiry in seconds
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: is_rpf_interface
                            
                            	Is RPF Interface
                            	**type**\: bool
                            
                            .. attribute:: is_outgoing_interface
                            
                            	Is outgoing Interface
                            	**type**\: bool
                            
                            .. attribute:: is_snoop_interface
                            
                            	Is snooping Interface
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface, self).__init__()

                                self.yang_name = "interface"
                                self.yang_parent_name = "redirect-route-database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("rpf-address", ("rpf_address", Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress))])
                                self._leafs = OrderedDict([
                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                    ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                                    ('expiry', (YLeaf(YType.uint64, 'expiry'), ['int'])),
                                    ('is_rpf_interface', (YLeaf(YType.boolean, 'is-rpf-interface'), ['bool'])),
                                    ('is_outgoing_interface', (YLeaf(YType.boolean, 'is-outgoing-interface'), ['bool'])),
                                    ('is_snoop_interface', (YLeaf(YType.boolean, 'is-snoop-interface'), ['bool'])),
                                ])
                                self.interface_name = None
                                self.uptime = None
                                self.expiry = None
                                self.is_rpf_interface = None
                                self.is_outgoing_interface = None
                                self.is_snoop_interface = None

                                self.rpf_address = Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress()
                                self.rpf_address.parent = self
                                self._children_name_map["rpf_address"] = "rpf-address"
                                self._segment_path = lambda: "interface"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/rpf-redirect/redirect-route-databases/redirect-route-database/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface, ['interface_name', 'uptime', 'expiry', 'is_rpf_interface', 'is_outgoing_interface', 'is_snoop_interface'], name, value)


                            class RpfAddress(Entity):
                                """
                                RPF Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress, self).__init__()

                                    self.yang_name = "rpf-address"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "rpf-address"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/rpf-redirect/redirect-route-databases/redirect-route-database/interface/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class BundleInterfaces(Entity):
                    """
                    PIM ECMP RPF\-redirect bundle information
                    
                    .. attribute:: bundle_interface
                    
                    	PIM ECMP RPF\-redirect bundle interface information
                    	**type**\: list of  		 :py:class:`BundleInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces.BundleInterface>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces, self).__init__()

                        self.yang_name = "bundle-interfaces"
                        self.yang_parent_name = "rpf-redirect"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("bundle-interface", ("bundle_interface", Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces.BundleInterface))])
                        self._leafs = OrderedDict()

                        self.bundle_interface = YList(self)
                        self._segment_path = lambda: "bundle-interfaces"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/rpf-redirect/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces, [], name, value)


                    class BundleInterface(Entity):
                        """
                        PIM ECMP RPF\-redirect bundle interface
                        information
                        
                        .. attribute:: bundle_name
                        
                        	Bundle name
                        	**type**\: str
                        
                        	**length:** 1..32
                        
                        .. attribute:: interface_name
                        
                        	Bundle interface name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: rpf_redirect_bundle_name
                        
                        	RPF redirect bundle name
                        	**type**\: str
                        
                        	**length:** 0..33
                        
                        .. attribute:: rpf_redirect_interface_name
                        
                        	RPF redirect interface name
                        	**type**\: str
                        
                        	**length:** 0..33
                        
                        .. attribute:: available_bandwidth
                        
                        	Bandwidth available in Kbps
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: allocated_bandwidth
                        
                        	Bandwidth allocated in Kbps
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: total_bandwidth
                        
                        	Total bandwidth used in Kbps
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: topology_bandwidth_used
                        
                        	Bandwidth used by topology in Kbps
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: snooping_bandwidth_used
                        
                        	Bandwidth used by snooped entries in Kbps
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: allocated_threshold_bandwidth
                        
                        	Configured threshold in Kbps
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: available_threshold_bandwidth
                        
                        	Available threshold in Kbps
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces.BundleInterface, self).__init__()

                            self.yang_name = "bundle-interface"
                            self.yang_parent_name = "bundle-interfaces"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('bundle_name', (YLeaf(YType.str, 'bundle-name'), ['str'])),
                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ('rpf_redirect_bundle_name', (YLeaf(YType.str, 'rpf-redirect-bundle-name'), ['str'])),
                                ('rpf_redirect_interface_name', (YLeaf(YType.str, 'rpf-redirect-interface-name'), ['str'])),
                                ('available_bandwidth', (YLeaf(YType.int32, 'available-bandwidth'), ['int'])),
                                ('allocated_bandwidth', (YLeaf(YType.int32, 'allocated-bandwidth'), ['int'])),
                                ('total_bandwidth', (YLeaf(YType.int32, 'total-bandwidth'), ['int'])),
                                ('topology_bandwidth_used', (YLeaf(YType.int32, 'topology-bandwidth-used'), ['int'])),
                                ('snooping_bandwidth_used', (YLeaf(YType.int32, 'snooping-bandwidth-used'), ['int'])),
                                ('allocated_threshold_bandwidth', (YLeaf(YType.int32, 'allocated-threshold-bandwidth'), ['int'])),
                                ('available_threshold_bandwidth', (YLeaf(YType.int32, 'available-threshold-bandwidth'), ['int'])),
                            ])
                            self.bundle_name = None
                            self.interface_name = None
                            self.rpf_redirect_bundle_name = None
                            self.rpf_redirect_interface_name = None
                            self.available_bandwidth = None
                            self.allocated_bandwidth = None
                            self.total_bandwidth = None
                            self.topology_bandwidth_used = None
                            self.snooping_bandwidth_used = None
                            self.allocated_threshold_bandwidth = None
                            self.available_threshold_bandwidth = None
                            self._segment_path = lambda: "bundle-interface"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/rpf-redirect/bundle-interfaces/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces.BundleInterface, ['bundle_name', 'interface_name', 'rpf_redirect_bundle_name', 'rpf_redirect_interface_name', 'available_bandwidth', 'allocated_bandwidth', 'total_bandwidth', 'topology_bandwidth_used', 'snooping_bandwidth_used', 'allocated_threshold_bandwidth', 'available_threshold_bandwidth'], name, value)


            class Tunnels(Entity):
                """
                Tunnels information that PIM has
                
                .. attribute:: tunnel
                
                	PIM tunnel information
                	**type**\: list of  		 :py:class:`Tunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Tunnels.Tunnel>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.Tunnels, self).__init__()

                    self.yang_name = "tunnels"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("tunnel", ("tunnel", Pim.Standby.DefaultContext.Tunnels.Tunnel))])
                    self._leafs = OrderedDict()

                    self.tunnel = YList(self)
                    self._segment_path = lambda: "tunnels"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.DefaultContext.Tunnels, [], name, value)


                class Tunnel(Entity):
                    """
                    PIM tunnel information
                    
                    .. attribute:: tunnel_name  (key)
                    
                    	Tunnel name
                    	**type**\: str
                    
                    	**length:** 1..64
                    
                    .. attribute:: source_address
                    
                    	Source addr known to PIM
                    	**type**\:  :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddress>`
                    
                    .. attribute:: rp_address
                    
                    	RP addr known to PIM
                    	**type**\:  :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Tunnels.Tunnel.RpAddress>`
                    
                    .. attribute:: source_address_netio
                    
                    	Source addr from netio
                    	**type**\:  :py:class:`SourceAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddressNetio>`
                    
                    .. attribute:: group_address_netio
                    
                    	Group addr from netio
                    	**type**\:  :py:class:`GroupAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Tunnels.Tunnel.GroupAddressNetio>`
                    
                    .. attribute:: vrf_name
                    
                    	VRF Name
                    	**type**\: str
                    
                    	**length:** 0..33
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.Tunnels.Tunnel, self).__init__()

                        self.yang_name = "tunnel"
                        self.yang_parent_name = "tunnels"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['tunnel_name']
                        self._child_classes = OrderedDict([("source-address", ("source_address", Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddress)), ("rp-address", ("rp_address", Pim.Standby.DefaultContext.Tunnels.Tunnel.RpAddress)), ("source-address-netio", ("source_address_netio", Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddressNetio)), ("group-address-netio", ("group_address_netio", Pim.Standby.DefaultContext.Tunnels.Tunnel.GroupAddressNetio))])
                        self._leafs = OrderedDict([
                            ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                        ])
                        self.tunnel_name = None
                        self.vrf_name = None

                        self.source_address = Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddress()
                        self.source_address.parent = self
                        self._children_name_map["source_address"] = "source-address"

                        self.rp_address = Pim.Standby.DefaultContext.Tunnels.Tunnel.RpAddress()
                        self.rp_address.parent = self
                        self._children_name_map["rp_address"] = "rp-address"

                        self.source_address_netio = Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddressNetio()
                        self.source_address_netio.parent = self
                        self._children_name_map["source_address_netio"] = "source-address-netio"

                        self.group_address_netio = Pim.Standby.DefaultContext.Tunnels.Tunnel.GroupAddressNetio()
                        self.group_address_netio.parent = self
                        self._children_name_map["group_address_netio"] = "group-address-netio"
                        self._segment_path = lambda: "tunnel" + "[tunnel-name='" + str(self.tunnel_name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/tunnels/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.Tunnels.Tunnel, ['tunnel_name', 'vrf_name'], name, value)


                    class SourceAddress(Entity):
                        """
                        Source addr known to PIM
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddress, self).__init__()

                            self.yang_name = "source-address"
                            self.yang_parent_name = "tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "source-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class RpAddress(Entity):
                        """
                        RP addr known to PIM
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Tunnels.Tunnel.RpAddress, self).__init__()

                            self.yang_name = "rp-address"
                            self.yang_parent_name = "tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "rp-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.Tunnels.Tunnel.RpAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class SourceAddressNetio(Entity):
                        """
                        Source addr from netio
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddressNetio, self).__init__()

                            self.yang_name = "source-address-netio"
                            self.yang_parent_name = "tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "source-address-netio"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddressNetio, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class GroupAddressNetio(Entity):
                        """
                        Group addr from netio
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Tunnels.Tunnel.GroupAddressNetio, self).__init__()

                            self.yang_name = "group-address-netio"
                            self.yang_parent_name = "tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "group-address-netio"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.Tunnels.Tunnel.GroupAddressNetio, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class MulticastStaticRoutes(Entity):
                """
                PIM multicast static route table
                
                .. attribute:: multicast_static_route
                
                	PIM multicast static route information
                	**type**\: list of  		 :py:class:`MulticastStaticRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.MulticastStaticRoutes, self).__init__()

                    self.yang_name = "multicast-static-routes"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("multicast-static-route", ("multicast_static_route", Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute))])
                    self._leafs = OrderedDict()

                    self.multicast_static_route = YList(self)
                    self._segment_path = lambda: "multicast-static-routes"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.DefaultContext.MulticastStaticRoutes, [], name, value)


                class MulticastStaticRoute(Entity):
                    """
                    PIM multicast static route information
                    
                    .. attribute:: address
                    
                    	Network address
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: prefix
                    
                    	Prefix
                    	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix>`
                    
                    .. attribute:: nexthop
                    
                    	Next Hop
                    	**type**\:  :py:class:`Nexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop>`
                    
                    .. attribute:: interface_name
                    
                    	Interface Handle
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: distance
                    
                    	Distance
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: prefix_length_xr
                    
                    	Prefix Length
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: is_via_lsm
                    
                    	LSM flag
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute, self).__init__()

                        self.yang_name = "multicast-static-route"
                        self.yang_parent_name = "multicast-static-routes"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("prefix", ("prefix", Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix)), ("nexthop", ("nexthop", Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop))])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str','str'])),
                            ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                            ('distance', (YLeaf(YType.uint32, 'distance'), ['int'])),
                            ('prefix_length_xr', (YLeaf(YType.uint8, 'prefix-length-xr'), ['int'])),
                            ('is_via_lsm', (YLeaf(YType.boolean, 'is-via-lsm'), ['bool'])),
                        ])
                        self.address = None
                        self.prefix_length = None
                        self.interface_name = None
                        self.distance = None
                        self.prefix_length_xr = None
                        self.is_via_lsm = None

                        self.prefix = Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix()
                        self.prefix.parent = self
                        self._children_name_map["prefix"] = "prefix"

                        self.nexthop = Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop()
                        self.nexthop.parent = self
                        self._children_name_map["nexthop"] = "nexthop"
                        self._segment_path = lambda: "multicast-static-route"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/multicast-static-routes/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute, ['address', 'prefix_length', 'interface_name', 'distance', 'prefix_length_xr', 'is_via_lsm'], name, value)


                    class Prefix(Entity):
                        """
                        Prefix
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix, self).__init__()

                            self.yang_name = "prefix"
                            self.yang_parent_name = "multicast-static-route"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "prefix"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/multicast-static-routes/multicast-static-route/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class Nexthop(Entity):
                        """
                        Next Hop
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop, self).__init__()

                            self.yang_name = "nexthop"
                            self.yang_parent_name = "multicast-static-route"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "nexthop"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/multicast-static-routes/multicast-static-route/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class Neighbors(Entity):
                """
                PIM neighbor table
                
                .. attribute:: neighbor
                
                	PIM neighbor information
                	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Neighbors.Neighbor>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.Neighbors, self).__init__()

                    self.yang_name = "neighbors"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("neighbor", ("neighbor", Pim.Standby.DefaultContext.Neighbors.Neighbor))])
                    self._leafs = OrderedDict()

                    self.neighbor = YList(self)
                    self._segment_path = lambda: "neighbors"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.DefaultContext.Neighbors, [], name, value)


                class Neighbor(Entity):
                    """
                    PIM neighbor information
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: neighbor_address
                    
                    	Neighbor address
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identifier
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: expires
                    
                    	Neighbor expiry in seconds
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: expiry_timer
                    
                    	Expiry timer in seconds
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: is_this_neighbor_us
                    
                    	Is this neighbor us ?
                    	**type**\: bool
                    
                    .. attribute:: is_this_neighbor_dr
                    
                    	Is this neighbor the DR
                    	**type**\: bool
                    
                    .. attribute:: is_dr_priority_capable
                    
                    	Is this neighbor DR priority capable ?
                    	**type**\: bool
                    
                    .. attribute:: dr_priority
                    
                    	DR priority
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Is this neighbor bidir capable ?
                    	**type**\: bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Is this neighbor proxy capable?
                    	**type**\: bool
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Is this neighbor capable of batching asserts?
                    	**type**\: bool
                    
                    .. attribute:: is_ecmp_redirect_capable
                    
                    	Is this neighbor capable of Ecmp Redirect?
                    	**type**\: bool
                    
                    .. attribute:: is_bfd_state
                    
                    	Is the neighbor bfd session created
                    	**type**\: bool
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_address_xr
                    
                    	List of Neighbor Addresses
                    	**type**\: list of  		 :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Neighbors.Neighbor.NeighborAddressXr>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.Neighbors.Neighbor, self).__init__()

                        self.yang_name = "neighbor"
                        self.yang_parent_name = "neighbors"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("neighbor-address-xr", ("neighbor_address_xr", Pim.Standby.DefaultContext.Neighbors.Neighbor.NeighborAddressXr))])
                        self._leafs = OrderedDict([
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                            ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                            ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                            ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                            ('expires', (YLeaf(YType.uint64, 'expires'), ['int'])),
                            ('expiry_timer', (YLeaf(YType.uint64, 'expiry-timer'), ['int'])),
                            ('is_this_neighbor_us', (YLeaf(YType.boolean, 'is-this-neighbor-us'), ['bool'])),
                            ('is_this_neighbor_dr', (YLeaf(YType.boolean, 'is-this-neighbor-dr'), ['bool'])),
                            ('is_dr_priority_capable', (YLeaf(YType.boolean, 'is-dr-priority-capable'), ['bool'])),
                            ('dr_priority', (YLeaf(YType.uint32, 'dr-priority'), ['int'])),
                            ('is_bidirectional_capable', (YLeaf(YType.boolean, 'is-bidirectional-capable'), ['bool'])),
                            ('is_proxy_capable', (YLeaf(YType.boolean, 'is-proxy-capable'), ['bool'])),
                            ('is_batch_asserts_capable', (YLeaf(YType.boolean, 'is-batch-asserts-capable'), ['bool'])),
                            ('is_ecmp_redirect_capable', (YLeaf(YType.boolean, 'is-ecmp-redirect-capable'), ['bool'])),
                            ('is_bfd_state', (YLeaf(YType.boolean, 'is-bfd-state'), ['bool'])),
                            ('propagation_delay', (YLeaf(YType.uint16, 'propagation-delay'), ['int'])),
                            ('override_interval', (YLeaf(YType.uint16, 'override-interval'), ['int'])),
                        ])
                        self.interface_name = None
                        self.neighbor_address = None
                        self.interface_name_xr = None
                        self.uptime = None
                        self.expires = None
                        self.expiry_timer = None
                        self.is_this_neighbor_us = None
                        self.is_this_neighbor_dr = None
                        self.is_dr_priority_capable = None
                        self.dr_priority = None
                        self.is_bidirectional_capable = None
                        self.is_proxy_capable = None
                        self.is_batch_asserts_capable = None
                        self.is_ecmp_redirect_capable = None
                        self.is_bfd_state = None
                        self.propagation_delay = None
                        self.override_interval = None

                        self.neighbor_address_xr = YList(self)
                        self._segment_path = lambda: "neighbor"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/neighbors/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.DefaultContext.Neighbors.Neighbor, ['interface_name', 'neighbor_address', 'interface_name_xr', 'uptime', 'expires', 'expiry_timer', 'is_this_neighbor_us', 'is_this_neighbor_dr', 'is_dr_priority_capable', 'dr_priority', 'is_bidirectional_capable', 'is_proxy_capable', 'is_batch_asserts_capable', 'is_ecmp_redirect_capable', 'is_bfd_state', 'propagation_delay', 'override_interval'], name, value)


                    class NeighborAddressXr(Entity):
                        """
                        List of Neighbor Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Neighbors.Neighbor.NeighborAddressXr, self).__init__()

                            self.yang_name = "neighbor-address-xr"
                            self.yang_parent_name = "neighbor"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "neighbor-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/neighbors/neighbor/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.DefaultContext.Neighbors.Neighbor.NeighborAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


        class Process(Entity):
            """
            Process
            
            .. attribute:: nsr
            
            	NSR Information
            	**type**\:  :py:class:`Nsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Process.Nsr>`
            
            .. attribute:: summary
            
            	PIM Global Summary
            	**type**\:  :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Process.Summary>`
            
            .. attribute:: nsf
            
            	PIM NSF information
            	**type**\:  :py:class:`Nsf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Process.Nsf>`
            
            .. attribute:: issu
            
            	ISSU Information
            	**type**\:  :py:class:`Issu <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Process.Issu>`
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(Pim.Standby.Process, self).__init__()

                self.yang_name = "process"
                self.yang_parent_name = "standby"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("nsr", ("nsr", Pim.Standby.Process.Nsr)), ("summary", ("summary", Pim.Standby.Process.Summary)), ("nsf", ("nsf", Pim.Standby.Process.Nsf)), ("issu", ("issu", Pim.Standby.Process.Issu))])
                self._leafs = OrderedDict()

                self.nsr = Pim.Standby.Process.Nsr()
                self.nsr.parent = self
                self._children_name_map["nsr"] = "nsr"

                self.summary = Pim.Standby.Process.Summary()
                self.summary.parent = self
                self._children_name_map["summary"] = "summary"

                self.nsf = Pim.Standby.Process.Nsf()
                self.nsf.parent = self
                self._children_name_map["nsf"] = "nsf"

                self.issu = Pim.Standby.Process.Issu()
                self.issu.parent = self
                self._children_name_map["issu"] = "issu"
                self._segment_path = lambda: "process"
                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Pim.Standby.Process, [], name, value)


            class Nsr(Entity):
                """
                NSR Information
                
                .. attribute:: state
                
                	NSR state
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: partner_connected
                
                	Partner process connected
                	**type**\: bool
                
                .. attribute:: rmf_notification_done
                
                	RMF Notification done
                	**type**\: bool
                
                .. attribute:: rmf_timer_valid
                
                	Is RMF timer running ?
                	**type**\: bool
                
                .. attribute:: rmf_timer_expiry
                
                	Time for RMF timer to expire
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_connection_up
                
                	Time when connection went up
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_connection_dn
                
                	Time when connection went down
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_rmf_ready
                
                	Time when RMF Rdy notif was sent
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_rmf_not_ready
                
                	Time when RMF Not\-Rdy notif was sent
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: count_connection_up
                
                	No. of times connection went up
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_connection_dn
                
                	No. of times connection went down
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_rmf_ready
                
                	No. of times RMF Ready notif was sent
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_rmf_not_ready
                
                	No. of times RMF Not Ready notif was sent
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Standby.Process.Nsr, self).__init__()

                    self.yang_name = "nsr"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('state', (YLeaf(YType.uint8, 'state'), ['int'])),
                        ('partner_connected', (YLeaf(YType.boolean, 'partner-connected'), ['bool'])),
                        ('rmf_notification_done', (YLeaf(YType.boolean, 'rmf-notification-done'), ['bool'])),
                        ('rmf_timer_valid', (YLeaf(YType.boolean, 'rmf-timer-valid'), ['bool'])),
                        ('rmf_timer_expiry', (YLeaf(YType.uint64, 'rmf-timer-expiry'), ['int'])),
                        ('last_connection_up', (YLeaf(YType.uint64, 'last-connection-up'), ['int'])),
                        ('last_connection_dn', (YLeaf(YType.uint64, 'last-connection-dn'), ['int'])),
                        ('last_rmf_ready', (YLeaf(YType.uint64, 'last-rmf-ready'), ['int'])),
                        ('last_rmf_not_ready', (YLeaf(YType.uint64, 'last-rmf-not-ready'), ['int'])),
                        ('count_connection_up', (YLeaf(YType.uint32, 'count-connection-up'), ['int'])),
                        ('count_connection_dn', (YLeaf(YType.uint32, 'count-connection-dn'), ['int'])),
                        ('count_rmf_ready', (YLeaf(YType.uint32, 'count-rmf-ready'), ['int'])),
                        ('count_rmf_not_ready', (YLeaf(YType.uint32, 'count-rmf-not-ready'), ['int'])),
                    ])
                    self.state = None
                    self.partner_connected = None
                    self.rmf_notification_done = None
                    self.rmf_timer_valid = None
                    self.rmf_timer_expiry = None
                    self.last_connection_up = None
                    self.last_connection_dn = None
                    self.last_rmf_ready = None
                    self.last_rmf_not_ready = None
                    self.count_connection_up = None
                    self.count_connection_dn = None
                    self.count_rmf_ready = None
                    self.count_rmf_not_ready = None
                    self._segment_path = lambda: "nsr"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/process/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.Process.Nsr, ['state', 'partner_connected', 'rmf_notification_done', 'rmf_timer_valid', 'rmf_timer_expiry', 'last_connection_up', 'last_connection_dn', 'last_rmf_ready', 'last_rmf_not_ready', 'count_connection_up', 'count_connection_dn', 'count_rmf_ready', 'count_rmf_not_ready'], name, value)


            class Summary(Entity):
                """
                PIM Global Summary
                
                .. attribute:: route_limit
                
                	Maximum routes
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_count
                
                	Current routes
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_low_water_mark
                
                	The number of routes below which the throttle on route creation will be lifted
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_route_limit_reached
                
                	Is route creation throttled
                	**type**\: bool
                
                .. attribute:: topology_interface_state_limit
                
                	Maximum Topology Interface State count
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_count
                
                	Current Topology Interface State count
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: rxi_low_water_mark
                
                	The rxi below which the throttle on interface creation will be lifted
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: rxi_limit_reached
                
                	Is interface creation throttled
                	**type**\: bool
                
                .. attribute:: register_limit
                
                	Maximum registers
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_count
                
                	Current registers
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_limit_reached
                
                	Is PIM SM register handling throttled
                	**type**\: bool
                
                .. attribute:: ranges_limit
                
                	Maximum group ranges from Autorp
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: ranges_count
                
                	Current group ranges from Autorp
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: ranges_threshold
                
                	OOR theshold of grange ranges from AutoRP
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_ranges_limit_reached
                
                	Is Auto\-RP group\-to\-RP mapping range creation throttled
                	**type**\: bool
                
                .. attribute:: bsr_ranges_limit
                
                	Maximum group ranges from BSR
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_ranges_count
                
                	Current group ranges from BSR
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_range_threshold
                
                	Threshold group range from BSR
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_bsr_ranges_threshold_reached
                
                	Is VRF\-specific BSR group\-to\-RP mapping range creation throttled
                	**type**\: bool
                
                .. attribute:: bsr_candidate_rp_set_limit
                
                	Maximum crp\-set from BSR
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_candidate_rp_set_count
                
                	Current crp\-set count from BSR
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_candidate_rp_set_threshold
                
                	Threshold crp\-set from BSR
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_maximum_enforcement_disabled
                
                	Is maximum enforcement disabled
                	**type**\: bool
                
                .. attribute:: is_node_low_memory
                
                	Is node in low memory condition
                	**type**\: bool
                
                .. attribute:: route_threshold
                
                	Threshold routes
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_auto_rp_ranges_limit
                
                	Global Auto\-RP maximum group ranges
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_global_auto_rp_ranges_limit_reached
                
                	Is global AutoRP group\-to\-RP mapping range creation throttled
                	**type**\: bool
                
                .. attribute:: global_bsr_ranges_limit
                
                	Global BSR maximum group ranges
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_count
                
                	Global BSR current group ranges
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_threshold
                
                	Global BSR Threshold group ranges
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_global_bsr_ranges_limit_reached
                
                	Is global BSR group\-to\-RP mapping range creation throttled
                	**type**\: bool
                
                .. attribute:: global_bsr_candidate_rp_set_limit
                
                	Global BSR maximum crp\-set
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_count
                
                	Global BSR current crp\-set count
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_threshold
                
                	Global BSR Threshold crp\-set
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_global_route_limit_reached
                
                	Is global route creation throttled
                	**type**\: bool
                
                .. attribute:: topology_interface_state_threshold
                
                	Topology Interface State threshold
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_global_rxi_limit_reached
                
                	Is global interface creation throttled
                	**type**\: bool
                
                .. attribute:: register_threshold
                
                	Threshold registers
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_register_limit
                
                	Maximum global registers
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_global_register_limit_reached
                
                	Is global PIM SM register handling throttled
                	**type**\: bool
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Standby.Process.Summary, self).__init__()

                    self.yang_name = "summary"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('route_limit', (YLeaf(YType.uint32, 'route-limit'), ['int'])),
                        ('route_count', (YLeaf(YType.uint32, 'route-count'), ['int'])),
                        ('route_low_water_mark', (YLeaf(YType.uint32, 'route-low-water-mark'), ['int'])),
                        ('is_route_limit_reached', (YLeaf(YType.boolean, 'is-route-limit-reached'), ['bool'])),
                        ('topology_interface_state_limit', (YLeaf(YType.uint32, 'topology-interface-state-limit'), ['int'])),
                        ('topology_interface_state_count', (YLeaf(YType.uint32, 'topology-interface-state-count'), ['int'])),
                        ('rxi_low_water_mark', (YLeaf(YType.uint32, 'rxi-low-water-mark'), ['int'])),
                        ('rxi_limit_reached', (YLeaf(YType.boolean, 'rxi-limit-reached'), ['bool'])),
                        ('register_limit', (YLeaf(YType.uint32, 'register-limit'), ['int'])),
                        ('register_count', (YLeaf(YType.uint32, 'register-count'), ['int'])),
                        ('register_limit_reached', (YLeaf(YType.boolean, 'register-limit-reached'), ['bool'])),
                        ('ranges_limit', (YLeaf(YType.uint32, 'ranges-limit'), ['int'])),
                        ('ranges_count', (YLeaf(YType.uint32, 'ranges-count'), ['int'])),
                        ('ranges_threshold', (YLeaf(YType.uint32, 'ranges-threshold'), ['int'])),
                        ('is_ranges_limit_reached', (YLeaf(YType.boolean, 'is-ranges-limit-reached'), ['bool'])),
                        ('bsr_ranges_limit', (YLeaf(YType.uint32, 'bsr-ranges-limit'), ['int'])),
                        ('bsr_ranges_count', (YLeaf(YType.uint32, 'bsr-ranges-count'), ['int'])),
                        ('bsr_range_threshold', (YLeaf(YType.uint32, 'bsr-range-threshold'), ['int'])),
                        ('is_bsr_ranges_threshold_reached', (YLeaf(YType.boolean, 'is-bsr-ranges-threshold-reached'), ['bool'])),
                        ('bsr_candidate_rp_set_limit', (YLeaf(YType.uint32, 'bsr-candidate-rp-set-limit'), ['int'])),
                        ('bsr_candidate_rp_set_count', (YLeaf(YType.uint32, 'bsr-candidate-rp-set-count'), ['int'])),
                        ('bsr_candidate_rp_set_threshold', (YLeaf(YType.uint32, 'bsr-candidate-rp-set-threshold'), ['int'])),
                        ('is_maximum_enforcement_disabled', (YLeaf(YType.boolean, 'is-maximum-enforcement-disabled'), ['bool'])),
                        ('is_node_low_memory', (YLeaf(YType.boolean, 'is-node-low-memory'), ['bool'])),
                        ('route_threshold', (YLeaf(YType.uint32, 'route-threshold'), ['int'])),
                        ('global_auto_rp_ranges_limit', (YLeaf(YType.uint32, 'global-auto-rp-ranges-limit'), ['int'])),
                        ('is_global_auto_rp_ranges_limit_reached', (YLeaf(YType.boolean, 'is-global-auto-rp-ranges-limit-reached'), ['bool'])),
                        ('global_bsr_ranges_limit', (YLeaf(YType.uint32, 'global-bsr-ranges-limit'), ['int'])),
                        ('global_bsr_ranges_count', (YLeaf(YType.uint32, 'global-bsr-ranges-count'), ['int'])),
                        ('global_bsr_ranges_threshold', (YLeaf(YType.uint32, 'global-bsr-ranges-threshold'), ['int'])),
                        ('is_global_bsr_ranges_limit_reached', (YLeaf(YType.boolean, 'is-global-bsr-ranges-limit-reached'), ['bool'])),
                        ('global_bsr_candidate_rp_set_limit', (YLeaf(YType.uint32, 'global-bsr-candidate-rp-set-limit'), ['int'])),
                        ('global_bsr_candidate_rp_set_count', (YLeaf(YType.uint32, 'global-bsr-candidate-rp-set-count'), ['int'])),
                        ('global_bsr_candidate_rp_set_threshold', (YLeaf(YType.uint32, 'global-bsr-candidate-rp-set-threshold'), ['int'])),
                        ('is_global_route_limit_reached', (YLeaf(YType.boolean, 'is-global-route-limit-reached'), ['bool'])),
                        ('topology_interface_state_threshold', (YLeaf(YType.uint32, 'topology-interface-state-threshold'), ['int'])),
                        ('is_global_rxi_limit_reached', (YLeaf(YType.boolean, 'is-global-rxi-limit-reached'), ['bool'])),
                        ('register_threshold', (YLeaf(YType.uint32, 'register-threshold'), ['int'])),
                        ('global_register_limit', (YLeaf(YType.uint32, 'global-register-limit'), ['int'])),
                        ('is_global_register_limit_reached', (YLeaf(YType.boolean, 'is-global-register-limit-reached'), ['bool'])),
                    ])
                    self.route_limit = None
                    self.route_count = None
                    self.route_low_water_mark = None
                    self.is_route_limit_reached = None
                    self.topology_interface_state_limit = None
                    self.topology_interface_state_count = None
                    self.rxi_low_water_mark = None
                    self.rxi_limit_reached = None
                    self.register_limit = None
                    self.register_count = None
                    self.register_limit_reached = None
                    self.ranges_limit = None
                    self.ranges_count = None
                    self.ranges_threshold = None
                    self.is_ranges_limit_reached = None
                    self.bsr_ranges_limit = None
                    self.bsr_ranges_count = None
                    self.bsr_range_threshold = None
                    self.is_bsr_ranges_threshold_reached = None
                    self.bsr_candidate_rp_set_limit = None
                    self.bsr_candidate_rp_set_count = None
                    self.bsr_candidate_rp_set_threshold = None
                    self.is_maximum_enforcement_disabled = None
                    self.is_node_low_memory = None
                    self.route_threshold = None
                    self.global_auto_rp_ranges_limit = None
                    self.is_global_auto_rp_ranges_limit_reached = None
                    self.global_bsr_ranges_limit = None
                    self.global_bsr_ranges_count = None
                    self.global_bsr_ranges_threshold = None
                    self.is_global_bsr_ranges_limit_reached = None
                    self.global_bsr_candidate_rp_set_limit = None
                    self.global_bsr_candidate_rp_set_count = None
                    self.global_bsr_candidate_rp_set_threshold = None
                    self.is_global_route_limit_reached = None
                    self.topology_interface_state_threshold = None
                    self.is_global_rxi_limit_reached = None
                    self.register_threshold = None
                    self.global_register_limit = None
                    self.is_global_register_limit_reached = None
                    self._segment_path = lambda: "summary"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/process/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.Process.Summary, ['route_limit', 'route_count', 'route_low_water_mark', 'is_route_limit_reached', 'topology_interface_state_limit', 'topology_interface_state_count', 'rxi_low_water_mark', 'rxi_limit_reached', 'register_limit', 'register_count', 'register_limit_reached', 'ranges_limit', 'ranges_count', 'ranges_threshold', 'is_ranges_limit_reached', 'bsr_ranges_limit', 'bsr_ranges_count', 'bsr_range_threshold', 'is_bsr_ranges_threshold_reached', 'bsr_candidate_rp_set_limit', 'bsr_candidate_rp_set_count', 'bsr_candidate_rp_set_threshold', 'is_maximum_enforcement_disabled', 'is_node_low_memory', 'route_threshold', 'global_auto_rp_ranges_limit', 'is_global_auto_rp_ranges_limit_reached', 'global_bsr_ranges_limit', 'global_bsr_ranges_count', 'global_bsr_ranges_threshold', 'is_global_bsr_ranges_limit_reached', 'global_bsr_candidate_rp_set_limit', 'global_bsr_candidate_rp_set_count', 'global_bsr_candidate_rp_set_threshold', 'is_global_route_limit_reached', 'topology_interface_state_threshold', 'is_global_rxi_limit_reached', 'register_threshold', 'global_register_limit', 'is_global_register_limit_reached'], name, value)


            class Nsf(Entity):
                """
                PIM NSF information
                
                .. attribute:: configured_state
                
                	Is Multicast NSF Configured
                	**type**\: bool
                
                .. attribute:: nsf_state
                
                	Are we currently in NSF
                	**type**\: bool
                
                .. attribute:: nsf_timeout
                
                	Multicast NSF timeout in seconds
                	**type**\: int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: nsf_time_left
                
                	Multicast NSF time left in seconds
                	**type**\: int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: waiting_timer
                
                	Waiting for NSF timer expiry
                	**type**\: bool
                
                .. attribute:: waiting_membership
                
                	Waiting for IGMP/MLD
                	**type**\: bool
                
                .. attribute:: respawn_count
                
                	Respawn Count
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: last_nsf_on
                
                	Last NSF time ON
                	**type**\: int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_nsf_off
                
                	Last NSF time off
                	**type**\: int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_nsf_on_sec
                
                	Last NSF time ON in Seconds
                	**type**\: int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: last_nsf_off_sec
                
                	Last NSF time OFF in Seconds
                	**type**\: int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: last_icd_notif_recv
                
                	Last ICD Notif Recv
                	**type**\: int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_icd_notif_recv_sec
                
                	Last ICD Notif Recv in Seconds
                	**type**\: int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Standby.Process.Nsf, self).__init__()

                    self.yang_name = "nsf"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('configured_state', (YLeaf(YType.boolean, 'configured-state'), ['bool'])),
                        ('nsf_state', (YLeaf(YType.boolean, 'nsf-state'), ['bool'])),
                        ('nsf_timeout', (YLeaf(YType.uint32, 'nsf-timeout'), ['int'])),
                        ('nsf_time_left', (YLeaf(YType.uint32, 'nsf-time-left'), ['int'])),
                        ('waiting_timer', (YLeaf(YType.boolean, 'waiting-timer'), ['bool'])),
                        ('waiting_membership', (YLeaf(YType.boolean, 'waiting-membership'), ['bool'])),
                        ('respawn_count', (YLeaf(YType.uint32, 'respawn-count'), ['int'])),
                        ('last_nsf_on', (YLeaf(YType.int64, 'last-nsf-on'), ['int'])),
                        ('last_nsf_off', (YLeaf(YType.int64, 'last-nsf-off'), ['int'])),
                        ('last_nsf_on_sec', (YLeaf(YType.int32, 'last-nsf-on-sec'), ['int'])),
                        ('last_nsf_off_sec', (YLeaf(YType.int32, 'last-nsf-off-sec'), ['int'])),
                        ('last_icd_notif_recv', (YLeaf(YType.int64, 'last-icd-notif-recv'), ['int'])),
                        ('last_icd_notif_recv_sec', (YLeaf(YType.int32, 'last-icd-notif-recv-sec'), ['int'])),
                    ])
                    self.configured_state = None
                    self.nsf_state = None
                    self.nsf_timeout = None
                    self.nsf_time_left = None
                    self.waiting_timer = None
                    self.waiting_membership = None
                    self.respawn_count = None
                    self.last_nsf_on = None
                    self.last_nsf_off = None
                    self.last_nsf_on_sec = None
                    self.last_nsf_off_sec = None
                    self.last_icd_notif_recv = None
                    self.last_icd_notif_recv_sec = None
                    self._segment_path = lambda: "nsf"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/process/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.Process.Nsf, ['configured_state', 'nsf_state', 'nsf_timeout', 'nsf_time_left', 'waiting_timer', 'waiting_membership', 'respawn_count', 'last_nsf_on', 'last_nsf_off', 'last_nsf_on_sec', 'last_nsf_off_sec', 'last_icd_notif_recv', 'last_icd_notif_recv_sec'], name, value)


            class Issu(Entity):
                """
                ISSU Information
                
                .. attribute:: informationvalid
                
                	Is Information valid ?
                	**type**\: bool
                
                .. attribute:: role_ha
                
                	HA role
                	**type**\: int
                
                	**range:** \-2147483648..2147483647
                
                .. attribute:: role_issu
                
                	ISSU role
                	**type**\: int
                
                	**range:** \-2147483648..2147483647
                
                .. attribute:: phase_issu
                
                	ISSU Phase
                	**type**\: int
                
                	**range:** \-2147483648..2147483647
                
                .. attribute:: last_ha_role_notification_received
                
                	Time when last HA role nfn was received
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_issu_role_notification_received
                
                	Time when last ISSU role nfn was received
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_issu_phase_notification_received
                
                	Time when last ISSU Phase nfn was received
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: is_eoc_received
                
                	Was EOC received ?
                	**type**\: bool
                
                .. attribute:: eoc_received_timestamp
                
                	Time when EOC was received
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: is_ihms_done_received
                
                	Was IHMS done received ?
                	**type**\: bool
                
                .. attribute:: ihms_received_timestamp
                
                	Time when IHMS done was received
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: is_rib_sync_received
                
                	Was RIB Sync received ?
                	**type**\: bool
                
                .. attribute:: rib_sync_received_timestamp
                
                	Time when RIB Sync was received
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: is_nbr_sync_received
                
                	Was NBR Sync achieved ?
                	**type**\: bool
                
                .. attribute:: nbr_sync_received_timestamp
                
                	Time when NBR Sync was achieved
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: is_checkpoint_idt_done
                
                	Was Checkpoint IDT done ?
                	**type**\: bool
                
                .. attribute:: checkpoint_idt_timestamp
                
                	Time when Checkpoint IDT done
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Standby.Process.Issu, self).__init__()

                    self.yang_name = "issu"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('informationvalid', (YLeaf(YType.boolean, 'informationvalid'), ['bool'])),
                        ('role_ha', (YLeaf(YType.int32, 'role-ha'), ['int'])),
                        ('role_issu', (YLeaf(YType.int32, 'role-issu'), ['int'])),
                        ('phase_issu', (YLeaf(YType.int32, 'phase-issu'), ['int'])),
                        ('last_ha_role_notification_received', (YLeaf(YType.uint64, 'last-ha-role-notification-received'), ['int'])),
                        ('last_issu_role_notification_received', (YLeaf(YType.uint64, 'last-issu-role-notification-received'), ['int'])),
                        ('last_issu_phase_notification_received', (YLeaf(YType.uint64, 'last-issu-phase-notification-received'), ['int'])),
                        ('is_eoc_received', (YLeaf(YType.boolean, 'is-eoc-received'), ['bool'])),
                        ('eoc_received_timestamp', (YLeaf(YType.uint64, 'eoc-received-timestamp'), ['int'])),
                        ('is_ihms_done_received', (YLeaf(YType.boolean, 'is-ihms-done-received'), ['bool'])),
                        ('ihms_received_timestamp', (YLeaf(YType.uint64, 'ihms-received-timestamp'), ['int'])),
                        ('is_rib_sync_received', (YLeaf(YType.boolean, 'is-rib-sync-received'), ['bool'])),
                        ('rib_sync_received_timestamp', (YLeaf(YType.uint64, 'rib-sync-received-timestamp'), ['int'])),
                        ('is_nbr_sync_received', (YLeaf(YType.boolean, 'is-nbr-sync-received'), ['bool'])),
                        ('nbr_sync_received_timestamp', (YLeaf(YType.uint64, 'nbr-sync-received-timestamp'), ['int'])),
                        ('is_checkpoint_idt_done', (YLeaf(YType.boolean, 'is-checkpoint-idt-done'), ['bool'])),
                        ('checkpoint_idt_timestamp', (YLeaf(YType.uint64, 'checkpoint-idt-timestamp'), ['int'])),
                    ])
                    self.informationvalid = None
                    self.role_ha = None
                    self.role_issu = None
                    self.phase_issu = None
                    self.last_ha_role_notification_received = None
                    self.last_issu_role_notification_received = None
                    self.last_issu_phase_notification_received = None
                    self.is_eoc_received = None
                    self.eoc_received_timestamp = None
                    self.is_ihms_done_received = None
                    self.ihms_received_timestamp = None
                    self.is_rib_sync_received = None
                    self.rib_sync_received_timestamp = None
                    self.is_nbr_sync_received = None
                    self.nbr_sync_received_timestamp = None
                    self.is_checkpoint_idt_done = None
                    self.checkpoint_idt_timestamp = None
                    self._segment_path = lambda: "issu"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/process/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.Process.Issu, ['informationvalid', 'role_ha', 'role_issu', 'phase_issu', 'last_ha_role_notification_received', 'last_issu_role_notification_received', 'last_issu_phase_notification_received', 'is_eoc_received', 'eoc_received_timestamp', 'is_ihms_done_received', 'ihms_received_timestamp', 'is_rib_sync_received', 'rib_sync_received_timestamp', 'is_nbr_sync_received', 'nbr_sync_received_timestamp', 'is_checkpoint_idt_done', 'checkpoint_idt_timestamp'], name, value)


        class Vrfs(Entity):
            """
            VRF Table
            
            .. attribute:: vrf
            
            	VRF name
            	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf>`
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(Pim.Standby.Vrfs, self).__init__()

                self.yang_name = "vrfs"
                self.yang_parent_name = "standby"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("vrf", ("vrf", Pim.Standby.Vrfs.Vrf))])
                self._leafs = OrderedDict()

                self.vrf = YList(self)
                self._segment_path = lambda: "vrfs"
                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Pim.Standby.Vrfs, [], name, value)


            class Vrf(Entity):
                """
                VRF name
                
                .. attribute:: vrf_name  (key)
                
                	VRF name 
                	**type**\: str
                
                	**length:** 1..32
                
                .. attribute:: ifrs_interfaces
                
                	PIM interfaces in forward reference store table
                	**type**\:  :py:class:`IfrsInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.IfrsInterfaces>`
                
                .. attribute:: safs
                
                	SAFI table and type
                	**type**\:  :py:class:`Safs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Safs>`
                
                .. attribute:: interface_statistics
                
                	PIM interface statistics
                	**type**\:  :py:class:`InterfaceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.InterfaceStatistics>`
                
                .. attribute:: topology_route_count
                
                	Topology route count information from PIM topology table
                	**type**\:  :py:class:`TopologyRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.TopologyRouteCount>`
                
                .. attribute:: jp_statistics
                
                	PIM join prune statistics table
                	**type**\:  :py:class:`JpStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.JpStatistics>`
                
                .. attribute:: mib_databases
                
                	PIM group database for mroute mibs table
                	**type**\:  :py:class:`MibDatabases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.MibDatabases>`
                
                .. attribute:: neighbor_old_formats
                
                	PIM neighbor table old format
                	**type**\:  :py:class:`NeighborOldFormats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.NeighborOldFormats>`
                
                .. attribute:: ifrs_summary
                
                	PIM interfaces in forward reference store summary
                	**type**\:  :py:class:`IfrsSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.IfrsSummary>`
                
                .. attribute:: ranges
                
                	PIM range list information
                	**type**\:  :py:class:`Ranges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Ranges>`
                
                .. attribute:: interface_old_formats
                
                	PIM interfaces in old format
                	**type**\:  :py:class:`InterfaceOldFormats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.InterfaceOldFormats>`
                
                .. attribute:: bsr
                
                	PIM BSR information
                	**type**\:  :py:class:`Bsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Bsr>`
                
                .. attribute:: route_policy
                
                	PIM route policy
                	**type**\:  :py:class:`RoutePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.RoutePolicy>`
                
                .. attribute:: rpf_summary
                
                	PIM RPF registration summary
                	**type**\:  :py:class:`RpfSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.RpfSummary>`
                
                .. attribute:: interfaces
                
                	PIM interfaces
                	**type**\:  :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Interfaces>`
                
                .. attribute:: net_io_tunnels
                
                	Tunnel information that NETIO has 
                	**type**\:  :py:class:`NetIoTunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.NetIoTunnels>`
                
                .. attribute:: bidir_df_states
                
                	Bidirectional PIM DF election state table
                	**type**\:  :py:class:`BidirDfStates <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.BidirDfStates>`
                
                .. attribute:: topologies
                
                	PIM topology table
                	**type**\:  :py:class:`Topologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Topologies>`
                
                .. attribute:: bgp_afs
                
                	PIM BGP SAFI table
                	**type**\:  :py:class:`BgpAfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.BgpAfs>`
                
                .. attribute:: auto_rp
                
                	PIM Auto\-RP information
                	**type**\:  :py:class:`AutoRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.AutoRp>`
                
                .. attribute:: topology_interface_flag_route_counts
                
                	Route count for topology with interface flag set
                	**type**\:  :py:class:`TopologyInterfaceFlagRouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts>`
                
                .. attribute:: group_map_sources
                
                	PIM group\-mapping with source information
                	**type**\:  :py:class:`GroupMapSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapSources>`
                
                .. attribute:: traffic_counters
                
                	PIM message traffic counters
                	**type**\:  :py:class:`TrafficCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.TrafficCounters>`
                
                .. attribute:: group_map_rpfs
                
                	PIM group mapping information
                	**type**\:  :py:class:`GroupMapRpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapRpfs>`
                
                .. attribute:: summary
                
                	PIM summary
                	**type**\:  :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Summary>`
                
                .. attribute:: gre
                
                	GRE information
                	**type**\:  :py:class:`Gre <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Gre>`
                
                .. attribute:: bidir_df_winners
                
                	Bidirectional PIM DF election winner table
                	**type**\:  :py:class:`BidirDfWinners <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.BidirDfWinners>`
                
                .. attribute:: table_contexts
                
                	PIM table context list
                	**type**\:  :py:class:`TableContexts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.TableContexts>`
                
                .. attribute:: neighbor_summaries
                
                	PIM neighbor summary table
                	**type**\:  :py:class:`NeighborSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.NeighborSummaries>`
                
                .. attribute:: context
                
                	PIM context information
                	**type**\:  :py:class:`Context <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Context>`
                
                .. attribute:: topology_entry_flag_route_counts
                
                	Route count for topology with entry flag set
                	**type**\:  :py:class:`TopologyEntryFlagRouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts>`
                
                .. attribute:: rpf_redirect
                
                	PIM ECMP RPF\-redirect bundle
                	**type**\:  :py:class:`RpfRedirect <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.RpfRedirect>`
                
                .. attribute:: tunnels
                
                	Tunnels information that PIM has
                	**type**\:  :py:class:`Tunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Tunnels>`
                
                .. attribute:: multicast_static_routes
                
                	PIM multicast static route table
                	**type**\:  :py:class:`MulticastStaticRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes>`
                
                .. attribute:: neighbors
                
                	PIM neighbor table
                	**type**\:  :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Neighbors>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Standby.Vrfs.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "vrfs"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['vrf_name']
                    self._child_classes = OrderedDict([("ifrs-interfaces", ("ifrs_interfaces", Pim.Standby.Vrfs.Vrf.IfrsInterfaces)), ("safs", ("safs", Pim.Standby.Vrfs.Vrf.Safs)), ("interface-statistics", ("interface_statistics", Pim.Standby.Vrfs.Vrf.InterfaceStatistics)), ("topology-route-count", ("topology_route_count", Pim.Standby.Vrfs.Vrf.TopologyRouteCount)), ("jp-statistics", ("jp_statistics", Pim.Standby.Vrfs.Vrf.JpStatistics)), ("mib-databases", ("mib_databases", Pim.Standby.Vrfs.Vrf.MibDatabases)), ("neighbor-old-formats", ("neighbor_old_formats", Pim.Standby.Vrfs.Vrf.NeighborOldFormats)), ("ifrs-summary", ("ifrs_summary", Pim.Standby.Vrfs.Vrf.IfrsSummary)), ("ranges", ("ranges", Pim.Standby.Vrfs.Vrf.Ranges)), ("interface-old-formats", ("interface_old_formats", Pim.Standby.Vrfs.Vrf.InterfaceOldFormats)), ("bsr", ("bsr", Pim.Standby.Vrfs.Vrf.Bsr)), ("route-policy", ("route_policy", Pim.Standby.Vrfs.Vrf.RoutePolicy)), ("rpf-summary", ("rpf_summary", Pim.Standby.Vrfs.Vrf.RpfSummary)), ("interfaces", ("interfaces", Pim.Standby.Vrfs.Vrf.Interfaces)), ("net-io-tunnels", ("net_io_tunnels", Pim.Standby.Vrfs.Vrf.NetIoTunnels)), ("bidir-df-states", ("bidir_df_states", Pim.Standby.Vrfs.Vrf.BidirDfStates)), ("topologies", ("topologies", Pim.Standby.Vrfs.Vrf.Topologies)), ("bgp-afs", ("bgp_afs", Pim.Standby.Vrfs.Vrf.BgpAfs)), ("auto-rp", ("auto_rp", Pim.Standby.Vrfs.Vrf.AutoRp)), ("topology-interface-flag-route-counts", ("topology_interface_flag_route_counts", Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts)), ("group-map-sources", ("group_map_sources", Pim.Standby.Vrfs.Vrf.GroupMapSources)), ("traffic-counters", ("traffic_counters", Pim.Standby.Vrfs.Vrf.TrafficCounters)), ("group-map-rpfs", ("group_map_rpfs", Pim.Standby.Vrfs.Vrf.GroupMapRpfs)), ("summary", ("summary", Pim.Standby.Vrfs.Vrf.Summary)), ("gre", ("gre", Pim.Standby.Vrfs.Vrf.Gre)), ("bidir-df-winners", ("bidir_df_winners", Pim.Standby.Vrfs.Vrf.BidirDfWinners)), ("table-contexts", ("table_contexts", Pim.Standby.Vrfs.Vrf.TableContexts)), ("neighbor-summaries", ("neighbor_summaries", Pim.Standby.Vrfs.Vrf.NeighborSummaries)), ("context", ("context", Pim.Standby.Vrfs.Vrf.Context)), ("topology-entry-flag-route-counts", ("topology_entry_flag_route_counts", Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts)), ("rpf-redirect", ("rpf_redirect", Pim.Standby.Vrfs.Vrf.RpfRedirect)), ("tunnels", ("tunnels", Pim.Standby.Vrfs.Vrf.Tunnels)), ("multicast-static-routes", ("multicast_static_routes", Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes)), ("neighbors", ("neighbors", Pim.Standby.Vrfs.Vrf.Neighbors))])
                    self._leafs = OrderedDict([
                        ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                    ])
                    self.vrf_name = None

                    self.ifrs_interfaces = Pim.Standby.Vrfs.Vrf.IfrsInterfaces()
                    self.ifrs_interfaces.parent = self
                    self._children_name_map["ifrs_interfaces"] = "ifrs-interfaces"

                    self.safs = Pim.Standby.Vrfs.Vrf.Safs()
                    self.safs.parent = self
                    self._children_name_map["safs"] = "safs"

                    self.interface_statistics = Pim.Standby.Vrfs.Vrf.InterfaceStatistics()
                    self.interface_statistics.parent = self
                    self._children_name_map["interface_statistics"] = "interface-statistics"

                    self.topology_route_count = Pim.Standby.Vrfs.Vrf.TopologyRouteCount()
                    self.topology_route_count.parent = self
                    self._children_name_map["topology_route_count"] = "topology-route-count"

                    self.jp_statistics = Pim.Standby.Vrfs.Vrf.JpStatistics()
                    self.jp_statistics.parent = self
                    self._children_name_map["jp_statistics"] = "jp-statistics"

                    self.mib_databases = Pim.Standby.Vrfs.Vrf.MibDatabases()
                    self.mib_databases.parent = self
                    self._children_name_map["mib_databases"] = "mib-databases"

                    self.neighbor_old_formats = Pim.Standby.Vrfs.Vrf.NeighborOldFormats()
                    self.neighbor_old_formats.parent = self
                    self._children_name_map["neighbor_old_formats"] = "neighbor-old-formats"

                    self.ifrs_summary = Pim.Standby.Vrfs.Vrf.IfrsSummary()
                    self.ifrs_summary.parent = self
                    self._children_name_map["ifrs_summary"] = "ifrs-summary"

                    self.ranges = Pim.Standby.Vrfs.Vrf.Ranges()
                    self.ranges.parent = self
                    self._children_name_map["ranges"] = "ranges"

                    self.interface_old_formats = Pim.Standby.Vrfs.Vrf.InterfaceOldFormats()
                    self.interface_old_formats.parent = self
                    self._children_name_map["interface_old_formats"] = "interface-old-formats"

                    self.bsr = Pim.Standby.Vrfs.Vrf.Bsr()
                    self.bsr.parent = self
                    self._children_name_map["bsr"] = "bsr"

                    self.route_policy = Pim.Standby.Vrfs.Vrf.RoutePolicy()
                    self.route_policy.parent = self
                    self._children_name_map["route_policy"] = "route-policy"

                    self.rpf_summary = Pim.Standby.Vrfs.Vrf.RpfSummary()
                    self.rpf_summary.parent = self
                    self._children_name_map["rpf_summary"] = "rpf-summary"

                    self.interfaces = Pim.Standby.Vrfs.Vrf.Interfaces()
                    self.interfaces.parent = self
                    self._children_name_map["interfaces"] = "interfaces"

                    self.net_io_tunnels = Pim.Standby.Vrfs.Vrf.NetIoTunnels()
                    self.net_io_tunnels.parent = self
                    self._children_name_map["net_io_tunnels"] = "net-io-tunnels"

                    self.bidir_df_states = Pim.Standby.Vrfs.Vrf.BidirDfStates()
                    self.bidir_df_states.parent = self
                    self._children_name_map["bidir_df_states"] = "bidir-df-states"

                    self.topologies = Pim.Standby.Vrfs.Vrf.Topologies()
                    self.topologies.parent = self
                    self._children_name_map["topologies"] = "topologies"

                    self.bgp_afs = Pim.Standby.Vrfs.Vrf.BgpAfs()
                    self.bgp_afs.parent = self
                    self._children_name_map["bgp_afs"] = "bgp-afs"

                    self.auto_rp = Pim.Standby.Vrfs.Vrf.AutoRp()
                    self.auto_rp.parent = self
                    self._children_name_map["auto_rp"] = "auto-rp"

                    self.topology_interface_flag_route_counts = Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts()
                    self.topology_interface_flag_route_counts.parent = self
                    self._children_name_map["topology_interface_flag_route_counts"] = "topology-interface-flag-route-counts"

                    self.group_map_sources = Pim.Standby.Vrfs.Vrf.GroupMapSources()
                    self.group_map_sources.parent = self
                    self._children_name_map["group_map_sources"] = "group-map-sources"

                    self.traffic_counters = Pim.Standby.Vrfs.Vrf.TrafficCounters()
                    self.traffic_counters.parent = self
                    self._children_name_map["traffic_counters"] = "traffic-counters"

                    self.group_map_rpfs = Pim.Standby.Vrfs.Vrf.GroupMapRpfs()
                    self.group_map_rpfs.parent = self
                    self._children_name_map["group_map_rpfs"] = "group-map-rpfs"

                    self.summary = Pim.Standby.Vrfs.Vrf.Summary()
                    self.summary.parent = self
                    self._children_name_map["summary"] = "summary"

                    self.gre = Pim.Standby.Vrfs.Vrf.Gre()
                    self.gre.parent = self
                    self._children_name_map["gre"] = "gre"

                    self.bidir_df_winners = Pim.Standby.Vrfs.Vrf.BidirDfWinners()
                    self.bidir_df_winners.parent = self
                    self._children_name_map["bidir_df_winners"] = "bidir-df-winners"

                    self.table_contexts = Pim.Standby.Vrfs.Vrf.TableContexts()
                    self.table_contexts.parent = self
                    self._children_name_map["table_contexts"] = "table-contexts"

                    self.neighbor_summaries = Pim.Standby.Vrfs.Vrf.NeighborSummaries()
                    self.neighbor_summaries.parent = self
                    self._children_name_map["neighbor_summaries"] = "neighbor-summaries"

                    self.context = Pim.Standby.Vrfs.Vrf.Context()
                    self.context.parent = self
                    self._children_name_map["context"] = "context"

                    self.topology_entry_flag_route_counts = Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts()
                    self.topology_entry_flag_route_counts.parent = self
                    self._children_name_map["topology_entry_flag_route_counts"] = "topology-entry-flag-route-counts"

                    self.rpf_redirect = Pim.Standby.Vrfs.Vrf.RpfRedirect()
                    self.rpf_redirect.parent = self
                    self._children_name_map["rpf_redirect"] = "rpf-redirect"

                    self.tunnels = Pim.Standby.Vrfs.Vrf.Tunnels()
                    self.tunnels.parent = self
                    self._children_name_map["tunnels"] = "tunnels"

                    self.multicast_static_routes = Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes()
                    self.multicast_static_routes.parent = self
                    self._children_name_map["multicast_static_routes"] = "multicast-static-routes"

                    self.neighbors = Pim.Standby.Vrfs.Vrf.Neighbors()
                    self.neighbors.parent = self
                    self._children_name_map["neighbors"] = "neighbors"
                    self._segment_path = lambda: "vrf" + "[vrf-name='" + str(self.vrf_name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/vrfs/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Standby.Vrfs.Vrf, ['vrf_name'], name, value)


                class IfrsInterfaces(Entity):
                    """
                    PIM interfaces in forward reference store table
                    
                    .. attribute:: ifrs_interface
                    
                    	PIM IFRS interface information
                    	**type**\: list of  		 :py:class:`IfrsInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.IfrsInterfaces, self).__init__()

                        self.yang_name = "ifrs-interfaces"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ifrs-interface", ("ifrs_interface", Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface))])
                        self._leafs = OrderedDict()

                        self.ifrs_interface = YList(self)
                        self._segment_path = lambda: "ifrs-interfaces"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.IfrsInterfaces, [], name, value)


                    class IfrsInterface(Entity):
                        """
                        PIM IFRS interface information
                        
                        .. attribute:: interface_name  (key)
                        
                        	Interface name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: dr_address
                        
                        	PIM Designated Router
                        	**type**\:  :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress>`
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identfier
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: interface_address_mask
                        
                        	Interface IP Address Mask
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: is_enabled
                        
                        	Is PIM enabled on this IF ?
                        	**type**\: bool
                        
                        .. attribute:: neighbor_count
                        
                        	No. of neighbors on this IF
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: external_neighbor_count
                        
                        	No. of external neighbors on this IF
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: hello_interval
                        
                        	Hello Interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: dr_priority
                        
                        	DR Priority
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: hello_expiry
                        
                        	Hello Timer Expiry
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: are_we_dr
                        
                        	Are we the DR on this IF ?
                        	**type**\: bool
                        
                        .. attribute:: bfd_enabled
                        
                        	BFD state
                        	**type**\: bool
                        
                        .. attribute:: bfd_interval
                        
                        	BFD Interval
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bfd_multiplier
                        
                        	BFD Multiplier
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_interface
                        
                        	 is this a Virtual Interfaces ?
                        	**type**\: bool
                        
                        .. attribute:: passive_interface
                        
                        	Passive PIM interface
                        	**type**\: bool
                        
                        .. attribute:: neighbor_filter_name
                        
                        	Neighbor Filter Name
                        	**type**\: str
                        
                        .. attribute:: join_prune_interval
                        
                        	Join\-Prune Interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: prune_delay_enabled
                        
                        	Prune Delay Enabled
                        	**type**\: bool
                        
                        .. attribute:: configured_propagation_delay
                        
                        	Configured Propagation Delay
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: configured_override_interval
                        
                        	Configured Override Interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: generation_id
                        
                        	Generation Identifier
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Bidir Capable
                        	**type**\: bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Proxy Capable
                        	**type**\: bool
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Batch Asserts Capable
                        	**type**\: bool
                        
                        .. attribute:: idb_oor_enabled
                        
                        	Interface oor enabled
                        	**type**\: bool
                        
                        .. attribute:: idb_acl_provided
                        
                        	ACL name provided
                        	**type**\: bool
                        
                        .. attribute:: idb_max_count
                        
                        	Interface ole max count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_threshold_count
                        
                        	Interface ole threshold count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_current_count
                        
                        	Interface ole current count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_acl_name
                        
                        	Interface ole ACL Name
                        	**type**\: str
                        
                        	**length:** 0..64
                        
                        .. attribute:: interface_address
                        
                        	List of Interface IP Addresses
                        	**type**\: list of  		 :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.InterfaceAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface, self).__init__()

                            self.yang_name = "ifrs-interface"
                            self.yang_parent_name = "ifrs-interfaces"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['interface_name']
                            self._child_classes = OrderedDict([("dr-address", ("dr_address", Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress)), ("interface-address", ("interface_address", Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.InterfaceAddress))])
                            self._leafs = OrderedDict([
                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                                ('interface_address_mask', (YLeaf(YType.uint8, 'interface-address-mask'), ['int'])),
                                ('is_enabled', (YLeaf(YType.boolean, 'is-enabled'), ['bool'])),
                                ('neighbor_count', (YLeaf(YType.uint16, 'neighbor-count'), ['int'])),
                                ('external_neighbor_count', (YLeaf(YType.uint16, 'external-neighbor-count'), ['int'])),
                                ('hello_interval', (YLeaf(YType.uint16, 'hello-interval'), ['int'])),
                                ('dr_priority', (YLeaf(YType.uint32, 'dr-priority'), ['int'])),
                                ('hello_expiry', (YLeaf(YType.uint64, 'hello-expiry'), ['int'])),
                                ('are_we_dr', (YLeaf(YType.boolean, 'are-we-dr'), ['bool'])),
                                ('bfd_enabled', (YLeaf(YType.boolean, 'bfd-enabled'), ['bool'])),
                                ('bfd_interval', (YLeaf(YType.uint32, 'bfd-interval'), ['int'])),
                                ('bfd_multiplier', (YLeaf(YType.uint32, 'bfd-multiplier'), ['int'])),
                                ('virtual_interface', (YLeaf(YType.boolean, 'virtual-interface'), ['bool'])),
                                ('passive_interface', (YLeaf(YType.boolean, 'passive-interface'), ['bool'])),
                                ('neighbor_filter_name', (YLeaf(YType.str, 'neighbor-filter-name'), ['str'])),
                                ('join_prune_interval', (YLeaf(YType.uint16, 'join-prune-interval'), ['int'])),
                                ('prune_delay_enabled', (YLeaf(YType.boolean, 'prune-delay-enabled'), ['bool'])),
                                ('configured_propagation_delay', (YLeaf(YType.uint16, 'configured-propagation-delay'), ['int'])),
                                ('propagation_delay', (YLeaf(YType.uint16, 'propagation-delay'), ['int'])),
                                ('configured_override_interval', (YLeaf(YType.uint16, 'configured-override-interval'), ['int'])),
                                ('override_interval', (YLeaf(YType.uint16, 'override-interval'), ['int'])),
                                ('generation_id', (YLeaf(YType.uint32, 'generation-id'), ['int'])),
                                ('is_bidirectional_capable', (YLeaf(YType.boolean, 'is-bidirectional-capable'), ['bool'])),
                                ('is_proxy_capable', (YLeaf(YType.boolean, 'is-proxy-capable'), ['bool'])),
                                ('is_batch_asserts_capable', (YLeaf(YType.boolean, 'is-batch-asserts-capable'), ['bool'])),
                                ('idb_oor_enabled', (YLeaf(YType.boolean, 'idb-oor-enabled'), ['bool'])),
                                ('idb_acl_provided', (YLeaf(YType.boolean, 'idb-acl-provided'), ['bool'])),
                                ('idb_max_count', (YLeaf(YType.uint32, 'idb-max-count'), ['int'])),
                                ('idb_threshold_count', (YLeaf(YType.uint32, 'idb-threshold-count'), ['int'])),
                                ('idb_current_count', (YLeaf(YType.uint32, 'idb-current-count'), ['int'])),
                                ('idb_acl_name', (YLeaf(YType.str, 'idb-acl-name'), ['str'])),
                            ])
                            self.interface_name = None
                            self.interface_name_xr = None
                            self.interface_address_mask = None
                            self.is_enabled = None
                            self.neighbor_count = None
                            self.external_neighbor_count = None
                            self.hello_interval = None
                            self.dr_priority = None
                            self.hello_expiry = None
                            self.are_we_dr = None
                            self.bfd_enabled = None
                            self.bfd_interval = None
                            self.bfd_multiplier = None
                            self.virtual_interface = None
                            self.passive_interface = None
                            self.neighbor_filter_name = None
                            self.join_prune_interval = None
                            self.prune_delay_enabled = None
                            self.configured_propagation_delay = None
                            self.propagation_delay = None
                            self.configured_override_interval = None
                            self.override_interval = None
                            self.generation_id = None
                            self.is_bidirectional_capable = None
                            self.is_proxy_capable = None
                            self.is_batch_asserts_capable = None
                            self.idb_oor_enabled = None
                            self.idb_acl_provided = None
                            self.idb_max_count = None
                            self.idb_threshold_count = None
                            self.idb_current_count = None
                            self.idb_acl_name = None

                            self.dr_address = Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress()
                            self.dr_address.parent = self
                            self._children_name_map["dr_address"] = "dr-address"

                            self.interface_address = YList(self)
                            self._segment_path = lambda: "ifrs-interface" + "[interface-name='" + str(self.interface_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface, ['interface_name', 'interface_name_xr', 'interface_address_mask', 'is_enabled', 'neighbor_count', 'external_neighbor_count', 'hello_interval', 'dr_priority', 'hello_expiry', 'are_we_dr', 'bfd_enabled', 'bfd_interval', 'bfd_multiplier', 'virtual_interface', 'passive_interface', 'neighbor_filter_name', 'join_prune_interval', 'prune_delay_enabled', 'configured_propagation_delay', 'propagation_delay', 'configured_override_interval', 'override_interval', 'generation_id', 'is_bidirectional_capable', 'is_proxy_capable', 'is_batch_asserts_capable', 'idb_oor_enabled', 'idb_acl_provided', 'idb_max_count', 'idb_threshold_count', 'idb_current_count', 'idb_acl_name'], name, value)


                        class DrAddress(Entity):
                            """
                            PIM Designated Router
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress, self).__init__()

                                self.yang_name = "dr-address"
                                self.yang_parent_name = "ifrs-interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "dr-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class InterfaceAddress(Entity):
                            """
                            List of Interface IP Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.InterfaceAddress, self).__init__()

                                self.yang_name = "interface-address"
                                self.yang_parent_name = "ifrs-interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "interface-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.InterfaceAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class Safs(Entity):
                    """
                    SAFI table and type
                    
                    .. attribute:: saf
                    
                    	SAF name 
                    	**type**\: list of  		 :py:class:`Saf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Safs.Saf>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.Safs, self).__init__()

                        self.yang_name = "safs"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("saf", ("saf", Pim.Standby.Vrfs.Vrf.Safs.Saf))])
                        self._leafs = OrderedDict()

                        self.saf = YList(self)
                        self._segment_path = lambda: "safs"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.Safs, [], name, value)


                    class Saf(Entity):
                        """
                        SAF name 
                        
                        .. attribute:: rpf_hash_source_groups
                        
                        	PIM RPF multipath hash outcome
                        	**type**\:  :py:class:`RpfHashSourceGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups>`
                        
                        .. attribute:: rpf_hash_sources
                        
                        	PIM RPF multipath hash outcome
                        	**type**\:  :py:class:`RpfHashSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources>`
                        
                        .. attribute:: rpfs
                        
                        	PIM RPF information table
                        	**type**\:  :py:class:`Rpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs>`
                        
                        .. attribute:: saf_name
                        
                        	SAF name 
                        	**type**\:  :py:class:`PimSafi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimSafi>`
                        
                        .. attribute:: topology_name
                        
                        	Topology name 
                        	**type**\: str
                        
                        	**length:** 1..32
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.Safs.Saf, self).__init__()

                            self.yang_name = "saf"
                            self.yang_parent_name = "safs"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rpf-hash-source-groups", ("rpf_hash_source_groups", Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups)), ("rpf-hash-sources", ("rpf_hash_sources", Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources)), ("rpfs", ("rpfs", Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs))])
                            self._leafs = OrderedDict([
                                ('saf_name', (YLeaf(YType.enumeration, 'saf-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimSafi', '')])),
                                ('topology_name', (YLeaf(YType.str, 'topology-name'), ['str'])),
                            ])
                            self.saf_name = None
                            self.topology_name = None

                            self.rpf_hash_source_groups = Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups()
                            self.rpf_hash_source_groups.parent = self
                            self._children_name_map["rpf_hash_source_groups"] = "rpf-hash-source-groups"

                            self.rpf_hash_sources = Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources()
                            self.rpf_hash_sources.parent = self
                            self._children_name_map["rpf_hash_sources"] = "rpf-hash-sources"

                            self.rpfs = Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs()
                            self.rpfs.parent = self
                            self._children_name_map["rpfs"] = "rpfs"
                            self._segment_path = lambda: "saf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.Safs.Saf, ['saf_name', 'topology_name'], name, value)


                        class RpfHashSourceGroups(Entity):
                            """
                            PIM RPF multipath hash outcome
                            
                            .. attribute:: rpf_hash_source_group
                            
                            	PIM RPF hash outcome for S,G
                            	**type**\: list of  		 :py:class:`RpfHashSourceGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups, self).__init__()

                                self.yang_name = "rpf-hash-source-groups"
                                self.yang_parent_name = "saf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("rpf-hash-source-group", ("rpf_hash_source_group", Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup))])
                                self._leafs = OrderedDict()

                                self.rpf_hash_source_group = YList(self)
                                self._segment_path = lambda: "rpf-hash-source-groups"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups, [], name, value)


                            class RpfHashSourceGroup(Entity):
                                """
                                PIM RPF hash outcome for S,G
                                
                                .. attribute:: source_address
                                
                                	Source address
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: group_address
                                
                                	Group address
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: mask_length
                                
                                	Hash mask length
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: mofrr
                                
                                	MOFRR
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_address
                                
                                	Next hop neighbor address
                                	**type**\:  :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress>`
                                
                                .. attribute:: secondary_next_hop_address
                                
                                	Secondary Next hop neighbor address
                                	**type**\:  :py:class:`SecondaryNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress>`
                                
                                .. attribute:: next_hop_multipath_enabled
                                
                                	Next hop multipath enabled?
                                	**type**\: bool
                                
                                .. attribute:: next_hop_interface
                                
                                	Next hop neighbor interface
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                .. attribute:: secondary_next_hop_interface
                                
                                	Secondary Next hop neighbor interface
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup, self).__init__()

                                    self.yang_name = "rpf-hash-source-group"
                                    self.yang_parent_name = "rpf-hash-source-groups"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("next-hop-address", ("next_hop_address", Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress)), ("secondary-next-hop-address", ("secondary_next_hop_address", Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress))])
                                    self._leafs = OrderedDict([
                                        ('source_address', (YLeaf(YType.str, 'source-address'), ['str','str'])),
                                        ('group_address', (YLeaf(YType.str, 'group-address'), ['str','str'])),
                                        ('mask_length', (YLeaf(YType.uint32, 'mask-length'), ['int'])),
                                        ('mofrr', (YLeaf(YType.uint32, 'mofrr'), ['int'])),
                                        ('next_hop_multipath_enabled', (YLeaf(YType.boolean, 'next-hop-multipath-enabled'), ['bool'])),
                                        ('next_hop_interface', (YLeaf(YType.str, 'next-hop-interface'), ['str'])),
                                        ('secondary_next_hop_interface', (YLeaf(YType.str, 'secondary-next-hop-interface'), ['str'])),
                                    ])
                                    self.source_address = None
                                    self.group_address = None
                                    self.mask_length = None
                                    self.mofrr = None
                                    self.next_hop_multipath_enabled = None
                                    self.next_hop_interface = None
                                    self.secondary_next_hop_interface = None

                                    self.next_hop_address = Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress()
                                    self.next_hop_address.parent = self
                                    self._children_name_map["next_hop_address"] = "next-hop-address"

                                    self.secondary_next_hop_address = Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress()
                                    self.secondary_next_hop_address.parent = self
                                    self._children_name_map["secondary_next_hop_address"] = "secondary-next-hop-address"
                                    self._segment_path = lambda: "rpf-hash-source-group"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup, ['source_address', 'group_address', 'mask_length', 'mofrr', 'next_hop_multipath_enabled', 'next_hop_interface', 'secondary_next_hop_interface'], name, value)


                                class NextHopAddress(Entity):
                                    """
                                    Next hop neighbor address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress, self).__init__()

                                        self.yang_name = "next-hop-address"
                                        self.yang_parent_name = "rpf-hash-source-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ])
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None
                                        self._segment_path = lambda: "next-hop-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                                class SecondaryNextHopAddress(Entity):
                                    """
                                    Secondary Next hop neighbor address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress, self).__init__()

                                        self.yang_name = "secondary-next-hop-address"
                                        self.yang_parent_name = "rpf-hash-source-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ])
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None
                                        self._segment_path = lambda: "secondary-next-hop-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class RpfHashSources(Entity):
                            """
                            PIM RPF multipath hash outcome
                            
                            .. attribute:: rpf_hash_source
                            
                            	PIM RPF hash outcome for S,G
                            	**type**\: list of  		 :py:class:`RpfHashSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources, self).__init__()

                                self.yang_name = "rpf-hash-sources"
                                self.yang_parent_name = "saf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("rpf-hash-source", ("rpf_hash_source", Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource))])
                                self._leafs = OrderedDict()

                                self.rpf_hash_source = YList(self)
                                self._segment_path = lambda: "rpf-hash-sources"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources, [], name, value)


                            class RpfHashSource(Entity):
                                """
                                PIM RPF hash outcome for S,G
                                
                                .. attribute:: source_address
                                
                                	Source address
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: mofrr
                                
                                	MOFRR
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_address
                                
                                	Next hop neighbor address
                                	**type**\:  :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress>`
                                
                                .. attribute:: secondary_next_hop_address
                                
                                	Secondary Next hop neighbor address
                                	**type**\:  :py:class:`SecondaryNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress>`
                                
                                .. attribute:: next_hop_multipath_enabled
                                
                                	Next hop multipath enabled?
                                	**type**\: bool
                                
                                .. attribute:: next_hop_interface
                                
                                	Next hop neighbor interface
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                .. attribute:: secondary_next_hop_interface
                                
                                	Secondary Next hop neighbor interface
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource, self).__init__()

                                    self.yang_name = "rpf-hash-source"
                                    self.yang_parent_name = "rpf-hash-sources"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("next-hop-address", ("next_hop_address", Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress)), ("secondary-next-hop-address", ("secondary_next_hop_address", Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress))])
                                    self._leafs = OrderedDict([
                                        ('source_address', (YLeaf(YType.str, 'source-address'), ['str','str'])),
                                        ('mofrr', (YLeaf(YType.uint32, 'mofrr'), ['int'])),
                                        ('next_hop_multipath_enabled', (YLeaf(YType.boolean, 'next-hop-multipath-enabled'), ['bool'])),
                                        ('next_hop_interface', (YLeaf(YType.str, 'next-hop-interface'), ['str'])),
                                        ('secondary_next_hop_interface', (YLeaf(YType.str, 'secondary-next-hop-interface'), ['str'])),
                                    ])
                                    self.source_address = None
                                    self.mofrr = None
                                    self.next_hop_multipath_enabled = None
                                    self.next_hop_interface = None
                                    self.secondary_next_hop_interface = None

                                    self.next_hop_address = Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress()
                                    self.next_hop_address.parent = self
                                    self._children_name_map["next_hop_address"] = "next-hop-address"

                                    self.secondary_next_hop_address = Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress()
                                    self.secondary_next_hop_address.parent = self
                                    self._children_name_map["secondary_next_hop_address"] = "secondary-next-hop-address"
                                    self._segment_path = lambda: "rpf-hash-source"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource, ['source_address', 'mofrr', 'next_hop_multipath_enabled', 'next_hop_interface', 'secondary_next_hop_interface'], name, value)


                                class NextHopAddress(Entity):
                                    """
                                    Next hop neighbor address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress, self).__init__()

                                        self.yang_name = "next-hop-address"
                                        self.yang_parent_name = "rpf-hash-source"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ])
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None
                                        self._segment_path = lambda: "next-hop-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                                class SecondaryNextHopAddress(Entity):
                                    """
                                    Secondary Next hop neighbor address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress, self).__init__()

                                        self.yang_name = "secondary-next-hop-address"
                                        self.yang_parent_name = "rpf-hash-source"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ])
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None
                                        self._segment_path = lambda: "secondary-next-hop-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class Rpfs(Entity):
                            """
                            PIM RPF information table
                            
                            .. attribute:: rpf
                            
                            	PIM RPF information
                            	**type**\: list of  		 :py:class:`Rpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs, self).__init__()

                                self.yang_name = "rpfs"
                                self.yang_parent_name = "saf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("rpf", ("rpf", Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf))])
                                self._leafs = OrderedDict()

                                self.rpf = YList(self)
                                self._segment_path = lambda: "rpfs"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs, [], name, value)


                            class Rpf(Entity):
                                """
                                PIM RPF information
                                
                                .. attribute:: registered_address  (key)
                                
                                	Address for which RPF lookup
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: registered_address_xr
                                
                                	Address registered
                                	**type**\:  :py:class:`RegisteredAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr>`
                                
                                .. attribute:: metric
                                
                                	Metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_preference
                                
                                	Metric preference
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_connected
                                
                                	Are we connected ?
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: is_rpf_bgp_route
                                
                                	Is RPF through BGP route
                                	**type**\: bool
                                
                                .. attribute:: rpf_path
                                
                                	RPF Paths list
                                	**type**\: list of  		 :py:class:`RpfPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf, self).__init__()

                                    self.yang_name = "rpf"
                                    self.yang_parent_name = "rpfs"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['registered_address']
                                    self._child_classes = OrderedDict([("registered-address-xr", ("registered_address_xr", Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr)), ("rpf-path", ("rpf_path", Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath))])
                                    self._leafs = OrderedDict([
                                        ('registered_address', (YLeaf(YType.str, 'registered-address'), ['str','str'])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_preference', (YLeaf(YType.uint32, 'metric-preference'), ['int'])),
                                        ('is_connected', (YLeaf(YType.uint8, 'is-connected'), ['int'])),
                                        ('is_rpf_bgp_route', (YLeaf(YType.boolean, 'is-rpf-bgp-route'), ['bool'])),
                                    ])
                                    self.registered_address = None
                                    self.metric = None
                                    self.metric_preference = None
                                    self.is_connected = None
                                    self.is_rpf_bgp_route = None

                                    self.registered_address_xr = Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr()
                                    self.registered_address_xr.parent = self
                                    self._children_name_map["registered_address_xr"] = "registered-address-xr"

                                    self.rpf_path = YList(self)
                                    self._segment_path = lambda: "rpf" + "[registered-address='" + str(self.registered_address) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf, ['registered_address', 'metric', 'metric_preference', 'is_connected', 'is_rpf_bgp_route'], name, value)


                                class RegisteredAddressXr(Entity):
                                    """
                                    Address registered
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr, self).__init__()

                                        self.yang_name = "registered-address-xr"
                                        self.yang_parent_name = "rpf"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ])
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None
                                        self._segment_path = lambda: "registered-address-xr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                                class RpfPath(Entity):
                                    """
                                    RPF Paths list
                                    
                                    .. attribute:: rpf_neighbor
                                    
                                    	RPF neighbor
                                    	**type**\:  :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor>`
                                    
                                    .. attribute:: rpf_nexthop
                                    
                                    	RPF nexthop
                                    	**type**\:  :py:class:`RpfNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop>`
                                    
                                    .. attribute:: rpf_interface_name
                                    
                                    	RPF Interface
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: is_rpf_interface_disabled
                                    
                                    	Is the rpf interface disabled ?
                                    	**type**\: bool
                                    
                                    .. attribute:: is_via_lsm
                                    
                                    	Via LSM
                                    	**type**\: bool
                                    
                                    .. attribute:: is_via_mlsm
                                    
                                    	Via Mstatic LSM
                                    	**type**\: bool
                                    
                                    .. attribute:: is_connector_attribute_present
                                    
                                    	Connector attribute present
                                    	**type**\: bool
                                    
                                    .. attribute:: connector
                                    
                                    	Connector Attribute
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    .. attribute:: extranet_vrf_name
                                    
                                    	Extranet VRF name
                                    	**type**\: str
                                    
                                    	**length:** 0..33
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath, self).__init__()

                                        self.yang_name = "rpf-path"
                                        self.yang_parent_name = "rpf"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("rpf-neighbor", ("rpf_neighbor", Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor)), ("rpf-nexthop", ("rpf_nexthop", Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop))])
                                        self._leafs = OrderedDict([
                                            ('rpf_interface_name', (YLeaf(YType.str, 'rpf-interface-name'), ['str'])),
                                            ('is_rpf_interface_disabled', (YLeaf(YType.boolean, 'is-rpf-interface-disabled'), ['bool'])),
                                            ('is_via_lsm', (YLeaf(YType.boolean, 'is-via-lsm'), ['bool'])),
                                            ('is_via_mlsm', (YLeaf(YType.boolean, 'is-via-mlsm'), ['bool'])),
                                            ('is_connector_attribute_present', (YLeaf(YType.boolean, 'is-connector-attribute-present'), ['bool'])),
                                            ('connector', (YLeaf(YType.str, 'connector'), ['str'])),
                                            ('extranet_vrf_name', (YLeaf(YType.str, 'extranet-vrf-name'), ['str'])),
                                        ])
                                        self.rpf_interface_name = None
                                        self.is_rpf_interface_disabled = None
                                        self.is_via_lsm = None
                                        self.is_via_mlsm = None
                                        self.is_connector_attribute_present = None
                                        self.connector = None
                                        self.extranet_vrf_name = None

                                        self.rpf_neighbor = Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor()
                                        self.rpf_neighbor.parent = self
                                        self._children_name_map["rpf_neighbor"] = "rpf-neighbor"

                                        self.rpf_nexthop = Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop()
                                        self.rpf_nexthop.parent = self
                                        self._children_name_map["rpf_nexthop"] = "rpf-nexthop"
                                        self._segment_path = lambda: "rpf-path"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath, ['rpf_interface_name', 'is_rpf_interface_disabled', 'is_via_lsm', 'is_via_mlsm', 'is_connector_attribute_present', 'connector', 'extranet_vrf_name'], name, value)


                                    class RpfNeighbor(Entity):
                                        """
                                        RPF neighbor
                                        
                                        .. attribute:: af_name
                                        
                                        	AFName
                                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Address
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-pim-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor, self).__init__()

                                            self.yang_name = "rpf-neighbor"
                                            self.yang_parent_name = "rpf-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                            ])
                                            self.af_name = None
                                            self.ipv4_address = None
                                            self.ipv6_address = None
                                            self._segment_path = lambda: "rpf-neighbor"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                                    class RpfNexthop(Entity):
                                        """
                                        RPF nexthop
                                        
                                        .. attribute:: af_name
                                        
                                        	AFName
                                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Address
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-pim-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop, self).__init__()

                                            self.yang_name = "rpf-nexthop"
                                            self.yang_parent_name = "rpf-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                            ])
                                            self.af_name = None
                                            self.ipv4_address = None
                                            self.ipv6_address = None
                                            self._segment_path = lambda: "rpf-nexthop"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class InterfaceStatistics(Entity):
                    """
                    PIM interface statistics
                    
                    .. attribute:: interface_statistic
                    
                    	PIM interface statistics
                    	**type**\: list of  		 :py:class:`InterfaceStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.InterfaceStatistics.InterfaceStatistic>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.InterfaceStatistics, self).__init__()

                        self.yang_name = "interface-statistics"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("interface-statistic", ("interface_statistic", Pim.Standby.Vrfs.Vrf.InterfaceStatistics.InterfaceStatistic))])
                        self._leafs = OrderedDict()

                        self.interface_statistic = YList(self)
                        self._segment_path = lambda: "interface-statistics"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.InterfaceStatistics, [], name, value)


                    class InterfaceStatistic(Entity):
                        """
                        PIM interface statistics
                        
                        .. attribute:: interface_name  (key)
                        
                        	Interface name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: input_hello
                        
                        	Hello packets in
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_hello
                        
                        	Hello packets out
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_register
                        
                        	Register packets in
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_register
                        
                        	Register packets out
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_register_stop
                        
                        	Register Stop packets in
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_register_stop
                        
                        	Register Stop packets out
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_jp
                        
                        	Join Prune packets in
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_jp
                        
                        	Join Prune packets out
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_bsr_message
                        
                        	Input BSR Messages
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_bsr_message
                        
                        	Output BSR Messages
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_assert
                        
                        	Assert packets in
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_assert
                        
                        	Assert packets out
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_graft_message
                        
                        	Input Graft Messages
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_graft_message
                        
                        	Output Graft Messages
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_graft_ack_message
                        
                        	Input Graft Ack Messages
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_graft_ack_message
                        
                        	Output Graft Ack Messages
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_candidate_rp_advertisement
                        
                        	Input Candidate\-RP Advertisment
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_candidate_rp_advertisement
                        
                        	Output Candidate\-RP Advertisment
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_df_election
                        
                        	DF Election packets in
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_df_election
                        
                        	DF Election packets out
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_miscellaneous
                        
                        	Miscellaneous packet in
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.InterfaceStatistics.InterfaceStatistic, self).__init__()

                            self.yang_name = "interface-statistic"
                            self.yang_parent_name = "interface-statistics"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['interface_name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ('input_hello', (YLeaf(YType.uint32, 'input-hello'), ['int'])),
                                ('output_hello', (YLeaf(YType.uint32, 'output-hello'), ['int'])),
                                ('input_register', (YLeaf(YType.uint32, 'input-register'), ['int'])),
                                ('output_register', (YLeaf(YType.uint32, 'output-register'), ['int'])),
                                ('input_register_stop', (YLeaf(YType.uint32, 'input-register-stop'), ['int'])),
                                ('output_register_stop', (YLeaf(YType.uint32, 'output-register-stop'), ['int'])),
                                ('input_jp', (YLeaf(YType.uint32, 'input-jp'), ['int'])),
                                ('output_jp', (YLeaf(YType.uint32, 'output-jp'), ['int'])),
                                ('input_bsr_message', (YLeaf(YType.uint32, 'input-bsr-message'), ['int'])),
                                ('output_bsr_message', (YLeaf(YType.uint32, 'output-bsr-message'), ['int'])),
                                ('input_assert', (YLeaf(YType.uint32, 'input-assert'), ['int'])),
                                ('output_assert', (YLeaf(YType.uint32, 'output-assert'), ['int'])),
                                ('input_graft_message', (YLeaf(YType.uint32, 'input-graft-message'), ['int'])),
                                ('output_graft_message', (YLeaf(YType.uint32, 'output-graft-message'), ['int'])),
                                ('input_graft_ack_message', (YLeaf(YType.uint32, 'input-graft-ack-message'), ['int'])),
                                ('output_graft_ack_message', (YLeaf(YType.uint32, 'output-graft-ack-message'), ['int'])),
                                ('input_candidate_rp_advertisement', (YLeaf(YType.uint32, 'input-candidate-rp-advertisement'), ['int'])),
                                ('output_candidate_rp_advertisement', (YLeaf(YType.uint32, 'output-candidate-rp-advertisement'), ['int'])),
                                ('input_df_election', (YLeaf(YType.uint32, 'input-df-election'), ['int'])),
                                ('output_df_election', (YLeaf(YType.uint32, 'output-df-election'), ['int'])),
                                ('input_miscellaneous', (YLeaf(YType.uint32, 'input-miscellaneous'), ['int'])),
                            ])
                            self.interface_name = None
                            self.input_hello = None
                            self.output_hello = None
                            self.input_register = None
                            self.output_register = None
                            self.input_register_stop = None
                            self.output_register_stop = None
                            self.input_jp = None
                            self.output_jp = None
                            self.input_bsr_message = None
                            self.output_bsr_message = None
                            self.input_assert = None
                            self.output_assert = None
                            self.input_graft_message = None
                            self.output_graft_message = None
                            self.input_graft_ack_message = None
                            self.output_graft_ack_message = None
                            self.input_candidate_rp_advertisement = None
                            self.output_candidate_rp_advertisement = None
                            self.input_df_election = None
                            self.output_df_election = None
                            self.input_miscellaneous = None
                            self._segment_path = lambda: "interface-statistic" + "[interface-name='" + str(self.interface_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.InterfaceStatistics.InterfaceStatistic, ['interface_name', 'input_hello', 'output_hello', 'input_register', 'output_register', 'input_register_stop', 'output_register_stop', 'input_jp', 'output_jp', 'input_bsr_message', 'output_bsr_message', 'input_assert', 'output_assert', 'input_graft_message', 'output_graft_message', 'input_graft_ack_message', 'output_graft_ack_message', 'input_candidate_rp_advertisement', 'output_candidate_rp_advertisement', 'input_df_election', 'output_df_election', 'input_miscellaneous'], name, value)


                class TopologyRouteCount(Entity):
                    """
                    Topology route count information from PIM
                    topology table
                    
                    .. attribute:: group_ranges
                    
                    	No. of (\*,G/M) routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: active_group_ranges
                    
                    	No. of (\*,G/M) routes active in mrib
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: groute_count
                    
                    	No. of (\*,G) routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sg_route_count
                    
                    	No. of (S,G) routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sgr_route_count
                    
                    	No. of (S,G)RPT routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.TopologyRouteCount, self).__init__()

                        self.yang_name = "topology-route-count"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('group_ranges', (YLeaf(YType.uint32, 'group-ranges'), ['int'])),
                            ('active_group_ranges', (YLeaf(YType.uint32, 'active-group-ranges'), ['int'])),
                            ('groute_count', (YLeaf(YType.uint32, 'groute-count'), ['int'])),
                            ('sg_route_count', (YLeaf(YType.uint32, 'sg-route-count'), ['int'])),
                            ('sgr_route_count', (YLeaf(YType.uint32, 'sgr-route-count'), ['int'])),
                            ('is_node_low_memory', (YLeaf(YType.boolean, 'is-node-low-memory'), ['bool'])),
                        ])
                        self.group_ranges = None
                        self.active_group_ranges = None
                        self.groute_count = None
                        self.sg_route_count = None
                        self.sgr_route_count = None
                        self.is_node_low_memory = None
                        self._segment_path = lambda: "topology-route-count"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.TopologyRouteCount, ['group_ranges', 'active_group_ranges', 'groute_count', 'sg_route_count', 'sgr_route_count', 'is_node_low_memory'], name, value)


                class JpStatistics(Entity):
                    """
                    PIM join prune statistics table
                    
                    .. attribute:: jp_statistic
                    
                    	PIM Join Prune Statistics
                    	**type**\: list of  		 :py:class:`JpStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.JpStatistics.JpStatistic>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.JpStatistics, self).__init__()

                        self.yang_name = "jp-statistics"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("jp-statistic", ("jp_statistic", Pim.Standby.Vrfs.Vrf.JpStatistics.JpStatistic))])
                        self._leafs = OrderedDict()

                        self.jp_statistic = YList(self)
                        self._segment_path = lambda: "jp-statistics"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.JpStatistics, [], name, value)


                    class JpStatistic(Entity):
                        """
                        PIM Join Prune Statistics
                        
                        .. attribute:: interface_name  (key)
                        
                        	Interface name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identifier
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: mtu
                        
                        	Interface MTU
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: transmitted
                        
                        	Transmitted
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: transmitted100
                        
                        	Transmitted 100 average
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: transmitted_1k
                        
                        	Transmitted 1K average
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: transmitted_10k
                        
                        	Transmitted 10K average
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: transmitted_50k
                        
                        	Deprecated by Transmitted100
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: received
                        
                        	Received
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: received100
                        
                        	Received 100 average
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: received_1k
                        
                        	Received 1K average
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: received_10k
                        
                        	Received 10K average
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: received_50k
                        
                        	Deprecated by Received100
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.JpStatistics.JpStatistic, self).__init__()

                            self.yang_name = "jp-statistic"
                            self.yang_parent_name = "jp-statistics"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['interface_name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                                ('mtu', (YLeaf(YType.uint32, 'mtu'), ['int'])),
                                ('transmitted', (YLeaf(YType.uint32, 'transmitted'), ['int'])),
                                ('transmitted100', (YLeaf(YType.uint16, 'transmitted100'), ['int'])),
                                ('transmitted_1k', (YLeaf(YType.uint16, 'transmitted-1k'), ['int'])),
                                ('transmitted_10k', (YLeaf(YType.uint16, 'transmitted-10k'), ['int'])),
                                ('transmitted_50k', (YLeaf(YType.uint16, 'transmitted-50k'), ['int'])),
                                ('received', (YLeaf(YType.uint32, 'received'), ['int'])),
                                ('received100', (YLeaf(YType.uint16, 'received100'), ['int'])),
                                ('received_1k', (YLeaf(YType.uint16, 'received-1k'), ['int'])),
                                ('received_10k', (YLeaf(YType.uint16, 'received-10k'), ['int'])),
                                ('received_50k', (YLeaf(YType.uint16, 'received-50k'), ['int'])),
                            ])
                            self.interface_name = None
                            self.interface_name_xr = None
                            self.mtu = None
                            self.transmitted = None
                            self.transmitted100 = None
                            self.transmitted_1k = None
                            self.transmitted_10k = None
                            self.transmitted_50k = None
                            self.received = None
                            self.received100 = None
                            self.received_1k = None
                            self.received_10k = None
                            self.received_50k = None
                            self._segment_path = lambda: "jp-statistic" + "[interface-name='" + str(self.interface_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.JpStatistics.JpStatistic, ['interface_name', 'interface_name_xr', 'mtu', 'transmitted', 'transmitted100', 'transmitted_1k', 'transmitted_10k', 'transmitted_50k', 'received', 'received100', 'received_1k', 'received_10k', 'received_50k'], name, value)


                class MibDatabases(Entity):
                    """
                    PIM group database for mroute mibs table
                    
                    .. attribute:: mib_database
                    
                    	PIM multicast static route information
                    	**type**\: list of  		 :py:class:`MibDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.MibDatabases, self).__init__()

                        self.yang_name = "mib-databases"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("mib-database", ("mib_database", Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase))])
                        self._leafs = OrderedDict()

                        self.mib_database = YList(self)
                        self._segment_path = lambda: "mib-databases"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.MibDatabases, [], name, value)


                    class MibDatabase(Entity):
                        """
                        PIM multicast static route information
                        
                        .. attribute:: source_address
                        
                        	Multicast static route source address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: group_address
                        
                        	Multicast satic route group address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source_netmask
                        
                        	Source mask
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: source_address_xr
                        
                        	Source Address
                        	**type**\:  :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr>`
                        
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:  :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr>`
                        
                        .. attribute:: rpf_neighbor
                        
                        	The RPF Neighbor
                        	**type**\:  :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor>`
                        
                        .. attribute:: rpf_root
                        
                        	Root of this mcast tree
                        	**type**\:  :py:class:`RpfRoot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot>`
                        
                        .. attribute:: upstream_assert_timer
                        
                        	Upstream Assert Timer
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: assert_metric
                        
                        	Assert Metric
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: assert_metric_preference
                        
                        	Assert Metric Preference
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: assert_rpt_bit
                        
                        	Assert RPT Bit
                        	**type**\: bool
                        
                        .. attribute:: spt_bit
                        
                        	Is SPT bit set ?
                        	**type**\: bool
                        
                        .. attribute:: rpf_mask
                        
                        	Mask of the multicast root
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rpf_safi
                        
                        	Unicast or mcast
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: rpf_table_name
                        
                        	RPF Table name
                        	**type**\: str
                        
                        .. attribute:: rpf_drop
                        
                        	RPF route\-policy drop
                        	**type**\: bool
                        
                        .. attribute:: rpf_extranet
                        
                        	Extranet RPF route\-policy
                        	**type**\: bool
                        
                        .. attribute:: rpf_interface_name
                        
                        	RPF interface name 
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: rpf_vrf_name
                        
                        	RPF VRF Name
                        	**type**\: str
                        
                        	**length:** 0..33
                        
                        .. attribute:: bidirectional_route
                        
                        	Is this Bidir ?
                        	**type**\: bool
                        
                        .. attribute:: uptime
                        
                        	Uptime of route
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: protocol
                        
                        	The PIM protocol
                        	**type**\:  :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase, self).__init__()

                            self.yang_name = "mib-database"
                            self.yang_parent_name = "mib-databases"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("source-address-xr", ("source_address_xr", Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr)), ("group-address-xr", ("group_address_xr", Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr)), ("rpf-neighbor", ("rpf_neighbor", Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor)), ("rpf-root", ("rpf_root", Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot))])
                            self._leafs = OrderedDict([
                                ('source_address', (YLeaf(YType.str, 'source-address'), ['str','str'])),
                                ('group_address', (YLeaf(YType.str, 'group-address'), ['str','str'])),
                                ('source_netmask', (YLeaf(YType.uint32, 'source-netmask'), ['int'])),
                                ('upstream_assert_timer', (YLeaf(YType.int32, 'upstream-assert-timer'), ['int'])),
                                ('assert_metric', (YLeaf(YType.uint32, 'assert-metric'), ['int'])),
                                ('assert_metric_preference', (YLeaf(YType.uint32, 'assert-metric-preference'), ['int'])),
                                ('assert_rpt_bit', (YLeaf(YType.boolean, 'assert-rpt-bit'), ['bool'])),
                                ('spt_bit', (YLeaf(YType.boolean, 'spt-bit'), ['bool'])),
                                ('rpf_mask', (YLeaf(YType.uint32, 'rpf-mask'), ['int'])),
                                ('rpf_safi', (YLeaf(YType.uint8, 'rpf-safi'), ['int'])),
                                ('rpf_table_name', (YLeaf(YType.str, 'rpf-table-name'), ['str'])),
                                ('rpf_drop', (YLeaf(YType.boolean, 'rpf-drop'), ['bool'])),
                                ('rpf_extranet', (YLeaf(YType.boolean, 'rpf-extranet'), ['bool'])),
                                ('rpf_interface_name', (YLeaf(YType.str, 'rpf-interface-name'), ['str'])),
                                ('rpf_vrf_name', (YLeaf(YType.str, 'rpf-vrf-name'), ['str'])),
                                ('bidirectional_route', (YLeaf(YType.boolean, 'bidirectional-route'), ['bool'])),
                                ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                                ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowProtocol', '')])),
                            ])
                            self.source_address = None
                            self.group_address = None
                            self.source_netmask = None
                            self.upstream_assert_timer = None
                            self.assert_metric = None
                            self.assert_metric_preference = None
                            self.assert_rpt_bit = None
                            self.spt_bit = None
                            self.rpf_mask = None
                            self.rpf_safi = None
                            self.rpf_table_name = None
                            self.rpf_drop = None
                            self.rpf_extranet = None
                            self.rpf_interface_name = None
                            self.rpf_vrf_name = None
                            self.bidirectional_route = None
                            self.uptime = None
                            self.protocol = None

                            self.source_address_xr = Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr()
                            self.source_address_xr.parent = self
                            self._children_name_map["source_address_xr"] = "source-address-xr"

                            self.group_address_xr = Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"

                            self.rpf_neighbor = Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor()
                            self.rpf_neighbor.parent = self
                            self._children_name_map["rpf_neighbor"] = "rpf-neighbor"

                            self.rpf_root = Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot()
                            self.rpf_root.parent = self
                            self._children_name_map["rpf_root"] = "rpf-root"
                            self._segment_path = lambda: "mib-database"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase, ['source_address', 'group_address', 'source_netmask', 'upstream_assert_timer', 'assert_metric', 'assert_metric_preference', 'assert_rpt_bit', 'spt_bit', 'rpf_mask', 'rpf_safi', 'rpf_table_name', 'rpf_drop', 'rpf_extranet', 'rpf_interface_name', 'rpf_vrf_name', 'bidirectional_route', 'uptime', 'protocol'], name, value)


                        class SourceAddressXr(Entity):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr, self).__init__()

                                self.yang_name = "source-address-xr"
                                self.yang_parent_name = "mib-database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "source-address-xr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "mib-database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "group-address-xr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class RpfNeighbor(Entity):
                            """
                            The RPF Neighbor
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor, self).__init__()

                                self.yang_name = "rpf-neighbor"
                                self.yang_parent_name = "mib-database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "rpf-neighbor"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class RpfRoot(Entity):
                            """
                            Root of this mcast tree
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot, self).__init__()

                                self.yang_name = "rpf-root"
                                self.yang_parent_name = "mib-database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "rpf-root"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class NeighborOldFormats(Entity):
                    """
                    PIM neighbor table old format
                    
                    .. attribute:: neighbor_old_format
                    
                    	PIM neighbor information
                    	**type**\: list of  		 :py:class:`NeighborOldFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.NeighborOldFormats, self).__init__()

                        self.yang_name = "neighbor-old-formats"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("neighbor-old-format", ("neighbor_old_format", Pim.Standby.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat))])
                        self._leafs = OrderedDict()

                        self.neighbor_old_format = YList(self)
                        self._segment_path = lambda: "neighbor-old-formats"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.NeighborOldFormats, [], name, value)


                    class NeighborOldFormat(Entity):
                        """
                        PIM neighbor information
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: neighbor_address
                        
                        	Neighbor address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identifier
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: expires
                        
                        	Neighbor expiry in seconds
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: expiry_timer
                        
                        	Expiry timer in seconds
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: is_this_neighbor_us
                        
                        	Is this neighbor us ?
                        	**type**\: bool
                        
                        .. attribute:: is_this_neighbor_dr
                        
                        	Is this neighbor the DR
                        	**type**\: bool
                        
                        .. attribute:: is_dr_priority_capable
                        
                        	Is this neighbor DR priority capable ?
                        	**type**\: bool
                        
                        .. attribute:: dr_priority
                        
                        	DR priority
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Is this neighbor bidir capable ?
                        	**type**\: bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Is this neighbor proxy capable?
                        	**type**\: bool
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Is this neighbor capable of batching asserts?
                        	**type**\: bool
                        
                        .. attribute:: is_ecmp_redirect_capable
                        
                        	Is this neighbor capable of Ecmp Redirect?
                        	**type**\: bool
                        
                        .. attribute:: is_bfd_state
                        
                        	Is the neighbor bfd session created
                        	**type**\: bool
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_address_xr
                        
                        	List of Neighbor Addresses
                        	**type**\: list of  		 :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat, self).__init__()

                            self.yang_name = "neighbor-old-format"
                            self.yang_parent_name = "neighbor-old-formats"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("neighbor-address-xr", ("neighbor_address_xr", Pim.Standby.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr))])
                            self._leafs = OrderedDict([
                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                                ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                                ('expires', (YLeaf(YType.uint64, 'expires'), ['int'])),
                                ('expiry_timer', (YLeaf(YType.uint64, 'expiry-timer'), ['int'])),
                                ('is_this_neighbor_us', (YLeaf(YType.boolean, 'is-this-neighbor-us'), ['bool'])),
                                ('is_this_neighbor_dr', (YLeaf(YType.boolean, 'is-this-neighbor-dr'), ['bool'])),
                                ('is_dr_priority_capable', (YLeaf(YType.boolean, 'is-dr-priority-capable'), ['bool'])),
                                ('dr_priority', (YLeaf(YType.uint32, 'dr-priority'), ['int'])),
                                ('is_bidirectional_capable', (YLeaf(YType.boolean, 'is-bidirectional-capable'), ['bool'])),
                                ('is_proxy_capable', (YLeaf(YType.boolean, 'is-proxy-capable'), ['bool'])),
                                ('is_batch_asserts_capable', (YLeaf(YType.boolean, 'is-batch-asserts-capable'), ['bool'])),
                                ('is_ecmp_redirect_capable', (YLeaf(YType.boolean, 'is-ecmp-redirect-capable'), ['bool'])),
                                ('is_bfd_state', (YLeaf(YType.boolean, 'is-bfd-state'), ['bool'])),
                                ('propagation_delay', (YLeaf(YType.uint16, 'propagation-delay'), ['int'])),
                                ('override_interval', (YLeaf(YType.uint16, 'override-interval'), ['int'])),
                            ])
                            self.interface_name = None
                            self.neighbor_address = None
                            self.interface_name_xr = None
                            self.uptime = None
                            self.expires = None
                            self.expiry_timer = None
                            self.is_this_neighbor_us = None
                            self.is_this_neighbor_dr = None
                            self.is_dr_priority_capable = None
                            self.dr_priority = None
                            self.is_bidirectional_capable = None
                            self.is_proxy_capable = None
                            self.is_batch_asserts_capable = None
                            self.is_ecmp_redirect_capable = None
                            self.is_bfd_state = None
                            self.propagation_delay = None
                            self.override_interval = None

                            self.neighbor_address_xr = YList(self)
                            self._segment_path = lambda: "neighbor-old-format"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat, ['interface_name', 'neighbor_address', 'interface_name_xr', 'uptime', 'expires', 'expiry_timer', 'is_this_neighbor_us', 'is_this_neighbor_dr', 'is_dr_priority_capable', 'dr_priority', 'is_bidirectional_capable', 'is_proxy_capable', 'is_batch_asserts_capable', 'is_ecmp_redirect_capable', 'is_bfd_state', 'propagation_delay', 'override_interval'], name, value)


                        class NeighborAddressXr(Entity):
                            """
                            List of Neighbor Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr, self).__init__()

                                self.yang_name = "neighbor-address-xr"
                                self.yang_parent_name = "neighbor-old-format"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "neighbor-address-xr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class IfrsSummary(Entity):
                    """
                    PIM interfaces in forward reference store
                    summary
                    
                    .. attribute:: interface_count
                    
                    	Number of interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: configuration_count
                    
                    	Configuration counts
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.IfrsSummary, self).__init__()

                        self.yang_name = "ifrs-summary"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('interface_count', (YLeaf(YType.uint32, 'interface-count'), ['int'])),
                            ('configuration_count', (YLeaf(YType.uint32, 'configuration-count'), ['int'])),
                        ])
                        self.interface_count = None
                        self.configuration_count = None
                        self._segment_path = lambda: "ifrs-summary"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.IfrsSummary, ['interface_count', 'configuration_count'], name, value)


                class Ranges(Entity):
                    """
                    PIM range list information
                    
                    .. attribute:: range
                    
                    	PIM range list information
                    	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Ranges.Range>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.Ranges, self).__init__()

                        self.yang_name = "ranges"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("range", ("range", Pim.Standby.Vrfs.Vrf.Ranges.Range))])
                        self._leafs = OrderedDict()

                        self.range = YList(self)
                        self._segment_path = lambda: "ranges"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.Ranges, [], name, value)


                    class Range(Entity):
                        """
                        PIM range list information
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: client
                        
                        	Client
                        	**type**\:  :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                        
                        .. attribute:: rp_address_xr
                        
                        	Rendezvous point address
                        	**type**\:  :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Ranges.Range.RpAddressXr>`
                        
                        .. attribute:: source_of_information
                        
                        	Source of information
                        	**type**\:  :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Ranges.Range.SourceOfInformation>`
                        
                        .. attribute:: protocol
                        
                        	PIM protocol
                        	**type**\:  :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: client_xr
                        
                        	Client mapping learnt via
                        	**type**\:  :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                        
                        .. attribute:: expires
                        
                        	When mapping expires
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: group_range
                        
                        	List of group ranges
                        	**type**\: list of  		 :py:class:`GroupRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.Ranges.Range, self).__init__()

                            self.yang_name = "range"
                            self.yang_parent_name = "ranges"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rp-address-xr", ("rp_address_xr", Pim.Standby.Vrfs.Vrf.Ranges.Range.RpAddressXr)), ("source-of-information", ("source_of_information", Pim.Standby.Vrfs.Vrf.Ranges.Range.SourceOfInformation)), ("group-range", ("group_range", Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange))])
                            self._leafs = OrderedDict([
                                ('rp_address', (YLeaf(YType.str, 'rp-address'), ['str','str'])),
                                ('client', (YLeaf(YType.enumeration, 'client'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimClient', '')])),
                                ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowProtocol', '')])),
                                ('client_xr', (YLeaf(YType.enumeration, 'client-xr'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowRangeClient', '')])),
                                ('expires', (YLeaf(YType.uint64, 'expires'), ['int'])),
                            ])
                            self.rp_address = None
                            self.client = None
                            self.protocol = None
                            self.client_xr = None
                            self.expires = None

                            self.rp_address_xr = Pim.Standby.Vrfs.Vrf.Ranges.Range.RpAddressXr()
                            self.rp_address_xr.parent = self
                            self._children_name_map["rp_address_xr"] = "rp-address-xr"

                            self.source_of_information = Pim.Standby.Vrfs.Vrf.Ranges.Range.SourceOfInformation()
                            self.source_of_information.parent = self
                            self._children_name_map["source_of_information"] = "source-of-information"

                            self.group_range = YList(self)
                            self._segment_path = lambda: "range"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.Ranges.Range, ['rp_address', 'client', 'protocol', 'client_xr', 'expires'], name, value)


                        class RpAddressXr(Entity):
                            """
                            Rendezvous point address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Ranges.Range.RpAddressXr, self).__init__()

                                self.yang_name = "rp-address-xr"
                                self.yang_parent_name = "range"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "rp-address-xr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.Ranges.Range.RpAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class SourceOfInformation(Entity):
                            """
                            Source of information
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Ranges.Range.SourceOfInformation, self).__init__()

                                self.yang_name = "source-of-information"
                                self.yang_parent_name = "range"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "source-of-information"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.Ranges.Range.SourceOfInformation, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class GroupRange(Entity):
                            """
                            List of group ranges
                            
                            .. attribute:: prefix
                            
                            	Group range prefix
                            	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix>`
                            
                            .. attribute:: source_of_information
                            
                            	Source of information
                            	**type**\:  :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation>`
                            
                            .. attribute:: prefix_length
                            
                            	Group range prefix length
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: expires
                            
                            	When mapping expires
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange, self).__init__()

                                self.yang_name = "group-range"
                                self.yang_parent_name = "range"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("prefix", ("prefix", Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix)), ("source-of-information", ("source_of_information", Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation))])
                                self._leafs = OrderedDict([
                                    ('prefix_length', (YLeaf(YType.int32, 'prefix-length'), ['int'])),
                                    ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                                    ('expires', (YLeaf(YType.uint64, 'expires'), ['int'])),
                                ])
                                self.prefix_length = None
                                self.uptime = None
                                self.expires = None

                                self.prefix = Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix()
                                self.prefix.parent = self
                                self._children_name_map["prefix"] = "prefix"

                                self.source_of_information = Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation()
                                self.source_of_information.parent = self
                                self._children_name_map["source_of_information"] = "source-of-information"
                                self._segment_path = lambda: "group-range"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange, ['prefix_length', 'uptime', 'expires'], name, value)


                            class Prefix(Entity):
                                """
                                Group range prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix, self).__init__()

                                    self.yang_name = "prefix"
                                    self.yang_parent_name = "group-range"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "prefix"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                            class SourceOfInformation(Entity):
                                """
                                Source of information
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation, self).__init__()

                                    self.yang_name = "source-of-information"
                                    self.yang_parent_name = "group-range"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "source-of-information"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class InterfaceOldFormats(Entity):
                    """
                    PIM interfaces in old format
                    
                    .. attribute:: interface_old_format
                    
                    	PIM interface name
                    	**type**\: list of  		 :py:class:`InterfaceOldFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.InterfaceOldFormats, self).__init__()

                        self.yang_name = "interface-old-formats"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("interface-old-format", ("interface_old_format", Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat))])
                        self._leafs = OrderedDict()

                        self.interface_old_format = YList(self)
                        self._segment_path = lambda: "interface-old-formats"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.InterfaceOldFormats, [], name, value)


                    class InterfaceOldFormat(Entity):
                        """
                        PIM interface name
                        
                        .. attribute:: interface_name  (key)
                        
                        	Interface name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: dr_address
                        
                        	PIM Designated Router
                        	**type**\:  :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress>`
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identfier
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: interface_address_mask
                        
                        	Interface IP Address Mask
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: is_enabled
                        
                        	Is PIM enabled on this IF ?
                        	**type**\: bool
                        
                        .. attribute:: neighbor_count
                        
                        	No. of neighbors on this IF
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: external_neighbor_count
                        
                        	No. of external neighbors on this IF
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: hello_interval
                        
                        	Hello Interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: dr_priority
                        
                        	DR Priority
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: hello_expiry
                        
                        	Hello Timer Expiry
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: are_we_dr
                        
                        	Are we the DR on this IF ?
                        	**type**\: bool
                        
                        .. attribute:: bfd_enabled
                        
                        	BFD state
                        	**type**\: bool
                        
                        .. attribute:: bfd_interval
                        
                        	BFD Interval
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bfd_multiplier
                        
                        	BFD Multiplier
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_interface
                        
                        	 is this a Virtual Interfaces ?
                        	**type**\: bool
                        
                        .. attribute:: passive_interface
                        
                        	Passive PIM interface
                        	**type**\: bool
                        
                        .. attribute:: neighbor_filter_name
                        
                        	Neighbor Filter Name
                        	**type**\: str
                        
                        .. attribute:: join_prune_interval
                        
                        	Join\-Prune Interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: prune_delay_enabled
                        
                        	Prune Delay Enabled
                        	**type**\: bool
                        
                        .. attribute:: configured_propagation_delay
                        
                        	Configured Propagation Delay
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: configured_override_interval
                        
                        	Configured Override Interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: generation_id
                        
                        	Generation Identifier
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Bidir Capable
                        	**type**\: bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Proxy Capable
                        	**type**\: bool
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Batch Asserts Capable
                        	**type**\: bool
                        
                        .. attribute:: idb_oor_enabled
                        
                        	Interface oor enabled
                        	**type**\: bool
                        
                        .. attribute:: idb_acl_provided
                        
                        	ACL name provided
                        	**type**\: bool
                        
                        .. attribute:: idb_max_count
                        
                        	Interface ole max count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_threshold_count
                        
                        	Interface ole threshold count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_current_count
                        
                        	Interface ole current count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_acl_name
                        
                        	Interface ole ACL Name
                        	**type**\: str
                        
                        	**length:** 0..64
                        
                        .. attribute:: interface_address
                        
                        	List of Interface IP Addresses
                        	**type**\: list of  		 :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat, self).__init__()

                            self.yang_name = "interface-old-format"
                            self.yang_parent_name = "interface-old-formats"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['interface_name']
                            self._child_classes = OrderedDict([("dr-address", ("dr_address", Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress)), ("interface-address", ("interface_address", Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress))])
                            self._leafs = OrderedDict([
                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                                ('interface_address_mask', (YLeaf(YType.uint8, 'interface-address-mask'), ['int'])),
                                ('is_enabled', (YLeaf(YType.boolean, 'is-enabled'), ['bool'])),
                                ('neighbor_count', (YLeaf(YType.uint16, 'neighbor-count'), ['int'])),
                                ('external_neighbor_count', (YLeaf(YType.uint16, 'external-neighbor-count'), ['int'])),
                                ('hello_interval', (YLeaf(YType.uint16, 'hello-interval'), ['int'])),
                                ('dr_priority', (YLeaf(YType.uint32, 'dr-priority'), ['int'])),
                                ('hello_expiry', (YLeaf(YType.uint64, 'hello-expiry'), ['int'])),
                                ('are_we_dr', (YLeaf(YType.boolean, 'are-we-dr'), ['bool'])),
                                ('bfd_enabled', (YLeaf(YType.boolean, 'bfd-enabled'), ['bool'])),
                                ('bfd_interval', (YLeaf(YType.uint32, 'bfd-interval'), ['int'])),
                                ('bfd_multiplier', (YLeaf(YType.uint32, 'bfd-multiplier'), ['int'])),
                                ('virtual_interface', (YLeaf(YType.boolean, 'virtual-interface'), ['bool'])),
                                ('passive_interface', (YLeaf(YType.boolean, 'passive-interface'), ['bool'])),
                                ('neighbor_filter_name', (YLeaf(YType.str, 'neighbor-filter-name'), ['str'])),
                                ('join_prune_interval', (YLeaf(YType.uint16, 'join-prune-interval'), ['int'])),
                                ('prune_delay_enabled', (YLeaf(YType.boolean, 'prune-delay-enabled'), ['bool'])),
                                ('configured_propagation_delay', (YLeaf(YType.uint16, 'configured-propagation-delay'), ['int'])),
                                ('propagation_delay', (YLeaf(YType.uint16, 'propagation-delay'), ['int'])),
                                ('configured_override_interval', (YLeaf(YType.uint16, 'configured-override-interval'), ['int'])),
                                ('override_interval', (YLeaf(YType.uint16, 'override-interval'), ['int'])),
                                ('generation_id', (YLeaf(YType.uint32, 'generation-id'), ['int'])),
                                ('is_bidirectional_capable', (YLeaf(YType.boolean, 'is-bidirectional-capable'), ['bool'])),
                                ('is_proxy_capable', (YLeaf(YType.boolean, 'is-proxy-capable'), ['bool'])),
                                ('is_batch_asserts_capable', (YLeaf(YType.boolean, 'is-batch-asserts-capable'), ['bool'])),
                                ('idb_oor_enabled', (YLeaf(YType.boolean, 'idb-oor-enabled'), ['bool'])),
                                ('idb_acl_provided', (YLeaf(YType.boolean, 'idb-acl-provided'), ['bool'])),
                                ('idb_max_count', (YLeaf(YType.uint32, 'idb-max-count'), ['int'])),
                                ('idb_threshold_count', (YLeaf(YType.uint32, 'idb-threshold-count'), ['int'])),
                                ('idb_current_count', (YLeaf(YType.uint32, 'idb-current-count'), ['int'])),
                                ('idb_acl_name', (YLeaf(YType.str, 'idb-acl-name'), ['str'])),
                            ])
                            self.interface_name = None
                            self.interface_name_xr = None
                            self.interface_address_mask = None
                            self.is_enabled = None
                            self.neighbor_count = None
                            self.external_neighbor_count = None
                            self.hello_interval = None
                            self.dr_priority = None
                            self.hello_expiry = None
                            self.are_we_dr = None
                            self.bfd_enabled = None
                            self.bfd_interval = None
                            self.bfd_multiplier = None
                            self.virtual_interface = None
                            self.passive_interface = None
                            self.neighbor_filter_name = None
                            self.join_prune_interval = None
                            self.prune_delay_enabled = None
                            self.configured_propagation_delay = None
                            self.propagation_delay = None
                            self.configured_override_interval = None
                            self.override_interval = None
                            self.generation_id = None
                            self.is_bidirectional_capable = None
                            self.is_proxy_capable = None
                            self.is_batch_asserts_capable = None
                            self.idb_oor_enabled = None
                            self.idb_acl_provided = None
                            self.idb_max_count = None
                            self.idb_threshold_count = None
                            self.idb_current_count = None
                            self.idb_acl_name = None

                            self.dr_address = Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress()
                            self.dr_address.parent = self
                            self._children_name_map["dr_address"] = "dr-address"

                            self.interface_address = YList(self)
                            self._segment_path = lambda: "interface-old-format" + "[interface-name='" + str(self.interface_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat, ['interface_name', 'interface_name_xr', 'interface_address_mask', 'is_enabled', 'neighbor_count', 'external_neighbor_count', 'hello_interval', 'dr_priority', 'hello_expiry', 'are_we_dr', 'bfd_enabled', 'bfd_interval', 'bfd_multiplier', 'virtual_interface', 'passive_interface', 'neighbor_filter_name', 'join_prune_interval', 'prune_delay_enabled', 'configured_propagation_delay', 'propagation_delay', 'configured_override_interval', 'override_interval', 'generation_id', 'is_bidirectional_capable', 'is_proxy_capable', 'is_batch_asserts_capable', 'idb_oor_enabled', 'idb_acl_provided', 'idb_max_count', 'idb_threshold_count', 'idb_current_count', 'idb_acl_name'], name, value)


                        class DrAddress(Entity):
                            """
                            PIM Designated Router
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress, self).__init__()

                                self.yang_name = "dr-address"
                                self.yang_parent_name = "interface-old-format"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "dr-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class InterfaceAddress(Entity):
                            """
                            List of Interface IP Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress, self).__init__()

                                self.yang_name = "interface-address"
                                self.yang_parent_name = "interface-old-format"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "interface-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class Bsr(Entity):
                    """
                    PIM BSR information
                    
                    .. attribute:: rp_caches
                    
                    	PIM BSR RP cache table
                    	**type**\:  :py:class:`RpCaches <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Bsr.RpCaches>`
                    
                    .. attribute:: candidate_rps
                    
                    	PIM candidate\-RP
                    	**type**\:  :py:class:`CandidateRps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps>`
                    
                    .. attribute:: bsr_elections
                    
                    	PIM BSR election state
                    	**type**\:  :py:class:`BsrElections <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Bsr.BsrElections>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.Bsr, self).__init__()

                        self.yang_name = "bsr"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("rp-caches", ("rp_caches", Pim.Standby.Vrfs.Vrf.Bsr.RpCaches)), ("candidate-rps", ("candidate_rps", Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps)), ("bsr-elections", ("bsr_elections", Pim.Standby.Vrfs.Vrf.Bsr.BsrElections))])
                        self._leafs = OrderedDict()

                        self.rp_caches = Pim.Standby.Vrfs.Vrf.Bsr.RpCaches()
                        self.rp_caches.parent = self
                        self._children_name_map["rp_caches"] = "rp-caches"

                        self.candidate_rps = Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps()
                        self.candidate_rps.parent = self
                        self._children_name_map["candidate_rps"] = "candidate-rps"

                        self.bsr_elections = Pim.Standby.Vrfs.Vrf.Bsr.BsrElections()
                        self.bsr_elections.parent = self
                        self._children_name_map["bsr_elections"] = "bsr-elections"
                        self._segment_path = lambda: "bsr"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.Bsr, [], name, value)


                    class RpCaches(Entity):
                        """
                        PIM BSR RP cache table
                        
                        .. attribute:: rp_cache
                        
                        	PIM BSR RP cache
                        	**type**\: list of  		 :py:class:`RpCache <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.Bsr.RpCaches, self).__init__()

                            self.yang_name = "rp-caches"
                            self.yang_parent_name = "bsr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rp-cache", ("rp_cache", Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache))])
                            self._leafs = OrderedDict()

                            self.rp_cache = YList(self)
                            self._segment_path = lambda: "rp-caches"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.Bsr.RpCaches, [], name, value)


                        class RpCache(Entity):
                            """
                            PIM BSR RP cache
                            
                            .. attribute:: group_prefix  (key)
                            
                            	Group prefix
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: group_prefix_xr
                            
                            	Group Prefix
                            	**type**\:  :py:class:`GroupPrefixXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr>`
                            
                            .. attribute:: candidate_rp_list
                            
                            	C\-RP list for this prefix
                            	**type**\:  :py:class:`CandidateRpList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList>`
                            
                            .. attribute:: group_prefix_length
                            
                            	Group Prefix Length
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: candidate_rp_group_count
                            
                            	C\-RP count for this Prefix
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache, self).__init__()

                                self.yang_name = "rp-cache"
                                self.yang_parent_name = "rp-caches"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['group_prefix']
                                self._child_classes = OrderedDict([("group-prefix-xr", ("group_prefix_xr", Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr)), ("candidate-rp-list", ("candidate_rp_list", Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList))])
                                self._leafs = OrderedDict([
                                    ('group_prefix', (YLeaf(YType.str, 'group-prefix'), ['str','str'])),
                                    ('group_prefix_length', (YLeaf(YType.uint32, 'group-prefix-length'), ['int'])),
                                    ('candidate_rp_group_count', (YLeaf(YType.uint32, 'candidate-rp-group-count'), ['int'])),
                                ])
                                self.group_prefix = None
                                self.group_prefix_length = None
                                self.candidate_rp_group_count = None

                                self.group_prefix_xr = Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr()
                                self.group_prefix_xr.parent = self
                                self._children_name_map["group_prefix_xr"] = "group-prefix-xr"

                                self.candidate_rp_list = Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList()
                                self.candidate_rp_list.parent = self
                                self._children_name_map["candidate_rp_list"] = "candidate-rp-list"
                                self._segment_path = lambda: "rp-cache" + "[group-prefix='" + str(self.group_prefix) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache, ['group_prefix', 'group_prefix_length', 'candidate_rp_group_count'], name, value)


                            class GroupPrefixXr(Entity):
                                """
                                Group Prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr, self).__init__()

                                    self.yang_name = "group-prefix-xr"
                                    self.yang_parent_name = "rp-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "group-prefix-xr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                            class CandidateRpList(Entity):
                                """
                                C\-RP list for this prefix
                                
                                .. attribute:: pim_bsr_crp_bag
                                
                                	pim bsr crp bag
                                	**type**\: list of  		 :py:class:`PimBsrCrpBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList, self).__init__()

                                    self.yang_name = "candidate-rp-list"
                                    self.yang_parent_name = "rp-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("pim-bsr-crp-bag", ("pim_bsr_crp_bag", Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag))])
                                    self._leafs = OrderedDict()

                                    self.pim_bsr_crp_bag = YList(self)
                                    self._segment_path = lambda: "candidate-rp-list"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList, [], name, value)


                                class PimBsrCrpBag(Entity):
                                    """
                                    pim bsr crp bag
                                    
                                    .. attribute:: candidate_rp_address
                                    
                                    	C\-RP address
                                    	**type**\:  :py:class:`CandidateRpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress>`
                                    
                                    .. attribute:: candidate_rp_holdtime
                                    
                                    	C\-RP Holdtime
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: candidate_rp_priority
                                    
                                    	C\-RP Priority
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: candidate_rp_up_time
                                    
                                    	C\-RP Uptime
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: candidate_rp_expires
                                    
                                    	C\-RP Expires
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: protocol
                                    
                                    	PIM Protocol
                                    	**type**\:  :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag, self).__init__()

                                        self.yang_name = "pim-bsr-crp-bag"
                                        self.yang_parent_name = "candidate-rp-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("candidate-rp-address", ("candidate_rp_address", Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress))])
                                        self._leafs = OrderedDict([
                                            ('candidate_rp_holdtime', (YLeaf(YType.uint16, 'candidate-rp-holdtime'), ['int'])),
                                            ('candidate_rp_priority', (YLeaf(YType.uint8, 'candidate-rp-priority'), ['int'])),
                                            ('candidate_rp_up_time', (YLeaf(YType.uint16, 'candidate-rp-up-time'), ['int'])),
                                            ('candidate_rp_expires', (YLeaf(YType.uint16, 'candidate-rp-expires'), ['int'])),
                                            ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowProtocol', '')])),
                                        ])
                                        self.candidate_rp_holdtime = None
                                        self.candidate_rp_priority = None
                                        self.candidate_rp_up_time = None
                                        self.candidate_rp_expires = None
                                        self.protocol = None

                                        self.candidate_rp_address = Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress()
                                        self.candidate_rp_address.parent = self
                                        self._children_name_map["candidate_rp_address"] = "candidate-rp-address"
                                        self._segment_path = lambda: "pim-bsr-crp-bag"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag, ['candidate_rp_holdtime', 'candidate_rp_priority', 'candidate_rp_up_time', 'candidate_rp_expires', 'protocol'], name, value)


                                    class CandidateRpAddress(Entity):
                                        """
                                        C\-RP address
                                        
                                        .. attribute:: af_name
                                        
                                        	AFName
                                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Address
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-pim-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress, self).__init__()

                                            self.yang_name = "candidate-rp-address"
                                            self.yang_parent_name = "pim-bsr-crp-bag"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                            ])
                                            self.af_name = None
                                            self.ipv4_address = None
                                            self.ipv6_address = None
                                            self._segment_path = lambda: "candidate-rp-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class CandidateRps(Entity):
                        """
                        PIM candidate\-RP
                        
                        .. attribute:: candidate_rp
                        
                        	PIM BSR candidate RP information
                        	**type**\: list of  		 :py:class:`CandidateRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps, self).__init__()

                            self.yang_name = "candidate-rps"
                            self.yang_parent_name = "bsr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("candidate-rp", ("candidate_rp", Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp))])
                            self._leafs = OrderedDict()

                            self.candidate_rp = YList(self)
                            self._segment_path = lambda: "candidate-rps"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps, [], name, value)


                        class CandidateRp(Entity):
                            """
                            PIM BSR candidate RP information
                            
                            .. attribute:: rp_address  (key)
                            
                            	Candidate\-RP address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: candidate_rp
                            
                            	Cand\-RP Address
                            	**type**\:  :py:class:`CandidateRp_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp_>`
                            
                            .. attribute:: candidate_rp_mode
                            
                            	Cand\-RP Mode
                            	**type**\:  :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                            
                            .. attribute:: candidate_rp_scope
                            
                            	Cand\-RP Scope
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: crp_priority
                            
                            	Cand\-RP Priority
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: crp_holdtime
                            
                            	Cand\-RP Holdtime
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: candidate_rp_advance_interval
                            
                            	Cand\-RP Adv Interval in seconds
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: candidate_rp_uptime
                            
                            	Cand\-RP uptime
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: acl_name
                            
                            	Group Access\-List Name
                            	**type**\: str
                            
                            	**length:** 0..33
                            
                            .. attribute:: crp_access
                            
                            	Group Ranges Using this Cand\-RP
                            	**type**\: list of  		 :py:class:`CrpAccess <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CrpAccess>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp, self).__init__()

                                self.yang_name = "candidate-rp"
                                self.yang_parent_name = "candidate-rps"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['rp_address']
                                self._child_classes = OrderedDict([("candidate-rp", ("candidate_rp", Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp_)), ("crp-access", ("crp_access", Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CrpAccess))])
                                self._leafs = OrderedDict([
                                    ('rp_address', (YLeaf(YType.str, 'rp-address'), ['str','str'])),
                                    ('candidate_rp_mode', (YLeaf(YType.enumeration, 'candidate-rp-mode'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowProtocol', '')])),
                                    ('candidate_rp_scope', (YLeaf(YType.int32, 'candidate-rp-scope'), ['int'])),
                                    ('crp_priority', (YLeaf(YType.uint8, 'crp-priority'), ['int'])),
                                    ('crp_holdtime', (YLeaf(YType.uint16, 'crp-holdtime'), ['int'])),
                                    ('candidate_rp_advance_interval', (YLeaf(YType.uint16, 'candidate-rp-advance-interval'), ['int'])),
                                    ('candidate_rp_uptime', (YLeaf(YType.uint16, 'candidate-rp-uptime'), ['int'])),
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                                ])
                                self.rp_address = None
                                self.candidate_rp_mode = None
                                self.candidate_rp_scope = None
                                self.crp_priority = None
                                self.crp_holdtime = None
                                self.candidate_rp_advance_interval = None
                                self.candidate_rp_uptime = None
                                self.acl_name = None

                                self.candidate_rp = Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp_()
                                self.candidate_rp.parent = self
                                self._children_name_map["candidate_rp"] = "candidate-rp"

                                self.crp_access = YList(self)
                                self._segment_path = lambda: "candidate-rp" + "[rp-address='" + str(self.rp_address) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp, ['rp_address', 'candidate_rp_mode', 'candidate_rp_scope', 'crp_priority', 'crp_holdtime', 'candidate_rp_advance_interval', 'candidate_rp_uptime', 'acl_name'], name, value)


                            class CandidateRp_(Entity):
                                """
                                Cand\-RP Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp_, self).__init__()

                                    self.yang_name = "candidate-rp"
                                    self.yang_parent_name = "candidate-rp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "candidate-rp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp_, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                            class CrpAccess(Entity):
                                """
                                Group Ranges Using this Cand\-RP
                                
                                .. attribute:: candidate_rp_mode
                                
                                	Cand\-RP Mode
                                	**type**\:  :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                                
                                .. attribute:: acl_name
                                
                                	Group Access\-List Name
                                	**type**\: str
                                
                                	**length:** 0..33
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CrpAccess, self).__init__()

                                    self.yang_name = "crp-access"
                                    self.yang_parent_name = "candidate-rp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('candidate_rp_mode', (YLeaf(YType.enumeration, 'candidate-rp-mode'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowProtocol', '')])),
                                        ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                                    ])
                                    self.candidate_rp_mode = None
                                    self.acl_name = None
                                    self._segment_path = lambda: "crp-access"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CrpAccess, ['candidate_rp_mode', 'acl_name'], name, value)


                    class BsrElections(Entity):
                        """
                        PIM BSR election state
                        
                        .. attribute:: bsr_election
                        
                        	PIM BSR information
                        	**type**\: list of  		 :py:class:`BsrElection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.Bsr.BsrElections, self).__init__()

                            self.yang_name = "bsr-elections"
                            self.yang_parent_name = "bsr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("bsr-election", ("bsr_election", Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection))])
                            self._leafs = OrderedDict()

                            self.bsr_election = YList(self)
                            self._segment_path = lambda: "bsr-elections"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.Bsr.BsrElections, [], name, value)


                        class BsrElection(Entity):
                            """
                            PIM BSR information
                            
                            .. attribute:: pim_scope  (key)
                            
                            	BSR information
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bsr_address
                            
                            	BSR address
                            	**type**\:  :py:class:`BsrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress>`
                            
                            .. attribute:: candidate_bsr_address
                            
                            	C\-BSR address
                            	**type**\:  :py:class:`CandidateBsrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress>`
                            
                            .. attribute:: bsr_priority
                            
                            	BSR Priority
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: bsr_mask_length
                            
                            	Hash Function Mask Length
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: bsr_up_time
                            
                            	BSR Uptime
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: bootstrap_timeout
                            
                            	Bootstrap Timeout
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: candidate_bsr_state
                            
                            	BSR Candidate State
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bsr_election_state
                            
                            	BSR Election State
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bsr_scope
                            
                            	BSR Scope
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: candidate_bsr_flag
                            
                            	BSR Candidate Config Flag
                            	**type**\: bool
                            
                            .. attribute:: candidate_bsr_priority
                            
                            	C\-BSR Priority
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: candidate_bsr_mask_length
                            
                            	C\-BSR Hash Func. Mask Len
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection, self).__init__()

                                self.yang_name = "bsr-election"
                                self.yang_parent_name = "bsr-elections"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['pim_scope']
                                self._child_classes = OrderedDict([("bsr-address", ("bsr_address", Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress)), ("candidate-bsr-address", ("candidate_bsr_address", Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress))])
                                self._leafs = OrderedDict([
                                    ('pim_scope', (YLeaf(YType.uint32, 'pim-scope'), ['int'])),
                                    ('bsr_priority', (YLeaf(YType.uint8, 'bsr-priority'), ['int'])),
                                    ('bsr_mask_length', (YLeaf(YType.uint8, 'bsr-mask-length'), ['int'])),
                                    ('bsr_up_time', (YLeaf(YType.uint16, 'bsr-up-time'), ['int'])),
                                    ('bootstrap_timeout', (YLeaf(YType.uint16, 'bootstrap-timeout'), ['int'])),
                                    ('candidate_bsr_state', (YLeaf(YType.uint32, 'candidate-bsr-state'), ['int'])),
                                    ('bsr_election_state', (YLeaf(YType.uint32, 'bsr-election-state'), ['int'])),
                                    ('bsr_scope', (YLeaf(YType.uint16, 'bsr-scope'), ['int'])),
                                    ('candidate_bsr_flag', (YLeaf(YType.boolean, 'candidate-bsr-flag'), ['bool'])),
                                    ('candidate_bsr_priority', (YLeaf(YType.uint8, 'candidate-bsr-priority'), ['int'])),
                                    ('candidate_bsr_mask_length', (YLeaf(YType.uint8, 'candidate-bsr-mask-length'), ['int'])),
                                ])
                                self.pim_scope = None
                                self.bsr_priority = None
                                self.bsr_mask_length = None
                                self.bsr_up_time = None
                                self.bootstrap_timeout = None
                                self.candidate_bsr_state = None
                                self.bsr_election_state = None
                                self.bsr_scope = None
                                self.candidate_bsr_flag = None
                                self.candidate_bsr_priority = None
                                self.candidate_bsr_mask_length = None

                                self.bsr_address = Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress()
                                self.bsr_address.parent = self
                                self._children_name_map["bsr_address"] = "bsr-address"

                                self.candidate_bsr_address = Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress()
                                self.candidate_bsr_address.parent = self
                                self._children_name_map["candidate_bsr_address"] = "candidate-bsr-address"
                                self._segment_path = lambda: "bsr-election" + "[pim-scope='" + str(self.pim_scope) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection, ['pim_scope', 'bsr_priority', 'bsr_mask_length', 'bsr_up_time', 'bootstrap_timeout', 'candidate_bsr_state', 'bsr_election_state', 'bsr_scope', 'candidate_bsr_flag', 'candidate_bsr_priority', 'candidate_bsr_mask_length'], name, value)


                            class BsrAddress(Entity):
                                """
                                BSR address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress, self).__init__()

                                    self.yang_name = "bsr-address"
                                    self.yang_parent_name = "bsr-election"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "bsr-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                            class CandidateBsrAddress(Entity):
                                """
                                C\-BSR address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress, self).__init__()

                                    self.yang_name = "candidate-bsr-address"
                                    self.yang_parent_name = "bsr-election"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "candidate-bsr-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class RoutePolicy(Entity):
                    """
                    PIM route policy
                    
                    .. attribute:: route_policy_statistics
                    
                    	PIM route policy statistics
                    	**type**\:  :py:class:`RoutePolicyStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics>`
                    
                    .. attribute:: route_policy_tests
                    
                    	PIM route policy test run table
                    	**type**\:  :py:class:`RoutePolicyTests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.RoutePolicy, self).__init__()

                        self.yang_name = "route-policy"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("route-policy-statistics", ("route_policy_statistics", Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics)), ("route-policy-tests", ("route_policy_tests", Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests))])
                        self._leafs = OrderedDict()

                        self.route_policy_statistics = Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics()
                        self.route_policy_statistics.parent = self
                        self._children_name_map["route_policy_statistics"] = "route-policy-statistics"

                        self.route_policy_tests = Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests()
                        self.route_policy_tests.parent = self
                        self._children_name_map["route_policy_tests"] = "route-policy-tests"
                        self._segment_path = lambda: "route-policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.RoutePolicy, [], name, value)


                    class RoutePolicyStatistics(Entity):
                        """
                        PIM route policy statistics
                        
                        .. attribute:: policy_name
                        
                        	RPF policy name
                        	**type**\: str
                        
                        .. attribute:: requests
                        
                        	Number of RPF lookup requests
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pass_
                        
                        	Number of RPF pass
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: drop
                        
                        	Number of RPF drops
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: default_table
                        
                        	Number of RPF lookup in default\-only Table
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: any_table
                        
                        	Number of RPF lookup in any Table
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics, self).__init__()

                            self.yang_name = "route-policy-statistics"
                            self.yang_parent_name = "route-policy"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('policy_name', (YLeaf(YType.str, 'policy-name'), ['str'])),
                                ('requests', (YLeaf(YType.uint32, 'requests'), ['int'])),
                                ('pass_', (YLeaf(YType.uint32, 'pass'), ['int'])),
                                ('drop', (YLeaf(YType.uint32, 'drop'), ['int'])),
                                ('default_table', (YLeaf(YType.uint32, 'default-table'), ['int'])),
                                ('any_table', (YLeaf(YType.uint32, 'any-table'), ['int'])),
                            ])
                            self.policy_name = None
                            self.requests = None
                            self.pass_ = None
                            self.drop = None
                            self.default_table = None
                            self.any_table = None
                            self._segment_path = lambda: "route-policy-statistics"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics, ['policy_name', 'requests', 'pass_', 'drop', 'default_table', 'any_table'], name, value)


                    class RoutePolicyTests(Entity):
                        """
                        PIM route policy test run table
                        
                        .. attribute:: route_policy_test
                        
                        	PIM route policy test run
                        	**type**\: list of  		 :py:class:`RoutePolicyTest <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests, self).__init__()

                            self.yang_name = "route-policy-tests"
                            self.yang_parent_name = "route-policy"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("route-policy-test", ("route_policy_test", Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest))])
                            self._leafs = OrderedDict()

                            self.route_policy_test = YList(self)
                            self._segment_path = lambda: "route-policy-tests"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests, [], name, value)


                        class RoutePolicyTest(Entity):
                            """
                            PIM route policy test run
                            
                            .. attribute:: source_address
                            
                            	Source IP address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: group_address
                            
                            	Group IP address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ext_comm
                            
                            	Extended Community
                            	**type**\: str
                            
                            	**length:** 1..8
                            
                            .. attribute:: source_address_xr
                            
                            	Source address
                            	**type**\:  :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr>`
                            
                            .. attribute:: group_address_xr
                            
                            	Source address
                            	**type**\:  :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr>`
                            
                            .. attribute:: policy_name
                            
                            	RPF policy name
                            	**type**\: str
                            
                            .. attribute:: extended_community_rt
                            
                            	Route Target
                            	**type**\: str
                            
                            	**length:** 0..33
                            
                            .. attribute:: pass_
                            
                            	Pass
                            	**type**\: bool
                            
                            .. attribute:: default_table
                            
                            	Default table selected
                            	**type**\: bool
                            
                            .. attribute:: vrf_name
                            
                            	VRF name
                            	**type**\: str
                            
                            	**length:** 0..33
                            
                            .. attribute:: afi
                            
                            	AFI
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: safi
                            
                            	SAFI
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: table_name
                            
                            	Table name
                            	**type**\: str
                            
                            .. attribute:: table_exists
                            
                            	Table exists
                            	**type**\: bool
                            
                            .. attribute:: table_active
                            
                            	Table active
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest, self).__init__()

                                self.yang_name = "route-policy-test"
                                self.yang_parent_name = "route-policy-tests"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("source-address-xr", ("source_address_xr", Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr)), ("group-address-xr", ("group_address_xr", Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr))])
                                self._leafs = OrderedDict([
                                    ('source_address', (YLeaf(YType.str, 'source-address'), ['str','str'])),
                                    ('group_address', (YLeaf(YType.str, 'group-address'), ['str','str'])),
                                    ('ext_comm', (YLeaf(YType.str, 'ext-comm'), ['str'])),
                                    ('policy_name', (YLeaf(YType.str, 'policy-name'), ['str'])),
                                    ('extended_community_rt', (YLeaf(YType.str, 'extended-community-rt'), ['str'])),
                                    ('pass_', (YLeaf(YType.boolean, 'pass'), ['bool'])),
                                    ('default_table', (YLeaf(YType.boolean, 'default-table'), ['bool'])),
                                    ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                    ('afi', (YLeaf(YType.uint32, 'afi'), ['int'])),
                                    ('safi', (YLeaf(YType.uint32, 'safi'), ['int'])),
                                    ('table_name', (YLeaf(YType.str, 'table-name'), ['str'])),
                                    ('table_exists', (YLeaf(YType.boolean, 'table-exists'), ['bool'])),
                                    ('table_active', (YLeaf(YType.boolean, 'table-active'), ['bool'])),
                                ])
                                self.source_address = None
                                self.group_address = None
                                self.ext_comm = None
                                self.policy_name = None
                                self.extended_community_rt = None
                                self.pass_ = None
                                self.default_table = None
                                self.vrf_name = None
                                self.afi = None
                                self.safi = None
                                self.table_name = None
                                self.table_exists = None
                                self.table_active = None

                                self.source_address_xr = Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr()
                                self.source_address_xr.parent = self
                                self._children_name_map["source_address_xr"] = "source-address-xr"

                                self.group_address_xr = Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"
                                self._segment_path = lambda: "route-policy-test"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest, ['source_address', 'group_address', 'ext_comm', 'policy_name', 'extended_community_rt', 'pass_', 'default_table', 'vrf_name', 'afi', 'safi', 'table_name', 'table_exists', 'table_active'], name, value)


                            class SourceAddressXr(Entity):
                                """
                                Source address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr, self).__init__()

                                    self.yang_name = "source-address-xr"
                                    self.yang_parent_name = "route-policy-test"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "source-address-xr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                            class GroupAddressXr(Entity):
                                """
                                Source address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr, self).__init__()

                                    self.yang_name = "group-address-xr"
                                    self.yang_parent_name = "route-policy-test"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "group-address-xr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class RpfSummary(Entity):
                    """
                    PIM RPF registration summary
                    
                    .. attribute:: default_safi
                    
                    	Default RPF Table SAFI
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: default_table_name
                    
                    	Default RPF Table Name
                    	**type**\: str
                    
                    .. attribute:: is_mbgp_configured
                    
                    	Is MBGP configured?
                    	**type**\: bool
                    
                    .. attribute:: is_ospf_te_configured
                    
                    	Is OSPF TE configured?
                    	**type**\: bool
                    
                    .. attribute:: is_isis_te_configured
                    
                    	Is ISIS TE configured?
                    	**type**\: bool
                    
                    .. attribute:: is_isis_mtr_configured
                    
                    	Is ISIS MTR configured?
                    	**type**\: bool
                    
                    .. attribute:: mo_frr_configured
                    
                    	Is MoFRR configured?
                    	**type**\: bool
                    
                    .. attribute:: rib_mo_frr_configured
                    
                    	Is MoFRR RIB configured?
                    	**type**\: bool
                    
                    .. attribute:: rump_enabled
                    
                    	Is RUMP MuRIB enabled?
                    	**type**\: bool
                    
                    .. attribute:: rib_convergence_timeout
                    
                    	RIB convergence timeout in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: rib_convergence_time_left
                    
                    	RIB convergence time left in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: is_multipath_enabled
                    
                    	Is Multipath Enabled ?
                    	**type**\: bool
                    
                    .. attribute:: is_multipath_interface_hash_enabled
                    
                    	Is Multipath Interface Hash Extension Enabled ?
                    	**type**\: bool
                    
                    .. attribute:: is_multipath_source_hash_enabled
                    
                    	Is Multipath Source based Hash Enabled ?
                    	**type**\: bool
                    
                    .. attribute:: is_multipath_source_next_hop_hash_enabled
                    
                    	Is Multipath Source\-Nexthop Hash Enabled ?
                    	**type**\: bool
                    
                    .. attribute:: rpf_registrations
                    
                    	RPF Registration count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_rib_convergence
                    
                    	RIB Convergence status
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.RpfSummary, self).__init__()

                        self.yang_name = "rpf-summary"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('default_safi', (YLeaf(YType.uint32, 'default-safi'), ['int'])),
                            ('default_table_name', (YLeaf(YType.str, 'default-table-name'), ['str'])),
                            ('is_mbgp_configured', (YLeaf(YType.boolean, 'is-mbgp-configured'), ['bool'])),
                            ('is_ospf_te_configured', (YLeaf(YType.boolean, 'is-ospf-te-configured'), ['bool'])),
                            ('is_isis_te_configured', (YLeaf(YType.boolean, 'is-isis-te-configured'), ['bool'])),
                            ('is_isis_mtr_configured', (YLeaf(YType.boolean, 'is-isis-mtr-configured'), ['bool'])),
                            ('mo_frr_configured', (YLeaf(YType.boolean, 'mo-frr-configured'), ['bool'])),
                            ('rib_mo_frr_configured', (YLeaf(YType.boolean, 'rib-mo-frr-configured'), ['bool'])),
                            ('rump_enabled', (YLeaf(YType.boolean, 'rump-enabled'), ['bool'])),
                            ('rib_convergence_timeout', (YLeaf(YType.uint32, 'rib-convergence-timeout'), ['int'])),
                            ('rib_convergence_time_left', (YLeaf(YType.uint32, 'rib-convergence-time-left'), ['int'])),
                            ('is_multipath_enabled', (YLeaf(YType.boolean, 'is-multipath-enabled'), ['bool'])),
                            ('is_multipath_interface_hash_enabled', (YLeaf(YType.boolean, 'is-multipath-interface-hash-enabled'), ['bool'])),
                            ('is_multipath_source_hash_enabled', (YLeaf(YType.boolean, 'is-multipath-source-hash-enabled'), ['bool'])),
                            ('is_multipath_source_next_hop_hash_enabled', (YLeaf(YType.boolean, 'is-multipath-source-next-hop-hash-enabled'), ['bool'])),
                            ('rpf_registrations', (YLeaf(YType.uint32, 'rpf-registrations'), ['int'])),
                            ('is_rib_convergence', (YLeaf(YType.boolean, 'is-rib-convergence'), ['bool'])),
                        ])
                        self.default_safi = None
                        self.default_table_name = None
                        self.is_mbgp_configured = None
                        self.is_ospf_te_configured = None
                        self.is_isis_te_configured = None
                        self.is_isis_mtr_configured = None
                        self.mo_frr_configured = None
                        self.rib_mo_frr_configured = None
                        self.rump_enabled = None
                        self.rib_convergence_timeout = None
                        self.rib_convergence_time_left = None
                        self.is_multipath_enabled = None
                        self.is_multipath_interface_hash_enabled = None
                        self.is_multipath_source_hash_enabled = None
                        self.is_multipath_source_next_hop_hash_enabled = None
                        self.rpf_registrations = None
                        self.is_rib_convergence = None
                        self._segment_path = lambda: "rpf-summary"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.RpfSummary, ['default_safi', 'default_table_name', 'is_mbgp_configured', 'is_ospf_te_configured', 'is_isis_te_configured', 'is_isis_mtr_configured', 'mo_frr_configured', 'rib_mo_frr_configured', 'rump_enabled', 'rib_convergence_timeout', 'rib_convergence_time_left', 'is_multipath_enabled', 'is_multipath_interface_hash_enabled', 'is_multipath_source_hash_enabled', 'is_multipath_source_next_hop_hash_enabled', 'rpf_registrations', 'is_rib_convergence'], name, value)


                class Interfaces(Entity):
                    """
                    PIM interfaces
                    
                    .. attribute:: interface
                    
                    	PIM interface name
                    	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Interfaces.Interface>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.Interfaces, self).__init__()

                        self.yang_name = "interfaces"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("interface", ("interface", Pim.Standby.Vrfs.Vrf.Interfaces.Interface))])
                        self._leafs = OrderedDict()

                        self.interface = YList(self)
                        self._segment_path = lambda: "interfaces"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.Interfaces, [], name, value)


                    class Interface(Entity):
                        """
                        PIM interface name
                        
                        .. attribute:: interface_name  (key)
                        
                        	Interface name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: dr_address
                        
                        	PIM Designated Router
                        	**type**\:  :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Interfaces.Interface.DrAddress>`
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identfier
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: interface_address_mask
                        
                        	Interface IP Address Mask
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: is_enabled
                        
                        	Is PIM enabled on this IF ?
                        	**type**\: bool
                        
                        .. attribute:: neighbor_count
                        
                        	No. of neighbors on this IF
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: external_neighbor_count
                        
                        	No. of external neighbors on this IF
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: hello_interval
                        
                        	Hello Interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: dr_priority
                        
                        	DR Priority
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: hello_expiry
                        
                        	Hello Timer Expiry
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: are_we_dr
                        
                        	Are we the DR on this IF ?
                        	**type**\: bool
                        
                        .. attribute:: bfd_enabled
                        
                        	BFD state
                        	**type**\: bool
                        
                        .. attribute:: bfd_interval
                        
                        	BFD Interval
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bfd_multiplier
                        
                        	BFD Multiplier
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_interface
                        
                        	 is this a Virtual Interfaces ?
                        	**type**\: bool
                        
                        .. attribute:: passive_interface
                        
                        	Passive PIM interface
                        	**type**\: bool
                        
                        .. attribute:: neighbor_filter_name
                        
                        	Neighbor Filter Name
                        	**type**\: str
                        
                        .. attribute:: join_prune_interval
                        
                        	Join\-Prune Interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: prune_delay_enabled
                        
                        	Prune Delay Enabled
                        	**type**\: bool
                        
                        .. attribute:: configured_propagation_delay
                        
                        	Configured Propagation Delay
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: configured_override_interval
                        
                        	Configured Override Interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: generation_id
                        
                        	Generation Identifier
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Bidir Capable
                        	**type**\: bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Proxy Capable
                        	**type**\: bool
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Batch Asserts Capable
                        	**type**\: bool
                        
                        .. attribute:: idb_oor_enabled
                        
                        	Interface oor enabled
                        	**type**\: bool
                        
                        .. attribute:: idb_acl_provided
                        
                        	ACL name provided
                        	**type**\: bool
                        
                        .. attribute:: idb_max_count
                        
                        	Interface ole max count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_threshold_count
                        
                        	Interface ole threshold count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_current_count
                        
                        	Interface ole current count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_acl_name
                        
                        	Interface ole ACL Name
                        	**type**\: str
                        
                        	**length:** 0..64
                        
                        .. attribute:: interface_address
                        
                        	List of Interface IP Addresses
                        	**type**\: list of  		 :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Interfaces.Interface.InterfaceAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.Interfaces.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "interfaces"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['interface_name']
                            self._child_classes = OrderedDict([("dr-address", ("dr_address", Pim.Standby.Vrfs.Vrf.Interfaces.Interface.DrAddress)), ("interface-address", ("interface_address", Pim.Standby.Vrfs.Vrf.Interfaces.Interface.InterfaceAddress))])
                            self._leafs = OrderedDict([
                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                                ('interface_address_mask', (YLeaf(YType.uint8, 'interface-address-mask'), ['int'])),
                                ('is_enabled', (YLeaf(YType.boolean, 'is-enabled'), ['bool'])),
                                ('neighbor_count', (YLeaf(YType.uint16, 'neighbor-count'), ['int'])),
                                ('external_neighbor_count', (YLeaf(YType.uint16, 'external-neighbor-count'), ['int'])),
                                ('hello_interval', (YLeaf(YType.uint16, 'hello-interval'), ['int'])),
                                ('dr_priority', (YLeaf(YType.uint32, 'dr-priority'), ['int'])),
                                ('hello_expiry', (YLeaf(YType.uint64, 'hello-expiry'), ['int'])),
                                ('are_we_dr', (YLeaf(YType.boolean, 'are-we-dr'), ['bool'])),
                                ('bfd_enabled', (YLeaf(YType.boolean, 'bfd-enabled'), ['bool'])),
                                ('bfd_interval', (YLeaf(YType.uint32, 'bfd-interval'), ['int'])),
                                ('bfd_multiplier', (YLeaf(YType.uint32, 'bfd-multiplier'), ['int'])),
                                ('virtual_interface', (YLeaf(YType.boolean, 'virtual-interface'), ['bool'])),
                                ('passive_interface', (YLeaf(YType.boolean, 'passive-interface'), ['bool'])),
                                ('neighbor_filter_name', (YLeaf(YType.str, 'neighbor-filter-name'), ['str'])),
                                ('join_prune_interval', (YLeaf(YType.uint16, 'join-prune-interval'), ['int'])),
                                ('prune_delay_enabled', (YLeaf(YType.boolean, 'prune-delay-enabled'), ['bool'])),
                                ('configured_propagation_delay', (YLeaf(YType.uint16, 'configured-propagation-delay'), ['int'])),
                                ('propagation_delay', (YLeaf(YType.uint16, 'propagation-delay'), ['int'])),
                                ('configured_override_interval', (YLeaf(YType.uint16, 'configured-override-interval'), ['int'])),
                                ('override_interval', (YLeaf(YType.uint16, 'override-interval'), ['int'])),
                                ('generation_id', (YLeaf(YType.uint32, 'generation-id'), ['int'])),
                                ('is_bidirectional_capable', (YLeaf(YType.boolean, 'is-bidirectional-capable'), ['bool'])),
                                ('is_proxy_capable', (YLeaf(YType.boolean, 'is-proxy-capable'), ['bool'])),
                                ('is_batch_asserts_capable', (YLeaf(YType.boolean, 'is-batch-asserts-capable'), ['bool'])),
                                ('idb_oor_enabled', (YLeaf(YType.boolean, 'idb-oor-enabled'), ['bool'])),
                                ('idb_acl_provided', (YLeaf(YType.boolean, 'idb-acl-provided'), ['bool'])),
                                ('idb_max_count', (YLeaf(YType.uint32, 'idb-max-count'), ['int'])),
                                ('idb_threshold_count', (YLeaf(YType.uint32, 'idb-threshold-count'), ['int'])),
                                ('idb_current_count', (YLeaf(YType.uint32, 'idb-current-count'), ['int'])),
                                ('idb_acl_name', (YLeaf(YType.str, 'idb-acl-name'), ['str'])),
                            ])
                            self.interface_name = None
                            self.interface_name_xr = None
                            self.interface_address_mask = None
                            self.is_enabled = None
                            self.neighbor_count = None
                            self.external_neighbor_count = None
                            self.hello_interval = None
                            self.dr_priority = None
                            self.hello_expiry = None
                            self.are_we_dr = None
                            self.bfd_enabled = None
                            self.bfd_interval = None
                            self.bfd_multiplier = None
                            self.virtual_interface = None
                            self.passive_interface = None
                            self.neighbor_filter_name = None
                            self.join_prune_interval = None
                            self.prune_delay_enabled = None
                            self.configured_propagation_delay = None
                            self.propagation_delay = None
                            self.configured_override_interval = None
                            self.override_interval = None
                            self.generation_id = None
                            self.is_bidirectional_capable = None
                            self.is_proxy_capable = None
                            self.is_batch_asserts_capable = None
                            self.idb_oor_enabled = None
                            self.idb_acl_provided = None
                            self.idb_max_count = None
                            self.idb_threshold_count = None
                            self.idb_current_count = None
                            self.idb_acl_name = None

                            self.dr_address = Pim.Standby.Vrfs.Vrf.Interfaces.Interface.DrAddress()
                            self.dr_address.parent = self
                            self._children_name_map["dr_address"] = "dr-address"

                            self.interface_address = YList(self)
                            self._segment_path = lambda: "interface" + "[interface-name='" + str(self.interface_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.Interfaces.Interface, ['interface_name', 'interface_name_xr', 'interface_address_mask', 'is_enabled', 'neighbor_count', 'external_neighbor_count', 'hello_interval', 'dr_priority', 'hello_expiry', 'are_we_dr', 'bfd_enabled', 'bfd_interval', 'bfd_multiplier', 'virtual_interface', 'passive_interface', 'neighbor_filter_name', 'join_prune_interval', 'prune_delay_enabled', 'configured_propagation_delay', 'propagation_delay', 'configured_override_interval', 'override_interval', 'generation_id', 'is_bidirectional_capable', 'is_proxy_capable', 'is_batch_asserts_capable', 'idb_oor_enabled', 'idb_acl_provided', 'idb_max_count', 'idb_threshold_count', 'idb_current_count', 'idb_acl_name'], name, value)


                        class DrAddress(Entity):
                            """
                            PIM Designated Router
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Interfaces.Interface.DrAddress, self).__init__()

                                self.yang_name = "dr-address"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "dr-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.Interfaces.Interface.DrAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class InterfaceAddress(Entity):
                            """
                            List of Interface IP Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Interfaces.Interface.InterfaceAddress, self).__init__()

                                self.yang_name = "interface-address"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "interface-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.Interfaces.Interface.InterfaceAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class NetIoTunnels(Entity):
                    """
                    Tunnel information that NETIO has 
                    
                    .. attribute:: net_io_tunnel
                    
                    	PIM netio tunnel information
                    	**type**\: list of  		 :py:class:`NetIoTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.NetIoTunnels, self).__init__()

                        self.yang_name = "net-io-tunnels"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("net-io-tunnel", ("net_io_tunnel", Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel))])
                        self._leafs = OrderedDict()

                        self.net_io_tunnel = YList(self)
                        self._segment_path = lambda: "net-io-tunnels"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.NetIoTunnels, [], name, value)


                    class NetIoTunnel(Entity):
                        """
                        PIM netio tunnel information
                        
                        .. attribute:: tunnel_name  (key)
                        
                        	Tunnel name
                        	**type**\: str
                        
                        	**length:** 1..64
                        
                        .. attribute:: source_address
                        
                        	Source addr known to PIM
                        	**type**\:  :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress>`
                        
                        .. attribute:: rp_address
                        
                        	RP addr known to PIM
                        	**type**\:  :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress>`
                        
                        .. attribute:: source_address_netio
                        
                        	Source addr from netio
                        	**type**\:  :py:class:`SourceAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio>`
                        
                        .. attribute:: group_address_netio
                        
                        	Group addr from netio
                        	**type**\:  :py:class:`GroupAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio>`
                        
                        .. attribute:: vrf_name
                        
                        	VRF Name
                        	**type**\: str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel, self).__init__()

                            self.yang_name = "net-io-tunnel"
                            self.yang_parent_name = "net-io-tunnels"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['tunnel_name']
                            self._child_classes = OrderedDict([("source-address", ("source_address", Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress)), ("rp-address", ("rp_address", Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress)), ("source-address-netio", ("source_address_netio", Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio)), ("group-address-netio", ("group_address_netio", Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio))])
                            self._leafs = OrderedDict([
                                ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                            ])
                            self.tunnel_name = None
                            self.vrf_name = None

                            self.source_address = Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"

                            self.rp_address = Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"

                            self.source_address_netio = Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio()
                            self.source_address_netio.parent = self
                            self._children_name_map["source_address_netio"] = "source-address-netio"

                            self.group_address_netio = Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio()
                            self.group_address_netio.parent = self
                            self._children_name_map["group_address_netio"] = "group-address-netio"
                            self._segment_path = lambda: "net-io-tunnel" + "[tunnel-name='" + str(self.tunnel_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel, ['tunnel_name', 'vrf_name'], name, value)


                        class SourceAddress(Entity):
                            """
                            Source addr known to PIM
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "net-io-tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "source-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class RpAddress(Entity):
                            """
                            RP addr known to PIM
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "net-io-tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "rp-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class SourceAddressNetio(Entity):
                            """
                            Source addr from netio
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio, self).__init__()

                                self.yang_name = "source-address-netio"
                                self.yang_parent_name = "net-io-tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "source-address-netio"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class GroupAddressNetio(Entity):
                            """
                            Group addr from netio
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio, self).__init__()

                                self.yang_name = "group-address-netio"
                                self.yang_parent_name = "net-io-tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "group-address-netio"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class BidirDfStates(Entity):
                    """
                    Bidirectional PIM DF election state table
                    
                    .. attribute:: bidir_df_state
                    
                    	Bidirectional PIM DF Election Table Entry
                    	**type**\: list of  		 :py:class:`BidirDfState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.BidirDfStates, self).__init__()

                        self.yang_name = "bidir-df-states"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("bidir-df-state", ("bidir_df_state", Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState))])
                        self._leafs = OrderedDict()

                        self.bidir_df_state = YList(self)
                        self._segment_path = lambda: "bidir-df-states"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.BidirDfStates, [], name, value)


                    class BidirDfState(Entity):
                        """
                        Bidirectional PIM DF Election Table Entry
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: rp_address_xr
                        
                        	RP Address
                        	**type**\:  :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr>`
                        
                        .. attribute:: pim_interface_name
                        
                        	Interface Name
                        	**type**\: str
                        
                        .. attribute:: election_state
                        
                        	DF Election State
                        	**type**\: str
                        
                        .. attribute:: time_seconds
                        
                        	Timer expires (seconds)
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: time_nano_seconds
                        
                        	Timer expires (nseconds)
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: nanosecond
                        
                        .. attribute:: our_metric
                        
                        	Metric
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: our_metric_preference
                        
                        	MetricPreference
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState, self).__init__()

                            self.yang_name = "bidir-df-state"
                            self.yang_parent_name = "bidir-df-states"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rp-address-xr", ("rp_address_xr", Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr))])
                            self._leafs = OrderedDict([
                                ('rp_address', (YLeaf(YType.str, 'rp-address'), ['str','str'])),
                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ('pim_interface_name', (YLeaf(YType.str, 'pim-interface-name'), ['str'])),
                                ('election_state', (YLeaf(YType.str, 'election-state'), ['str'])),
                                ('time_seconds', (YLeaf(YType.uint64, 'time-seconds'), ['int'])),
                                ('time_nano_seconds', (YLeaf(YType.uint64, 'time-nano-seconds'), ['int'])),
                                ('our_metric', (YLeaf(YType.uint32, 'our-metric'), ['int'])),
                                ('our_metric_preference', (YLeaf(YType.uint32, 'our-metric-preference'), ['int'])),
                            ])
                            self.rp_address = None
                            self.interface_name = None
                            self.pim_interface_name = None
                            self.election_state = None
                            self.time_seconds = None
                            self.time_nano_seconds = None
                            self.our_metric = None
                            self.our_metric_preference = None

                            self.rp_address_xr = Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr()
                            self.rp_address_xr.parent = self
                            self._children_name_map["rp_address_xr"] = "rp-address-xr"
                            self._segment_path = lambda: "bidir-df-state"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState, ['rp_address', 'interface_name', 'pim_interface_name', 'election_state', 'time_seconds', 'time_nano_seconds', 'our_metric', 'our_metric_preference'], name, value)


                        class RpAddressXr(Entity):
                            """
                            RP Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr, self).__init__()

                                self.yang_name = "rp-address-xr"
                                self.yang_parent_name = "bidir-df-state"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "rp-address-xr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class Topologies(Entity):
                    """
                    PIM topology table
                    
                    .. attribute:: topology
                    
                    	PIM topology information
                    	**type**\: list of  		 :py:class:`Topology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Topologies.Topology>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.Topologies, self).__init__()

                        self.yang_name = "topologies"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("topology", ("topology", Pim.Standby.Vrfs.Vrf.Topologies.Topology))])
                        self._leafs = OrderedDict()

                        self.topology = YList(self)
                        self._segment_path = lambda: "topologies"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.Topologies, [], name, value)


                    class Topology(Entity):
                        """
                        PIM topology information
                        
                        .. attribute:: source_address
                        
                        	Source address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: group_address
                        
                        	Group address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: rpt
                        
                        	RPT bit
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:  :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Topologies.Topology.GroupAddressXr>`
                        
                        .. attribute:: source_address_xr
                        
                        	Source Address
                        	**type**\:  :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Topologies.Topology.SourceAddressXr>`
                        
                        .. attribute:: rp_address
                        
                        	RP Address (If rpt)
                        	**type**\:  :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpAddress>`
                        
                        .. attribute:: rpf_neighbor
                        
                        	RPF Neighbor
                        	**type**\:  :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfNeighbor>`
                        
                        .. attribute:: secondary_rpf_neighbor
                        
                        	Secondary RPF Neighbor
                        	**type**\:  :py:class:`SecondaryRpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor>`
                        
                        .. attribute:: rpf_root
                        
                        	Root of this mcast tree
                        	**type**\:  :py:class:`RpfRoot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfRoot>`
                        
                        .. attribute:: proxy_address
                        
                        	RPF Proxy address
                        	**type**\:  :py:class:`ProxyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Topologies.Topology.ProxyAddress>`
                        
                        .. attribute:: orig_src_address
                        
                        	Orig Src Address
                        	**type**\:  :py:class:`OrigSrcAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress>`
                        
                        .. attribute:: limit_reached
                        
                        	Have we throttled the creation of routes or interfaces ?
                        	**type**\: bool
                        
                        .. attribute:: low_memory
                        
                        	Node is running low on memory
                        	**type**\: bool
                        
                        .. attribute:: protocol
                        
                        	The PIM protocol
                        	**type**\:  :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: wildcard
                        
                        	WC \-Wildcard
                        	**type**\: bool
                        
                        .. attribute:: rpt_xr
                        
                        	Is this on the RPT ?
                        	**type**\: bool
                        
                        .. attribute:: spt
                        
                        	Is this on the SPT ?
                        	**type**\: bool
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: expiry
                        
                        	When this entry expires
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: alive
                        
                        	Alive time in seconds (\-1 if never)
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: register_received_timer
                        
                        	Register Received Timer in seconds (\-1 if never)
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: remote_source
                        
                        	MSDP told us
                        	**type**\: bool
                        
                        .. attribute:: crossed_threshold
                        
                        	Incoming traffic crossed threshold. MT flag set
                        	**type**\: bool
                        
                        .. attribute:: data_mdt_addr_assigned
                        
                        	PIM has assigned a Data MDT Address
                        	**type**\: bool
                        
                        .. attribute:: rpf_interface_name
                        
                        	Interface Identifier
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: rpf_vrf_name
                        
                        	RPF VRF Name
                        	**type**\: str
                        
                        	**length:** 0..33
                        
                        .. attribute:: rpf_safi
                        
                        	Unicast or mcast
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: rpf_table_name
                        
                        	RPF Table name
                        	**type**\: str
                        
                        .. attribute:: rpf_drop
                        
                        	RPF route\-policy drop
                        	**type**\: bool
                        
                        .. attribute:: rpf_extranet
                        
                        	Extranet RPF route\-policy
                        	**type**\: bool
                        
                        .. attribute:: is_via_lsm
                        
                        	Via LSM
                        	**type**\: bool
                        
                        .. attribute:: secondary_rpf_interface_name
                        
                        	Secondary Interface Identifier
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: connected
                        
                        	Is Connected ?
                        	**type**\: bool
                        
                        .. attribute:: proxy
                        
                        	Is the RPF target a proxy?
                        	**type**\: bool
                        
                        .. attribute:: rpf_proxy_enabled
                        
                        	Is rpf if proxy enabled?
                        	**type**\: bool
                        
                        .. attribute:: mofrr_enabled
                        
                        	Is this SG MoFRR enabled?
                        	**type**\: bool
                        
                        .. attribute:: rib_mo_frr_enabled
                        
                        	Is this SG MoFRR enabled?
                        	**type**\: bool
                        
                        .. attribute:: jp_timer
                        
                        	Join\-Prune Timer
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: jp_status
                        
                        	Join\-Prune Status
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: suppress_registers
                        
                        	When the Null register probe expires
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: assume_alive
                        
                        	The Assume Alive Bit
                        	**type**\: bool
                        
                        .. attribute:: probe_alive
                        
                        	The Probe Alive Bit
                        	**type**\: bool
                        
                        .. attribute:: really_alive
                        
                        	The Really Alive Bit
                        	**type**\: bool
                        
                        .. attribute:: inherit_alive
                        
                        	The Inherit Alive Bit
                        	**type**\: bool
                        
                        .. attribute:: inherit_spt
                        
                        	The Inherit SPT Bit
                        	**type**\: bool
                        
                        .. attribute:: signal_sources
                        
                        	Signal Sources on route?
                        	**type**\: bool
                        
                        .. attribute:: dont_check_connected
                        
                        	Do we need to make the connected check on this route ?
                        	**type**\: bool
                        
                        .. attribute:: register_received
                        
                        	Have registers been received for this source ?
                        	**type**\: bool
                        
                        .. attribute:: last_hop
                        
                        	Are we last hop ?
                        	**type**\: bool
                        
                        .. attribute:: sending_registers
                        
                        	Are we sending registers for this route ?
                        	**type**\: bool
                        
                        .. attribute:: sending_null_registers
                        
                        	Are we sending null registers for this route ?
                        	**type**\: bool
                        
                        .. attribute:: sa_sent
                        
                        	BGP SA sent
                        	**type**\: bool
                        
                        .. attribute:: sa_received
                        
                        	BGP SA received
                        	**type**\: bool
                        
                        .. attribute:: sa_joined
                        
                        	BGP SA join
                        	**type**\: bool
                        
                        .. attribute:: anycast_rp_match
                        
                        	Group matches Anycast\-RP policy
                        	**type**\: bool
                        
                        .. attribute:: anycast_rp_route_target
                        
                        	Anycast\-RP RT
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: bgp_join
                        
                        	BGP C JOIN
                        	**type**\: bool
                        
                        .. attribute:: bgp_jp_time
                        
                        	BGP C JP Time
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: customer_routing_type
                        
                        	Type of Customer Routing in the MVPN
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: extranet_route
                        
                        	Is a Extranet route ?
                        	**type**\: bool
                        
                        .. attribute:: mofrr_active
                        
                        	Is MoFRR Active?
                        	**type**\: bool
                        
                        .. attribute:: mofrr_primary
                        
                        	Is this Mofrr Primary?
                        	**type**\: bool
                        
                        .. attribute:: mofrr_backup
                        
                        	Is this Mofrr Backup?
                        	**type**\: bool
                        
                        .. attribute:: vxlan
                        
                        	Is this VXLAN?
                        	**type**\: bool
                        
                        .. attribute:: kat_state
                        
                        	Keep Alive Timer State
                        	**type**\: bool
                        
                        .. attribute:: outgoing_interface
                        
                        	Outgoing interface list
                        	**type**\: list of  		 :py:class:`OutgoingInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.Topologies.Topology, self).__init__()

                            self.yang_name = "topology"
                            self.yang_parent_name = "topologies"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("group-address-xr", ("group_address_xr", Pim.Standby.Vrfs.Vrf.Topologies.Topology.GroupAddressXr)), ("source-address-xr", ("source_address_xr", Pim.Standby.Vrfs.Vrf.Topologies.Topology.SourceAddressXr)), ("rp-address", ("rp_address", Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpAddress)), ("rpf-neighbor", ("rpf_neighbor", Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfNeighbor)), ("secondary-rpf-neighbor", ("secondary_rpf_neighbor", Pim.Standby.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor)), ("rpf-root", ("rpf_root", Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfRoot)), ("proxy-address", ("proxy_address", Pim.Standby.Vrfs.Vrf.Topologies.Topology.ProxyAddress)), ("orig-src-address", ("orig_src_address", Pim.Standby.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress)), ("outgoing-interface", ("outgoing_interface", Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface))])
                            self._leafs = OrderedDict([
                                ('source_address', (YLeaf(YType.str, 'source-address'), ['str','str'])),
                                ('group_address', (YLeaf(YType.str, 'group-address'), ['str','str'])),
                                ('rpt', (YLeaf(YType.uint32, 'rpt'), ['int'])),
                                ('limit_reached', (YLeaf(YType.boolean, 'limit-reached'), ['bool'])),
                                ('low_memory', (YLeaf(YType.boolean, 'low-memory'), ['bool'])),
                                ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowProtocol', '')])),
                                ('wildcard', (YLeaf(YType.boolean, 'wildcard'), ['bool'])),
                                ('rpt_xr', (YLeaf(YType.boolean, 'rpt-xr'), ['bool'])),
                                ('spt', (YLeaf(YType.boolean, 'spt'), ['bool'])),
                                ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                                ('expiry', (YLeaf(YType.uint64, 'expiry'), ['int'])),
                                ('alive', (YLeaf(YType.int32, 'alive'), ['int'])),
                                ('register_received_timer', (YLeaf(YType.int32, 'register-received-timer'), ['int'])),
                                ('remote_source', (YLeaf(YType.boolean, 'remote-source'), ['bool'])),
                                ('crossed_threshold', (YLeaf(YType.boolean, 'crossed-threshold'), ['bool'])),
                                ('data_mdt_addr_assigned', (YLeaf(YType.boolean, 'data-mdt-addr-assigned'), ['bool'])),
                                ('rpf_interface_name', (YLeaf(YType.str, 'rpf-interface-name'), ['str'])),
                                ('rpf_vrf_name', (YLeaf(YType.str, 'rpf-vrf-name'), ['str'])),
                                ('rpf_safi', (YLeaf(YType.uint8, 'rpf-safi'), ['int'])),
                                ('rpf_table_name', (YLeaf(YType.str, 'rpf-table-name'), ['str'])),
                                ('rpf_drop', (YLeaf(YType.boolean, 'rpf-drop'), ['bool'])),
                                ('rpf_extranet', (YLeaf(YType.boolean, 'rpf-extranet'), ['bool'])),
                                ('is_via_lsm', (YLeaf(YType.boolean, 'is-via-lsm'), ['bool'])),
                                ('secondary_rpf_interface_name', (YLeaf(YType.str, 'secondary-rpf-interface-name'), ['str'])),
                                ('connected', (YLeaf(YType.boolean, 'connected'), ['bool'])),
                                ('proxy', (YLeaf(YType.boolean, 'proxy'), ['bool'])),
                                ('rpf_proxy_enabled', (YLeaf(YType.boolean, 'rpf-proxy-enabled'), ['bool'])),
                                ('mofrr_enabled', (YLeaf(YType.boolean, 'mofrr-enabled'), ['bool'])),
                                ('rib_mo_frr_enabled', (YLeaf(YType.boolean, 'rib-mo-frr-enabled'), ['bool'])),
                                ('jp_timer', (YLeaf(YType.int32, 'jp-timer'), ['int'])),
                                ('jp_status', (YLeaf(YType.int32, 'jp-status'), ['int'])),
                                ('suppress_registers', (YLeaf(YType.int32, 'suppress-registers'), ['int'])),
                                ('assume_alive', (YLeaf(YType.boolean, 'assume-alive'), ['bool'])),
                                ('probe_alive', (YLeaf(YType.boolean, 'probe-alive'), ['bool'])),
                                ('really_alive', (YLeaf(YType.boolean, 'really-alive'), ['bool'])),
                                ('inherit_alive', (YLeaf(YType.boolean, 'inherit-alive'), ['bool'])),
                                ('inherit_spt', (YLeaf(YType.boolean, 'inherit-spt'), ['bool'])),
                                ('signal_sources', (YLeaf(YType.boolean, 'signal-sources'), ['bool'])),
                                ('dont_check_connected', (YLeaf(YType.boolean, 'dont-check-connected'), ['bool'])),
                                ('register_received', (YLeaf(YType.boolean, 'register-received'), ['bool'])),
                                ('last_hop', (YLeaf(YType.boolean, 'last-hop'), ['bool'])),
                                ('sending_registers', (YLeaf(YType.boolean, 'sending-registers'), ['bool'])),
                                ('sending_null_registers', (YLeaf(YType.boolean, 'sending-null-registers'), ['bool'])),
                                ('sa_sent', (YLeaf(YType.boolean, 'sa-sent'), ['bool'])),
                                ('sa_received', (YLeaf(YType.boolean, 'sa-received'), ['bool'])),
                                ('sa_joined', (YLeaf(YType.boolean, 'sa-joined'), ['bool'])),
                                ('anycast_rp_match', (YLeaf(YType.boolean, 'anycast-rp-match'), ['bool'])),
                                ('anycast_rp_route_target', (YLeaf(YType.str, 'anycast-rp-route-target'), ['str'])),
                                ('bgp_join', (YLeaf(YType.boolean, 'bgp-join'), ['bool'])),
                                ('bgp_jp_time', (YLeaf(YType.uint64, 'bgp-jp-time'), ['int'])),
                                ('customer_routing_type', (YLeaf(YType.int32, 'customer-routing-type'), ['int'])),
                                ('extranet_route', (YLeaf(YType.boolean, 'extranet-route'), ['bool'])),
                                ('mofrr_active', (YLeaf(YType.boolean, 'mofrr-active'), ['bool'])),
                                ('mofrr_primary', (YLeaf(YType.boolean, 'mofrr-primary'), ['bool'])),
                                ('mofrr_backup', (YLeaf(YType.boolean, 'mofrr-backup'), ['bool'])),
                                ('vxlan', (YLeaf(YType.boolean, 'vxlan'), ['bool'])),
                                ('kat_state', (YLeaf(YType.boolean, 'kat-state'), ['bool'])),
                            ])
                            self.source_address = None
                            self.group_address = None
                            self.rpt = None
                            self.limit_reached = None
                            self.low_memory = None
                            self.protocol = None
                            self.wildcard = None
                            self.rpt_xr = None
                            self.spt = None
                            self.uptime = None
                            self.expiry = None
                            self.alive = None
                            self.register_received_timer = None
                            self.remote_source = None
                            self.crossed_threshold = None
                            self.data_mdt_addr_assigned = None
                            self.rpf_interface_name = None
                            self.rpf_vrf_name = None
                            self.rpf_safi = None
                            self.rpf_table_name = None
                            self.rpf_drop = None
                            self.rpf_extranet = None
                            self.is_via_lsm = None
                            self.secondary_rpf_interface_name = None
                            self.connected = None
                            self.proxy = None
                            self.rpf_proxy_enabled = None
                            self.mofrr_enabled = None
                            self.rib_mo_frr_enabled = None
                            self.jp_timer = None
                            self.jp_status = None
                            self.suppress_registers = None
                            self.assume_alive = None
                            self.probe_alive = None
                            self.really_alive = None
                            self.inherit_alive = None
                            self.inherit_spt = None
                            self.signal_sources = None
                            self.dont_check_connected = None
                            self.register_received = None
                            self.last_hop = None
                            self.sending_registers = None
                            self.sending_null_registers = None
                            self.sa_sent = None
                            self.sa_received = None
                            self.sa_joined = None
                            self.anycast_rp_match = None
                            self.anycast_rp_route_target = None
                            self.bgp_join = None
                            self.bgp_jp_time = None
                            self.customer_routing_type = None
                            self.extranet_route = None
                            self.mofrr_active = None
                            self.mofrr_primary = None
                            self.mofrr_backup = None
                            self.vxlan = None
                            self.kat_state = None

                            self.group_address_xr = Pim.Standby.Vrfs.Vrf.Topologies.Topology.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"

                            self.source_address_xr = Pim.Standby.Vrfs.Vrf.Topologies.Topology.SourceAddressXr()
                            self.source_address_xr.parent = self
                            self._children_name_map["source_address_xr"] = "source-address-xr"

                            self.rp_address = Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"

                            self.rpf_neighbor = Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfNeighbor()
                            self.rpf_neighbor.parent = self
                            self._children_name_map["rpf_neighbor"] = "rpf-neighbor"

                            self.secondary_rpf_neighbor = Pim.Standby.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor()
                            self.secondary_rpf_neighbor.parent = self
                            self._children_name_map["secondary_rpf_neighbor"] = "secondary-rpf-neighbor"

                            self.rpf_root = Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfRoot()
                            self.rpf_root.parent = self
                            self._children_name_map["rpf_root"] = "rpf-root"

                            self.proxy_address = Pim.Standby.Vrfs.Vrf.Topologies.Topology.ProxyAddress()
                            self.proxy_address.parent = self
                            self._children_name_map["proxy_address"] = "proxy-address"

                            self.orig_src_address = Pim.Standby.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress()
                            self.orig_src_address.parent = self
                            self._children_name_map["orig_src_address"] = "orig-src-address"

                            self.outgoing_interface = YList(self)
                            self._segment_path = lambda: "topology"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.Topologies.Topology, ['source_address', 'group_address', 'rpt', 'limit_reached', 'low_memory', 'protocol', 'wildcard', 'rpt_xr', 'spt', 'uptime', 'expiry', 'alive', 'register_received_timer', 'remote_source', 'crossed_threshold', 'data_mdt_addr_assigned', 'rpf_interface_name', 'rpf_vrf_name', 'rpf_safi', 'rpf_table_name', 'rpf_drop', 'rpf_extranet', 'is_via_lsm', 'secondary_rpf_interface_name', 'connected', 'proxy', 'rpf_proxy_enabled', 'mofrr_enabled', 'rib_mo_frr_enabled', 'jp_timer', 'jp_status', 'suppress_registers', 'assume_alive', 'probe_alive', 'really_alive', 'inherit_alive', 'inherit_spt', 'signal_sources', 'dont_check_connected', 'register_received', 'last_hop', 'sending_registers', 'sending_null_registers', 'sa_sent', 'sa_received', 'sa_joined', 'anycast_rp_match', 'anycast_rp_route_target', 'bgp_join', 'bgp_jp_time', 'customer_routing_type', 'extranet_route', 'mofrr_active', 'mofrr_primary', 'mofrr_backup', 'vxlan', 'kat_state'], name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Topologies.Topology.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "group-address-xr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.Topologies.Topology.GroupAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class SourceAddressXr(Entity):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Topologies.Topology.SourceAddressXr, self).__init__()

                                self.yang_name = "source-address-xr"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "source-address-xr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.Topologies.Topology.SourceAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class RpAddress(Entity):
                            """
                            RP Address (If rpt)
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "rp-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class RpfNeighbor(Entity):
                            """
                            RPF Neighbor
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfNeighbor, self).__init__()

                                self.yang_name = "rpf-neighbor"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "rpf-neighbor"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfNeighbor, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class SecondaryRpfNeighbor(Entity):
                            """
                            Secondary RPF Neighbor
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor, self).__init__()

                                self.yang_name = "secondary-rpf-neighbor"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "secondary-rpf-neighbor"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class RpfRoot(Entity):
                            """
                            Root of this mcast tree
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfRoot, self).__init__()

                                self.yang_name = "rpf-root"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "rpf-root"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfRoot, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class ProxyAddress(Entity):
                            """
                            RPF Proxy address.
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Topologies.Topology.ProxyAddress, self).__init__()

                                self.yang_name = "proxy-address"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "proxy-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.Topologies.Topology.ProxyAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class OrigSrcAddress(Entity):
                            """
                            Orig Src Address.
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress, self).__init__()

                                self.yang_name = "orig-src-address"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "orig-src-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class OutgoingInterface(Entity):
                            """
                            Outgoing interface list
                            
                            .. attribute:: assert_winner
                            
                            	Assert Winner
                            	**type**\:  :py:class:`AssertWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner>`
                            
                            .. attribute:: interface_name
                            
                            	Interface Identifier
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: expiry
                            
                            	Expiry in seconds
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: bgp_c_mcast_prune_delay_timer
                            
                            	BGP C\-MCAST Prune Suppression in seconds
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: jp_timer
                            
                            	Join\-Prune Timer (secs)
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: second
                            
                            .. attribute:: jp_state
                            
                            	Join\-Prune State
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: assert_timer
                            
                            	Assert Timer in seconds
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: second
                            
                            .. attribute:: local_members
                            
                            	Local Information. Deprecated \- use 'local\-members\-information' instead
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: internal_interest_info
                            
                            	Internal Interest. Deprecated \- use 'internal\-interest\-information' instead
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: forwarding_state
                            
                            	Forward or Prune
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: immediate_state
                            
                            	Immediate fwding state
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: last_hop
                            
                            	Are we last hop ?
                            	**type**\: bool
                            
                            .. attribute:: mldp_inband_mdt
                            
                            	MLDP Inband MDT interface
                            	**type**\: bool
                            
                            .. attribute:: mldp_stale
                            
                            	OLE is stale
                            	**type**\: bool
                            
                            .. attribute:: sa_prune
                            
                            	BGP SA Prune state
                            	**type**\: bool
                            
                            .. attribute:: admin_boundary
                            
                            	Is this an administrative boundary ?
                            	**type**\: bool
                            
                            .. attribute:: igmp_membership
                            
                            	IGMP membership
                            	**type**\: bool
                            
                            .. attribute:: mdt_safi_join
                            
                            	MDT Safi join
                            	**type**\: bool
                            
                            .. attribute:: mvpn_safi_join
                            
                            	MVPN Safi join
                            	**type**\: bool
                            
                            .. attribute:: local_mdt_join
                            
                            	Default MDT Join
                            	**type**\: bool
                            
                            .. attribute:: data_mdt_join
                            
                            	Data MDT join
                            	**type**\: bool
                            
                            .. attribute:: mvpnv6_safi_join
                            
                            	MVPN IPv6 Safi join
                            	**type**\: bool
                            
                            .. attribute:: bgp_c_mcast_join
                            
                            	BGP C\-Mcast join
                            	**type**\: bool
                            
                            .. attribute:: vrf_name
                            
                            	VRF which physically owns
                            	**type**\: str
                            
                            	**length:** 0..33
                            
                            .. attribute:: extranet_interface
                            
                            	Is this an Extranet Interface ?
                            	**type**\: bool
                            
                            .. attribute:: internal_interest_information
                            
                            	Internal Interest. Replaces internal\-interest\-info
                            	**type**\:  :py:class:`PimInternalInterestInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimInternalInterestInfo>`
                            
                            .. attribute:: local_members_information
                            
                            	Local Information. Replaces local\-members
                            	**type**\:  :py:class:`PimShowLocalInterest <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowLocalInterest>`
                            
                            .. attribute:: assert_state
                            
                            	Assert State
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface, self).__init__()

                                self.yang_name = "outgoing-interface"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("assert-winner", ("assert_winner", Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner))])
                                self._leafs = OrderedDict([
                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                    ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                                    ('expiry', (YLeaf(YType.uint64, 'expiry'), ['int'])),
                                    ('bgp_c_mcast_prune_delay_timer', (YLeaf(YType.uint64, 'bgp-c-mcast-prune-delay-timer'), ['int'])),
                                    ('jp_timer', (YLeaf(YType.int32, 'jp-timer'), ['int'])),
                                    ('jp_state', (YLeaf(YType.int32, 'jp-state'), ['int'])),
                                    ('assert_timer', (YLeaf(YType.int32, 'assert-timer'), ['int'])),
                                    ('local_members', (YLeaf(YType.int32, 'local-members'), ['int'])),
                                    ('internal_interest_info', (YLeaf(YType.int32, 'internal-interest-info'), ['int'])),
                                    ('forwarding_state', (YLeaf(YType.int32, 'forwarding-state'), ['int'])),
                                    ('immediate_state', (YLeaf(YType.int32, 'immediate-state'), ['int'])),
                                    ('last_hop', (YLeaf(YType.boolean, 'last-hop'), ['bool'])),
                                    ('mldp_inband_mdt', (YLeaf(YType.boolean, 'mldp-inband-mdt'), ['bool'])),
                                    ('mldp_stale', (YLeaf(YType.boolean, 'mldp-stale'), ['bool'])),
                                    ('sa_prune', (YLeaf(YType.boolean, 'sa-prune'), ['bool'])),
                                    ('admin_boundary', (YLeaf(YType.boolean, 'admin-boundary'), ['bool'])),
                                    ('igmp_membership', (YLeaf(YType.boolean, 'igmp-membership'), ['bool'])),
                                    ('mdt_safi_join', (YLeaf(YType.boolean, 'mdt-safi-join'), ['bool'])),
                                    ('mvpn_safi_join', (YLeaf(YType.boolean, 'mvpn-safi-join'), ['bool'])),
                                    ('local_mdt_join', (YLeaf(YType.boolean, 'local-mdt-join'), ['bool'])),
                                    ('data_mdt_join', (YLeaf(YType.boolean, 'data-mdt-join'), ['bool'])),
                                    ('mvpnv6_safi_join', (YLeaf(YType.boolean, 'mvpnv6-safi-join'), ['bool'])),
                                    ('bgp_c_mcast_join', (YLeaf(YType.boolean, 'bgp-c-mcast-join'), ['bool'])),
                                    ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                    ('extranet_interface', (YLeaf(YType.boolean, 'extranet-interface'), ['bool'])),
                                    ('internal_interest_information', (YLeaf(YType.enumeration, 'internal-interest-information'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimInternalInterestInfo', '')])),
                                    ('local_members_information', (YLeaf(YType.enumeration, 'local-members-information'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowLocalInterest', '')])),
                                    ('assert_state', (YLeaf(YType.boolean, 'assert-state'), ['bool'])),
                                ])
                                self.interface_name = None
                                self.uptime = None
                                self.expiry = None
                                self.bgp_c_mcast_prune_delay_timer = None
                                self.jp_timer = None
                                self.jp_state = None
                                self.assert_timer = None
                                self.local_members = None
                                self.internal_interest_info = None
                                self.forwarding_state = None
                                self.immediate_state = None
                                self.last_hop = None
                                self.mldp_inband_mdt = None
                                self.mldp_stale = None
                                self.sa_prune = None
                                self.admin_boundary = None
                                self.igmp_membership = None
                                self.mdt_safi_join = None
                                self.mvpn_safi_join = None
                                self.local_mdt_join = None
                                self.data_mdt_join = None
                                self.mvpnv6_safi_join = None
                                self.bgp_c_mcast_join = None
                                self.vrf_name = None
                                self.extranet_interface = None
                                self.internal_interest_information = None
                                self.local_members_information = None
                                self.assert_state = None

                                self.assert_winner = Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner()
                                self.assert_winner.parent = self
                                self._children_name_map["assert_winner"] = "assert-winner"
                                self._segment_path = lambda: "outgoing-interface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface, ['interface_name', 'uptime', 'expiry', 'bgp_c_mcast_prune_delay_timer', 'jp_timer', 'jp_state', 'assert_timer', 'local_members', 'internal_interest_info', 'forwarding_state', 'immediate_state', 'last_hop', 'mldp_inband_mdt', 'mldp_stale', 'sa_prune', 'admin_boundary', 'igmp_membership', 'mdt_safi_join', 'mvpn_safi_join', 'local_mdt_join', 'data_mdt_join', 'mvpnv6_safi_join', 'bgp_c_mcast_join', 'vrf_name', 'extranet_interface', 'internal_interest_information', 'local_members_information', 'assert_state'], name, value)


                            class AssertWinner(Entity):
                                """
                                Assert Winner
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner, self).__init__()

                                    self.yang_name = "assert-winner"
                                    self.yang_parent_name = "outgoing-interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "assert-winner"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class BgpAfs(Entity):
                    """
                    PIM BGP SAFI table
                    
                    .. attribute:: bgp_af
                    
                    	PIM BGP SAFI information
                    	**type**\: list of  		 :py:class:`BgpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.BgpAfs, self).__init__()

                        self.yang_name = "bgp-afs"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("bgp-af", ("bgp_af", Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf))])
                        self._leafs = OrderedDict()

                        self.bgp_af = YList(self)
                        self._segment_path = lambda: "bgp-afs"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.BgpAfs, [], name, value)


                    class BgpAf(Entity):
                        """
                        PIM BGP SAFI information
                        
                        .. attribute:: source_address
                        
                        	Source IP address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: group_address
                        
                        	Group IP address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source
                        
                        	Source address
                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Source>`
                        
                        .. attribute:: group
                        
                        	Group address
                        	**type**\:  :py:class:`Group <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Group>`
                        
                        .. attribute:: next_hop
                        
                        	Next hop address
                        	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.NextHop>`
                        
                        .. attribute:: route_distinguisher
                        
                        	Router ID
                        	**type**\: str
                        
                        	**length:** 0..256
                        
                        .. attribute:: extranet_path_count
                        
                        	Count of dependent extranet paths
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_bgp_added
                        
                        	SAFI learnt from BGP
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf, self).__init__()

                            self.yang_name = "bgp-af"
                            self.yang_parent_name = "bgp-afs"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("source", ("source", Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Source)), ("group", ("group", Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Group)), ("next-hop", ("next_hop", Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.NextHop))])
                            self._leafs = OrderedDict([
                                ('source_address', (YLeaf(YType.str, 'source-address'), ['str','str'])),
                                ('group_address', (YLeaf(YType.str, 'group-address'), ['str','str'])),
                                ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                ('extranet_path_count', (YLeaf(YType.uint32, 'extranet-path-count'), ['int'])),
                                ('is_bgp_added', (YLeaf(YType.boolean, 'is-bgp-added'), ['bool'])),
                            ])
                            self.source_address = None
                            self.group_address = None
                            self.route_distinguisher = None
                            self.extranet_path_count = None
                            self.is_bgp_added = None

                            self.source = Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Source()
                            self.source.parent = self
                            self._children_name_map["source"] = "source"

                            self.group = Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Group()
                            self.group.parent = self
                            self._children_name_map["group"] = "group"

                            self.next_hop = Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.NextHop()
                            self.next_hop.parent = self
                            self._children_name_map["next_hop"] = "next-hop"
                            self._segment_path = lambda: "bgp-af"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf, ['source_address', 'group_address', 'route_distinguisher', 'extranet_path_count', 'is_bgp_added'], name, value)


                        class Source(Entity):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "bgp-af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "source"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Source, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class Group(Entity):
                            """
                            Group address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Group, self).__init__()

                                self.yang_name = "group"
                                self.yang_parent_name = "bgp-af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "group"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Group, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class NextHop(Entity):
                            """
                            Next hop address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.NextHop, self).__init__()

                                self.yang_name = "next-hop"
                                self.yang_parent_name = "bgp-af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "next-hop"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.NextHop, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class AutoRp(Entity):
                    """
                    PIM Auto\-RP information
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.AutoRp, self).__init__()

                        self.yang_name = "auto-rp"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "auto-rp"
                        self._is_frozen = True


                class TopologyInterfaceFlagRouteCounts(Entity):
                    """
                    Route count for topology with interface flag set
                    
                    .. attribute:: topology_interface_flag_route_count
                    
                    	Route count for topology with interface flag set
                    	**type**\: list of  		 :py:class:`TopologyInterfaceFlagRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts, self).__init__()

                        self.yang_name = "topology-interface-flag-route-counts"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("topology-interface-flag-route-count", ("topology_interface_flag_route_count", Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount))])
                        self._leafs = OrderedDict()

                        self.topology_interface_flag_route_count = YList(self)
                        self._segment_path = lambda: "topology-interface-flag-route-counts"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts, [], name, value)


                    class TopologyInterfaceFlagRouteCount(Entity):
                        """
                        Route count for topology with interface flag
                        set
                        
                        .. attribute:: interface_flag  (key)
                        
                        	Interface flag
                        	**type**\:  :py:class:`PimTopologyInterfaceFlag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimTopologyInterfaceFlag>`
                        
                        .. attribute:: group_ranges
                        
                        	No. of (\*,G/M) routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: active_group_ranges
                        
                        	No. of (\*,G/M) routes active in mrib
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: groute_count
                        
                        	No. of (\*,G) routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sg_route_count
                        
                        	No. of (S,G) routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sgr_route_count
                        
                        	No. of (S,G)RPT routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_node_low_memory
                        
                        	Is node in low memory condition
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount, self).__init__()

                            self.yang_name = "topology-interface-flag-route-count"
                            self.yang_parent_name = "topology-interface-flag-route-counts"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['interface_flag']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface_flag', (YLeaf(YType.enumeration, 'interface-flag'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimTopologyInterfaceFlag', '')])),
                                ('group_ranges', (YLeaf(YType.uint32, 'group-ranges'), ['int'])),
                                ('active_group_ranges', (YLeaf(YType.uint32, 'active-group-ranges'), ['int'])),
                                ('groute_count', (YLeaf(YType.uint32, 'groute-count'), ['int'])),
                                ('sg_route_count', (YLeaf(YType.uint32, 'sg-route-count'), ['int'])),
                                ('sgr_route_count', (YLeaf(YType.uint32, 'sgr-route-count'), ['int'])),
                                ('is_node_low_memory', (YLeaf(YType.boolean, 'is-node-low-memory'), ['bool'])),
                            ])
                            self.interface_flag = None
                            self.group_ranges = None
                            self.active_group_ranges = None
                            self.groute_count = None
                            self.sg_route_count = None
                            self.sgr_route_count = None
                            self.is_node_low_memory = None
                            self._segment_path = lambda: "topology-interface-flag-route-count" + "[interface-flag='" + str(self.interface_flag) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount, ['interface_flag', 'group_ranges', 'active_group_ranges', 'groute_count', 'sg_route_count', 'sgr_route_count', 'is_node_low_memory'], name, value)


                class GroupMapSources(Entity):
                    """
                    PIM group\-mapping with source information
                    
                    .. attribute:: group_map_source
                    
                    	PIM Group Mapping Entry with source information
                    	**type**\: list of  		 :py:class:`GroupMapSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.GroupMapSources, self).__init__()

                        self.yang_name = "group-map-sources"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("group-map-source", ("group_map_source", Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource))])
                        self._leafs = OrderedDict()

                        self.group_map_source = YList(self)
                        self._segment_path = lambda: "group-map-sources"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.GroupMapSources, [], name, value)


                    class GroupMapSource(Entity):
                        """
                        PIM Group Mapping Entry with source information
                        
                        .. attribute:: prefix
                        
                        	Prefix
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: client
                        
                        	Client
                        	**type**\:  :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:  :py:class:`PimProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimProtocol>`
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: priority
                        
                        	RP Priority
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: source_of_information
                        
                        	The source of information
                        	**type**\:  :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation>`
                        
                        .. attribute:: group_map_information
                        
                        	Group Mapping information
                        	**type**\:  :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation>`
                        
                        .. attribute:: holdtime
                        
                        	Holdtime in seconds
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: expires
                        
                        	Mapping expiry time in seconds
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: uptime
                        
                        	Mapping uptime in seconds
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource, self).__init__()

                            self.yang_name = "group-map-source"
                            self.yang_parent_name = "group-map-sources"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("source-of-information", ("source_of_information", Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation)), ("group-map-information", ("group_map_information", Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation))])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                ('client', (YLeaf(YType.enumeration, 'client'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimClient', '')])),
                                ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimProtocol', '')])),
                                ('rp_address', (YLeaf(YType.str, 'rp-address'), ['str','str'])),
                                ('priority', (YLeaf(YType.uint32, 'priority'), ['int'])),
                                ('holdtime', (YLeaf(YType.int32, 'holdtime'), ['int'])),
                                ('expires', (YLeaf(YType.uint64, 'expires'), ['int'])),
                                ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                            ])
                            self.prefix = None
                            self.prefix_length = None
                            self.client = None
                            self.protocol = None
                            self.rp_address = None
                            self.priority = None
                            self.holdtime = None
                            self.expires = None
                            self.uptime = None

                            self.source_of_information = Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation()
                            self.source_of_information.parent = self
                            self._children_name_map["source_of_information"] = "source-of-information"

                            self.group_map_information = Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation()
                            self.group_map_information.parent = self
                            self._children_name_map["group_map_information"] = "group-map-information"
                            self._segment_path = lambda: "group-map-source"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource, ['prefix', 'prefix_length', 'client', 'protocol', 'rp_address', 'priority', 'holdtime', 'expires', 'uptime'], name, value)


                        class SourceOfInformation(Entity):
                            """
                            The source of information
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation, self).__init__()

                                self.yang_name = "source-of-information"
                                self.yang_parent_name = "group-map-source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "source-of-information"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class GroupMapInformation(Entity):
                            """
                            Group Mapping information
                            
                            .. attribute:: prefix
                            
                            	Group range prefix
                            	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix>`
                            
                            .. attribute:: rp_address
                            
                            	Rendezvous Point Address
                            	**type**\:  :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress>`
                            
                            .. attribute:: prefix_length
                            
                            	Group range prefix length
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: client
                            
                            	Client mapping learnt from
                            	**type**\:  :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                            
                            .. attribute:: protocol
                            
                            	Protocol mode of the range
                            	**type**\:  :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                            
                            .. attribute:: group_count
                            
                            	No. of groups in this range
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_used
                            
                            	Is this mapping being used?
                            	**type**\: bool
                            
                            .. attribute:: mrib_active
                            
                            	Is this mapping active in MRIB?
                            	**type**\: bool
                            
                            .. attribute:: is_override
                            
                            	Is this the override range?
                            	**type**\: bool
                            
                            .. attribute:: priority
                            
                            	Bootstrap priority
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation, self).__init__()

                                self.yang_name = "group-map-information"
                                self.yang_parent_name = "group-map-source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("prefix", ("prefix", Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix)), ("rp-address", ("rp_address", Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress))])
                                self._leafs = OrderedDict([
                                    ('prefix_length', (YLeaf(YType.int32, 'prefix-length'), ['int'])),
                                    ('client', (YLeaf(YType.enumeration, 'client'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowRangeClient', '')])),
                                    ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowProtocol', '')])),
                                    ('group_count', (YLeaf(YType.uint32, 'group-count'), ['int'])),
                                    ('is_used', (YLeaf(YType.boolean, 'is-used'), ['bool'])),
                                    ('mrib_active', (YLeaf(YType.boolean, 'mrib-active'), ['bool'])),
                                    ('is_override', (YLeaf(YType.boolean, 'is-override'), ['bool'])),
                                    ('priority', (YLeaf(YType.uint32, 'priority'), ['int'])),
                                ])
                                self.prefix_length = None
                                self.client = None
                                self.protocol = None
                                self.group_count = None
                                self.is_used = None
                                self.mrib_active = None
                                self.is_override = None
                                self.priority = None

                                self.prefix = Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix()
                                self.prefix.parent = self
                                self._children_name_map["prefix"] = "prefix"

                                self.rp_address = Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress()
                                self.rp_address.parent = self
                                self._children_name_map["rp_address"] = "rp-address"
                                self._segment_path = lambda: "group-map-information"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation, ['prefix_length', 'client', 'protocol', 'group_count', 'is_used', 'mrib_active', 'is_override', 'priority'], name, value)


                            class Prefix(Entity):
                                """
                                Group range prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix, self).__init__()

                                    self.yang_name = "prefix"
                                    self.yang_parent_name = "group-map-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "prefix"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                            class RpAddress(Entity):
                                """
                                Rendezvous Point Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress, self).__init__()

                                    self.yang_name = "rp-address"
                                    self.yang_parent_name = "group-map-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "rp-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class TrafficCounters(Entity):
                    """
                    PIM message traffic counters
                    
                    .. attribute:: elapsed_time
                    
                    	Running time for counters in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: inputs
                    
                    	Packets in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: outputs
                    
                    	Packets out
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: format_error
                    
                    	Malformed packets in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pakman_error
                    
                    	Pakman packets dropped
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: standby_packets_error
                    
                    	Packets received in standby state
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: checksum_error
                    
                    	Checksum errors
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: socket_error
                    
                    	Socket errors
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: send_queue_full
                    
                    	Packets dropped since send queue was full
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: boundary_acl_rx_drop
                    
                    	Inc. JP dropped since boundary ACL confg
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: boundary_acl_tx_drop
                    
                    	Out JP dropped since boundary ACL confg
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: no_socket_connection
                    
                    	Packets dropped since no socket connection
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: no_source_address
                    
                    	Packets dropped since no source address
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_hello
                    
                    	Hello packets in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_hello
                    
                    	Hello packets out
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_jp
                    
                    	Join Prune packets in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_jp
                    
                    	Join Prune packets out
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_data_register
                    
                    	Data Register packets in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_null_register
                    
                    	Null Register packets in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_null_register
                    
                    	Null Register packets out
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_register_stop
                    
                    	Register Stop packets in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_register_stop
                    
                    	Register Stop packets out
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_assert
                    
                    	Assert packets in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_assert_batched
                    
                    	Batched Assert packets in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_assert
                    
                    	Assert packets out
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_assert_batched
                    
                    	Batched Assert packets out
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_df_election
                    
                    	DF Election packets in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_df_election
                    
                    	DF Election packets out
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_bsr_message
                    
                    	Input BSR Messages
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_bsr_message
                    
                    	Output BSR Messages
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_candidate_rp_advertisement
                    
                    	Input Candidate\-RP Advertisment
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_candidate_rp_advertisement
                    
                    	Output Candidate\-RP Advertisment
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_ecmp_redirect
                    
                    	Input Ecmp Redirect
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_ecmp_redirect
                    
                    	Output Ecmp Redirect
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_loop_error
                    
                    	Output on loopback error
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_invalid_lsm_identifier
                    
                    	 Invalid LSM ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_idb_error
                    
                    	No IDB for intf error
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_vrf_error
                    
                    	No VRF for idb error
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_pim_error
                    
                    	PIM Disabled on intf error
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_pim_version_error
                    
                    	Invalid PIM version error
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_join_group
                    
                    	Output Join Groups
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_prune_group
                    
                    	Output Prune Groups
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_join_prune_bytes
                    
                    	Output JP Bytes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: byte
                    
                    .. attribute:: output_hello_bytes
                    
                    	Output Hello Bytes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: byte
                    
                    .. attribute:: non_supported_packets
                    
                    	PIM non supported pckets
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_registers
                    
                    	PIM invalid registers received
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_join_prunes
                    
                    	PIM invalid Join/Prunes received
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_packman_error
                    
                    	Packets Dropped due to Pakman Error
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_read_socket_error
                    
                    	Packet Read Socket Error
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_queue_last_clear
                    
                    	Time in seconds since the last clear of all packet queues stats
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: packets_standby
                    
                    	Packets Dropped due to Standby Error
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: no_mdt_socket_connection
                    
                    	Packets dropped since no mdt socket connection
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_send_queue_full
                    
                    	Packets dropped since mdt send queue was full
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_socket_error
                    
                    	MDT Socket errors
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_join_tlv_sent
                    
                    	Data MDT Join Msgs sent
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_join_tlv_received
                    
                    	Data MDT Join Msgs received
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_join_bad_type
                    
                    	Data MDT TLV bad type
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_drop_local_source_address
                    
                    	Data MDT Join msgs dropped due to local source addr
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_drop_null_local_address
                    
                    	Data MDT Join msgs dropped due to null local addr
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_drop_no_idb
                    
                    	Data MDT Join msgs dropped due to idb missing
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_drop_no_vrf
                    
                    	Data MDT Join msgs dropped due to vrf missing
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_destination_packets
                    
                    	Control Packets with Invalid Destination
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_joins_drop_multiple_encapsulation
                    
                    	MDT Join msgs dropped due to multiple Encap limitation
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: truncated_pim_packets
                    
                    	Packets dropped due to truncated Joins or Prunes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_source_encodings
                    
                    	Number of invalid source encodings received
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_hello_options
                    
                    	Number of invalid hello options received
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_queue
                    
                    	Packet queue state and statistics
                    	**type**\: list of  		 :py:class:`PacketQueue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.TrafficCounters, self).__init__()

                        self.yang_name = "traffic-counters"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("packet-queue", ("packet_queue", Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue))])
                        self._leafs = OrderedDict([
                            ('elapsed_time', (YLeaf(YType.uint32, 'elapsed-time'), ['int'])),
                            ('inputs', (YLeaf(YType.uint32, 'inputs'), ['int'])),
                            ('outputs', (YLeaf(YType.uint32, 'outputs'), ['int'])),
                            ('format_error', (YLeaf(YType.uint32, 'format-error'), ['int'])),
                            ('pakman_error', (YLeaf(YType.uint32, 'pakman-error'), ['int'])),
                            ('standby_packets_error', (YLeaf(YType.uint32, 'standby-packets-error'), ['int'])),
                            ('checksum_error', (YLeaf(YType.uint32, 'checksum-error'), ['int'])),
                            ('socket_error', (YLeaf(YType.uint32, 'socket-error'), ['int'])),
                            ('send_queue_full', (YLeaf(YType.uint32, 'send-queue-full'), ['int'])),
                            ('boundary_acl_rx_drop', (YLeaf(YType.uint32, 'boundary-acl-rx-drop'), ['int'])),
                            ('boundary_acl_tx_drop', (YLeaf(YType.uint32, 'boundary-acl-tx-drop'), ['int'])),
                            ('no_socket_connection', (YLeaf(YType.uint32, 'no-socket-connection'), ['int'])),
                            ('no_source_address', (YLeaf(YType.uint32, 'no-source-address'), ['int'])),
                            ('input_hello', (YLeaf(YType.uint32, 'input-hello'), ['int'])),
                            ('output_hello', (YLeaf(YType.uint32, 'output-hello'), ['int'])),
                            ('input_jp', (YLeaf(YType.uint32, 'input-jp'), ['int'])),
                            ('output_jp', (YLeaf(YType.uint32, 'output-jp'), ['int'])),
                            ('input_data_register', (YLeaf(YType.uint32, 'input-data-register'), ['int'])),
                            ('input_null_register', (YLeaf(YType.uint32, 'input-null-register'), ['int'])),
                            ('output_null_register', (YLeaf(YType.uint32, 'output-null-register'), ['int'])),
                            ('input_register_stop', (YLeaf(YType.uint32, 'input-register-stop'), ['int'])),
                            ('output_register_stop', (YLeaf(YType.uint32, 'output-register-stop'), ['int'])),
                            ('input_assert', (YLeaf(YType.uint32, 'input-assert'), ['int'])),
                            ('input_assert_batched', (YLeaf(YType.uint32, 'input-assert-batched'), ['int'])),
                            ('output_assert', (YLeaf(YType.uint32, 'output-assert'), ['int'])),
                            ('output_assert_batched', (YLeaf(YType.uint32, 'output-assert-batched'), ['int'])),
                            ('input_df_election', (YLeaf(YType.uint32, 'input-df-election'), ['int'])),
                            ('output_df_election', (YLeaf(YType.uint32, 'output-df-election'), ['int'])),
                            ('input_bsr_message', (YLeaf(YType.uint32, 'input-bsr-message'), ['int'])),
                            ('output_bsr_message', (YLeaf(YType.uint32, 'output-bsr-message'), ['int'])),
                            ('input_candidate_rp_advertisement', (YLeaf(YType.uint32, 'input-candidate-rp-advertisement'), ['int'])),
                            ('output_candidate_rp_advertisement', (YLeaf(YType.uint32, 'output-candidate-rp-advertisement'), ['int'])),
                            ('input_ecmp_redirect', (YLeaf(YType.uint32, 'input-ecmp-redirect'), ['int'])),
                            ('output_ecmp_redirect', (YLeaf(YType.uint32, 'output-ecmp-redirect'), ['int'])),
                            ('output_loop_error', (YLeaf(YType.uint32, 'output-loop-error'), ['int'])),
                            ('mldp_mdt_invalid_lsm_identifier', (YLeaf(YType.uint32, 'mldp-mdt-invalid-lsm-identifier'), ['int'])),
                            ('input_no_idb_error', (YLeaf(YType.uint32, 'input-no-idb-error'), ['int'])),
                            ('input_no_vrf_error', (YLeaf(YType.uint32, 'input-no-vrf-error'), ['int'])),
                            ('input_no_pim_error', (YLeaf(YType.uint32, 'input-no-pim-error'), ['int'])),
                            ('input_pim_version_error', (YLeaf(YType.uint32, 'input-pim-version-error'), ['int'])),
                            ('output_join_group', (YLeaf(YType.uint32, 'output-join-group'), ['int'])),
                            ('output_prune_group', (YLeaf(YType.uint32, 'output-prune-group'), ['int'])),
                            ('output_join_prune_bytes', (YLeaf(YType.uint32, 'output-join-prune-bytes'), ['int'])),
                            ('output_hello_bytes', (YLeaf(YType.uint32, 'output-hello-bytes'), ['int'])),
                            ('non_supported_packets', (YLeaf(YType.uint32, 'non-supported-packets'), ['int'])),
                            ('invalid_registers', (YLeaf(YType.uint32, 'invalid-registers'), ['int'])),
                            ('invalid_join_prunes', (YLeaf(YType.uint32, 'invalid-join-prunes'), ['int'])),
                            ('packet_packman_error', (YLeaf(YType.uint32, 'packet-packman-error'), ['int'])),
                            ('packet_read_socket_error', (YLeaf(YType.uint32, 'packet-read-socket-error'), ['int'])),
                            ('packet_queue_last_clear', (YLeaf(YType.uint32, 'packet-queue-last-clear'), ['int'])),
                            ('packets_standby', (YLeaf(YType.uint32, 'packets-standby'), ['int'])),
                            ('no_mdt_socket_connection', (YLeaf(YType.uint32, 'no-mdt-socket-connection'), ['int'])),
                            ('mdt_send_queue_full', (YLeaf(YType.uint32, 'mdt-send-queue-full'), ['int'])),
                            ('mdt_socket_error', (YLeaf(YType.uint32, 'mdt-socket-error'), ['int'])),
                            ('mdt_join_tlv_sent', (YLeaf(YType.uint32, 'mdt-join-tlv-sent'), ['int'])),
                            ('mdt_join_tlv_received', (YLeaf(YType.uint32, 'mdt-join-tlv-received'), ['int'])),
                            ('mdt_join_bad_type', (YLeaf(YType.uint32, 'mdt-join-bad-type'), ['int'])),
                            ('mdt_drop_local_source_address', (YLeaf(YType.uint32, 'mdt-drop-local-source-address'), ['int'])),
                            ('mdt_drop_null_local_address', (YLeaf(YType.uint32, 'mdt-drop-null-local-address'), ['int'])),
                            ('mdt_drop_no_idb', (YLeaf(YType.uint32, 'mdt-drop-no-idb'), ['int'])),
                            ('mdt_drop_no_vrf', (YLeaf(YType.uint32, 'mdt-drop-no-vrf'), ['int'])),
                            ('invalid_destination_packets', (YLeaf(YType.uint32, 'invalid-destination-packets'), ['int'])),
                            ('mdt_joins_drop_multiple_encapsulation', (YLeaf(YType.uint32, 'mdt-joins-drop-multiple-encapsulation'), ['int'])),
                            ('truncated_pim_packets', (YLeaf(YType.uint32, 'truncated-pim-packets'), ['int'])),
                            ('invalid_source_encodings', (YLeaf(YType.uint32, 'invalid-source-encodings'), ['int'])),
                            ('invalid_hello_options', (YLeaf(YType.uint32, 'invalid-hello-options'), ['int'])),
                        ])
                        self.elapsed_time = None
                        self.inputs = None
                        self.outputs = None
                        self.format_error = None
                        self.pakman_error = None
                        self.standby_packets_error = None
                        self.checksum_error = None
                        self.socket_error = None
                        self.send_queue_full = None
                        self.boundary_acl_rx_drop = None
                        self.boundary_acl_tx_drop = None
                        self.no_socket_connection = None
                        self.no_source_address = None
                        self.input_hello = None
                        self.output_hello = None
                        self.input_jp = None
                        self.output_jp = None
                        self.input_data_register = None
                        self.input_null_register = None
                        self.output_null_register = None
                        self.input_register_stop = None
                        self.output_register_stop = None
                        self.input_assert = None
                        self.input_assert_batched = None
                        self.output_assert = None
                        self.output_assert_batched = None
                        self.input_df_election = None
                        self.output_df_election = None
                        self.input_bsr_message = None
                        self.output_bsr_message = None
                        self.input_candidate_rp_advertisement = None
                        self.output_candidate_rp_advertisement = None
                        self.input_ecmp_redirect = None
                        self.output_ecmp_redirect = None
                        self.output_loop_error = None
                        self.mldp_mdt_invalid_lsm_identifier = None
                        self.input_no_idb_error = None
                        self.input_no_vrf_error = None
                        self.input_no_pim_error = None
                        self.input_pim_version_error = None
                        self.output_join_group = None
                        self.output_prune_group = None
                        self.output_join_prune_bytes = None
                        self.output_hello_bytes = None
                        self.non_supported_packets = None
                        self.invalid_registers = None
                        self.invalid_join_prunes = None
                        self.packet_packman_error = None
                        self.packet_read_socket_error = None
                        self.packet_queue_last_clear = None
                        self.packets_standby = None
                        self.no_mdt_socket_connection = None
                        self.mdt_send_queue_full = None
                        self.mdt_socket_error = None
                        self.mdt_join_tlv_sent = None
                        self.mdt_join_tlv_received = None
                        self.mdt_join_bad_type = None
                        self.mdt_drop_local_source_address = None
                        self.mdt_drop_null_local_address = None
                        self.mdt_drop_no_idb = None
                        self.mdt_drop_no_vrf = None
                        self.invalid_destination_packets = None
                        self.mdt_joins_drop_multiple_encapsulation = None
                        self.truncated_pim_packets = None
                        self.invalid_source_encodings = None
                        self.invalid_hello_options = None

                        self.packet_queue = YList(self)
                        self._segment_path = lambda: "traffic-counters"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.TrafficCounters, ['elapsed_time', 'inputs', 'outputs', 'format_error', 'pakman_error', 'standby_packets_error', 'checksum_error', 'socket_error', 'send_queue_full', 'boundary_acl_rx_drop', 'boundary_acl_tx_drop', 'no_socket_connection', 'no_source_address', 'input_hello', 'output_hello', 'input_jp', 'output_jp', 'input_data_register', 'input_null_register', 'output_null_register', 'input_register_stop', 'output_register_stop', 'input_assert', 'input_assert_batched', 'output_assert', 'output_assert_batched', 'input_df_election', 'output_df_election', 'input_bsr_message', 'output_bsr_message', 'input_candidate_rp_advertisement', 'output_candidate_rp_advertisement', 'input_ecmp_redirect', 'output_ecmp_redirect', 'output_loop_error', 'mldp_mdt_invalid_lsm_identifier', 'input_no_idb_error', 'input_no_vrf_error', 'input_no_pim_error', 'input_pim_version_error', 'output_join_group', 'output_prune_group', 'output_join_prune_bytes', 'output_hello_bytes', 'non_supported_packets', 'invalid_registers', 'invalid_join_prunes', 'packet_packman_error', 'packet_read_socket_error', 'packet_queue_last_clear', 'packets_standby', 'no_mdt_socket_connection', 'mdt_send_queue_full', 'mdt_socket_error', 'mdt_join_tlv_sent', 'mdt_join_tlv_received', 'mdt_join_bad_type', 'mdt_drop_local_source_address', 'mdt_drop_null_local_address', 'mdt_drop_no_idb', 'mdt_drop_no_vrf', 'invalid_destination_packets', 'mdt_joins_drop_multiple_encapsulation', 'truncated_pim_packets', 'invalid_source_encodings', 'invalid_hello_options'], name, value)


                    class PacketQueue(Entity):
                        """
                        Packet queue state and statistics
                        
                        .. attribute:: packet_queue_state
                        
                        	State of the queue
                        	**type**\:  :py:class:`PacketQueueState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState>`
                        
                        .. attribute:: packet_queue_stats
                        
                        	Statistics about the queue
                        	**type**\:  :py:class:`PacketQueueStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats>`
                        
                        .. attribute:: packet_queue_priority
                        
                        	Priority of this packet queue
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue, self).__init__()

                            self.yang_name = "packet-queue"
                            self.yang_parent_name = "traffic-counters"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("packet-queue-state", ("packet_queue_state", Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState)), ("packet-queue-stats", ("packet_queue_stats", Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats))])
                            self._leafs = OrderedDict([
                                ('packet_queue_priority', (YLeaf(YType.uint32, 'packet-queue-priority'), ['int'])),
                            ])
                            self.packet_queue_priority = None

                            self.packet_queue_state = Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState()
                            self.packet_queue_state.parent = self
                            self._children_name_map["packet_queue_state"] = "packet-queue-state"

                            self.packet_queue_stats = Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats()
                            self.packet_queue_stats.parent = self
                            self._children_name_map["packet_queue_stats"] = "packet-queue-stats"
                            self._segment_path = lambda: "packet-queue"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue, ['packet_queue_priority'], name, value)


                        class PacketQueueState(Entity):
                            """
                            State of the queue
                            
                            .. attribute:: max_queue_size
                            
                            	Maximum size of queue in bytes
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: queue_size_bytes
                            
                            	Size of queue in bytes
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: queue_size_packets
                            
                            	Size of queue in number of packets
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState, self).__init__()

                                self.yang_name = "packet-queue-state"
                                self.yang_parent_name = "packet-queue"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('max_queue_size', (YLeaf(YType.uint32, 'max-queue-size'), ['int'])),
                                    ('queue_size_bytes', (YLeaf(YType.uint32, 'queue-size-bytes'), ['int'])),
                                    ('queue_size_packets', (YLeaf(YType.uint32, 'queue-size-packets'), ['int'])),
                                ])
                                self.max_queue_size = None
                                self.queue_size_bytes = None
                                self.queue_size_packets = None
                                self._segment_path = lambda: "packet-queue-state"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState, ['max_queue_size', 'queue_size_bytes', 'queue_size_packets'], name, value)


                        class PacketQueueStats(Entity):
                            """
                            Statistics about the queue
                            
                            .. attribute:: enqueued_packets
                            
                            	Total number of packets enqueued to this queue
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: dequeued_packets
                            
                            	Total number of packets dequeued from this queue
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: high_water_mark_packets
                            
                            	Highest number of packets enqueued in this queue
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: high_water_mark_bytes
                            
                            	Highest number of bytes enqueued in this queue
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: tail_drops
                            
                            	Number packets dropped from this queue due to max size
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats, self).__init__()

                                self.yang_name = "packet-queue-stats"
                                self.yang_parent_name = "packet-queue"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('enqueued_packets', (YLeaf(YType.uint32, 'enqueued-packets'), ['int'])),
                                    ('dequeued_packets', (YLeaf(YType.uint32, 'dequeued-packets'), ['int'])),
                                    ('high_water_mark_packets', (YLeaf(YType.uint32, 'high-water-mark-packets'), ['int'])),
                                    ('high_water_mark_bytes', (YLeaf(YType.uint32, 'high-water-mark-bytes'), ['int'])),
                                    ('tail_drops', (YLeaf(YType.uint32, 'tail-drops'), ['int'])),
                                ])
                                self.enqueued_packets = None
                                self.dequeued_packets = None
                                self.high_water_mark_packets = None
                                self.high_water_mark_bytes = None
                                self.tail_drops = None
                                self._segment_path = lambda: "packet-queue-stats"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats, ['enqueued_packets', 'dequeued_packets', 'high_water_mark_packets', 'high_water_mark_bytes', 'tail_drops'], name, value)


                class GroupMapRpfs(Entity):
                    """
                    PIM group mapping information
                    
                    .. attribute:: group_map_rpf
                    
                    	PIM group mapping entry
                    	**type**\: list of  		 :py:class:`GroupMapRpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.GroupMapRpfs, self).__init__()

                        self.yang_name = "group-map-rpfs"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("group-map-rpf", ("group_map_rpf", Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf))])
                        self._leafs = OrderedDict()

                        self.group_map_rpf = YList(self)
                        self._segment_path = lambda: "group-map-rpfs"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.GroupMapRpfs, [], name, value)


                    class GroupMapRpf(Entity):
                        """
                        PIM group mapping entry
                        
                        .. attribute:: prefix
                        
                        	Prefix
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: client
                        
                        	Client
                        	**type**\:  :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:  :py:class:`PimProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimProtocol>`
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: rp_priority
                        
                        	RP priority
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rpf_neighbor
                        
                        	RPF neighbor to the RP
                        	**type**\:  :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor>`
                        
                        .. attribute:: group_map_information
                        
                        	Group Mapping information
                        	**type**\:  :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation>`
                        
                        .. attribute:: are_we_rp
                        
                        	Are we the RP?
                        	**type**\: bool
                        
                        .. attribute:: rpf_interface_name
                        
                        	RPF interface to the RP
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: rpf_vrf_name
                        
                        	RPF VRF Name
                        	**type**\: str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf, self).__init__()

                            self.yang_name = "group-map-rpf"
                            self.yang_parent_name = "group-map-rpfs"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rpf-neighbor", ("rpf_neighbor", Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor)), ("group-map-information", ("group_map_information", Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation))])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                ('client', (YLeaf(YType.enumeration, 'client'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimClient', '')])),
                                ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimProtocol', '')])),
                                ('rp_address', (YLeaf(YType.str, 'rp-address'), ['str','str'])),
                                ('rp_priority', (YLeaf(YType.uint32, 'rp-priority'), ['int'])),
                                ('are_we_rp', (YLeaf(YType.boolean, 'are-we-rp'), ['bool'])),
                                ('rpf_interface_name', (YLeaf(YType.str, 'rpf-interface-name'), ['str'])),
                                ('rpf_vrf_name', (YLeaf(YType.str, 'rpf-vrf-name'), ['str'])),
                            ])
                            self.prefix = None
                            self.prefix_length = None
                            self.client = None
                            self.protocol = None
                            self.rp_address = None
                            self.rp_priority = None
                            self.are_we_rp = None
                            self.rpf_interface_name = None
                            self.rpf_vrf_name = None

                            self.rpf_neighbor = Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor()
                            self.rpf_neighbor.parent = self
                            self._children_name_map["rpf_neighbor"] = "rpf-neighbor"

                            self.group_map_information = Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation()
                            self.group_map_information.parent = self
                            self._children_name_map["group_map_information"] = "group-map-information"
                            self._segment_path = lambda: "group-map-rpf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf, ['prefix', 'prefix_length', 'client', 'protocol', 'rp_address', 'rp_priority', 'are_we_rp', 'rpf_interface_name', 'rpf_vrf_name'], name, value)


                        class RpfNeighbor(Entity):
                            """
                            RPF neighbor to the RP
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor, self).__init__()

                                self.yang_name = "rpf-neighbor"
                                self.yang_parent_name = "group-map-rpf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "rpf-neighbor"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class GroupMapInformation(Entity):
                            """
                            Group Mapping information
                            
                            .. attribute:: prefix
                            
                            	Group range prefix
                            	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix>`
                            
                            .. attribute:: rp_address
                            
                            	Rendezvous Point Address
                            	**type**\:  :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress>`
                            
                            .. attribute:: prefix_length
                            
                            	Group range prefix length
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: client
                            
                            	Client mapping learnt from
                            	**type**\:  :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                            
                            .. attribute:: protocol
                            
                            	Protocol mode of the range
                            	**type**\:  :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                            
                            .. attribute:: group_count
                            
                            	No. of groups in this range
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_used
                            
                            	Is this mapping being used?
                            	**type**\: bool
                            
                            .. attribute:: mrib_active
                            
                            	Is this mapping active in MRIB?
                            	**type**\: bool
                            
                            .. attribute:: is_override
                            
                            	Is this the override range?
                            	**type**\: bool
                            
                            .. attribute:: priority
                            
                            	Bootstrap priority
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation, self).__init__()

                                self.yang_name = "group-map-information"
                                self.yang_parent_name = "group-map-rpf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("prefix", ("prefix", Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix)), ("rp-address", ("rp_address", Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress))])
                                self._leafs = OrderedDict([
                                    ('prefix_length', (YLeaf(YType.int32, 'prefix-length'), ['int'])),
                                    ('client', (YLeaf(YType.enumeration, 'client'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowRangeClient', '')])),
                                    ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowProtocol', '')])),
                                    ('group_count', (YLeaf(YType.uint32, 'group-count'), ['int'])),
                                    ('is_used', (YLeaf(YType.boolean, 'is-used'), ['bool'])),
                                    ('mrib_active', (YLeaf(YType.boolean, 'mrib-active'), ['bool'])),
                                    ('is_override', (YLeaf(YType.boolean, 'is-override'), ['bool'])),
                                    ('priority', (YLeaf(YType.uint32, 'priority'), ['int'])),
                                ])
                                self.prefix_length = None
                                self.client = None
                                self.protocol = None
                                self.group_count = None
                                self.is_used = None
                                self.mrib_active = None
                                self.is_override = None
                                self.priority = None

                                self.prefix = Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix()
                                self.prefix.parent = self
                                self._children_name_map["prefix"] = "prefix"

                                self.rp_address = Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress()
                                self.rp_address.parent = self
                                self._children_name_map["rp_address"] = "rp-address"
                                self._segment_path = lambda: "group-map-information"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation, ['prefix_length', 'client', 'protocol', 'group_count', 'is_used', 'mrib_active', 'is_override', 'priority'], name, value)


                            class Prefix(Entity):
                                """
                                Group range prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix, self).__init__()

                                    self.yang_name = "prefix"
                                    self.yang_parent_name = "group-map-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "prefix"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                            class RpAddress(Entity):
                                """
                                Rendezvous Point Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress, self).__init__()

                                    self.yang_name = "rp-address"
                                    self.yang_parent_name = "group-map-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "rp-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class Summary(Entity):
                    """
                    PIM summary
                    
                    .. attribute:: route_limit
                    
                    	Maximum routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_count
                    
                    	Current routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_low_water_mark
                    
                    	The number of routes below which the throttle on route creation will be lifted
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_route_limit_reached
                    
                    	Is route creation throttled
                    	**type**\: bool
                    
                    .. attribute:: topology_interface_state_limit
                    
                    	Maximum Topology Interface State count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: topology_interface_state_count
                    
                    	Current Topology Interface State count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rxi_low_water_mark
                    
                    	The rxi below which the throttle on interface creation will be lifted
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rxi_limit_reached
                    
                    	Is interface creation throttled
                    	**type**\: bool
                    
                    .. attribute:: register_limit
                    
                    	Maximum registers
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: register_count
                    
                    	Current registers
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: register_limit_reached
                    
                    	Is PIM SM register handling throttled
                    	**type**\: bool
                    
                    .. attribute:: ranges_limit
                    
                    	Maximum group ranges from Autorp
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ranges_count
                    
                    	Current group ranges from Autorp
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ranges_threshold
                    
                    	OOR theshold of grange ranges from AutoRP
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_ranges_limit_reached
                    
                    	Is Auto\-RP group\-to\-RP mapping range creation throttled
                    	**type**\: bool
                    
                    .. attribute:: bsr_ranges_limit
                    
                    	Maximum group ranges from BSR
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_ranges_count
                    
                    	Current group ranges from BSR
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_range_threshold
                    
                    	Threshold group range from BSR
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_bsr_ranges_threshold_reached
                    
                    	Is VRF\-specific BSR group\-to\-RP mapping range creation throttled
                    	**type**\: bool
                    
                    .. attribute:: bsr_candidate_rp_set_limit
                    
                    	Maximum crp\-set from BSR
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_candidate_rp_set_count
                    
                    	Current crp\-set count from BSR
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_candidate_rp_set_threshold
                    
                    	Threshold crp\-set from BSR
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_maximum_enforcement_disabled
                    
                    	Is maximum enforcement disabled
                    	**type**\: bool
                    
                    .. attribute:: is_node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\: bool
                    
                    .. attribute:: route_threshold
                    
                    	Threshold routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_auto_rp_ranges_limit
                    
                    	Global Auto\-RP maximum group ranges
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_global_auto_rp_ranges_limit_reached
                    
                    	Is global AutoRP group\-to\-RP mapping range creation throttled
                    	**type**\: bool
                    
                    .. attribute:: global_bsr_ranges_limit
                    
                    	Global BSR maximum group ranges
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_ranges_count
                    
                    	Global BSR current group ranges
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_ranges_threshold
                    
                    	Global BSR Threshold group ranges
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_global_bsr_ranges_limit_reached
                    
                    	Is global BSR group\-to\-RP mapping range creation throttled
                    	**type**\: bool
                    
                    .. attribute:: global_bsr_candidate_rp_set_limit
                    
                    	Global BSR maximum crp\-set
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_candidate_rp_set_count
                    
                    	Global BSR current crp\-set count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_candidate_rp_set_threshold
                    
                    	Global BSR Threshold crp\-set
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_global_route_limit_reached
                    
                    	Is global route creation throttled
                    	**type**\: bool
                    
                    .. attribute:: topology_interface_state_threshold
                    
                    	Topology Interface State threshold
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_global_rxi_limit_reached
                    
                    	Is global interface creation throttled
                    	**type**\: bool
                    
                    .. attribute:: register_threshold
                    
                    	Threshold registers
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_register_limit
                    
                    	Maximum global registers
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_global_register_limit_reached
                    
                    	Is global PIM SM register handling throttled
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.Summary, self).__init__()

                        self.yang_name = "summary"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_limit', (YLeaf(YType.uint32, 'route-limit'), ['int'])),
                            ('route_count', (YLeaf(YType.uint32, 'route-count'), ['int'])),
                            ('route_low_water_mark', (YLeaf(YType.uint32, 'route-low-water-mark'), ['int'])),
                            ('is_route_limit_reached', (YLeaf(YType.boolean, 'is-route-limit-reached'), ['bool'])),
                            ('topology_interface_state_limit', (YLeaf(YType.uint32, 'topology-interface-state-limit'), ['int'])),
                            ('topology_interface_state_count', (YLeaf(YType.uint32, 'topology-interface-state-count'), ['int'])),
                            ('rxi_low_water_mark', (YLeaf(YType.uint32, 'rxi-low-water-mark'), ['int'])),
                            ('rxi_limit_reached', (YLeaf(YType.boolean, 'rxi-limit-reached'), ['bool'])),
                            ('register_limit', (YLeaf(YType.uint32, 'register-limit'), ['int'])),
                            ('register_count', (YLeaf(YType.uint32, 'register-count'), ['int'])),
                            ('register_limit_reached', (YLeaf(YType.boolean, 'register-limit-reached'), ['bool'])),
                            ('ranges_limit', (YLeaf(YType.uint32, 'ranges-limit'), ['int'])),
                            ('ranges_count', (YLeaf(YType.uint32, 'ranges-count'), ['int'])),
                            ('ranges_threshold', (YLeaf(YType.uint32, 'ranges-threshold'), ['int'])),
                            ('is_ranges_limit_reached', (YLeaf(YType.boolean, 'is-ranges-limit-reached'), ['bool'])),
                            ('bsr_ranges_limit', (YLeaf(YType.uint32, 'bsr-ranges-limit'), ['int'])),
                            ('bsr_ranges_count', (YLeaf(YType.uint32, 'bsr-ranges-count'), ['int'])),
                            ('bsr_range_threshold', (YLeaf(YType.uint32, 'bsr-range-threshold'), ['int'])),
                            ('is_bsr_ranges_threshold_reached', (YLeaf(YType.boolean, 'is-bsr-ranges-threshold-reached'), ['bool'])),
                            ('bsr_candidate_rp_set_limit', (YLeaf(YType.uint32, 'bsr-candidate-rp-set-limit'), ['int'])),
                            ('bsr_candidate_rp_set_count', (YLeaf(YType.uint32, 'bsr-candidate-rp-set-count'), ['int'])),
                            ('bsr_candidate_rp_set_threshold', (YLeaf(YType.uint32, 'bsr-candidate-rp-set-threshold'), ['int'])),
                            ('is_maximum_enforcement_disabled', (YLeaf(YType.boolean, 'is-maximum-enforcement-disabled'), ['bool'])),
                            ('is_node_low_memory', (YLeaf(YType.boolean, 'is-node-low-memory'), ['bool'])),
                            ('route_threshold', (YLeaf(YType.uint32, 'route-threshold'), ['int'])),
                            ('global_auto_rp_ranges_limit', (YLeaf(YType.uint32, 'global-auto-rp-ranges-limit'), ['int'])),
                            ('is_global_auto_rp_ranges_limit_reached', (YLeaf(YType.boolean, 'is-global-auto-rp-ranges-limit-reached'), ['bool'])),
                            ('global_bsr_ranges_limit', (YLeaf(YType.uint32, 'global-bsr-ranges-limit'), ['int'])),
                            ('global_bsr_ranges_count', (YLeaf(YType.uint32, 'global-bsr-ranges-count'), ['int'])),
                            ('global_bsr_ranges_threshold', (YLeaf(YType.uint32, 'global-bsr-ranges-threshold'), ['int'])),
                            ('is_global_bsr_ranges_limit_reached', (YLeaf(YType.boolean, 'is-global-bsr-ranges-limit-reached'), ['bool'])),
                            ('global_bsr_candidate_rp_set_limit', (YLeaf(YType.uint32, 'global-bsr-candidate-rp-set-limit'), ['int'])),
                            ('global_bsr_candidate_rp_set_count', (YLeaf(YType.uint32, 'global-bsr-candidate-rp-set-count'), ['int'])),
                            ('global_bsr_candidate_rp_set_threshold', (YLeaf(YType.uint32, 'global-bsr-candidate-rp-set-threshold'), ['int'])),
                            ('is_global_route_limit_reached', (YLeaf(YType.boolean, 'is-global-route-limit-reached'), ['bool'])),
                            ('topology_interface_state_threshold', (YLeaf(YType.uint32, 'topology-interface-state-threshold'), ['int'])),
                            ('is_global_rxi_limit_reached', (YLeaf(YType.boolean, 'is-global-rxi-limit-reached'), ['bool'])),
                            ('register_threshold', (YLeaf(YType.uint32, 'register-threshold'), ['int'])),
                            ('global_register_limit', (YLeaf(YType.uint32, 'global-register-limit'), ['int'])),
                            ('is_global_register_limit_reached', (YLeaf(YType.boolean, 'is-global-register-limit-reached'), ['bool'])),
                        ])
                        self.route_limit = None
                        self.route_count = None
                        self.route_low_water_mark = None
                        self.is_route_limit_reached = None
                        self.topology_interface_state_limit = None
                        self.topology_interface_state_count = None
                        self.rxi_low_water_mark = None
                        self.rxi_limit_reached = None
                        self.register_limit = None
                        self.register_count = None
                        self.register_limit_reached = None
                        self.ranges_limit = None
                        self.ranges_count = None
                        self.ranges_threshold = None
                        self.is_ranges_limit_reached = None
                        self.bsr_ranges_limit = None
                        self.bsr_ranges_count = None
                        self.bsr_range_threshold = None
                        self.is_bsr_ranges_threshold_reached = None
                        self.bsr_candidate_rp_set_limit = None
                        self.bsr_candidate_rp_set_count = None
                        self.bsr_candidate_rp_set_threshold = None
                        self.is_maximum_enforcement_disabled = None
                        self.is_node_low_memory = None
                        self.route_threshold = None
                        self.global_auto_rp_ranges_limit = None
                        self.is_global_auto_rp_ranges_limit_reached = None
                        self.global_bsr_ranges_limit = None
                        self.global_bsr_ranges_count = None
                        self.global_bsr_ranges_threshold = None
                        self.is_global_bsr_ranges_limit_reached = None
                        self.global_bsr_candidate_rp_set_limit = None
                        self.global_bsr_candidate_rp_set_count = None
                        self.global_bsr_candidate_rp_set_threshold = None
                        self.is_global_route_limit_reached = None
                        self.topology_interface_state_threshold = None
                        self.is_global_rxi_limit_reached = None
                        self.register_threshold = None
                        self.global_register_limit = None
                        self.is_global_register_limit_reached = None
                        self._segment_path = lambda: "summary"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.Summary, ['route_limit', 'route_count', 'route_low_water_mark', 'is_route_limit_reached', 'topology_interface_state_limit', 'topology_interface_state_count', 'rxi_low_water_mark', 'rxi_limit_reached', 'register_limit', 'register_count', 'register_limit_reached', 'ranges_limit', 'ranges_count', 'ranges_threshold', 'is_ranges_limit_reached', 'bsr_ranges_limit', 'bsr_ranges_count', 'bsr_range_threshold', 'is_bsr_ranges_threshold_reached', 'bsr_candidate_rp_set_limit', 'bsr_candidate_rp_set_count', 'bsr_candidate_rp_set_threshold', 'is_maximum_enforcement_disabled', 'is_node_low_memory', 'route_threshold', 'global_auto_rp_ranges_limit', 'is_global_auto_rp_ranges_limit_reached', 'global_bsr_ranges_limit', 'global_bsr_ranges_count', 'global_bsr_ranges_threshold', 'is_global_bsr_ranges_limit_reached', 'global_bsr_candidate_rp_set_limit', 'global_bsr_candidate_rp_set_count', 'global_bsr_candidate_rp_set_threshold', 'is_global_route_limit_reached', 'topology_interface_state_threshold', 'is_global_rxi_limit_reached', 'register_threshold', 'global_register_limit', 'is_global_register_limit_reached'], name, value)


                class Gre(Entity):
                    """
                    GRE information
                    
                    .. attribute:: gre_hashes
                    
                    	GRE hash
                    	**type**\:  :py:class:`GreHashes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Gre.GreHashes>`
                    
                    .. attribute:: gre_next_hops
                    
                    	GRE destination neighbor table
                    	**type**\:  :py:class:`GreNextHops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Gre.GreNextHops>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.Gre, self).__init__()

                        self.yang_name = "gre"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("gre-hashes", ("gre_hashes", Pim.Standby.Vrfs.Vrf.Gre.GreHashes)), ("gre-next-hops", ("gre_next_hops", Pim.Standby.Vrfs.Vrf.Gre.GreNextHops))])
                        self._leafs = OrderedDict()

                        self.gre_hashes = Pim.Standby.Vrfs.Vrf.Gre.GreHashes()
                        self.gre_hashes.parent = self
                        self._children_name_map["gre_hashes"] = "gre-hashes"

                        self.gre_next_hops = Pim.Standby.Vrfs.Vrf.Gre.GreNextHops()
                        self.gre_next_hops.parent = self
                        self._children_name_map["gre_next_hops"] = "gre-next-hops"
                        self._segment_path = lambda: "gre"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.Gre, [], name, value)


                    class GreHashes(Entity):
                        """
                        GRE hash
                        
                        .. attribute:: gre_hash
                        
                        	PIM GRE Hashed Underlying Interface
                        	**type**\: list of  		 :py:class:`GreHash <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Gre.GreHashes.GreHash>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.Gre.GreHashes, self).__init__()

                            self.yang_name = "gre-hashes"
                            self.yang_parent_name = "gre"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("gre-hash", ("gre_hash", Pim.Standby.Vrfs.Vrf.Gre.GreHashes.GreHash))])
                            self._leafs = OrderedDict()

                            self.gre_hash = YList(self)
                            self._segment_path = lambda: "gre-hashes"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.Gre.GreHashes, [], name, value)


                        class GreHash(Entity):
                            """
                            PIM GRE Hashed Underlying Interface
                            
                            .. attribute:: source_address  (key)
                            
                            	Source address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: destination_address  (key)
                            
                            	Destination address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ifname  (key)
                            
                            	GRE Tunnel Interface
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: next_hop_interface
                            
                            	Next hop neighbor interface
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Gre.GreHashes.GreHash, self).__init__()

                                self.yang_name = "gre-hash"
                                self.yang_parent_name = "gre-hashes"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['source_address','destination_address','ifname']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('source_address', (YLeaf(YType.str, 'source-address'), ['str','str'])),
                                    ('destination_address', (YLeaf(YType.str, 'destination-address'), ['str','str'])),
                                    ('ifname', (YLeaf(YType.str, 'ifname'), ['str'])),
                                    ('next_hop_interface', (YLeaf(YType.str, 'next-hop-interface'), ['str'])),
                                ])
                                self.source_address = None
                                self.destination_address = None
                                self.ifname = None
                                self.next_hop_interface = None
                                self._segment_path = lambda: "gre-hash" + "[source-address='" + str(self.source_address) + "']" + "[destination-address='" + str(self.destination_address) + "']" + "[ifname='" + str(self.ifname) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.Gre.GreHashes.GreHash, ['source_address', 'destination_address', 'ifname', 'next_hop_interface'], name, value)


                    class GreNextHops(Entity):
                        """
                        GRE destination neighbor table
                        
                        .. attribute:: gre_next_hop
                        
                        	PIM GRE address next\-hop information
                        	**type**\: list of  		 :py:class:`GreNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.Gre.GreNextHops, self).__init__()

                            self.yang_name = "gre-next-hops"
                            self.yang_parent_name = "gre"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("gre-next-hop", ("gre_next_hop", Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop))])
                            self._leafs = OrderedDict()

                            self.gre_next_hop = YList(self)
                            self._segment_path = lambda: "gre-next-hops"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.Gre.GreNextHops, [], name, value)


                        class GreNextHop(Entity):
                            """
                            PIM GRE address next\-hop information
                            
                            .. attribute:: destination_address  (key)
                            
                            	GRE destination address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: registered_address
                            
                            	Address registered
                            	**type**\:  :py:class:`RegisteredAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress>`
                            
                            .. attribute:: metric
                            
                            	Metric
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_preference
                            
                            	Metric preference
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_connected
                            
                            	Are we connected ?
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: gre_path
                            
                            	GRE Paths list
                            	**type**\: list of  		 :py:class:`GrePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop, self).__init__()

                                self.yang_name = "gre-next-hop"
                                self.yang_parent_name = "gre-next-hops"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['destination_address']
                                self._child_classes = OrderedDict([("registered-address", ("registered_address", Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress)), ("gre-path", ("gre_path", Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath))])
                                self._leafs = OrderedDict([
                                    ('destination_address', (YLeaf(YType.str, 'destination-address'), ['str','str'])),
                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                    ('metric_preference', (YLeaf(YType.uint32, 'metric-preference'), ['int'])),
                                    ('is_connected', (YLeaf(YType.uint8, 'is-connected'), ['int'])),
                                ])
                                self.destination_address = None
                                self.metric = None
                                self.metric_preference = None
                                self.is_connected = None

                                self.registered_address = Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress()
                                self.registered_address.parent = self
                                self._children_name_map["registered_address"] = "registered-address"

                                self.gre_path = YList(self)
                                self._segment_path = lambda: "gre-next-hop" + "[destination-address='" + str(self.destination_address) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop, ['destination_address', 'metric', 'metric_preference', 'is_connected'], name, value)


                            class RegisteredAddress(Entity):
                                """
                                Address registered
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress, self).__init__()

                                    self.yang_name = "registered-address"
                                    self.yang_parent_name = "gre-next-hop"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "registered-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                            class GrePath(Entity):
                                """
                                GRE Paths list
                                
                                .. attribute:: gre_neighbor
                                
                                	GRE neighbor
                                	**type**\:  :py:class:`GreNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor>`
                                
                                .. attribute:: gre_next_hop
                                
                                	GRE nexthop
                                	**type**\:  :py:class:`GreNextHop_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop_>`
                                
                                .. attribute:: gre_interface_name
                                
                                	GRE Interface
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                .. attribute:: is_gre_interface_disabled
                                
                                	Is the gre interface disabled ?
                                	**type**\: bool
                                
                                .. attribute:: is_via_lsm
                                
                                	Via LSM
                                	**type**\: bool
                                
                                .. attribute:: is_connector_attribute_present
                                
                                	Connector attribute present
                                	**type**\: bool
                                
                                .. attribute:: extranet_vrf_name
                                
                                	Extranet VRF name
                                	**type**\: str
                                
                                	**length:** 0..33
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath, self).__init__()

                                    self.yang_name = "gre-path"
                                    self.yang_parent_name = "gre-next-hop"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("gre-neighbor", ("gre_neighbor", Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor)), ("gre-next-hop", ("gre_next_hop", Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop_))])
                                    self._leafs = OrderedDict([
                                        ('gre_interface_name', (YLeaf(YType.str, 'gre-interface-name'), ['str'])),
                                        ('is_gre_interface_disabled', (YLeaf(YType.boolean, 'is-gre-interface-disabled'), ['bool'])),
                                        ('is_via_lsm', (YLeaf(YType.boolean, 'is-via-lsm'), ['bool'])),
                                        ('is_connector_attribute_present', (YLeaf(YType.boolean, 'is-connector-attribute-present'), ['bool'])),
                                        ('extranet_vrf_name', (YLeaf(YType.str, 'extranet-vrf-name'), ['str'])),
                                    ])
                                    self.gre_interface_name = None
                                    self.is_gre_interface_disabled = None
                                    self.is_via_lsm = None
                                    self.is_connector_attribute_present = None
                                    self.extranet_vrf_name = None

                                    self.gre_neighbor = Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor()
                                    self.gre_neighbor.parent = self
                                    self._children_name_map["gre_neighbor"] = "gre-neighbor"

                                    self.gre_next_hop = Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop_()
                                    self.gre_next_hop.parent = self
                                    self._children_name_map["gre_next_hop"] = "gre-next-hop"
                                    self._segment_path = lambda: "gre-path"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath, ['gre_interface_name', 'is_gre_interface_disabled', 'is_via_lsm', 'is_connector_attribute_present', 'extranet_vrf_name'], name, value)


                                class GreNeighbor(Entity):
                                    """
                                    GRE neighbor
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor, self).__init__()

                                        self.yang_name = "gre-neighbor"
                                        self.yang_parent_name = "gre-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ])
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None
                                        self._segment_path = lambda: "gre-neighbor"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                                class GreNextHop_(Entity):
                                    """
                                    GRE nexthop
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop_, self).__init__()

                                        self.yang_name = "gre-next-hop"
                                        self.yang_parent_name = "gre-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ])
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None
                                        self._segment_path = lambda: "gre-next-hop"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop_, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class BidirDfWinners(Entity):
                    """
                    Bidirectional PIM DF election winner table
                    
                    .. attribute:: bidir_df_winner
                    
                    	Bidirectional PIM DF election table entry
                    	**type**\: list of  		 :py:class:`BidirDfWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.BidirDfWinners, self).__init__()

                        self.yang_name = "bidir-df-winners"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("bidir-df-winner", ("bidir_df_winner", Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner))])
                        self._leafs = OrderedDict()

                        self.bidir_df_winner = YList(self)
                        self._segment_path = lambda: "bidir-df-winners"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.BidirDfWinners, [], name, value)


                    class BidirDfWinner(Entity):
                        """
                        Bidirectional PIM DF election table entry
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: rp_address_xr
                        
                        	RP Address
                        	**type**\:  :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr>`
                        
                        .. attribute:: df_winner
                        
                        	DF Winner
                        	**type**\:  :py:class:`DfWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner>`
                        
                        .. attribute:: pim_interface_name
                        
                        	Interface Name
                        	**type**\: str
                        
                        .. attribute:: are_we_df
                        
                        	Are we DF
                        	**type**\: bool
                        
                        .. attribute:: rp_lan
                        
                        	Is this the RP LAN
                        	**type**\: bool
                        
                        .. attribute:: metric
                        
                        	Metric
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: metric_preference
                        
                        	Metric Preference
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner, self).__init__()

                            self.yang_name = "bidir-df-winner"
                            self.yang_parent_name = "bidir-df-winners"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rp-address-xr", ("rp_address_xr", Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr)), ("df-winner", ("df_winner", Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner))])
                            self._leafs = OrderedDict([
                                ('rp_address', (YLeaf(YType.str, 'rp-address'), ['str','str'])),
                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ('pim_interface_name', (YLeaf(YType.str, 'pim-interface-name'), ['str'])),
                                ('are_we_df', (YLeaf(YType.boolean, 'are-we-df'), ['bool'])),
                                ('rp_lan', (YLeaf(YType.boolean, 'rp-lan'), ['bool'])),
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                ('metric_preference', (YLeaf(YType.uint32, 'metric-preference'), ['int'])),
                                ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                            ])
                            self.rp_address = None
                            self.interface_name = None
                            self.pim_interface_name = None
                            self.are_we_df = None
                            self.rp_lan = None
                            self.metric = None
                            self.metric_preference = None
                            self.uptime = None

                            self.rp_address_xr = Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr()
                            self.rp_address_xr.parent = self
                            self._children_name_map["rp_address_xr"] = "rp-address-xr"

                            self.df_winner = Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner()
                            self.df_winner.parent = self
                            self._children_name_map["df_winner"] = "df-winner"
                            self._segment_path = lambda: "bidir-df-winner"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner, ['rp_address', 'interface_name', 'pim_interface_name', 'are_we_df', 'rp_lan', 'metric', 'metric_preference', 'uptime'], name, value)


                        class RpAddressXr(Entity):
                            """
                            RP Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr, self).__init__()

                                self.yang_name = "rp-address-xr"
                                self.yang_parent_name = "bidir-df-winner"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "rp-address-xr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class DfWinner(Entity):
                            """
                            DF Winner
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner, self).__init__()

                                self.yang_name = "df-winner"
                                self.yang_parent_name = "bidir-df-winner"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "df-winner"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class TableContexts(Entity):
                    """
                    PIM table context list
                    
                    .. attribute:: table_context
                    
                    	PIM table context information
                    	**type**\: list of  		 :py:class:`TableContext <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.TableContexts.TableContext>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.TableContexts, self).__init__()

                        self.yang_name = "table-contexts"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("table-context", ("table_context", Pim.Standby.Vrfs.Vrf.TableContexts.TableContext))])
                        self._leafs = OrderedDict()

                        self.table_context = YList(self)
                        self._segment_path = lambda: "table-contexts"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.TableContexts, [], name, value)


                    class TableContext(Entity):
                        """
                        PIM table context information
                        
                        .. attribute:: saf_name
                        
                        	SAF name
                        	**type**\:  :py:class:`PimSafi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimSafi>`
                        
                        .. attribute:: topology_name
                        
                        	Topology name
                        	**type**\: str
                        
                        	**length:** 1..32
                        
                        .. attribute:: afi
                        
                        	AFI
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: safi
                        
                        	SAFI
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_name
                        
                        	Table name
                        	**type**\: str
                        
                        .. attribute:: vrf_id
                        
                        	VRF ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_id
                        
                        	Table ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_active
                        
                        	Active status
                        	**type**\: bool
                        
                        .. attribute:: is_ital_registration_done
                        
                        	ITAL reg status
                        	**type**\: bool
                        
                        .. attribute:: is_rib_registration_done
                        
                        	RIB reg status
                        	**type**\: bool
                        
                        .. attribute:: is_rib_convergence_received
                        
                        	RIB Convergence receive status
                        	**type**\: bool
                        
                        .. attribute:: is_rib_convergence
                        
                        	RIB Convergence status
                        	**type**\: bool
                        
                        .. attribute:: rpf_registrations
                        
                        	RPF Registration count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.TableContexts.TableContext, self).__init__()

                            self.yang_name = "table-context"
                            self.yang_parent_name = "table-contexts"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('saf_name', (YLeaf(YType.enumeration, 'saf-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimSafi', '')])),
                                ('topology_name', (YLeaf(YType.str, 'topology-name'), ['str'])),
                                ('afi', (YLeaf(YType.uint32, 'afi'), ['int'])),
                                ('safi', (YLeaf(YType.uint32, 'safi'), ['int'])),
                                ('table_name', (YLeaf(YType.str, 'table-name'), ['str'])),
                                ('vrf_id', (YLeaf(YType.uint32, 'vrf-id'), ['int'])),
                                ('table_id', (YLeaf(YType.uint32, 'table-id'), ['int'])),
                                ('is_active', (YLeaf(YType.boolean, 'is-active'), ['bool'])),
                                ('is_ital_registration_done', (YLeaf(YType.boolean, 'is-ital-registration-done'), ['bool'])),
                                ('is_rib_registration_done', (YLeaf(YType.boolean, 'is-rib-registration-done'), ['bool'])),
                                ('is_rib_convergence_received', (YLeaf(YType.boolean, 'is-rib-convergence-received'), ['bool'])),
                                ('is_rib_convergence', (YLeaf(YType.boolean, 'is-rib-convergence'), ['bool'])),
                                ('rpf_registrations', (YLeaf(YType.uint32, 'rpf-registrations'), ['int'])),
                            ])
                            self.saf_name = None
                            self.topology_name = None
                            self.afi = None
                            self.safi = None
                            self.table_name = None
                            self.vrf_id = None
                            self.table_id = None
                            self.is_active = None
                            self.is_ital_registration_done = None
                            self.is_rib_registration_done = None
                            self.is_rib_convergence_received = None
                            self.is_rib_convergence = None
                            self.rpf_registrations = None
                            self._segment_path = lambda: "table-context"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.TableContexts.TableContext, ['saf_name', 'topology_name', 'afi', 'safi', 'table_name', 'vrf_id', 'table_id', 'is_active', 'is_ital_registration_done', 'is_rib_registration_done', 'is_rib_convergence_received', 'is_rib_convergence', 'rpf_registrations'], name, value)


                class NeighborSummaries(Entity):
                    """
                    PIM neighbor summary table
                    
                    .. attribute:: neighbor_summary
                    
                    	PIM neighbor summary information
                    	**type**\: list of  		 :py:class:`NeighborSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.NeighborSummaries.NeighborSummary>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.NeighborSummaries, self).__init__()

                        self.yang_name = "neighbor-summaries"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("neighbor-summary", ("neighbor_summary", Pim.Standby.Vrfs.Vrf.NeighborSummaries.NeighborSummary))])
                        self._leafs = OrderedDict()

                        self.neighbor_summary = YList(self)
                        self._segment_path = lambda: "neighbor-summaries"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.NeighborSummaries, [], name, value)


                    class NeighborSummary(Entity):
                        """
                        PIM neighbor summary information
                        
                        .. attribute:: interface_name  (key)
                        
                        	Interface name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: number_of_neighbors
                        
                        	Number of neighbors
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: number_of_external_neighbors
                        
                        	Number of external neighbors
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.NeighborSummaries.NeighborSummary, self).__init__()

                            self.yang_name = "neighbor-summary"
                            self.yang_parent_name = "neighbor-summaries"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['interface_name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ('number_of_neighbors', (YLeaf(YType.int32, 'number-of-neighbors'), ['int'])),
                                ('number_of_external_neighbors', (YLeaf(YType.int32, 'number-of-external-neighbors'), ['int'])),
                            ])
                            self.interface_name = None
                            self.number_of_neighbors = None
                            self.number_of_external_neighbors = None
                            self._segment_path = lambda: "neighbor-summary" + "[interface-name='" + str(self.interface_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.NeighborSummaries.NeighborSummary, ['interface_name', 'number_of_neighbors', 'number_of_external_neighbors'], name, value)


                class Context(Entity):
                    """
                    PIM context information
                    
                    .. attribute:: remote_default_group
                    
                    	Remote Default Group
                    	**type**\:  :py:class:`RemoteDefaultGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Context.RemoteDefaultGroup>`
                    
                    .. attribute:: rpf_default_table
                    
                    	RPF Default Table
                    	**type**\:  :py:class:`RpfDefaultTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Context.RpfDefaultTable>`
                    
                    .. attribute:: vrf_id
                    
                    	VRF ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_id
                    
                    	Table ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: murib_id
                    
                    	MURIB ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rpf_id
                    
                    	RPF ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: remote_table_id
                    
                    	Remote Table ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_default_group
                    
                    	MDT Default group
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: mdt_source
                    
                    	MDT source
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: mdt_source_interface
                    
                    	MDT Source Interface Name
                    	**type**\: str
                    
                    .. attribute:: mdt_interface
                    
                    	MDT handle
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: mdt_gre_rpf_identifier
                    
                    	GRE\-MDT RPF Identifier
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_gre_remote_rpf_identifier
                    
                    	GRE\-MDT Remote RPF Identifier
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_unicast_rib_registration
                    
                    	Ucast RIB Registration
                    	**type**\: bool
                    
                    .. attribute:: is_multicast_rib_registration
                    
                    	Mcast RIB Registration
                    	**type**\: bool
                    
                    .. attribute:: is_active
                    
                    	Active
                    	**type**\: bool
                    
                    .. attribute:: is_active_ital
                    
                    	Active ITAL
                    	**type**\: bool
                    
                    .. attribute:: is_mrib_register
                    
                    	MRIB Register
                    	**type**\: bool
                    
                    .. attribute:: is_mdt_owner
                    
                    	MDT Owner
                    	**type**\: bool
                    
                    .. attribute:: is_routing_enabled
                    
                    	Routing Enabled
                    	**type**\: bool
                    
                    .. attribute:: is_socket_add_required
                    
                    	VRF required on Socket
                    	**type**\: bool
                    
                    .. attribute:: is_socket_added
                    
                    	VRF added on Socket
                    	**type**\: bool
                    
                    .. attribute:: is_lpts_socket_add_required
                    
                    	VRF LPTS filter required on Socket
                    	**type**\: bool
                    
                    .. attribute:: is_lpts_socket_added
                    
                    	VRF LPTS filter added on Socket
                    	**type**\: bool
                    
                    .. attribute:: is_udp_socket_add_required
                    
                    	VRF added on UDP Socket
                    	**type**\: bool
                    
                    .. attribute:: is_udp_socket_added
                    
                    	VRF added on UDP Socket
                    	**type**\: bool
                    
                    .. attribute:: is_udp_socket_bind_required
                    
                    	VRF bind required on UDP Socket
                    	**type**\: bool
                    
                    .. attribute:: is_udp_socket_bind
                    
                    	VRF bound on UDP Socket
                    	**type**\: bool
                    
                    .. attribute:: is_register_injection_socket_add_required
                    
                    	VRF required on Register Injection Socket
                    	**type**\: bool
                    
                    .. attribute:: is_register_injection_socket_added
                    
                    	VRF added on Register Injection Socket
                    	**type**\: bool
                    
                    .. attribute:: is_register_injection_lpts_socket_add_required
                    
                    	VRF LPTS filter required on Register Injection Socket
                    	**type**\: bool
                    
                    .. attribute:: is_register_injection_lpts_socket_added
                    
                    	VRF LPTS filter added on Register Injection Socket
                    	**type**\: bool
                    
                    .. attribute:: is_m_host_publish_pending
                    
                    	Publish pending for MHost Default interface
                    	**type**\: bool
                    
                    .. attribute:: mhost_interface
                    
                    	MHost handle
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: mhost_default_interface_config
                    
                    	Configured Mhost Defint
                    	**type**\: str
                    
                    .. attribute:: mdt_mtu
                    
                    	MDT MTU
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: maximum_mdt_aggregation
                    
                    	MDT max aggregation
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_data_switchover_interval
                    
                    	Data MDT Switchover interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_data_announce_interval
                    
                    	Data MDT Announce interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: non_default_vrf_count_on_socket
                    
                    	Count of non\-default vrfs on raw socket
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\: str
                    
                    .. attribute:: mdt_neighbor_filter_name
                    
                    	MDT Neighbor Filter Name
                    	**type**\: str
                    
                    .. attribute:: allow_rp_configured
                    
                    	Allow RP Configured
                    	**type**\: bool
                    
                    .. attribute:: allow_rp_group_list
                    
                    	Allow RP Group\-List ACL Name
                    	**type**\: str
                    
                    	**length:** 0..64
                    
                    .. attribute:: allow_rp_rp_list
                    
                    	Allow RP RP\-list ACL Name
                    	**type**\: str
                    
                    	**length:** 0..64
                    
                    .. attribute:: sg_expiry_timer_configured
                    
                    	S,G Expiry Timer Configured
                    	**type**\: bool
                    
                    .. attribute:: sg_expiry_time
                    
                    	S,G Expiry Time Configured, in seconds
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    	**units**\: second
                    
                    .. attribute:: sg_expiry_timer_sg_list
                    
                    	S,G expiry timer ACL name
                    	**type**\: str
                    
                    	**length:** 0..64
                    
                    .. attribute:: mldp_mdt_name
                    
                    	MLDP MDT Name
                    	**type**\: str
                    
                    .. attribute:: mldp_mdt_interface
                    
                    	MLDP MDT handle
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: mldp_mdt_mtu
                    
                    	MLDP MDT MTU
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_maximum_mdt_aggregation
                    
                    	MLDP MDT max aggregation
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_data_switchover_interval
                    
                    	MLDP Data MDT Switchover interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_data_announce_interval
                    
                    	MLDP Data MDT Announce interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_rpf_identifier
                    
                    	MLDP RPF\-ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_remote_rpf_identifier
                    
                    	MLDP Remote RPF\-ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_create_mldp_mdt_interface
                    
                    	Create MLDP MDT interface
                    	**type**\: bool
                    
                    .. attribute:: is_mldp_mdt_owner
                    
                    	MLDP MDT Owner
                    	**type**\: bool
                    
                    .. attribute:: mldp_root_count
                    
                    	MLDP Root count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_head_lsm_identifier
                    
                    	MLDP Head LSM\-ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_remote_head_lsm_identifier
                    
                    	MLDP Remote Head LSM\-ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: organization_unique_identifier
                    
                    	OUI for VPN\-ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vpn_index
                    
                    	VPN Index
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_partitioned_mdt_configured
                    
                    	MLDP Partitioned MDT
                    	**type**\: bool
                    
                    .. attribute:: mldp_remote_partitioned_mdt_configured
                    
                    	MLDP Remote Partitioned MDT
                    	**type**\: bool
                    
                    .. attribute:: mldp_partioned_mp2m_ptree
                    
                    	MP2MP Partitioned MDT tree
                    	**type**\: bool
                    
                    .. attribute:: mldp_partitioned_head_lsm_identifier
                    
                    	Partitioned MDT Head LSM\-ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_head_local_label
                    
                    	Partitioned MDT Head local label
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_partitioned_mdt_identifier
                    
                    	MLDP Partitioned MDT Identifier
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bgp_auto_discovery_configured
                    
                    	BGP Auto\-Discovery configured
                    	**type**\: bool
                    
                    .. attribute:: suppress_pim_data_mdt_tlv
                    
                    	Suppress PIM Data\-MDT TLV Announcements
                    	**type**\: bool
                    
                    .. attribute:: inter_autonomous_system_enabled
                    
                    	Inter\-AS Enabled
                    	**type**\: bool
                    
                    .. attribute:: bgp_source_active_announce
                    
                    	Send BGP Source\-Active Announcements
                    	**type**\: bool
                    
                    .. attribute:: bgp_i_pmsi_added
                    
                    	BGP I\-PMSI Added
                    	**type**\: bool
                    
                    .. attribute:: mldp_bsr_control_tree_added
                    
                    	MLDP BSR Control tree added
                    	**type**\: bool
                    
                    .. attribute:: mldp_auto_rp_discovery_tree_added
                    
                    	MLDP Autorp Discovery Control tree added
                    	**type**\: bool
                    
                    .. attribute:: mldp_auto_rp_announce_tree_added
                    
                    	MLDP Autorp Announce Control tree added
                    	**type**\: bool
                    
                    .. attribute:: bgp_auto_discovery_type
                    
                    	BGP Auto Discovery Type
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_partitioned_mdt_control_identifier
                    
                    	Partitioned MDT Control Identifier
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_partitioned_ir_control_identifier
                    
                    	Partitioned IR MDT Control Identifier
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_control_head_lsm_identifier
                    
                    	MLDP MVPN Identifier
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: umh
                    
                    	Join UMH Core\-Tree
                    	**type**\: bool
                    
                    .. attribute:: suppress_shared_tree_join
                    
                    	Suppress Shared\-Tree Joins
                    	**type**\: bool
                    
                    .. attribute:: rsvp_te_mdt_name
                    
                    	RSVP\-TE MDT Name
                    	**type**\: str
                    
                    .. attribute:: rsvp_te_mdt_interface
                    
                    	RSVP\-TEMDT handle
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: rsvp_te_mdt_mtu
                    
                    	RSVP\-TEMDT MTU
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_maximum_mdt_aggregation
                    
                    	RSVP\-TE MDT max aggregation
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_data_switchover_interval
                    
                    	RSVP\-TE Data MDT Switchover interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_data_announce_interval
                    
                    	RSVP\-TE Data MDT Announce interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_rpf_identifier
                    
                    	RSVP\-TE RPF\-ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_create_rsvp_te_mdt_interface
                    
                    	Create RSVP\-TE MDT interface
                    	**type**\: bool
                    
                    .. attribute:: is_rsvp_te_mdt_owner
                    
                    	RSVP\-TE MDT Owner
                    	**type**\: bool
                    
                    .. attribute:: rsvp_te_mdt_static_p2mp_count
                    
                    	Number of Static P2MP\-TE MDT
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: p2mpte_li_drop
                    
                    	Route LI updates dropped for P2MP
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_name
                    
                    	IR MDT Name
                    	**type**\: str
                    
                    .. attribute:: ir_mdt_interface
                    
                    	IRMDT handle
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: ir_mdt_mtu
                    
                    	IRMDT MTU
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_maximum_mdt_aggregation
                    
                    	IR MDT max aggregation
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_data_switchover_interval
                    
                    	IR Data MDT Switchover interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_data_announce_interval
                    
                    	IR Data MDT Announce interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_rpf_identifier
                    
                    	IR RPF\-ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_tail_label
                    
                    	IR Tail Label
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_create_ir_mdt_interface
                    
                    	Create IR MDT interface
                    	**type**\: bool
                    
                    .. attribute:: is_ir_mdt_owner
                    
                    	IR MDT Owner
                    	**type**\: bool
                    
                    .. attribute:: in_b_and_mdt_name
                    
                    	Inband MDT Name
                    	**type**\: str
                    
                    .. attribute:: in_b_and_mdt_interface
                    
                    	Inband MDT handle
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: in_b_and_mdt_mtu
                    
                    	Inband MDT MTU
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_band_maximum_mdt_aggregation
                    
                    	Inband MDT max aggregation
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_b_and_mdt_data_switchover_interval
                    
                    	Inband Data MDT Switchover interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_b_and_mdt_data_announce_interval
                    
                    	Inband Data MDT Announce interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_b_and_mdt_rpf_identifier
                    
                    	Inband RPF\-ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_create_in_b_and_mdt_interface
                    
                    	Create Inband MDT interface
                    	**type**\: bool
                    
                    .. attribute:: is_in_b_and_mdt_owner
                    
                    	Inband MDT Owner
                    	**type**\: bool
                    
                    .. attribute:: in_band_signaling_local_enabled
                    
                    	Inband signaling Local enabled
                    	**type**\: bool
                    
                    .. attribute:: in_band_signaling_remote_enabled
                    
                    	Inband signaling Remote enabled
                    	**type**\: bool
                    
                    .. attribute:: valid_rd_present
                    
                    	RD is valid
                    	**type**\: bool
                    
                    .. attribute:: stale_rd_present
                    
                    	RD is stale
                    	**type**\: bool
                    
                    .. attribute:: route_distinguisher
                    
                    	RD value
                    	**type**\: str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: gin_b_and_mdt_name
                    
                    	Inband MDT Name
                    	**type**\: str
                    
                    .. attribute:: gin_b_and_mdt_interface
                    
                    	Inband MDT handle
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: gin_b_and_mdt_mtu
                    
                    	Inband MDT MTU
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gin_band_maximum_mdt_aggregation
                    
                    	Inband MDT max aggregation
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gin_b_and_mdt_data_switchover_interval
                    
                    	Inband Data MDT Switchover interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gin_b_and_mdt_data_announce_interval
                    
                    	Inband Data MDT Announce interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gin_b_and_mdt_rpf_identifier
                    
                    	Inband RPF\-ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_create_gin_b_and_mdt_interface
                    
                    	Create Inband MDT interface
                    	**type**\: bool
                    
                    .. attribute:: is_gin_b_and_mdt_owner
                    
                    	Inband MDT Owner
                    	**type**\: bool
                    
                    .. attribute:: is_pim_nsf_rib_converged
                    
                    	PIM NSF RIB converged
                    	**type**\: bool
                    
                    .. attribute:: is_pim_nsf_rib_converge_received
                    
                    	PIM NSF RIB converge received
                    	**type**\: bool
                    
                    .. attribute:: is_rib_multipath_enabled
                    
                    	PIM RIB multiplath enabled
                    	**type**\: bool
                    
                    .. attribute:: is_rib_multipath_interface_hash
                    
                    	PIM RIB multipath interface hash
                    	**type**\: bool
                    
                    .. attribute:: is_rib_multipath_source_hash
                    
                    	PIM RIB multipath source based hash
                    	**type**\: bool
                    
                    .. attribute:: is_rib_multipath_source_next_hop_hash
                    
                    	PIM RIB multipath source\-nexthop hash
                    	**type**\: bool
                    
                    .. attribute:: rump_enabled
                    
                    	PIM is using MuRIB
                    	**type**\: bool
                    
                    .. attribute:: is_create_mdt_interface
                    
                    	Create MDT interface
                    	**type**\: bool
                    
                    .. attribute:: is_auto_rp_listen_enabled
                    
                    	Auto RP Listen Enabled
                    	**type**\: bool
                    
                    .. attribute:: is_all_interface_disable_operation
                    
                    	PIM all interface disable operation
                    	**type**\: bool
                    
                    .. attribute:: is_default_granges
                    
                    	Default granges
                    	**type**\: bool
                    
                    .. attribute:: is_auto_rp_listen_sock_add
                    
                    	Auto RP listen sock add
                    	**type**\: bool
                    
                    .. attribute:: is_redistribution_reset
                    
                    	Pending redist reset
                    	**type**\: bool
                    
                    .. attribute:: redistribution_reset_count
                    
                    	Redist reset count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rpf_policy_name
                    
                    	RPF topology selection route\-policy name
                    	**type**\: str
                    
                    .. attribute:: table_count
                    
                    	Number of configured Tables
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: active_table_count
                    
                    	Number of active Tables
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: anycast_rp_policy_name
                    
                    	Anycast\-RP Policy Name
                    	**type**\: str
                    
                    .. attribute:: anycast_rp_configured
                    
                    	Anycast\-RP config
                    	**type**\: bool
                    
                    .. attribute:: bgp_remote_on
                    
                    	BGP remote interface status
                    	**type**\: bool
                    
                    .. attribute:: bgp_remote_interface_name
                    
                    	BGP remote interface name
                    	**type**\: str
                    
                    .. attribute:: bgp_remote_interface
                    
                    	BGP remote interface handle
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: bgp_remote_address
                    
                    	BGP remote interface address
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: bgp_remote_state
                    
                    	BGP remote interface state
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: physical_interface_count
                    
                    	Enabled Physical Interface Count
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: virtual_interface_count
                    
                    	Enabled Virtual Interface Count
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: virtual_mlc_interface_name
                    
                    	Virtual master line card Interface
                    	**type**\: str
                    
                    .. attribute:: mdt_immediate_switch
                    
                    	MDT Immediate Switch
                    	**type**\: bool
                    
                    .. attribute:: mldp_root_address
                    
                    	MLDP Root addresses
                    	**type**\: list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: export_route_target
                    
                    	Export Route Targets
                    	**type**\: list of  		 :py:class:`ExportRouteTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Context.ExportRouteTarget>`
                    
                    .. attribute:: import_route_target
                    
                    	Import Route Targets
                    	**type**\: list of  		 :py:class:`ImportRouteTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Context.ImportRouteTarget>`
                    
                    .. attribute:: anycast_rp_range
                    
                    	Anycast\-RP Ranges
                    	**type**\: list of  		 :py:class:`AnycastRpRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.Context, self).__init__()

                        self.yang_name = "context"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("remote-default-group", ("remote_default_group", Pim.Standby.Vrfs.Vrf.Context.RemoteDefaultGroup)), ("rpf-default-table", ("rpf_default_table", Pim.Standby.Vrfs.Vrf.Context.RpfDefaultTable)), ("export-route-target", ("export_route_target", Pim.Standby.Vrfs.Vrf.Context.ExportRouteTarget)), ("import-route-target", ("import_route_target", Pim.Standby.Vrfs.Vrf.Context.ImportRouteTarget)), ("anycast-rp-range", ("anycast_rp_range", Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange))])
                        self._leafs = OrderedDict([
                            ('vrf_id', (YLeaf(YType.uint32, 'vrf-id'), ['int'])),
                            ('table_id', (YLeaf(YType.uint32, 'table-id'), ['int'])),
                            ('murib_id', (YLeaf(YType.uint32, 'murib-id'), ['int'])),
                            ('rpf_id', (YLeaf(YType.uint32, 'rpf-id'), ['int'])),
                            ('remote_table_id', (YLeaf(YType.uint32, 'remote-table-id'), ['int'])),
                            ('mdt_default_group', (YLeaf(YType.str, 'mdt-default-group'), ['str'])),
                            ('mdt_source', (YLeaf(YType.str, 'mdt-source'), ['str'])),
                            ('mdt_source_interface', (YLeaf(YType.str, 'mdt-source-interface'), ['str'])),
                            ('mdt_interface', (YLeaf(YType.str, 'mdt-interface'), ['str'])),
                            ('mdt_gre_rpf_identifier', (YLeaf(YType.uint32, 'mdt-gre-rpf-identifier'), ['int'])),
                            ('mdt_gre_remote_rpf_identifier', (YLeaf(YType.uint32, 'mdt-gre-remote-rpf-identifier'), ['int'])),
                            ('is_unicast_rib_registration', (YLeaf(YType.boolean, 'is-unicast-rib-registration'), ['bool'])),
                            ('is_multicast_rib_registration', (YLeaf(YType.boolean, 'is-multicast-rib-registration'), ['bool'])),
                            ('is_active', (YLeaf(YType.boolean, 'is-active'), ['bool'])),
                            ('is_active_ital', (YLeaf(YType.boolean, 'is-active-ital'), ['bool'])),
                            ('is_mrib_register', (YLeaf(YType.boolean, 'is-mrib-register'), ['bool'])),
                            ('is_mdt_owner', (YLeaf(YType.boolean, 'is-mdt-owner'), ['bool'])),
                            ('is_routing_enabled', (YLeaf(YType.boolean, 'is-routing-enabled'), ['bool'])),
                            ('is_socket_add_required', (YLeaf(YType.boolean, 'is-socket-add-required'), ['bool'])),
                            ('is_socket_added', (YLeaf(YType.boolean, 'is-socket-added'), ['bool'])),
                            ('is_lpts_socket_add_required', (YLeaf(YType.boolean, 'is-lpts-socket-add-required'), ['bool'])),
                            ('is_lpts_socket_added', (YLeaf(YType.boolean, 'is-lpts-socket-added'), ['bool'])),
                            ('is_udp_socket_add_required', (YLeaf(YType.boolean, 'is-udp-socket-add-required'), ['bool'])),
                            ('is_udp_socket_added', (YLeaf(YType.boolean, 'is-udp-socket-added'), ['bool'])),
                            ('is_udp_socket_bind_required', (YLeaf(YType.boolean, 'is-udp-socket-bind-required'), ['bool'])),
                            ('is_udp_socket_bind', (YLeaf(YType.boolean, 'is-udp-socket-bind'), ['bool'])),
                            ('is_register_injection_socket_add_required', (YLeaf(YType.boolean, 'is-register-injection-socket-add-required'), ['bool'])),
                            ('is_register_injection_socket_added', (YLeaf(YType.boolean, 'is-register-injection-socket-added'), ['bool'])),
                            ('is_register_injection_lpts_socket_add_required', (YLeaf(YType.boolean, 'is-register-injection-lpts-socket-add-required'), ['bool'])),
                            ('is_register_injection_lpts_socket_added', (YLeaf(YType.boolean, 'is-register-injection-lpts-socket-added'), ['bool'])),
                            ('is_m_host_publish_pending', (YLeaf(YType.boolean, 'is-m-host-publish-pending'), ['bool'])),
                            ('mhost_interface', (YLeaf(YType.str, 'mhost-interface'), ['str'])),
                            ('mhost_default_interface_config', (YLeaf(YType.str, 'mhost-default-interface-config'), ['str'])),
                            ('mdt_mtu', (YLeaf(YType.uint32, 'mdt-mtu'), ['int'])),
                            ('maximum_mdt_aggregation', (YLeaf(YType.uint32, 'maximum-mdt-aggregation'), ['int'])),
                            ('mdt_data_switchover_interval', (YLeaf(YType.uint32, 'mdt-data-switchover-interval'), ['int'])),
                            ('mdt_data_announce_interval', (YLeaf(YType.uint32, 'mdt-data-announce-interval'), ['int'])),
                            ('non_default_vrf_count_on_socket', (YLeaf(YType.uint32, 'non-default-vrf-count-on-socket'), ['int'])),
                            ('neighbor_filter_name', (YLeaf(YType.str, 'neighbor-filter-name'), ['str'])),
                            ('mdt_neighbor_filter_name', (YLeaf(YType.str, 'mdt-neighbor-filter-name'), ['str'])),
                            ('allow_rp_configured', (YLeaf(YType.boolean, 'allow-rp-configured'), ['bool'])),
                            ('allow_rp_group_list', (YLeaf(YType.str, 'allow-rp-group-list'), ['str'])),
                            ('allow_rp_rp_list', (YLeaf(YType.str, 'allow-rp-rp-list'), ['str'])),
                            ('sg_expiry_timer_configured', (YLeaf(YType.boolean, 'sg-expiry-timer-configured'), ['bool'])),
                            ('sg_expiry_time', (YLeaf(YType.uint16, 'sg-expiry-time'), ['int'])),
                            ('sg_expiry_timer_sg_list', (YLeaf(YType.str, 'sg-expiry-timer-sg-list'), ['str'])),
                            ('mldp_mdt_name', (YLeaf(YType.str, 'mldp-mdt-name'), ['str'])),
                            ('mldp_mdt_interface', (YLeaf(YType.str, 'mldp-mdt-interface'), ['str'])),
                            ('mldp_mdt_mtu', (YLeaf(YType.uint32, 'mldp-mdt-mtu'), ['int'])),
                            ('mldp_maximum_mdt_aggregation', (YLeaf(YType.uint32, 'mldp-maximum-mdt-aggregation'), ['int'])),
                            ('mldp_mdt_data_switchover_interval', (YLeaf(YType.uint32, 'mldp-mdt-data-switchover-interval'), ['int'])),
                            ('mldp_mdt_data_announce_interval', (YLeaf(YType.uint32, 'mldp-mdt-data-announce-interval'), ['int'])),
                            ('mldp_mdt_rpf_identifier', (YLeaf(YType.uint32, 'mldp-mdt-rpf-identifier'), ['int'])),
                            ('mldp_mdt_remote_rpf_identifier', (YLeaf(YType.uint32, 'mldp-mdt-remote-rpf-identifier'), ['int'])),
                            ('is_create_mldp_mdt_interface', (YLeaf(YType.boolean, 'is-create-mldp-mdt-interface'), ['bool'])),
                            ('is_mldp_mdt_owner', (YLeaf(YType.boolean, 'is-mldp-mdt-owner'), ['bool'])),
                            ('mldp_root_count', (YLeaf(YType.uint32, 'mldp-root-count'), ['int'])),
                            ('mldp_head_lsm_identifier', (YLeaf(YType.uint32, 'mldp-head-lsm-identifier'), ['int'])),
                            ('mldp_remote_head_lsm_identifier', (YLeaf(YType.uint32, 'mldp-remote-head-lsm-identifier'), ['int'])),
                            ('organization_unique_identifier', (YLeaf(YType.uint32, 'organization-unique-identifier'), ['int'])),
                            ('vpn_index', (YLeaf(YType.uint32, 'vpn-index'), ['int'])),
                            ('mldp_partitioned_mdt_configured', (YLeaf(YType.boolean, 'mldp-partitioned-mdt-configured'), ['bool'])),
                            ('mldp_remote_partitioned_mdt_configured', (YLeaf(YType.boolean, 'mldp-remote-partitioned-mdt-configured'), ['bool'])),
                            ('mldp_partioned_mp2m_ptree', (YLeaf(YType.boolean, 'mldp-partioned-mp2m-ptree'), ['bool'])),
                            ('mldp_partitioned_head_lsm_identifier', (YLeaf(YType.uint32, 'mldp-partitioned-head-lsm-identifier'), ['int'])),
                            ('mldp_head_local_label', (YLeaf(YType.uint32, 'mldp-head-local-label'), ['int'])),
                            ('mldp_partitioned_mdt_identifier', (YLeaf(YType.uint32, 'mldp-partitioned-mdt-identifier'), ['int'])),
                            ('bgp_auto_discovery_configured', (YLeaf(YType.boolean, 'bgp-auto-discovery-configured'), ['bool'])),
                            ('suppress_pim_data_mdt_tlv', (YLeaf(YType.boolean, 'suppress-pim-data-mdt-tlv'), ['bool'])),
                            ('inter_autonomous_system_enabled', (YLeaf(YType.boolean, 'inter-autonomous-system-enabled'), ['bool'])),
                            ('bgp_source_active_announce', (YLeaf(YType.boolean, 'bgp-source-active-announce'), ['bool'])),
                            ('bgp_i_pmsi_added', (YLeaf(YType.boolean, 'bgp-i-pmsi-added'), ['bool'])),
                            ('mldp_bsr_control_tree_added', (YLeaf(YType.boolean, 'mldp-bsr-control-tree-added'), ['bool'])),
                            ('mldp_auto_rp_discovery_tree_added', (YLeaf(YType.boolean, 'mldp-auto-rp-discovery-tree-added'), ['bool'])),
                            ('mldp_auto_rp_announce_tree_added', (YLeaf(YType.boolean, 'mldp-auto-rp-announce-tree-added'), ['bool'])),
                            ('bgp_auto_discovery_type', (YLeaf(YType.uint32, 'bgp-auto-discovery-type'), ['int'])),
                            ('mdt_partitioned_mdt_control_identifier', (YLeaf(YType.uint32, 'mdt-partitioned-mdt-control-identifier'), ['int'])),
                            ('mdt_partitioned_ir_control_identifier', (YLeaf(YType.uint32, 'mdt-partitioned-ir-control-identifier'), ['int'])),
                            ('mldp_control_head_lsm_identifier', (YLeaf(YType.uint32, 'mldp-control-head-lsm-identifier'), ['int'])),
                            ('umh', (YLeaf(YType.boolean, 'umh'), ['bool'])),
                            ('suppress_shared_tree_join', (YLeaf(YType.boolean, 'suppress-shared-tree-join'), ['bool'])),
                            ('rsvp_te_mdt_name', (YLeaf(YType.str, 'rsvp-te-mdt-name'), ['str'])),
                            ('rsvp_te_mdt_interface', (YLeaf(YType.str, 'rsvp-te-mdt-interface'), ['str'])),
                            ('rsvp_te_mdt_mtu', (YLeaf(YType.uint32, 'rsvp-te-mdt-mtu'), ['int'])),
                            ('rsvp_te_maximum_mdt_aggregation', (YLeaf(YType.uint32, 'rsvp-te-maximum-mdt-aggregation'), ['int'])),
                            ('rsvp_te_mdt_data_switchover_interval', (YLeaf(YType.uint32, 'rsvp-te-mdt-data-switchover-interval'), ['int'])),
                            ('rsvp_te_mdt_data_announce_interval', (YLeaf(YType.uint32, 'rsvp-te-mdt-data-announce-interval'), ['int'])),
                            ('rsvp_te_mdt_rpf_identifier', (YLeaf(YType.uint32, 'rsvp-te-mdt-rpf-identifier'), ['int'])),
                            ('is_create_rsvp_te_mdt_interface', (YLeaf(YType.boolean, 'is-create-rsvp-te-mdt-interface'), ['bool'])),
                            ('is_rsvp_te_mdt_owner', (YLeaf(YType.boolean, 'is-rsvp-te-mdt-owner'), ['bool'])),
                            ('rsvp_te_mdt_static_p2mp_count', (YLeaf(YType.uint32, 'rsvp-te-mdt-static-p2mp-count'), ['int'])),
                            ('p2mpte_li_drop', (YLeaf(YType.uint32, 'p2mpte-li-drop'), ['int'])),
                            ('ir_mdt_name', (YLeaf(YType.str, 'ir-mdt-name'), ['str'])),
                            ('ir_mdt_interface', (YLeaf(YType.str, 'ir-mdt-interface'), ['str'])),
                            ('ir_mdt_mtu', (YLeaf(YType.uint32, 'ir-mdt-mtu'), ['int'])),
                            ('ir_maximum_mdt_aggregation', (YLeaf(YType.uint32, 'ir-maximum-mdt-aggregation'), ['int'])),
                            ('ir_mdt_data_switchover_interval', (YLeaf(YType.uint32, 'ir-mdt-data-switchover-interval'), ['int'])),
                            ('ir_mdt_data_announce_interval', (YLeaf(YType.uint32, 'ir-mdt-data-announce-interval'), ['int'])),
                            ('ir_mdt_rpf_identifier', (YLeaf(YType.uint32, 'ir-mdt-rpf-identifier'), ['int'])),
                            ('ir_mdt_tail_label', (YLeaf(YType.uint32, 'ir-mdt-tail-label'), ['int'])),
                            ('is_create_ir_mdt_interface', (YLeaf(YType.boolean, 'is-create-ir-mdt-interface'), ['bool'])),
                            ('is_ir_mdt_owner', (YLeaf(YType.boolean, 'is-ir-mdt-owner'), ['bool'])),
                            ('in_b_and_mdt_name', (YLeaf(YType.str, 'in-b-and-mdt-name'), ['str'])),
                            ('in_b_and_mdt_interface', (YLeaf(YType.str, 'in-b-and-mdt-interface'), ['str'])),
                            ('in_b_and_mdt_mtu', (YLeaf(YType.uint32, 'in-b-and-mdt-mtu'), ['int'])),
                            ('in_band_maximum_mdt_aggregation', (YLeaf(YType.uint32, 'in-band-maximum-mdt-aggregation'), ['int'])),
                            ('in_b_and_mdt_data_switchover_interval', (YLeaf(YType.uint32, 'in-b-and-mdt-data-switchover-interval'), ['int'])),
                            ('in_b_and_mdt_data_announce_interval', (YLeaf(YType.uint32, 'in-b-and-mdt-data-announce-interval'), ['int'])),
                            ('in_b_and_mdt_rpf_identifier', (YLeaf(YType.uint32, 'in-b-and-mdt-rpf-identifier'), ['int'])),
                            ('is_create_in_b_and_mdt_interface', (YLeaf(YType.boolean, 'is-create-in-b-and-mdt-interface'), ['bool'])),
                            ('is_in_b_and_mdt_owner', (YLeaf(YType.boolean, 'is-in-b-and-mdt-owner'), ['bool'])),
                            ('in_band_signaling_local_enabled', (YLeaf(YType.boolean, 'in-band-signaling-local-enabled'), ['bool'])),
                            ('in_band_signaling_remote_enabled', (YLeaf(YType.boolean, 'in-band-signaling-remote-enabled'), ['bool'])),
                            ('valid_rd_present', (YLeaf(YType.boolean, 'valid-rd-present'), ['bool'])),
                            ('stale_rd_present', (YLeaf(YType.boolean, 'stale-rd-present'), ['bool'])),
                            ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                            ('gin_b_and_mdt_name', (YLeaf(YType.str, 'gin-b-and-mdt-name'), ['str'])),
                            ('gin_b_and_mdt_interface', (YLeaf(YType.str, 'gin-b-and-mdt-interface'), ['str'])),
                            ('gin_b_and_mdt_mtu', (YLeaf(YType.uint32, 'gin-b-and-mdt-mtu'), ['int'])),
                            ('gin_band_maximum_mdt_aggregation', (YLeaf(YType.uint32, 'gin-band-maximum-mdt-aggregation'), ['int'])),
                            ('gin_b_and_mdt_data_switchover_interval', (YLeaf(YType.uint32, 'gin-b-and-mdt-data-switchover-interval'), ['int'])),
                            ('gin_b_and_mdt_data_announce_interval', (YLeaf(YType.uint32, 'gin-b-and-mdt-data-announce-interval'), ['int'])),
                            ('gin_b_and_mdt_rpf_identifier', (YLeaf(YType.uint32, 'gin-b-and-mdt-rpf-identifier'), ['int'])),
                            ('is_create_gin_b_and_mdt_interface', (YLeaf(YType.boolean, 'is-create-gin-b-and-mdt-interface'), ['bool'])),
                            ('is_gin_b_and_mdt_owner', (YLeaf(YType.boolean, 'is-gin-b-and-mdt-owner'), ['bool'])),
                            ('is_pim_nsf_rib_converged', (YLeaf(YType.boolean, 'is-pim-nsf-rib-converged'), ['bool'])),
                            ('is_pim_nsf_rib_converge_received', (YLeaf(YType.boolean, 'is-pim-nsf-rib-converge-received'), ['bool'])),
                            ('is_rib_multipath_enabled', (YLeaf(YType.boolean, 'is-rib-multipath-enabled'), ['bool'])),
                            ('is_rib_multipath_interface_hash', (YLeaf(YType.boolean, 'is-rib-multipath-interface-hash'), ['bool'])),
                            ('is_rib_multipath_source_hash', (YLeaf(YType.boolean, 'is-rib-multipath-source-hash'), ['bool'])),
                            ('is_rib_multipath_source_next_hop_hash', (YLeaf(YType.boolean, 'is-rib-multipath-source-next-hop-hash'), ['bool'])),
                            ('rump_enabled', (YLeaf(YType.boolean, 'rump-enabled'), ['bool'])),
                            ('is_create_mdt_interface', (YLeaf(YType.boolean, 'is-create-mdt-interface'), ['bool'])),
                            ('is_auto_rp_listen_enabled', (YLeaf(YType.boolean, 'is-auto-rp-listen-enabled'), ['bool'])),
                            ('is_all_interface_disable_operation', (YLeaf(YType.boolean, 'is-all-interface-disable-operation'), ['bool'])),
                            ('is_default_granges', (YLeaf(YType.boolean, 'is-default-granges'), ['bool'])),
                            ('is_auto_rp_listen_sock_add', (YLeaf(YType.boolean, 'is-auto-rp-listen-sock-add'), ['bool'])),
                            ('is_redistribution_reset', (YLeaf(YType.boolean, 'is-redistribution-reset'), ['bool'])),
                            ('redistribution_reset_count', (YLeaf(YType.uint32, 'redistribution-reset-count'), ['int'])),
                            ('rpf_policy_name', (YLeaf(YType.str, 'rpf-policy-name'), ['str'])),
                            ('table_count', (YLeaf(YType.uint32, 'table-count'), ['int'])),
                            ('active_table_count', (YLeaf(YType.uint32, 'active-table-count'), ['int'])),
                            ('anycast_rp_policy_name', (YLeaf(YType.str, 'anycast-rp-policy-name'), ['str'])),
                            ('anycast_rp_configured', (YLeaf(YType.boolean, 'anycast-rp-configured'), ['bool'])),
                            ('bgp_remote_on', (YLeaf(YType.boolean, 'bgp-remote-on'), ['bool'])),
                            ('bgp_remote_interface_name', (YLeaf(YType.str, 'bgp-remote-interface-name'), ['str'])),
                            ('bgp_remote_interface', (YLeaf(YType.str, 'bgp-remote-interface'), ['str'])),
                            ('bgp_remote_address', (YLeaf(YType.str, 'bgp-remote-address'), ['str'])),
                            ('bgp_remote_state', (YLeaf(YType.uint32, 'bgp-remote-state'), ['int'])),
                            ('physical_interface_count', (YLeaf(YType.uint64, 'physical-interface-count'), ['int'])),
                            ('virtual_interface_count', (YLeaf(YType.uint64, 'virtual-interface-count'), ['int'])),
                            ('virtual_mlc_interface_name', (YLeaf(YType.str, 'virtual-mlc-interface-name'), ['str'])),
                            ('mdt_immediate_switch', (YLeaf(YType.boolean, 'mdt-immediate-switch'), ['bool'])),
                            ('mldp_root_address', (YLeafList(YType.uint32, 'mldp-root-address'), ['int'])),
                        ])
                        self.vrf_id = None
                        self.table_id = None
                        self.murib_id = None
                        self.rpf_id = None
                        self.remote_table_id = None
                        self.mdt_default_group = None
                        self.mdt_source = None
                        self.mdt_source_interface = None
                        self.mdt_interface = None
                        self.mdt_gre_rpf_identifier = None
                        self.mdt_gre_remote_rpf_identifier = None
                        self.is_unicast_rib_registration = None
                        self.is_multicast_rib_registration = None
                        self.is_active = None
                        self.is_active_ital = None
                        self.is_mrib_register = None
                        self.is_mdt_owner = None
                        self.is_routing_enabled = None
                        self.is_socket_add_required = None
                        self.is_socket_added = None
                        self.is_lpts_socket_add_required = None
                        self.is_lpts_socket_added = None
                        self.is_udp_socket_add_required = None
                        self.is_udp_socket_added = None
                        self.is_udp_socket_bind_required = None
                        self.is_udp_socket_bind = None
                        self.is_register_injection_socket_add_required = None
                        self.is_register_injection_socket_added = None
                        self.is_register_injection_lpts_socket_add_required = None
                        self.is_register_injection_lpts_socket_added = None
                        self.is_m_host_publish_pending = None
                        self.mhost_interface = None
                        self.mhost_default_interface_config = None
                        self.mdt_mtu = None
                        self.maximum_mdt_aggregation = None
                        self.mdt_data_switchover_interval = None
                        self.mdt_data_announce_interval = None
                        self.non_default_vrf_count_on_socket = None
                        self.neighbor_filter_name = None
                        self.mdt_neighbor_filter_name = None
                        self.allow_rp_configured = None
                        self.allow_rp_group_list = None
                        self.allow_rp_rp_list = None
                        self.sg_expiry_timer_configured = None
                        self.sg_expiry_time = None
                        self.sg_expiry_timer_sg_list = None
                        self.mldp_mdt_name = None
                        self.mldp_mdt_interface = None
                        self.mldp_mdt_mtu = None
                        self.mldp_maximum_mdt_aggregation = None
                        self.mldp_mdt_data_switchover_interval = None
                        self.mldp_mdt_data_announce_interval = None
                        self.mldp_mdt_rpf_identifier = None
                        self.mldp_mdt_remote_rpf_identifier = None
                        self.is_create_mldp_mdt_interface = None
                        self.is_mldp_mdt_owner = None
                        self.mldp_root_count = None
                        self.mldp_head_lsm_identifier = None
                        self.mldp_remote_head_lsm_identifier = None
                        self.organization_unique_identifier = None
                        self.vpn_index = None
                        self.mldp_partitioned_mdt_configured = None
                        self.mldp_remote_partitioned_mdt_configured = None
                        self.mldp_partioned_mp2m_ptree = None
                        self.mldp_partitioned_head_lsm_identifier = None
                        self.mldp_head_local_label = None
                        self.mldp_partitioned_mdt_identifier = None
                        self.bgp_auto_discovery_configured = None
                        self.suppress_pim_data_mdt_tlv = None
                        self.inter_autonomous_system_enabled = None
                        self.bgp_source_active_announce = None
                        self.bgp_i_pmsi_added = None
                        self.mldp_bsr_control_tree_added = None
                        self.mldp_auto_rp_discovery_tree_added = None
                        self.mldp_auto_rp_announce_tree_added = None
                        self.bgp_auto_discovery_type = None
                        self.mdt_partitioned_mdt_control_identifier = None
                        self.mdt_partitioned_ir_control_identifier = None
                        self.mldp_control_head_lsm_identifier = None
                        self.umh = None
                        self.suppress_shared_tree_join = None
                        self.rsvp_te_mdt_name = None
                        self.rsvp_te_mdt_interface = None
                        self.rsvp_te_mdt_mtu = None
                        self.rsvp_te_maximum_mdt_aggregation = None
                        self.rsvp_te_mdt_data_switchover_interval = None
                        self.rsvp_te_mdt_data_announce_interval = None
                        self.rsvp_te_mdt_rpf_identifier = None
                        self.is_create_rsvp_te_mdt_interface = None
                        self.is_rsvp_te_mdt_owner = None
                        self.rsvp_te_mdt_static_p2mp_count = None
                        self.p2mpte_li_drop = None
                        self.ir_mdt_name = None
                        self.ir_mdt_interface = None
                        self.ir_mdt_mtu = None
                        self.ir_maximum_mdt_aggregation = None
                        self.ir_mdt_data_switchover_interval = None
                        self.ir_mdt_data_announce_interval = None
                        self.ir_mdt_rpf_identifier = None
                        self.ir_mdt_tail_label = None
                        self.is_create_ir_mdt_interface = None
                        self.is_ir_mdt_owner = None
                        self.in_b_and_mdt_name = None
                        self.in_b_and_mdt_interface = None
                        self.in_b_and_mdt_mtu = None
                        self.in_band_maximum_mdt_aggregation = None
                        self.in_b_and_mdt_data_switchover_interval = None
                        self.in_b_and_mdt_data_announce_interval = None
                        self.in_b_and_mdt_rpf_identifier = None
                        self.is_create_in_b_and_mdt_interface = None
                        self.is_in_b_and_mdt_owner = None
                        self.in_band_signaling_local_enabled = None
                        self.in_band_signaling_remote_enabled = None
                        self.valid_rd_present = None
                        self.stale_rd_present = None
                        self.route_distinguisher = None
                        self.gin_b_and_mdt_name = None
                        self.gin_b_and_mdt_interface = None
                        self.gin_b_and_mdt_mtu = None
                        self.gin_band_maximum_mdt_aggregation = None
                        self.gin_b_and_mdt_data_switchover_interval = None
                        self.gin_b_and_mdt_data_announce_interval = None
                        self.gin_b_and_mdt_rpf_identifier = None
                        self.is_create_gin_b_and_mdt_interface = None
                        self.is_gin_b_and_mdt_owner = None
                        self.is_pim_nsf_rib_converged = None
                        self.is_pim_nsf_rib_converge_received = None
                        self.is_rib_multipath_enabled = None
                        self.is_rib_multipath_interface_hash = None
                        self.is_rib_multipath_source_hash = None
                        self.is_rib_multipath_source_next_hop_hash = None
                        self.rump_enabled = None
                        self.is_create_mdt_interface = None
                        self.is_auto_rp_listen_enabled = None
                        self.is_all_interface_disable_operation = None
                        self.is_default_granges = None
                        self.is_auto_rp_listen_sock_add = None
                        self.is_redistribution_reset = None
                        self.redistribution_reset_count = None
                        self.rpf_policy_name = None
                        self.table_count = None
                        self.active_table_count = None
                        self.anycast_rp_policy_name = None
                        self.anycast_rp_configured = None
                        self.bgp_remote_on = None
                        self.bgp_remote_interface_name = None
                        self.bgp_remote_interface = None
                        self.bgp_remote_address = None
                        self.bgp_remote_state = None
                        self.physical_interface_count = None
                        self.virtual_interface_count = None
                        self.virtual_mlc_interface_name = None
                        self.mdt_immediate_switch = None
                        self.mldp_root_address = []

                        self.remote_default_group = Pim.Standby.Vrfs.Vrf.Context.RemoteDefaultGroup()
                        self.remote_default_group.parent = self
                        self._children_name_map["remote_default_group"] = "remote-default-group"

                        self.rpf_default_table = Pim.Standby.Vrfs.Vrf.Context.RpfDefaultTable()
                        self.rpf_default_table.parent = self
                        self._children_name_map["rpf_default_table"] = "rpf-default-table"

                        self.export_route_target = YList(self)
                        self.import_route_target = YList(self)
                        self.anycast_rp_range = YList(self)
                        self._segment_path = lambda: "context"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.Context, ['vrf_id', 'table_id', 'murib_id', 'rpf_id', 'remote_table_id', 'mdt_default_group', 'mdt_source', 'mdt_source_interface', 'mdt_interface', 'mdt_gre_rpf_identifier', 'mdt_gre_remote_rpf_identifier', 'is_unicast_rib_registration', 'is_multicast_rib_registration', 'is_active', 'is_active_ital', 'is_mrib_register', 'is_mdt_owner', 'is_routing_enabled', 'is_socket_add_required', 'is_socket_added', 'is_lpts_socket_add_required', 'is_lpts_socket_added', 'is_udp_socket_add_required', 'is_udp_socket_added', 'is_udp_socket_bind_required', 'is_udp_socket_bind', 'is_register_injection_socket_add_required', 'is_register_injection_socket_added', 'is_register_injection_lpts_socket_add_required', 'is_register_injection_lpts_socket_added', 'is_m_host_publish_pending', 'mhost_interface', 'mhost_default_interface_config', 'mdt_mtu', 'maximum_mdt_aggregation', 'mdt_data_switchover_interval', 'mdt_data_announce_interval', 'non_default_vrf_count_on_socket', 'neighbor_filter_name', 'mdt_neighbor_filter_name', 'allow_rp_configured', 'allow_rp_group_list', 'allow_rp_rp_list', 'sg_expiry_timer_configured', 'sg_expiry_time', 'sg_expiry_timer_sg_list', 'mldp_mdt_name', 'mldp_mdt_interface', 'mldp_mdt_mtu', 'mldp_maximum_mdt_aggregation', 'mldp_mdt_data_switchover_interval', 'mldp_mdt_data_announce_interval', 'mldp_mdt_rpf_identifier', 'mldp_mdt_remote_rpf_identifier', 'is_create_mldp_mdt_interface', 'is_mldp_mdt_owner', 'mldp_root_count', 'mldp_head_lsm_identifier', 'mldp_remote_head_lsm_identifier', 'organization_unique_identifier', 'vpn_index', 'mldp_partitioned_mdt_configured', 'mldp_remote_partitioned_mdt_configured', 'mldp_partioned_mp2m_ptree', 'mldp_partitioned_head_lsm_identifier', 'mldp_head_local_label', 'mldp_partitioned_mdt_identifier', 'bgp_auto_discovery_configured', 'suppress_pim_data_mdt_tlv', 'inter_autonomous_system_enabled', 'bgp_source_active_announce', 'bgp_i_pmsi_added', 'mldp_bsr_control_tree_added', 'mldp_auto_rp_discovery_tree_added', 'mldp_auto_rp_announce_tree_added', 'bgp_auto_discovery_type', 'mdt_partitioned_mdt_control_identifier', 'mdt_partitioned_ir_control_identifier', 'mldp_control_head_lsm_identifier', 'umh', 'suppress_shared_tree_join', 'rsvp_te_mdt_name', 'rsvp_te_mdt_interface', 'rsvp_te_mdt_mtu', 'rsvp_te_maximum_mdt_aggregation', 'rsvp_te_mdt_data_switchover_interval', 'rsvp_te_mdt_data_announce_interval', 'rsvp_te_mdt_rpf_identifier', 'is_create_rsvp_te_mdt_interface', 'is_rsvp_te_mdt_owner', 'rsvp_te_mdt_static_p2mp_count', 'p2mpte_li_drop', 'ir_mdt_name', 'ir_mdt_interface', 'ir_mdt_mtu', 'ir_maximum_mdt_aggregation', 'ir_mdt_data_switchover_interval', 'ir_mdt_data_announce_interval', 'ir_mdt_rpf_identifier', 'ir_mdt_tail_label', 'is_create_ir_mdt_interface', 'is_ir_mdt_owner', 'in_b_and_mdt_name', 'in_b_and_mdt_interface', 'in_b_and_mdt_mtu', 'in_band_maximum_mdt_aggregation', 'in_b_and_mdt_data_switchover_interval', 'in_b_and_mdt_data_announce_interval', 'in_b_and_mdt_rpf_identifier', 'is_create_in_b_and_mdt_interface', 'is_in_b_and_mdt_owner', 'in_band_signaling_local_enabled', 'in_band_signaling_remote_enabled', 'valid_rd_present', 'stale_rd_present', 'route_distinguisher', 'gin_b_and_mdt_name', 'gin_b_and_mdt_interface', 'gin_b_and_mdt_mtu', 'gin_band_maximum_mdt_aggregation', 'gin_b_and_mdt_data_switchover_interval', 'gin_b_and_mdt_data_announce_interval', 'gin_b_and_mdt_rpf_identifier', 'is_create_gin_b_and_mdt_interface', 'is_gin_b_and_mdt_owner', 'is_pim_nsf_rib_converged', 'is_pim_nsf_rib_converge_received', 'is_rib_multipath_enabled', 'is_rib_multipath_interface_hash', 'is_rib_multipath_source_hash', 'is_rib_multipath_source_next_hop_hash', 'rump_enabled', 'is_create_mdt_interface', 'is_auto_rp_listen_enabled', 'is_all_interface_disable_operation', 'is_default_granges', 'is_auto_rp_listen_sock_add', 'is_redistribution_reset', 'redistribution_reset_count', 'rpf_policy_name', 'table_count', 'active_table_count', 'anycast_rp_policy_name', 'anycast_rp_configured', 'bgp_remote_on', 'bgp_remote_interface_name', 'bgp_remote_interface', 'bgp_remote_address', 'bgp_remote_state', 'physical_interface_count', 'virtual_interface_count', 'virtual_mlc_interface_name', 'mdt_immediate_switch', 'mldp_root_address'], name, value)


                    class RemoteDefaultGroup(Entity):
                        """
                        Remote Default Group
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.Context.RemoteDefaultGroup, self).__init__()

                            self.yang_name = "remote-default-group"
                            self.yang_parent_name = "context"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "remote-default-group"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.Context.RemoteDefaultGroup, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class RpfDefaultTable(Entity):
                        """
                        RPF Default Table
                        
                        .. attribute:: afi
                        
                        	AFI
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: safi
                        
                        	SAFI
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_name
                        
                        	Table name
                        	**type**\: str
                        
                        .. attribute:: vrf_id
                        
                        	VRF ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_id
                        
                        	Table ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_active
                        
                        	Active status
                        	**type**\: bool
                        
                        .. attribute:: is_ital_registration_done
                        
                        	ITAL reg status
                        	**type**\: bool
                        
                        .. attribute:: is_rib_registration_done
                        
                        	RIB reg status
                        	**type**\: bool
                        
                        .. attribute:: is_rib_convergence_received
                        
                        	RIB Convergence receive status
                        	**type**\: bool
                        
                        .. attribute:: is_rib_convergence
                        
                        	RIB Convergence status
                        	**type**\: bool
                        
                        .. attribute:: rpf_registrations
                        
                        	RPF Registration count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.Context.RpfDefaultTable, self).__init__()

                            self.yang_name = "rpf-default-table"
                            self.yang_parent_name = "context"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('afi', (YLeaf(YType.uint32, 'afi'), ['int'])),
                                ('safi', (YLeaf(YType.uint32, 'safi'), ['int'])),
                                ('table_name', (YLeaf(YType.str, 'table-name'), ['str'])),
                                ('vrf_id', (YLeaf(YType.uint32, 'vrf-id'), ['int'])),
                                ('table_id', (YLeaf(YType.uint32, 'table-id'), ['int'])),
                                ('is_active', (YLeaf(YType.boolean, 'is-active'), ['bool'])),
                                ('is_ital_registration_done', (YLeaf(YType.boolean, 'is-ital-registration-done'), ['bool'])),
                                ('is_rib_registration_done', (YLeaf(YType.boolean, 'is-rib-registration-done'), ['bool'])),
                                ('is_rib_convergence_received', (YLeaf(YType.boolean, 'is-rib-convergence-received'), ['bool'])),
                                ('is_rib_convergence', (YLeaf(YType.boolean, 'is-rib-convergence'), ['bool'])),
                                ('rpf_registrations', (YLeaf(YType.uint32, 'rpf-registrations'), ['int'])),
                            ])
                            self.afi = None
                            self.safi = None
                            self.table_name = None
                            self.vrf_id = None
                            self.table_id = None
                            self.is_active = None
                            self.is_ital_registration_done = None
                            self.is_rib_registration_done = None
                            self.is_rib_convergence_received = None
                            self.is_rib_convergence = None
                            self.rpf_registrations = None
                            self._segment_path = lambda: "rpf-default-table"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.Context.RpfDefaultTable, ['afi', 'safi', 'table_name', 'vrf_id', 'table_id', 'is_active', 'is_ital_registration_done', 'is_rib_registration_done', 'is_rib_convergence_received', 'is_rib_convergence', 'rpf_registrations'], name, value)


                    class ExportRouteTarget(Entity):
                        """
                        Export Route Targets
                        
                        .. attribute:: route_target
                        
                        	Route Target Extended community value
                        	**type**\: str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        .. attribute:: configured
                        
                        	Configured Route Target
                        	**type**\: bool
                        
                        .. attribute:: anycast_rp
                        
                        	Anycast\-RP Group
                        	**type**\: bool
                        
                        .. attribute:: anycast_rp_marked
                        
                        	Anycast\-RP Group marked
                        	**type**\: bool
                        
                        .. attribute:: update_pending
                        
                        	Update Pending to BGP
                        	**type**\: bool
                        
                        .. attribute:: bgp_auto_discovery
                        
                        	BGP Auto Discovery
                        	**type**\: bool
                        
                        .. attribute:: segment_border
                        
                        	Segment Border
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.Context.ExportRouteTarget, self).__init__()

                            self.yang_name = "export-route-target"
                            self.yang_parent_name = "context"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('route_target', (YLeaf(YType.str, 'route-target'), ['str'])),
                                ('configured', (YLeaf(YType.boolean, 'configured'), ['bool'])),
                                ('anycast_rp', (YLeaf(YType.boolean, 'anycast-rp'), ['bool'])),
                                ('anycast_rp_marked', (YLeaf(YType.boolean, 'anycast-rp-marked'), ['bool'])),
                                ('update_pending', (YLeaf(YType.boolean, 'update-pending'), ['bool'])),
                                ('bgp_auto_discovery', (YLeaf(YType.boolean, 'bgp-auto-discovery'), ['bool'])),
                                ('segment_border', (YLeaf(YType.boolean, 'segment-border'), ['bool'])),
                            ])
                            self.route_target = None
                            self.configured = None
                            self.anycast_rp = None
                            self.anycast_rp_marked = None
                            self.update_pending = None
                            self.bgp_auto_discovery = None
                            self.segment_border = None
                            self._segment_path = lambda: "export-route-target"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.Context.ExportRouteTarget, ['route_target', 'configured', 'anycast_rp', 'anycast_rp_marked', 'update_pending', 'bgp_auto_discovery', 'segment_border'], name, value)


                    class ImportRouteTarget(Entity):
                        """
                        Import Route Targets
                        
                        .. attribute:: route_target
                        
                        	Route Target Extended community value
                        	**type**\: str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        .. attribute:: configured
                        
                        	Configured Route Target
                        	**type**\: bool
                        
                        .. attribute:: anycast_rp
                        
                        	Anycast\-RP Group
                        	**type**\: bool
                        
                        .. attribute:: anycast_rp_marked
                        
                        	Anycast\-RP Group marked
                        	**type**\: bool
                        
                        .. attribute:: update_pending
                        
                        	Update Pending to BGP
                        	**type**\: bool
                        
                        .. attribute:: bgp_auto_discovery
                        
                        	BGP Auto Discovery
                        	**type**\: bool
                        
                        .. attribute:: segment_border
                        
                        	Segment Border
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.Context.ImportRouteTarget, self).__init__()

                            self.yang_name = "import-route-target"
                            self.yang_parent_name = "context"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('route_target', (YLeaf(YType.str, 'route-target'), ['str'])),
                                ('configured', (YLeaf(YType.boolean, 'configured'), ['bool'])),
                                ('anycast_rp', (YLeaf(YType.boolean, 'anycast-rp'), ['bool'])),
                                ('anycast_rp_marked', (YLeaf(YType.boolean, 'anycast-rp-marked'), ['bool'])),
                                ('update_pending', (YLeaf(YType.boolean, 'update-pending'), ['bool'])),
                                ('bgp_auto_discovery', (YLeaf(YType.boolean, 'bgp-auto-discovery'), ['bool'])),
                                ('segment_border', (YLeaf(YType.boolean, 'segment-border'), ['bool'])),
                            ])
                            self.route_target = None
                            self.configured = None
                            self.anycast_rp = None
                            self.anycast_rp_marked = None
                            self.update_pending = None
                            self.bgp_auto_discovery = None
                            self.segment_border = None
                            self._segment_path = lambda: "import-route-target"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.Context.ImportRouteTarget, ['route_target', 'configured', 'anycast_rp', 'anycast_rp_marked', 'update_pending', 'bgp_auto_discovery', 'segment_border'], name, value)


                    class AnycastRpRange(Entity):
                        """
                        Anycast\-RP Ranges
                        
                        .. attribute:: prefix
                        
                        	Anycast\-RP Range Prefix
                        	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Anycast\-RP Range Prefix Length
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: ancast_rp_marked
                        
                        	Anycast\-RP Range marked
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange, self).__init__()

                            self.yang_name = "anycast-rp-range"
                            self.yang_parent_name = "context"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("prefix", ("prefix", Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange.Prefix))])
                            self._leafs = OrderedDict([
                                ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                ('ancast_rp_marked', (YLeaf(YType.boolean, 'ancast-rp-marked'), ['bool'])),
                            ])
                            self.prefix_length = None
                            self.ancast_rp_marked = None

                            self.prefix = Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"
                            self._segment_path = lambda: "anycast-rp-range"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange, ['prefix_length', 'ancast_rp_marked'], name, value)


                        class Prefix(Entity):
                            """
                            Anycast\-RP Range Prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "anycast-rp-range"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "prefix"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange.Prefix, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class TopologyEntryFlagRouteCounts(Entity):
                    """
                    Route count for topology with entry flag set
                    
                    .. attribute:: topology_entry_flag_route_count
                    
                    	Route count for topology with entry flag set
                    	**type**\: list of  		 :py:class:`TopologyEntryFlagRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts, self).__init__()

                        self.yang_name = "topology-entry-flag-route-counts"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("topology-entry-flag-route-count", ("topology_entry_flag_route_count", Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount))])
                        self._leafs = OrderedDict()

                        self.topology_entry_flag_route_count = YList(self)
                        self._segment_path = lambda: "topology-entry-flag-route-counts"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts, [], name, value)


                    class TopologyEntryFlagRouteCount(Entity):
                        """
                        Route count for topology with entry flag set
                        
                        .. attribute:: entry_flag  (key)
                        
                        	entry flag
                        	**type**\:  :py:class:`PimTopologyEntryFlag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimTopologyEntryFlag>`
                        
                        .. attribute:: group_ranges
                        
                        	No. of (\*,G/M) routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: active_group_ranges
                        
                        	No. of (\*,G/M) routes active in mrib
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: groute_count
                        
                        	No. of (\*,G) routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sg_route_count
                        
                        	No. of (S,G) routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sgr_route_count
                        
                        	No. of (S,G)RPT routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_node_low_memory
                        
                        	Is node in low memory condition
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount, self).__init__()

                            self.yang_name = "topology-entry-flag-route-count"
                            self.yang_parent_name = "topology-entry-flag-route-counts"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['entry_flag']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('entry_flag', (YLeaf(YType.enumeration, 'entry-flag'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimTopologyEntryFlag', '')])),
                                ('group_ranges', (YLeaf(YType.uint32, 'group-ranges'), ['int'])),
                                ('active_group_ranges', (YLeaf(YType.uint32, 'active-group-ranges'), ['int'])),
                                ('groute_count', (YLeaf(YType.uint32, 'groute-count'), ['int'])),
                                ('sg_route_count', (YLeaf(YType.uint32, 'sg-route-count'), ['int'])),
                                ('sgr_route_count', (YLeaf(YType.uint32, 'sgr-route-count'), ['int'])),
                                ('is_node_low_memory', (YLeaf(YType.boolean, 'is-node-low-memory'), ['bool'])),
                            ])
                            self.entry_flag = None
                            self.group_ranges = None
                            self.active_group_ranges = None
                            self.groute_count = None
                            self.sg_route_count = None
                            self.sgr_route_count = None
                            self.is_node_low_memory = None
                            self._segment_path = lambda: "topology-entry-flag-route-count" + "[entry-flag='" + str(self.entry_flag) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount, ['entry_flag', 'group_ranges', 'active_group_ranges', 'groute_count', 'sg_route_count', 'sgr_route_count', 'is_node_low_memory'], name, value)


                class RpfRedirect(Entity):
                    """
                    PIM ECMP RPF\-redirect bundle
                    
                    .. attribute:: redirect_route_databases
                    
                    	PIM ECMP RPF\-redirect route database
                    	**type**\:  :py:class:`RedirectRouteDatabases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases>`
                    
                    .. attribute:: bundle_interfaces
                    
                    	PIM ECMP RPF\-redirect bundle information
                    	**type**\:  :py:class:`BundleInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.RpfRedirect, self).__init__()

                        self.yang_name = "rpf-redirect"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("redirect-route-databases", ("redirect_route_databases", Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases)), ("bundle-interfaces", ("bundle_interfaces", Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces))])
                        self._leafs = OrderedDict()

                        self.redirect_route_databases = Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases()
                        self.redirect_route_databases.parent = self
                        self._children_name_map["redirect_route_databases"] = "redirect-route-databases"

                        self.bundle_interfaces = Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces()
                        self.bundle_interfaces.parent = self
                        self._children_name_map["bundle_interfaces"] = "bundle-interfaces"
                        self._segment_path = lambda: "rpf-redirect"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.RpfRedirect, [], name, value)


                    class RedirectRouteDatabases(Entity):
                        """
                        PIM ECMP RPF\-redirect route database
                        
                        .. attribute:: redirect_route_database
                        
                        	PIM ECMP RPF\-redirect route information
                        	**type**\: list of  		 :py:class:`RedirectRouteDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases, self).__init__()

                            self.yang_name = "redirect-route-databases"
                            self.yang_parent_name = "rpf-redirect"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("redirect-route-database", ("redirect_route_database", Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase))])
                            self._leafs = OrderedDict()

                            self.redirect_route_database = YList(self)
                            self._segment_path = lambda: "redirect-route-databases"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases, [], name, value)


                        class RedirectRouteDatabase(Entity):
                            """
                            PIM ECMP RPF\-redirect route information
                            
                            .. attribute:: source_address
                            
                            	Source address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: group_address
                            
                            	Group address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: group_address_xr
                            
                            	Group ddress
                            	**type**\:  :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr>`
                            
                            .. attribute:: source_address_xr
                            
                            	Source address
                            	**type**\:  :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr>`
                            
                            .. attribute:: bandwidth
                            
                            	Bandwidth in Kbps
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: interface
                            
                            	Outgoing interface list
                            	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase, self).__init__()

                                self.yang_name = "redirect-route-database"
                                self.yang_parent_name = "redirect-route-databases"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("group-address-xr", ("group_address_xr", Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr)), ("source-address-xr", ("source_address_xr", Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr)), ("interface", ("interface", Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface))])
                                self._leafs = OrderedDict([
                                    ('source_address', (YLeaf(YType.str, 'source-address'), ['str','str'])),
                                    ('group_address', (YLeaf(YType.str, 'group-address'), ['str','str'])),
                                    ('bandwidth', (YLeaf(YType.uint32, 'bandwidth'), ['int'])),
                                    ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                                ])
                                self.source_address = None
                                self.group_address = None
                                self.bandwidth = None
                                self.uptime = None

                                self.group_address_xr = Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"

                                self.source_address_xr = Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr()
                                self.source_address_xr.parent = self
                                self._children_name_map["source_address_xr"] = "source-address-xr"

                                self.interface = YList(self)
                                self._segment_path = lambda: "redirect-route-database"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase, ['source_address', 'group_address', 'bandwidth', 'uptime'], name, value)


                            class GroupAddressXr(Entity):
                                """
                                Group ddress
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr, self).__init__()

                                    self.yang_name = "group-address-xr"
                                    self.yang_parent_name = "redirect-route-database"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "group-address-xr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                            class SourceAddressXr(Entity):
                                """
                                Source address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr, self).__init__()

                                    self.yang_name = "source-address-xr"
                                    self.yang_parent_name = "redirect-route-database"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "source-address-xr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                            class Interface(Entity):
                                """
                                Outgoing interface list
                                
                                .. attribute:: rpf_address
                                
                                	RPF Address
                                	**type**\:  :py:class:`RpfAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress>`
                                
                                .. attribute:: interface_name
                                
                                	Interface name
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                .. attribute:: uptime
                                
                                	Uptime in seconds
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: second
                                
                                .. attribute:: expiry
                                
                                	Expiry in seconds
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: second
                                
                                .. attribute:: is_rpf_interface
                                
                                	Is RPF Interface
                                	**type**\: bool
                                
                                .. attribute:: is_outgoing_interface
                                
                                	Is outgoing Interface
                                	**type**\: bool
                                
                                .. attribute:: is_snoop_interface
                                
                                	Is snooping Interface
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface, self).__init__()

                                    self.yang_name = "interface"
                                    self.yang_parent_name = "redirect-route-database"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("rpf-address", ("rpf_address", Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress))])
                                    self._leafs = OrderedDict([
                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                        ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                                        ('expiry', (YLeaf(YType.uint64, 'expiry'), ['int'])),
                                        ('is_rpf_interface', (YLeaf(YType.boolean, 'is-rpf-interface'), ['bool'])),
                                        ('is_outgoing_interface', (YLeaf(YType.boolean, 'is-outgoing-interface'), ['bool'])),
                                        ('is_snoop_interface', (YLeaf(YType.boolean, 'is-snoop-interface'), ['bool'])),
                                    ])
                                    self.interface_name = None
                                    self.uptime = None
                                    self.expiry = None
                                    self.is_rpf_interface = None
                                    self.is_outgoing_interface = None
                                    self.is_snoop_interface = None

                                    self.rpf_address = Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress()
                                    self.rpf_address.parent = self
                                    self._children_name_map["rpf_address"] = "rpf-address"
                                    self._segment_path = lambda: "interface"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface, ['interface_name', 'uptime', 'expiry', 'is_rpf_interface', 'is_outgoing_interface', 'is_snoop_interface'], name, value)


                                class RpfAddress(Entity):
                                    """
                                    RPF Address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress, self).__init__()

                                        self.yang_name = "rpf-address"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ])
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None
                                        self._segment_path = lambda: "rpf-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class BundleInterfaces(Entity):
                        """
                        PIM ECMP RPF\-redirect bundle information
                        
                        .. attribute:: bundle_interface
                        
                        	PIM ECMP RPF\-redirect bundle interface information
                        	**type**\: list of  		 :py:class:`BundleInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces.BundleInterface>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces, self).__init__()

                            self.yang_name = "bundle-interfaces"
                            self.yang_parent_name = "rpf-redirect"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("bundle-interface", ("bundle_interface", Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces.BundleInterface))])
                            self._leafs = OrderedDict()

                            self.bundle_interface = YList(self)
                            self._segment_path = lambda: "bundle-interfaces"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces, [], name, value)


                        class BundleInterface(Entity):
                            """
                            PIM ECMP RPF\-redirect bundle interface
                            information
                            
                            .. attribute:: bundle_name
                            
                            	Bundle name
                            	**type**\: str
                            
                            	**length:** 1..32
                            
                            .. attribute:: interface_name
                            
                            	Bundle interface name
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: rpf_redirect_bundle_name
                            
                            	RPF redirect bundle name
                            	**type**\: str
                            
                            	**length:** 0..33
                            
                            .. attribute:: rpf_redirect_interface_name
                            
                            	RPF redirect interface name
                            	**type**\: str
                            
                            	**length:** 0..33
                            
                            .. attribute:: available_bandwidth
                            
                            	Bandwidth available in Kbps
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: allocated_bandwidth
                            
                            	Bandwidth allocated in Kbps
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: total_bandwidth
                            
                            	Total bandwidth used in Kbps
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: topology_bandwidth_used
                            
                            	Bandwidth used by topology in Kbps
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: snooping_bandwidth_used
                            
                            	Bandwidth used by snooped entries in Kbps
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: allocated_threshold_bandwidth
                            
                            	Configured threshold in Kbps
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: available_threshold_bandwidth
                            
                            	Available threshold in Kbps
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces.BundleInterface, self).__init__()

                                self.yang_name = "bundle-interface"
                                self.yang_parent_name = "bundle-interfaces"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('bundle_name', (YLeaf(YType.str, 'bundle-name'), ['str'])),
                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                    ('rpf_redirect_bundle_name', (YLeaf(YType.str, 'rpf-redirect-bundle-name'), ['str'])),
                                    ('rpf_redirect_interface_name', (YLeaf(YType.str, 'rpf-redirect-interface-name'), ['str'])),
                                    ('available_bandwidth', (YLeaf(YType.int32, 'available-bandwidth'), ['int'])),
                                    ('allocated_bandwidth', (YLeaf(YType.int32, 'allocated-bandwidth'), ['int'])),
                                    ('total_bandwidth', (YLeaf(YType.int32, 'total-bandwidth'), ['int'])),
                                    ('topology_bandwidth_used', (YLeaf(YType.int32, 'topology-bandwidth-used'), ['int'])),
                                    ('snooping_bandwidth_used', (YLeaf(YType.int32, 'snooping-bandwidth-used'), ['int'])),
                                    ('allocated_threshold_bandwidth', (YLeaf(YType.int32, 'allocated-threshold-bandwidth'), ['int'])),
                                    ('available_threshold_bandwidth', (YLeaf(YType.int32, 'available-threshold-bandwidth'), ['int'])),
                                ])
                                self.bundle_name = None
                                self.interface_name = None
                                self.rpf_redirect_bundle_name = None
                                self.rpf_redirect_interface_name = None
                                self.available_bandwidth = None
                                self.allocated_bandwidth = None
                                self.total_bandwidth = None
                                self.topology_bandwidth_used = None
                                self.snooping_bandwidth_used = None
                                self.allocated_threshold_bandwidth = None
                                self.available_threshold_bandwidth = None
                                self._segment_path = lambda: "bundle-interface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces.BundleInterface, ['bundle_name', 'interface_name', 'rpf_redirect_bundle_name', 'rpf_redirect_interface_name', 'available_bandwidth', 'allocated_bandwidth', 'total_bandwidth', 'topology_bandwidth_used', 'snooping_bandwidth_used', 'allocated_threshold_bandwidth', 'available_threshold_bandwidth'], name, value)


                class Tunnels(Entity):
                    """
                    Tunnels information that PIM has
                    
                    .. attribute:: tunnel
                    
                    	PIM tunnel information
                    	**type**\: list of  		 :py:class:`Tunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.Tunnels, self).__init__()

                        self.yang_name = "tunnels"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("tunnel", ("tunnel", Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel))])
                        self._leafs = OrderedDict()

                        self.tunnel = YList(self)
                        self._segment_path = lambda: "tunnels"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.Tunnels, [], name, value)


                    class Tunnel(Entity):
                        """
                        PIM tunnel information
                        
                        .. attribute:: tunnel_name  (key)
                        
                        	Tunnel name
                        	**type**\: str
                        
                        	**length:** 1..64
                        
                        .. attribute:: source_address
                        
                        	Source addr known to PIM
                        	**type**\:  :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress>`
                        
                        .. attribute:: rp_address
                        
                        	RP addr known to PIM
                        	**type**\:  :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.RpAddress>`
                        
                        .. attribute:: source_address_netio
                        
                        	Source addr from netio
                        	**type**\:  :py:class:`SourceAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio>`
                        
                        .. attribute:: group_address_netio
                        
                        	Group addr from netio
                        	**type**\:  :py:class:`GroupAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio>`
                        
                        .. attribute:: vrf_name
                        
                        	VRF Name
                        	**type**\: str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel, self).__init__()

                            self.yang_name = "tunnel"
                            self.yang_parent_name = "tunnels"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['tunnel_name']
                            self._child_classes = OrderedDict([("source-address", ("source_address", Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress)), ("rp-address", ("rp_address", Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.RpAddress)), ("source-address-netio", ("source_address_netio", Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio)), ("group-address-netio", ("group_address_netio", Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio))])
                            self._leafs = OrderedDict([
                                ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                            ])
                            self.tunnel_name = None
                            self.vrf_name = None

                            self.source_address = Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"

                            self.rp_address = Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"

                            self.source_address_netio = Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio()
                            self.source_address_netio.parent = self
                            self._children_name_map["source_address_netio"] = "source-address-netio"

                            self.group_address_netio = Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio()
                            self.group_address_netio.parent = self
                            self._children_name_map["group_address_netio"] = "group-address-netio"
                            self._segment_path = lambda: "tunnel" + "[tunnel-name='" + str(self.tunnel_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel, ['tunnel_name', 'vrf_name'], name, value)


                        class SourceAddress(Entity):
                            """
                            Source addr known to PIM
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "source-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class RpAddress(Entity):
                            """
                            RP addr known to PIM
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "rp-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.RpAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class SourceAddressNetio(Entity):
                            """
                            Source addr from netio
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio, self).__init__()

                                self.yang_name = "source-address-netio"
                                self.yang_parent_name = "tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "source-address-netio"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class GroupAddressNetio(Entity):
                            """
                            Group addr from netio
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio, self).__init__()

                                self.yang_name = "group-address-netio"
                                self.yang_parent_name = "tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "group-address-netio"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class MulticastStaticRoutes(Entity):
                    """
                    PIM multicast static route table
                    
                    .. attribute:: multicast_static_route
                    
                    	PIM multicast static route information
                    	**type**\: list of  		 :py:class:`MulticastStaticRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes, self).__init__()

                        self.yang_name = "multicast-static-routes"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("multicast-static-route", ("multicast_static_route", Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute))])
                        self._leafs = OrderedDict()

                        self.multicast_static_route = YList(self)
                        self._segment_path = lambda: "multicast-static-routes"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes, [], name, value)


                    class MulticastStaticRoute(Entity):
                        """
                        PIM multicast static route information
                        
                        .. attribute:: address
                        
                        	Network address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: prefix
                        
                        	Prefix
                        	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix>`
                        
                        .. attribute:: nexthop
                        
                        	Next Hop
                        	**type**\:  :py:class:`Nexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop>`
                        
                        .. attribute:: interface_name
                        
                        	Interface Handle
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: distance
                        
                        	Distance
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: prefix_length_xr
                        
                        	Prefix Length
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: is_via_lsm
                        
                        	LSM flag
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute, self).__init__()

                            self.yang_name = "multicast-static-route"
                            self.yang_parent_name = "multicast-static-routes"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("prefix", ("prefix", Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix)), ("nexthop", ("nexthop", Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop))])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str','str'])),
                                ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ('distance', (YLeaf(YType.uint32, 'distance'), ['int'])),
                                ('prefix_length_xr', (YLeaf(YType.uint8, 'prefix-length-xr'), ['int'])),
                                ('is_via_lsm', (YLeaf(YType.boolean, 'is-via-lsm'), ['bool'])),
                            ])
                            self.address = None
                            self.prefix_length = None
                            self.interface_name = None
                            self.distance = None
                            self.prefix_length_xr = None
                            self.is_via_lsm = None

                            self.prefix = Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"

                            self.nexthop = Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop()
                            self.nexthop.parent = self
                            self._children_name_map["nexthop"] = "nexthop"
                            self._segment_path = lambda: "multicast-static-route"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute, ['address', 'prefix_length', 'interface_name', 'distance', 'prefix_length_xr', 'is_via_lsm'], name, value)


                        class Prefix(Entity):
                            """
                            Prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "multicast-static-route"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "prefix"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class Nexthop(Entity):
                            """
                            Next Hop
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop, self).__init__()

                                self.yang_name = "nexthop"
                                self.yang_parent_name = "multicast-static-route"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "nexthop"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class Neighbors(Entity):
                    """
                    PIM neighbor table
                    
                    .. attribute:: neighbor
                    
                    	PIM neighbor information
                    	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Neighbors.Neighbor>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.Neighbors, self).__init__()

                        self.yang_name = "neighbors"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("neighbor", ("neighbor", Pim.Standby.Vrfs.Vrf.Neighbors.Neighbor))])
                        self._leafs = OrderedDict()

                        self.neighbor = YList(self)
                        self._segment_path = lambda: "neighbors"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Standby.Vrfs.Vrf.Neighbors, [], name, value)


                    class Neighbor(Entity):
                        """
                        PIM neighbor information
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: neighbor_address
                        
                        	Neighbor address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identifier
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: expires
                        
                        	Neighbor expiry in seconds
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: expiry_timer
                        
                        	Expiry timer in seconds
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: is_this_neighbor_us
                        
                        	Is this neighbor us ?
                        	**type**\: bool
                        
                        .. attribute:: is_this_neighbor_dr
                        
                        	Is this neighbor the DR
                        	**type**\: bool
                        
                        .. attribute:: is_dr_priority_capable
                        
                        	Is this neighbor DR priority capable ?
                        	**type**\: bool
                        
                        .. attribute:: dr_priority
                        
                        	DR priority
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Is this neighbor bidir capable ?
                        	**type**\: bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Is this neighbor proxy capable?
                        	**type**\: bool
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Is this neighbor capable of batching asserts?
                        	**type**\: bool
                        
                        .. attribute:: is_ecmp_redirect_capable
                        
                        	Is this neighbor capable of Ecmp Redirect?
                        	**type**\: bool
                        
                        .. attribute:: is_bfd_state
                        
                        	Is the neighbor bfd session created
                        	**type**\: bool
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_address_xr
                        
                        	List of Neighbor Addresses
                        	**type**\: list of  		 :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Neighbors.Neighbor.NeighborAddressXr>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.Neighbors.Neighbor, self).__init__()

                            self.yang_name = "neighbor"
                            self.yang_parent_name = "neighbors"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("neighbor-address-xr", ("neighbor_address_xr", Pim.Standby.Vrfs.Vrf.Neighbors.Neighbor.NeighborAddressXr))])
                            self._leafs = OrderedDict([
                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                                ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                                ('expires', (YLeaf(YType.uint64, 'expires'), ['int'])),
                                ('expiry_timer', (YLeaf(YType.uint64, 'expiry-timer'), ['int'])),
                                ('is_this_neighbor_us', (YLeaf(YType.boolean, 'is-this-neighbor-us'), ['bool'])),
                                ('is_this_neighbor_dr', (YLeaf(YType.boolean, 'is-this-neighbor-dr'), ['bool'])),
                                ('is_dr_priority_capable', (YLeaf(YType.boolean, 'is-dr-priority-capable'), ['bool'])),
                                ('dr_priority', (YLeaf(YType.uint32, 'dr-priority'), ['int'])),
                                ('is_bidirectional_capable', (YLeaf(YType.boolean, 'is-bidirectional-capable'), ['bool'])),
                                ('is_proxy_capable', (YLeaf(YType.boolean, 'is-proxy-capable'), ['bool'])),
                                ('is_batch_asserts_capable', (YLeaf(YType.boolean, 'is-batch-asserts-capable'), ['bool'])),
                                ('is_ecmp_redirect_capable', (YLeaf(YType.boolean, 'is-ecmp-redirect-capable'), ['bool'])),
                                ('is_bfd_state', (YLeaf(YType.boolean, 'is-bfd-state'), ['bool'])),
                                ('propagation_delay', (YLeaf(YType.uint16, 'propagation-delay'), ['int'])),
                                ('override_interval', (YLeaf(YType.uint16, 'override-interval'), ['int'])),
                            ])
                            self.interface_name = None
                            self.neighbor_address = None
                            self.interface_name_xr = None
                            self.uptime = None
                            self.expires = None
                            self.expiry_timer = None
                            self.is_this_neighbor_us = None
                            self.is_this_neighbor_dr = None
                            self.is_dr_priority_capable = None
                            self.dr_priority = None
                            self.is_bidirectional_capable = None
                            self.is_proxy_capable = None
                            self.is_batch_asserts_capable = None
                            self.is_ecmp_redirect_capable = None
                            self.is_bfd_state = None
                            self.propagation_delay = None
                            self.override_interval = None

                            self.neighbor_address_xr = YList(self)
                            self._segment_path = lambda: "neighbor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Standby.Vrfs.Vrf.Neighbors.Neighbor, ['interface_name', 'neighbor_address', 'interface_name_xr', 'uptime', 'expires', 'expiry_timer', 'is_this_neighbor_us', 'is_this_neighbor_dr', 'is_dr_priority_capable', 'dr_priority', 'is_bidirectional_capable', 'is_proxy_capable', 'is_batch_asserts_capable', 'is_ecmp_redirect_capable', 'is_bfd_state', 'propagation_delay', 'override_interval'], name, value)


                        class NeighborAddressXr(Entity):
                            """
                            List of Neighbor Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Neighbors.Neighbor.NeighborAddressXr, self).__init__()

                                self.yang_name = "neighbor-address-xr"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "neighbor-address-xr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Standby.Vrfs.Vrf.Neighbors.Neighbor.NeighborAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


    class Active(Entity):
        """
        Active Process
        
        .. attribute:: default_context
        
        	Default Context
        	**type**\:  :py:class:`DefaultContext <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext>`
        
        .. attribute:: process
        
        	Process
        	**type**\:  :py:class:`Process <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Process>`
        
        .. attribute:: vrfs
        
        	VRF Table
        	**type**\:  :py:class:`Vrfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs>`
        
        

        """

        _prefix = 'ipv4-pim-oper'
        _revision = '2017-09-07'

        def __init__(self):
            super(Pim.Active, self).__init__()

            self.yang_name = "active"
            self.yang_parent_name = "pim"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("default-context", ("default_context", Pim.Active.DefaultContext)), ("process", ("process", Pim.Active.Process)), ("vrfs", ("vrfs", Pim.Active.Vrfs))])
            self._leafs = OrderedDict()

            self.default_context = Pim.Active.DefaultContext()
            self.default_context.parent = self
            self._children_name_map["default_context"] = "default-context"

            self.process = Pim.Active.Process()
            self.process.parent = self
            self._children_name_map["process"] = "process"

            self.vrfs = Pim.Active.Vrfs()
            self.vrfs.parent = self
            self._children_name_map["vrfs"] = "vrfs"
            self._segment_path = lambda: "active"
            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Pim.Active, [], name, value)


        class DefaultContext(Entity):
            """
            Default Context
            
            .. attribute:: global_interfaces
            
            	PIM global interface table
            	**type**\:  :py:class:`GlobalInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GlobalInterfaces>`
            
            .. attribute:: ifrs_interfaces
            
            	PIM interfaces in forward reference store table
            	**type**\:  :py:class:`IfrsInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.IfrsInterfaces>`
            
            .. attribute:: safs
            
            	SAFI table and type
            	**type**\:  :py:class:`Safs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Safs>`
            
            .. attribute:: interface_statistics
            
            	PIM interface statistics
            	**type**\:  :py:class:`InterfaceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.InterfaceStatistics>`
            
            .. attribute:: topology_route_count
            
            	Topology route count information from PIM topology table
            	**type**\:  :py:class:`TopologyRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.TopologyRouteCount>`
            
            .. attribute:: jp_statistics
            
            	PIM join prune statistics table
            	**type**\:  :py:class:`JpStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.JpStatistics>`
            
            .. attribute:: mib_databases
            
            	PIM group database for mroute mibs table
            	**type**\:  :py:class:`MibDatabases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.MibDatabases>`
            
            .. attribute:: neighbor_old_formats
            
            	PIM neighbor table old format
            	**type**\:  :py:class:`NeighborOldFormats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.NeighborOldFormats>`
            
            .. attribute:: ifrs_summary
            
            	PIM interfaces in forward reference store summary
            	**type**\:  :py:class:`IfrsSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.IfrsSummary>`
            
            .. attribute:: ranges
            
            	PIM range list information
            	**type**\:  :py:class:`Ranges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Ranges>`
            
            .. attribute:: interface_old_formats
            
            	PIM interfaces in old format
            	**type**\:  :py:class:`InterfaceOldFormats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.InterfaceOldFormats>`
            
            .. attribute:: bsr
            
            	PIM BSR information
            	**type**\:  :py:class:`Bsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Bsr>`
            
            .. attribute:: route_policy
            
            	PIM route policy
            	**type**\:  :py:class:`RoutePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.RoutePolicy>`
            
            .. attribute:: rpf_summary
            
            	PIM RPF registration summary
            	**type**\:  :py:class:`RpfSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.RpfSummary>`
            
            .. attribute:: interfaces
            
            	PIM interfaces
            	**type**\:  :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Interfaces>`
            
            .. attribute:: net_io_tunnels
            
            	Tunnel information that NETIO has 
            	**type**\:  :py:class:`NetIoTunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.NetIoTunnels>`
            
            .. attribute:: bidir_df_states
            
            	Bidirectional PIM DF election state table
            	**type**\:  :py:class:`BidirDfStates <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.BidirDfStates>`
            
            .. attribute:: topologies
            
            	PIM topology table
            	**type**\:  :py:class:`Topologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Topologies>`
            
            .. attribute:: bgp_afs
            
            	PIM BGP SAFI table
            	**type**\:  :py:class:`BgpAfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.BgpAfs>`
            
            .. attribute:: auto_rp
            
            	PIM Auto\-RP information
            	**type**\:  :py:class:`AutoRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.AutoRp>`
            
            .. attribute:: topology_interface_flag_route_counts
            
            	Route count for topology with interface flag set
            	**type**\:  :py:class:`TopologyInterfaceFlagRouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts>`
            
            .. attribute:: group_map_sources
            
            	PIM group\-mapping with source information
            	**type**\:  :py:class:`GroupMapSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapSources>`
            
            .. attribute:: traffic_counters
            
            	PIM message traffic counters
            	**type**\:  :py:class:`TrafficCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.TrafficCounters>`
            
            .. attribute:: group_map_rpfs
            
            	PIM group mapping information
            	**type**\:  :py:class:`GroupMapRpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapRpfs>`
            
            .. attribute:: summary
            
            	PIM summary
            	**type**\:  :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Summary>`
            
            .. attribute:: gre
            
            	GRE information
            	**type**\:  :py:class:`Gre <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Gre>`
            
            .. attribute:: bidir_df_winners
            
            	Bidirectional PIM DF election winner table
            	**type**\:  :py:class:`BidirDfWinners <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.BidirDfWinners>`
            
            .. attribute:: table_contexts
            
            	PIM table context list
            	**type**\:  :py:class:`TableContexts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.TableContexts>`
            
            .. attribute:: neighbor_summaries
            
            	PIM neighbor summary table
            	**type**\:  :py:class:`NeighborSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.NeighborSummaries>`
            
            .. attribute:: context
            
            	PIM context information
            	**type**\:  :py:class:`Context <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Context>`
            
            .. attribute:: topology_entry_flag_route_counts
            
            	Route count for topology with entry flag set
            	**type**\:  :py:class:`TopologyEntryFlagRouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts>`
            
            .. attribute:: rpf_redirect
            
            	PIM ECMP RPF\-redirect bundle
            	**type**\:  :py:class:`RpfRedirect <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.RpfRedirect>`
            
            .. attribute:: tunnels
            
            	Tunnels information that PIM has
            	**type**\:  :py:class:`Tunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Tunnels>`
            
            .. attribute:: multicast_static_routes
            
            	PIM multicast static route table
            	**type**\:  :py:class:`MulticastStaticRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.MulticastStaticRoutes>`
            
            .. attribute:: neighbors
            
            	PIM neighbor table
            	**type**\:  :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Neighbors>`
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(Pim.Active.DefaultContext, self).__init__()

                self.yang_name = "default-context"
                self.yang_parent_name = "active"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("global-interfaces", ("global_interfaces", Pim.Active.DefaultContext.GlobalInterfaces)), ("ifrs-interfaces", ("ifrs_interfaces", Pim.Active.DefaultContext.IfrsInterfaces)), ("safs", ("safs", Pim.Active.DefaultContext.Safs)), ("interface-statistics", ("interface_statistics", Pim.Active.DefaultContext.InterfaceStatistics)), ("topology-route-count", ("topology_route_count", Pim.Active.DefaultContext.TopologyRouteCount)), ("jp-statistics", ("jp_statistics", Pim.Active.DefaultContext.JpStatistics)), ("mib-databases", ("mib_databases", Pim.Active.DefaultContext.MibDatabases)), ("neighbor-old-formats", ("neighbor_old_formats", Pim.Active.DefaultContext.NeighborOldFormats)), ("ifrs-summary", ("ifrs_summary", Pim.Active.DefaultContext.IfrsSummary)), ("ranges", ("ranges", Pim.Active.DefaultContext.Ranges)), ("interface-old-formats", ("interface_old_formats", Pim.Active.DefaultContext.InterfaceOldFormats)), ("bsr", ("bsr", Pim.Active.DefaultContext.Bsr)), ("route-policy", ("route_policy", Pim.Active.DefaultContext.RoutePolicy)), ("rpf-summary", ("rpf_summary", Pim.Active.DefaultContext.RpfSummary)), ("interfaces", ("interfaces", Pim.Active.DefaultContext.Interfaces)), ("net-io-tunnels", ("net_io_tunnels", Pim.Active.DefaultContext.NetIoTunnels)), ("bidir-df-states", ("bidir_df_states", Pim.Active.DefaultContext.BidirDfStates)), ("topologies", ("topologies", Pim.Active.DefaultContext.Topologies)), ("bgp-afs", ("bgp_afs", Pim.Active.DefaultContext.BgpAfs)), ("auto-rp", ("auto_rp", Pim.Active.DefaultContext.AutoRp)), ("topology-interface-flag-route-counts", ("topology_interface_flag_route_counts", Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts)), ("group-map-sources", ("group_map_sources", Pim.Active.DefaultContext.GroupMapSources)), ("traffic-counters", ("traffic_counters", Pim.Active.DefaultContext.TrafficCounters)), ("group-map-rpfs", ("group_map_rpfs", Pim.Active.DefaultContext.GroupMapRpfs)), ("summary", ("summary", Pim.Active.DefaultContext.Summary)), ("gre", ("gre", Pim.Active.DefaultContext.Gre)), ("bidir-df-winners", ("bidir_df_winners", Pim.Active.DefaultContext.BidirDfWinners)), ("table-contexts", ("table_contexts", Pim.Active.DefaultContext.TableContexts)), ("neighbor-summaries", ("neighbor_summaries", Pim.Active.DefaultContext.NeighborSummaries)), ("context", ("context", Pim.Active.DefaultContext.Context)), ("topology-entry-flag-route-counts", ("topology_entry_flag_route_counts", Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts)), ("rpf-redirect", ("rpf_redirect", Pim.Active.DefaultContext.RpfRedirect)), ("tunnels", ("tunnels", Pim.Active.DefaultContext.Tunnels)), ("multicast-static-routes", ("multicast_static_routes", Pim.Active.DefaultContext.MulticastStaticRoutes)), ("neighbors", ("neighbors", Pim.Active.DefaultContext.Neighbors))])
                self._leafs = OrderedDict()

                self.global_interfaces = Pim.Active.DefaultContext.GlobalInterfaces()
                self.global_interfaces.parent = self
                self._children_name_map["global_interfaces"] = "global-interfaces"

                self.ifrs_interfaces = Pim.Active.DefaultContext.IfrsInterfaces()
                self.ifrs_interfaces.parent = self
                self._children_name_map["ifrs_interfaces"] = "ifrs-interfaces"

                self.safs = Pim.Active.DefaultContext.Safs()
                self.safs.parent = self
                self._children_name_map["safs"] = "safs"

                self.interface_statistics = Pim.Active.DefaultContext.InterfaceStatistics()
                self.interface_statistics.parent = self
                self._children_name_map["interface_statistics"] = "interface-statistics"

                self.topology_route_count = Pim.Active.DefaultContext.TopologyRouteCount()
                self.topology_route_count.parent = self
                self._children_name_map["topology_route_count"] = "topology-route-count"

                self.jp_statistics = Pim.Active.DefaultContext.JpStatistics()
                self.jp_statistics.parent = self
                self._children_name_map["jp_statistics"] = "jp-statistics"

                self.mib_databases = Pim.Active.DefaultContext.MibDatabases()
                self.mib_databases.parent = self
                self._children_name_map["mib_databases"] = "mib-databases"

                self.neighbor_old_formats = Pim.Active.DefaultContext.NeighborOldFormats()
                self.neighbor_old_formats.parent = self
                self._children_name_map["neighbor_old_formats"] = "neighbor-old-formats"

                self.ifrs_summary = Pim.Active.DefaultContext.IfrsSummary()
                self.ifrs_summary.parent = self
                self._children_name_map["ifrs_summary"] = "ifrs-summary"

                self.ranges = Pim.Active.DefaultContext.Ranges()
                self.ranges.parent = self
                self._children_name_map["ranges"] = "ranges"

                self.interface_old_formats = Pim.Active.DefaultContext.InterfaceOldFormats()
                self.interface_old_formats.parent = self
                self._children_name_map["interface_old_formats"] = "interface-old-formats"

                self.bsr = Pim.Active.DefaultContext.Bsr()
                self.bsr.parent = self
                self._children_name_map["bsr"] = "bsr"

                self.route_policy = Pim.Active.DefaultContext.RoutePolicy()
                self.route_policy.parent = self
                self._children_name_map["route_policy"] = "route-policy"

                self.rpf_summary = Pim.Active.DefaultContext.RpfSummary()
                self.rpf_summary.parent = self
                self._children_name_map["rpf_summary"] = "rpf-summary"

                self.interfaces = Pim.Active.DefaultContext.Interfaces()
                self.interfaces.parent = self
                self._children_name_map["interfaces"] = "interfaces"

                self.net_io_tunnels = Pim.Active.DefaultContext.NetIoTunnels()
                self.net_io_tunnels.parent = self
                self._children_name_map["net_io_tunnels"] = "net-io-tunnels"

                self.bidir_df_states = Pim.Active.DefaultContext.BidirDfStates()
                self.bidir_df_states.parent = self
                self._children_name_map["bidir_df_states"] = "bidir-df-states"

                self.topologies = Pim.Active.DefaultContext.Topologies()
                self.topologies.parent = self
                self._children_name_map["topologies"] = "topologies"

                self.bgp_afs = Pim.Active.DefaultContext.BgpAfs()
                self.bgp_afs.parent = self
                self._children_name_map["bgp_afs"] = "bgp-afs"

                self.auto_rp = Pim.Active.DefaultContext.AutoRp()
                self.auto_rp.parent = self
                self._children_name_map["auto_rp"] = "auto-rp"

                self.topology_interface_flag_route_counts = Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts()
                self.topology_interface_flag_route_counts.parent = self
                self._children_name_map["topology_interface_flag_route_counts"] = "topology-interface-flag-route-counts"

                self.group_map_sources = Pim.Active.DefaultContext.GroupMapSources()
                self.group_map_sources.parent = self
                self._children_name_map["group_map_sources"] = "group-map-sources"

                self.traffic_counters = Pim.Active.DefaultContext.TrafficCounters()
                self.traffic_counters.parent = self
                self._children_name_map["traffic_counters"] = "traffic-counters"

                self.group_map_rpfs = Pim.Active.DefaultContext.GroupMapRpfs()
                self.group_map_rpfs.parent = self
                self._children_name_map["group_map_rpfs"] = "group-map-rpfs"

                self.summary = Pim.Active.DefaultContext.Summary()
                self.summary.parent = self
                self._children_name_map["summary"] = "summary"

                self.gre = Pim.Active.DefaultContext.Gre()
                self.gre.parent = self
                self._children_name_map["gre"] = "gre"

                self.bidir_df_winners = Pim.Active.DefaultContext.BidirDfWinners()
                self.bidir_df_winners.parent = self
                self._children_name_map["bidir_df_winners"] = "bidir-df-winners"

                self.table_contexts = Pim.Active.DefaultContext.TableContexts()
                self.table_contexts.parent = self
                self._children_name_map["table_contexts"] = "table-contexts"

                self.neighbor_summaries = Pim.Active.DefaultContext.NeighborSummaries()
                self.neighbor_summaries.parent = self
                self._children_name_map["neighbor_summaries"] = "neighbor-summaries"

                self.context = Pim.Active.DefaultContext.Context()
                self.context.parent = self
                self._children_name_map["context"] = "context"

                self.topology_entry_flag_route_counts = Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts()
                self.topology_entry_flag_route_counts.parent = self
                self._children_name_map["topology_entry_flag_route_counts"] = "topology-entry-flag-route-counts"

                self.rpf_redirect = Pim.Active.DefaultContext.RpfRedirect()
                self.rpf_redirect.parent = self
                self._children_name_map["rpf_redirect"] = "rpf-redirect"

                self.tunnels = Pim.Active.DefaultContext.Tunnels()
                self.tunnels.parent = self
                self._children_name_map["tunnels"] = "tunnels"

                self.multicast_static_routes = Pim.Active.DefaultContext.MulticastStaticRoutes()
                self.multicast_static_routes.parent = self
                self._children_name_map["multicast_static_routes"] = "multicast-static-routes"

                self.neighbors = Pim.Active.DefaultContext.Neighbors()
                self.neighbors.parent = self
                self._children_name_map["neighbors"] = "neighbors"
                self._segment_path = lambda: "default-context"
                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Pim.Active.DefaultContext, [], name, value)


            class GlobalInterfaces(Entity):
                """
                PIM global interface table
                
                .. attribute:: global_interface
                
                	PIM interface name
                	**type**\: list of  		 :py:class:`GlobalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Active.DefaultContext.GlobalInterfaces, self).__init__()

                    self.yang_name = "global-interfaces"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("global-interface", ("global_interface", Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface))])
                    self._leafs = OrderedDict()

                    self.global_interface = YList(self)
                    self._segment_path = lambda: "global-interfaces"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.DefaultContext.GlobalInterfaces, [], name, value)


                class GlobalInterface(Entity):
                    """
                    PIM interface name
                    
                    .. attribute:: interface_name  (key)
                    
                    	Interface name
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: dr_address
                    
                    	PIM Designated Router
                    	**type**\:  :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress>`
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identfier
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: interface_address_mask
                    
                    	Interface IP Address Mask
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: is_enabled
                    
                    	Is PIM enabled on this IF ?
                    	**type**\: bool
                    
                    .. attribute:: neighbor_count
                    
                    	No. of neighbors on this IF
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: external_neighbor_count
                    
                    	No. of external neighbors on this IF
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: hello_interval
                    
                    	Hello Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dr_priority
                    
                    	DR Priority
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_expiry
                    
                    	Hello Timer Expiry
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: are_we_dr
                    
                    	Are we the DR on this IF ?
                    	**type**\: bool
                    
                    .. attribute:: bfd_enabled
                    
                    	BFD state
                    	**type**\: bool
                    
                    .. attribute:: bfd_interval
                    
                    	BFD Interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bfd_multiplier
                    
                    	BFD Multiplier
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_interface
                    
                    	 is this a Virtual Interfaces ?
                    	**type**\: bool
                    
                    .. attribute:: passive_interface
                    
                    	Passive PIM interface
                    	**type**\: bool
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\: str
                    
                    .. attribute:: join_prune_interval
                    
                    	Join\-Prune Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: prune_delay_enabled
                    
                    	Prune Delay Enabled
                    	**type**\: bool
                    
                    .. attribute:: configured_propagation_delay
                    
                    	Configured Propagation Delay
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_override_interval
                    
                    	Configured Override Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: generation_id
                    
                    	Generation Identifier
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Bidir Capable
                    	**type**\: bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Proxy Capable
                    	**type**\: bool
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Batch Asserts Capable
                    	**type**\: bool
                    
                    .. attribute:: idb_oor_enabled
                    
                    	Interface oor enabled
                    	**type**\: bool
                    
                    .. attribute:: idb_acl_provided
                    
                    	ACL name provided
                    	**type**\: bool
                    
                    .. attribute:: idb_max_count
                    
                    	Interface ole max count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_threshold_count
                    
                    	Interface ole threshold count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_current_count
                    
                    	Interface ole current count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_acl_name
                    
                    	Interface ole ACL Name
                    	**type**\: str
                    
                    	**length:** 0..64
                    
                    .. attribute:: interface_address
                    
                    	List of Interface IP Addresses
                    	**type**\: list of  		 :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.InterfaceAddress>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface, self).__init__()

                        self.yang_name = "global-interface"
                        self.yang_parent_name = "global-interfaces"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['interface_name']
                        self._child_classes = OrderedDict([("dr-address", ("dr_address", Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress)), ("interface-address", ("interface_address", Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.InterfaceAddress))])
                        self._leafs = OrderedDict([
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                            ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                            ('interface_address_mask', (YLeaf(YType.uint8, 'interface-address-mask'), ['int'])),
                            ('is_enabled', (YLeaf(YType.boolean, 'is-enabled'), ['bool'])),
                            ('neighbor_count', (YLeaf(YType.uint16, 'neighbor-count'), ['int'])),
                            ('external_neighbor_count', (YLeaf(YType.uint16, 'external-neighbor-count'), ['int'])),
                            ('hello_interval', (YLeaf(YType.uint16, 'hello-interval'), ['int'])),
                            ('dr_priority', (YLeaf(YType.uint32, 'dr-priority'), ['int'])),
                            ('hello_expiry', (YLeaf(YType.uint64, 'hello-expiry'), ['int'])),
                            ('are_we_dr', (YLeaf(YType.boolean, 'are-we-dr'), ['bool'])),
                            ('bfd_enabled', (YLeaf(YType.boolean, 'bfd-enabled'), ['bool'])),
                            ('bfd_interval', (YLeaf(YType.uint32, 'bfd-interval'), ['int'])),
                            ('bfd_multiplier', (YLeaf(YType.uint32, 'bfd-multiplier'), ['int'])),
                            ('virtual_interface', (YLeaf(YType.boolean, 'virtual-interface'), ['bool'])),
                            ('passive_interface', (YLeaf(YType.boolean, 'passive-interface'), ['bool'])),
                            ('neighbor_filter_name', (YLeaf(YType.str, 'neighbor-filter-name'), ['str'])),
                            ('join_prune_interval', (YLeaf(YType.uint16, 'join-prune-interval'), ['int'])),
                            ('prune_delay_enabled', (YLeaf(YType.boolean, 'prune-delay-enabled'), ['bool'])),
                            ('configured_propagation_delay', (YLeaf(YType.uint16, 'configured-propagation-delay'), ['int'])),
                            ('propagation_delay', (YLeaf(YType.uint16, 'propagation-delay'), ['int'])),
                            ('configured_override_interval', (YLeaf(YType.uint16, 'configured-override-interval'), ['int'])),
                            ('override_interval', (YLeaf(YType.uint16, 'override-interval'), ['int'])),
                            ('generation_id', (YLeaf(YType.uint32, 'generation-id'), ['int'])),
                            ('is_bidirectional_capable', (YLeaf(YType.boolean, 'is-bidirectional-capable'), ['bool'])),
                            ('is_proxy_capable', (YLeaf(YType.boolean, 'is-proxy-capable'), ['bool'])),
                            ('is_batch_asserts_capable', (YLeaf(YType.boolean, 'is-batch-asserts-capable'), ['bool'])),
                            ('idb_oor_enabled', (YLeaf(YType.boolean, 'idb-oor-enabled'), ['bool'])),
                            ('idb_acl_provided', (YLeaf(YType.boolean, 'idb-acl-provided'), ['bool'])),
                            ('idb_max_count', (YLeaf(YType.uint32, 'idb-max-count'), ['int'])),
                            ('idb_threshold_count', (YLeaf(YType.uint32, 'idb-threshold-count'), ['int'])),
                            ('idb_current_count', (YLeaf(YType.uint32, 'idb-current-count'), ['int'])),
                            ('idb_acl_name', (YLeaf(YType.str, 'idb-acl-name'), ['str'])),
                        ])
                        self.interface_name = None
                        self.interface_name_xr = None
                        self.interface_address_mask = None
                        self.is_enabled = None
                        self.neighbor_count = None
                        self.external_neighbor_count = None
                        self.hello_interval = None
                        self.dr_priority = None
                        self.hello_expiry = None
                        self.are_we_dr = None
                        self.bfd_enabled = None
                        self.bfd_interval = None
                        self.bfd_multiplier = None
                        self.virtual_interface = None
                        self.passive_interface = None
                        self.neighbor_filter_name = None
                        self.join_prune_interval = None
                        self.prune_delay_enabled = None
                        self.configured_propagation_delay = None
                        self.propagation_delay = None
                        self.configured_override_interval = None
                        self.override_interval = None
                        self.generation_id = None
                        self.is_bidirectional_capable = None
                        self.is_proxy_capable = None
                        self.is_batch_asserts_capable = None
                        self.idb_oor_enabled = None
                        self.idb_acl_provided = None
                        self.idb_max_count = None
                        self.idb_threshold_count = None
                        self.idb_current_count = None
                        self.idb_acl_name = None

                        self.dr_address = Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress()
                        self.dr_address.parent = self
                        self._children_name_map["dr_address"] = "dr-address"

                        self.interface_address = YList(self)
                        self._segment_path = lambda: "global-interface" + "[interface-name='" + str(self.interface_name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/global-interfaces/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface, ['interface_name', 'interface_name_xr', 'interface_address_mask', 'is_enabled', 'neighbor_count', 'external_neighbor_count', 'hello_interval', 'dr_priority', 'hello_expiry', 'are_we_dr', 'bfd_enabled', 'bfd_interval', 'bfd_multiplier', 'virtual_interface', 'passive_interface', 'neighbor_filter_name', 'join_prune_interval', 'prune_delay_enabled', 'configured_propagation_delay', 'propagation_delay', 'configured_override_interval', 'override_interval', 'generation_id', 'is_bidirectional_capable', 'is_proxy_capable', 'is_batch_asserts_capable', 'idb_oor_enabled', 'idb_acl_provided', 'idb_max_count', 'idb_threshold_count', 'idb_current_count', 'idb_acl_name'], name, value)


                    class DrAddress(Entity):
                        """
                        PIM Designated Router
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress, self).__init__()

                            self.yang_name = "dr-address"
                            self.yang_parent_name = "global-interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "dr-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class InterfaceAddress(Entity):
                        """
                        List of Interface IP Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.InterfaceAddress, self).__init__()

                            self.yang_name = "interface-address"
                            self.yang_parent_name = "global-interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "interface-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.InterfaceAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class IfrsInterfaces(Entity):
                """
                PIM interfaces in forward reference store table
                
                .. attribute:: ifrs_interface
                
                	PIM IFRS interface information
                	**type**\: list of  		 :py:class:`IfrsInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Active.DefaultContext.IfrsInterfaces, self).__init__()

                    self.yang_name = "ifrs-interfaces"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ifrs-interface", ("ifrs_interface", Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface))])
                    self._leafs = OrderedDict()

                    self.ifrs_interface = YList(self)
                    self._segment_path = lambda: "ifrs-interfaces"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.DefaultContext.IfrsInterfaces, [], name, value)


                class IfrsInterface(Entity):
                    """
                    PIM IFRS interface information
                    
                    .. attribute:: interface_name  (key)
                    
                    	Interface name
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: dr_address
                    
                    	PIM Designated Router
                    	**type**\:  :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress>`
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identfier
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: interface_address_mask
                    
                    	Interface IP Address Mask
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: is_enabled
                    
                    	Is PIM enabled on this IF ?
                    	**type**\: bool
                    
                    .. attribute:: neighbor_count
                    
                    	No. of neighbors on this IF
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: external_neighbor_count
                    
                    	No. of external neighbors on this IF
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: hello_interval
                    
                    	Hello Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dr_priority
                    
                    	DR Priority
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_expiry
                    
                    	Hello Timer Expiry
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: are_we_dr
                    
                    	Are we the DR on this IF ?
                    	**type**\: bool
                    
                    .. attribute:: bfd_enabled
                    
                    	BFD state
                    	**type**\: bool
                    
                    .. attribute:: bfd_interval
                    
                    	BFD Interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bfd_multiplier
                    
                    	BFD Multiplier
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_interface
                    
                    	 is this a Virtual Interfaces ?
                    	**type**\: bool
                    
                    .. attribute:: passive_interface
                    
                    	Passive PIM interface
                    	**type**\: bool
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\: str
                    
                    .. attribute:: join_prune_interval
                    
                    	Join\-Prune Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: prune_delay_enabled
                    
                    	Prune Delay Enabled
                    	**type**\: bool
                    
                    .. attribute:: configured_propagation_delay
                    
                    	Configured Propagation Delay
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_override_interval
                    
                    	Configured Override Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: generation_id
                    
                    	Generation Identifier
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Bidir Capable
                    	**type**\: bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Proxy Capable
                    	**type**\: bool
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Batch Asserts Capable
                    	**type**\: bool
                    
                    .. attribute:: idb_oor_enabled
                    
                    	Interface oor enabled
                    	**type**\: bool
                    
                    .. attribute:: idb_acl_provided
                    
                    	ACL name provided
                    	**type**\: bool
                    
                    .. attribute:: idb_max_count
                    
                    	Interface ole max count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_threshold_count
                    
                    	Interface ole threshold count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_current_count
                    
                    	Interface ole current count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_acl_name
                    
                    	Interface ole ACL Name
                    	**type**\: str
                    
                    	**length:** 0..64
                    
                    .. attribute:: interface_address
                    
                    	List of Interface IP Addresses
                    	**type**\: list of  		 :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.InterfaceAddress>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface, self).__init__()

                        self.yang_name = "ifrs-interface"
                        self.yang_parent_name = "ifrs-interfaces"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['interface_name']
                        self._child_classes = OrderedDict([("dr-address", ("dr_address", Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress)), ("interface-address", ("interface_address", Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.InterfaceAddress))])
                        self._leafs = OrderedDict([
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                            ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                            ('interface_address_mask', (YLeaf(YType.uint8, 'interface-address-mask'), ['int'])),
                            ('is_enabled', (YLeaf(YType.boolean, 'is-enabled'), ['bool'])),
                            ('neighbor_count', (YLeaf(YType.uint16, 'neighbor-count'), ['int'])),
                            ('external_neighbor_count', (YLeaf(YType.uint16, 'external-neighbor-count'), ['int'])),
                            ('hello_interval', (YLeaf(YType.uint16, 'hello-interval'), ['int'])),
                            ('dr_priority', (YLeaf(YType.uint32, 'dr-priority'), ['int'])),
                            ('hello_expiry', (YLeaf(YType.uint64, 'hello-expiry'), ['int'])),
                            ('are_we_dr', (YLeaf(YType.boolean, 'are-we-dr'), ['bool'])),
                            ('bfd_enabled', (YLeaf(YType.boolean, 'bfd-enabled'), ['bool'])),
                            ('bfd_interval', (YLeaf(YType.uint32, 'bfd-interval'), ['int'])),
                            ('bfd_multiplier', (YLeaf(YType.uint32, 'bfd-multiplier'), ['int'])),
                            ('virtual_interface', (YLeaf(YType.boolean, 'virtual-interface'), ['bool'])),
                            ('passive_interface', (YLeaf(YType.boolean, 'passive-interface'), ['bool'])),
                            ('neighbor_filter_name', (YLeaf(YType.str, 'neighbor-filter-name'), ['str'])),
                            ('join_prune_interval', (YLeaf(YType.uint16, 'join-prune-interval'), ['int'])),
                            ('prune_delay_enabled', (YLeaf(YType.boolean, 'prune-delay-enabled'), ['bool'])),
                            ('configured_propagation_delay', (YLeaf(YType.uint16, 'configured-propagation-delay'), ['int'])),
                            ('propagation_delay', (YLeaf(YType.uint16, 'propagation-delay'), ['int'])),
                            ('configured_override_interval', (YLeaf(YType.uint16, 'configured-override-interval'), ['int'])),
                            ('override_interval', (YLeaf(YType.uint16, 'override-interval'), ['int'])),
                            ('generation_id', (YLeaf(YType.uint32, 'generation-id'), ['int'])),
                            ('is_bidirectional_capable', (YLeaf(YType.boolean, 'is-bidirectional-capable'), ['bool'])),
                            ('is_proxy_capable', (YLeaf(YType.boolean, 'is-proxy-capable'), ['bool'])),
                            ('is_batch_asserts_capable', (YLeaf(YType.boolean, 'is-batch-asserts-capable'), ['bool'])),
                            ('idb_oor_enabled', (YLeaf(YType.boolean, 'idb-oor-enabled'), ['bool'])),
                            ('idb_acl_provided', (YLeaf(YType.boolean, 'idb-acl-provided'), ['bool'])),
                            ('idb_max_count', (YLeaf(YType.uint32, 'idb-max-count'), ['int'])),
                            ('idb_threshold_count', (YLeaf(YType.uint32, 'idb-threshold-count'), ['int'])),
                            ('idb_current_count', (YLeaf(YType.uint32, 'idb-current-count'), ['int'])),
                            ('idb_acl_name', (YLeaf(YType.str, 'idb-acl-name'), ['str'])),
                        ])
                        self.interface_name = None
                        self.interface_name_xr = None
                        self.interface_address_mask = None
                        self.is_enabled = None
                        self.neighbor_count = None
                        self.external_neighbor_count = None
                        self.hello_interval = None
                        self.dr_priority = None
                        self.hello_expiry = None
                        self.are_we_dr = None
                        self.bfd_enabled = None
                        self.bfd_interval = None
                        self.bfd_multiplier = None
                        self.virtual_interface = None
                        self.passive_interface = None
                        self.neighbor_filter_name = None
                        self.join_prune_interval = None
                        self.prune_delay_enabled = None
                        self.configured_propagation_delay = None
                        self.propagation_delay = None
                        self.configured_override_interval = None
                        self.override_interval = None
                        self.generation_id = None
                        self.is_bidirectional_capable = None
                        self.is_proxy_capable = None
                        self.is_batch_asserts_capable = None
                        self.idb_oor_enabled = None
                        self.idb_acl_provided = None
                        self.idb_max_count = None
                        self.idb_threshold_count = None
                        self.idb_current_count = None
                        self.idb_acl_name = None

                        self.dr_address = Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress()
                        self.dr_address.parent = self
                        self._children_name_map["dr_address"] = "dr-address"

                        self.interface_address = YList(self)
                        self._segment_path = lambda: "ifrs-interface" + "[interface-name='" + str(self.interface_name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/ifrs-interfaces/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface, ['interface_name', 'interface_name_xr', 'interface_address_mask', 'is_enabled', 'neighbor_count', 'external_neighbor_count', 'hello_interval', 'dr_priority', 'hello_expiry', 'are_we_dr', 'bfd_enabled', 'bfd_interval', 'bfd_multiplier', 'virtual_interface', 'passive_interface', 'neighbor_filter_name', 'join_prune_interval', 'prune_delay_enabled', 'configured_propagation_delay', 'propagation_delay', 'configured_override_interval', 'override_interval', 'generation_id', 'is_bidirectional_capable', 'is_proxy_capable', 'is_batch_asserts_capable', 'idb_oor_enabled', 'idb_acl_provided', 'idb_max_count', 'idb_threshold_count', 'idb_current_count', 'idb_acl_name'], name, value)


                    class DrAddress(Entity):
                        """
                        PIM Designated Router
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress, self).__init__()

                            self.yang_name = "dr-address"
                            self.yang_parent_name = "ifrs-interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "dr-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class InterfaceAddress(Entity):
                        """
                        List of Interface IP Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.InterfaceAddress, self).__init__()

                            self.yang_name = "interface-address"
                            self.yang_parent_name = "ifrs-interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "interface-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.InterfaceAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class Safs(Entity):
                """
                SAFI table and type
                
                .. attribute:: saf
                
                	SAF name 
                	**type**\: list of  		 :py:class:`Saf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Safs.Saf>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Active.DefaultContext.Safs, self).__init__()

                    self.yang_name = "safs"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("saf", ("saf", Pim.Active.DefaultContext.Safs.Saf))])
                    self._leafs = OrderedDict()

                    self.saf = YList(self)
                    self._segment_path = lambda: "safs"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.DefaultContext.Safs, [], name, value)


                class Saf(Entity):
                    """
                    SAF name 
                    
                    .. attribute:: rpf_hash_source_groups
                    
                    	PIM RPF multipath hash outcome
                    	**type**\:  :py:class:`RpfHashSourceGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups>`
                    
                    .. attribute:: rpf_hash_sources
                    
                    	PIM RPF multipath hash outcome
                    	**type**\:  :py:class:`RpfHashSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Safs.Saf.RpfHashSources>`
                    
                    .. attribute:: rpfs
                    
                    	PIM RPF information table
                    	**type**\:  :py:class:`Rpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Safs.Saf.Rpfs>`
                    
                    .. attribute:: saf_name
                    
                    	SAF name 
                    	**type**\:  :py:class:`PimSafi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimSafi>`
                    
                    .. attribute:: topology_name
                    
                    	Topology name 
                    	**type**\: str
                    
                    	**length:** 1..32
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.Safs.Saf, self).__init__()

                        self.yang_name = "saf"
                        self.yang_parent_name = "safs"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("rpf-hash-source-groups", ("rpf_hash_source_groups", Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups)), ("rpf-hash-sources", ("rpf_hash_sources", Pim.Active.DefaultContext.Safs.Saf.RpfHashSources)), ("rpfs", ("rpfs", Pim.Active.DefaultContext.Safs.Saf.Rpfs))])
                        self._leafs = OrderedDict([
                            ('saf_name', (YLeaf(YType.enumeration, 'saf-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimSafi', '')])),
                            ('topology_name', (YLeaf(YType.str, 'topology-name'), ['str'])),
                        ])
                        self.saf_name = None
                        self.topology_name = None

                        self.rpf_hash_source_groups = Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups()
                        self.rpf_hash_source_groups.parent = self
                        self._children_name_map["rpf_hash_source_groups"] = "rpf-hash-source-groups"

                        self.rpf_hash_sources = Pim.Active.DefaultContext.Safs.Saf.RpfHashSources()
                        self.rpf_hash_sources.parent = self
                        self._children_name_map["rpf_hash_sources"] = "rpf-hash-sources"

                        self.rpfs = Pim.Active.DefaultContext.Safs.Saf.Rpfs()
                        self.rpfs.parent = self
                        self._children_name_map["rpfs"] = "rpfs"
                        self._segment_path = lambda: "saf"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/safs/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.Safs.Saf, ['saf_name', 'topology_name'], name, value)


                    class RpfHashSourceGroups(Entity):
                        """
                        PIM RPF multipath hash outcome
                        
                        .. attribute:: rpf_hash_source_group
                        
                        	PIM RPF hash outcome for S,G
                        	**type**\: list of  		 :py:class:`RpfHashSourceGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups, self).__init__()

                            self.yang_name = "rpf-hash-source-groups"
                            self.yang_parent_name = "saf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rpf-hash-source-group", ("rpf_hash_source_group", Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup))])
                            self._leafs = OrderedDict()

                            self.rpf_hash_source_group = YList(self)
                            self._segment_path = lambda: "rpf-hash-source-groups"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/safs/saf/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups, [], name, value)


                        class RpfHashSourceGroup(Entity):
                            """
                            PIM RPF hash outcome for S,G
                            
                            .. attribute:: source_address
                            
                            	Source address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: group_address
                            
                            	Group address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: mask_length
                            
                            	Hash mask length
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mofrr
                            
                            	MOFRR
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: next_hop_address
                            
                            	Next hop neighbor address
                            	**type**\:  :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress>`
                            
                            .. attribute:: secondary_next_hop_address
                            
                            	Secondary Next hop neighbor address
                            	**type**\:  :py:class:`SecondaryNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress>`
                            
                            .. attribute:: next_hop_multipath_enabled
                            
                            	Next hop multipath enabled?
                            	**type**\: bool
                            
                            .. attribute:: next_hop_interface
                            
                            	Next hop neighbor interface
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: secondary_next_hop_interface
                            
                            	Secondary Next hop neighbor interface
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup, self).__init__()

                                self.yang_name = "rpf-hash-source-group"
                                self.yang_parent_name = "rpf-hash-source-groups"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("next-hop-address", ("next_hop_address", Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress)), ("secondary-next-hop-address", ("secondary_next_hop_address", Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress))])
                                self._leafs = OrderedDict([
                                    ('source_address', (YLeaf(YType.str, 'source-address'), ['str','str'])),
                                    ('group_address', (YLeaf(YType.str, 'group-address'), ['str','str'])),
                                    ('mask_length', (YLeaf(YType.uint32, 'mask-length'), ['int'])),
                                    ('mofrr', (YLeaf(YType.uint32, 'mofrr'), ['int'])),
                                    ('next_hop_multipath_enabled', (YLeaf(YType.boolean, 'next-hop-multipath-enabled'), ['bool'])),
                                    ('next_hop_interface', (YLeaf(YType.str, 'next-hop-interface'), ['str'])),
                                    ('secondary_next_hop_interface', (YLeaf(YType.str, 'secondary-next-hop-interface'), ['str'])),
                                ])
                                self.source_address = None
                                self.group_address = None
                                self.mask_length = None
                                self.mofrr = None
                                self.next_hop_multipath_enabled = None
                                self.next_hop_interface = None
                                self.secondary_next_hop_interface = None

                                self.next_hop_address = Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress()
                                self.next_hop_address.parent = self
                                self._children_name_map["next_hop_address"] = "next-hop-address"

                                self.secondary_next_hop_address = Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress()
                                self.secondary_next_hop_address.parent = self
                                self._children_name_map["secondary_next_hop_address"] = "secondary-next-hop-address"
                                self._segment_path = lambda: "rpf-hash-source-group"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/safs/saf/rpf-hash-source-groups/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup, ['source_address', 'group_address', 'mask_length', 'mofrr', 'next_hop_multipath_enabled', 'next_hop_interface', 'secondary_next_hop_interface'], name, value)


                            class NextHopAddress(Entity):
                                """
                                Next hop neighbor address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress, self).__init__()

                                    self.yang_name = "next-hop-address"
                                    self.yang_parent_name = "rpf-hash-source-group"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "next-hop-address"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/safs/saf/rpf-hash-source-groups/rpf-hash-source-group/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                            class SecondaryNextHopAddress(Entity):
                                """
                                Secondary Next hop neighbor address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress, self).__init__()

                                    self.yang_name = "secondary-next-hop-address"
                                    self.yang_parent_name = "rpf-hash-source-group"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "secondary-next-hop-address"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/safs/saf/rpf-hash-source-groups/rpf-hash-source-group/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class RpfHashSources(Entity):
                        """
                        PIM RPF multipath hash outcome
                        
                        .. attribute:: rpf_hash_source
                        
                        	PIM RPF hash outcome for S,G
                        	**type**\: list of  		 :py:class:`RpfHashSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Safs.Saf.RpfHashSources, self).__init__()

                            self.yang_name = "rpf-hash-sources"
                            self.yang_parent_name = "saf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rpf-hash-source", ("rpf_hash_source", Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource))])
                            self._leafs = OrderedDict()

                            self.rpf_hash_source = YList(self)
                            self._segment_path = lambda: "rpf-hash-sources"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/safs/saf/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.Safs.Saf.RpfHashSources, [], name, value)


                        class RpfHashSource(Entity):
                            """
                            PIM RPF hash outcome for S,G
                            
                            .. attribute:: source_address
                            
                            	Source address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: mofrr
                            
                            	MOFRR
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: next_hop_address
                            
                            	Next hop neighbor address
                            	**type**\:  :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress>`
                            
                            .. attribute:: secondary_next_hop_address
                            
                            	Secondary Next hop neighbor address
                            	**type**\:  :py:class:`SecondaryNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress>`
                            
                            .. attribute:: next_hop_multipath_enabled
                            
                            	Next hop multipath enabled?
                            	**type**\: bool
                            
                            .. attribute:: next_hop_interface
                            
                            	Next hop neighbor interface
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: secondary_next_hop_interface
                            
                            	Secondary Next hop neighbor interface
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource, self).__init__()

                                self.yang_name = "rpf-hash-source"
                                self.yang_parent_name = "rpf-hash-sources"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("next-hop-address", ("next_hop_address", Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress)), ("secondary-next-hop-address", ("secondary_next_hop_address", Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress))])
                                self._leafs = OrderedDict([
                                    ('source_address', (YLeaf(YType.str, 'source-address'), ['str','str'])),
                                    ('mofrr', (YLeaf(YType.uint32, 'mofrr'), ['int'])),
                                    ('next_hop_multipath_enabled', (YLeaf(YType.boolean, 'next-hop-multipath-enabled'), ['bool'])),
                                    ('next_hop_interface', (YLeaf(YType.str, 'next-hop-interface'), ['str'])),
                                    ('secondary_next_hop_interface', (YLeaf(YType.str, 'secondary-next-hop-interface'), ['str'])),
                                ])
                                self.source_address = None
                                self.mofrr = None
                                self.next_hop_multipath_enabled = None
                                self.next_hop_interface = None
                                self.secondary_next_hop_interface = None

                                self.next_hop_address = Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress()
                                self.next_hop_address.parent = self
                                self._children_name_map["next_hop_address"] = "next-hop-address"

                                self.secondary_next_hop_address = Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress()
                                self.secondary_next_hop_address.parent = self
                                self._children_name_map["secondary_next_hop_address"] = "secondary-next-hop-address"
                                self._segment_path = lambda: "rpf-hash-source"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/safs/saf/rpf-hash-sources/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource, ['source_address', 'mofrr', 'next_hop_multipath_enabled', 'next_hop_interface', 'secondary_next_hop_interface'], name, value)


                            class NextHopAddress(Entity):
                                """
                                Next hop neighbor address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress, self).__init__()

                                    self.yang_name = "next-hop-address"
                                    self.yang_parent_name = "rpf-hash-source"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "next-hop-address"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/safs/saf/rpf-hash-sources/rpf-hash-source/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                            class SecondaryNextHopAddress(Entity):
                                """
                                Secondary Next hop neighbor address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress, self).__init__()

                                    self.yang_name = "secondary-next-hop-address"
                                    self.yang_parent_name = "rpf-hash-source"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "secondary-next-hop-address"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/safs/saf/rpf-hash-sources/rpf-hash-source/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class Rpfs(Entity):
                        """
                        PIM RPF information table
                        
                        .. attribute:: rpf
                        
                        	PIM RPF information
                        	**type**\: list of  		 :py:class:`Rpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Safs.Saf.Rpfs, self).__init__()

                            self.yang_name = "rpfs"
                            self.yang_parent_name = "saf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rpf", ("rpf", Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf))])
                            self._leafs = OrderedDict()

                            self.rpf = YList(self)
                            self._segment_path = lambda: "rpfs"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/safs/saf/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.Safs.Saf.Rpfs, [], name, value)


                        class Rpf(Entity):
                            """
                            PIM RPF information
                            
                            .. attribute:: registered_address  (key)
                            
                            	Address for which RPF lookup
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: registered_address_xr
                            
                            	Address registered
                            	**type**\:  :py:class:`RegisteredAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr>`
                            
                            .. attribute:: metric
                            
                            	Metric
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_preference
                            
                            	Metric preference
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_connected
                            
                            	Are we connected ?
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: is_rpf_bgp_route
                            
                            	Is RPF through BGP route
                            	**type**\: bool
                            
                            .. attribute:: rpf_path
                            
                            	RPF Paths list
                            	**type**\: list of  		 :py:class:`RpfPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf, self).__init__()

                                self.yang_name = "rpf"
                                self.yang_parent_name = "rpfs"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['registered_address']
                                self._child_classes = OrderedDict([("registered-address-xr", ("registered_address_xr", Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr)), ("rpf-path", ("rpf_path", Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath))])
                                self._leafs = OrderedDict([
                                    ('registered_address', (YLeaf(YType.str, 'registered-address'), ['str','str'])),
                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                    ('metric_preference', (YLeaf(YType.uint32, 'metric-preference'), ['int'])),
                                    ('is_connected', (YLeaf(YType.uint8, 'is-connected'), ['int'])),
                                    ('is_rpf_bgp_route', (YLeaf(YType.boolean, 'is-rpf-bgp-route'), ['bool'])),
                                ])
                                self.registered_address = None
                                self.metric = None
                                self.metric_preference = None
                                self.is_connected = None
                                self.is_rpf_bgp_route = None

                                self.registered_address_xr = Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr()
                                self.registered_address_xr.parent = self
                                self._children_name_map["registered_address_xr"] = "registered-address-xr"

                                self.rpf_path = YList(self)
                                self._segment_path = lambda: "rpf" + "[registered-address='" + str(self.registered_address) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/safs/saf/rpfs/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf, ['registered_address', 'metric', 'metric_preference', 'is_connected', 'is_rpf_bgp_route'], name, value)


                            class RegisteredAddressXr(Entity):
                                """
                                Address registered
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr, self).__init__()

                                    self.yang_name = "registered-address-xr"
                                    self.yang_parent_name = "rpf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "registered-address-xr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                            class RpfPath(Entity):
                                """
                                RPF Paths list
                                
                                .. attribute:: rpf_neighbor
                                
                                	RPF neighbor
                                	**type**\:  :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor>`
                                
                                .. attribute:: rpf_nexthop
                                
                                	RPF nexthop
                                	**type**\:  :py:class:`RpfNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop>`
                                
                                .. attribute:: rpf_interface_name
                                
                                	RPF Interface
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                .. attribute:: is_rpf_interface_disabled
                                
                                	Is the rpf interface disabled ?
                                	**type**\: bool
                                
                                .. attribute:: is_via_lsm
                                
                                	Via LSM
                                	**type**\: bool
                                
                                .. attribute:: is_via_mlsm
                                
                                	Via Mstatic LSM
                                	**type**\: bool
                                
                                .. attribute:: is_connector_attribute_present
                                
                                	Connector attribute present
                                	**type**\: bool
                                
                                .. attribute:: connector
                                
                                	Connector Attribute
                                	**type**\: str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                .. attribute:: extranet_vrf_name
                                
                                	Extranet VRF name
                                	**type**\: str
                                
                                	**length:** 0..33
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath, self).__init__()

                                    self.yang_name = "rpf-path"
                                    self.yang_parent_name = "rpf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("rpf-neighbor", ("rpf_neighbor", Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor)), ("rpf-nexthop", ("rpf_nexthop", Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop))])
                                    self._leafs = OrderedDict([
                                        ('rpf_interface_name', (YLeaf(YType.str, 'rpf-interface-name'), ['str'])),
                                        ('is_rpf_interface_disabled', (YLeaf(YType.boolean, 'is-rpf-interface-disabled'), ['bool'])),
                                        ('is_via_lsm', (YLeaf(YType.boolean, 'is-via-lsm'), ['bool'])),
                                        ('is_via_mlsm', (YLeaf(YType.boolean, 'is-via-mlsm'), ['bool'])),
                                        ('is_connector_attribute_present', (YLeaf(YType.boolean, 'is-connector-attribute-present'), ['bool'])),
                                        ('connector', (YLeaf(YType.str, 'connector'), ['str'])),
                                        ('extranet_vrf_name', (YLeaf(YType.str, 'extranet-vrf-name'), ['str'])),
                                    ])
                                    self.rpf_interface_name = None
                                    self.is_rpf_interface_disabled = None
                                    self.is_via_lsm = None
                                    self.is_via_mlsm = None
                                    self.is_connector_attribute_present = None
                                    self.connector = None
                                    self.extranet_vrf_name = None

                                    self.rpf_neighbor = Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor()
                                    self.rpf_neighbor.parent = self
                                    self._children_name_map["rpf_neighbor"] = "rpf-neighbor"

                                    self.rpf_nexthop = Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop()
                                    self.rpf_nexthop.parent = self
                                    self._children_name_map["rpf_nexthop"] = "rpf-nexthop"
                                    self._segment_path = lambda: "rpf-path"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath, ['rpf_interface_name', 'is_rpf_interface_disabled', 'is_via_lsm', 'is_via_mlsm', 'is_connector_attribute_present', 'connector', 'extranet_vrf_name'], name, value)


                                class RpfNeighbor(Entity):
                                    """
                                    RPF neighbor
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor, self).__init__()

                                        self.yang_name = "rpf-neighbor"
                                        self.yang_parent_name = "rpf-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ])
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None
                                        self._segment_path = lambda: "rpf-neighbor"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                                class RpfNexthop(Entity):
                                    """
                                    RPF nexthop
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop, self).__init__()

                                        self.yang_name = "rpf-nexthop"
                                        self.yang_parent_name = "rpf-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ])
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None
                                        self._segment_path = lambda: "rpf-nexthop"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class InterfaceStatistics(Entity):
                """
                PIM interface statistics
                
                .. attribute:: interface_statistic
                
                	PIM interface statistics
                	**type**\: list of  		 :py:class:`InterfaceStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.InterfaceStatistics.InterfaceStatistic>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Active.DefaultContext.InterfaceStatistics, self).__init__()

                    self.yang_name = "interface-statistics"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("interface-statistic", ("interface_statistic", Pim.Active.DefaultContext.InterfaceStatistics.InterfaceStatistic))])
                    self._leafs = OrderedDict()

                    self.interface_statistic = YList(self)
                    self._segment_path = lambda: "interface-statistics"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.DefaultContext.InterfaceStatistics, [], name, value)


                class InterfaceStatistic(Entity):
                    """
                    PIM interface statistics
                    
                    .. attribute:: interface_name  (key)
                    
                    	Interface name
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: input_hello
                    
                    	Hello packets in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_hello
                    
                    	Hello packets out
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_register
                    
                    	Register packets in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_register
                    
                    	Register packets out
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_register_stop
                    
                    	Register Stop packets in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_register_stop
                    
                    	Register Stop packets out
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_jp
                    
                    	Join Prune packets in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_jp
                    
                    	Join Prune packets out
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_bsr_message
                    
                    	Input BSR Messages
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_bsr_message
                    
                    	Output BSR Messages
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_assert
                    
                    	Assert packets in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_assert
                    
                    	Assert packets out
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_graft_message
                    
                    	Input Graft Messages
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_graft_message
                    
                    	Output Graft Messages
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_graft_ack_message
                    
                    	Input Graft Ack Messages
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_graft_ack_message
                    
                    	Output Graft Ack Messages
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_candidate_rp_advertisement
                    
                    	Input Candidate\-RP Advertisment
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_candidate_rp_advertisement
                    
                    	Output Candidate\-RP Advertisment
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_df_election
                    
                    	DF Election packets in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_df_election
                    
                    	DF Election packets out
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_miscellaneous
                    
                    	Miscellaneous packet in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.InterfaceStatistics.InterfaceStatistic, self).__init__()

                        self.yang_name = "interface-statistic"
                        self.yang_parent_name = "interface-statistics"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['interface_name']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                            ('input_hello', (YLeaf(YType.uint32, 'input-hello'), ['int'])),
                            ('output_hello', (YLeaf(YType.uint32, 'output-hello'), ['int'])),
                            ('input_register', (YLeaf(YType.uint32, 'input-register'), ['int'])),
                            ('output_register', (YLeaf(YType.uint32, 'output-register'), ['int'])),
                            ('input_register_stop', (YLeaf(YType.uint32, 'input-register-stop'), ['int'])),
                            ('output_register_stop', (YLeaf(YType.uint32, 'output-register-stop'), ['int'])),
                            ('input_jp', (YLeaf(YType.uint32, 'input-jp'), ['int'])),
                            ('output_jp', (YLeaf(YType.uint32, 'output-jp'), ['int'])),
                            ('input_bsr_message', (YLeaf(YType.uint32, 'input-bsr-message'), ['int'])),
                            ('output_bsr_message', (YLeaf(YType.uint32, 'output-bsr-message'), ['int'])),
                            ('input_assert', (YLeaf(YType.uint32, 'input-assert'), ['int'])),
                            ('output_assert', (YLeaf(YType.uint32, 'output-assert'), ['int'])),
                            ('input_graft_message', (YLeaf(YType.uint32, 'input-graft-message'), ['int'])),
                            ('output_graft_message', (YLeaf(YType.uint32, 'output-graft-message'), ['int'])),
                            ('input_graft_ack_message', (YLeaf(YType.uint32, 'input-graft-ack-message'), ['int'])),
                            ('output_graft_ack_message', (YLeaf(YType.uint32, 'output-graft-ack-message'), ['int'])),
                            ('input_candidate_rp_advertisement', (YLeaf(YType.uint32, 'input-candidate-rp-advertisement'), ['int'])),
                            ('output_candidate_rp_advertisement', (YLeaf(YType.uint32, 'output-candidate-rp-advertisement'), ['int'])),
                            ('input_df_election', (YLeaf(YType.uint32, 'input-df-election'), ['int'])),
                            ('output_df_election', (YLeaf(YType.uint32, 'output-df-election'), ['int'])),
                            ('input_miscellaneous', (YLeaf(YType.uint32, 'input-miscellaneous'), ['int'])),
                        ])
                        self.interface_name = None
                        self.input_hello = None
                        self.output_hello = None
                        self.input_register = None
                        self.output_register = None
                        self.input_register_stop = None
                        self.output_register_stop = None
                        self.input_jp = None
                        self.output_jp = None
                        self.input_bsr_message = None
                        self.output_bsr_message = None
                        self.input_assert = None
                        self.output_assert = None
                        self.input_graft_message = None
                        self.output_graft_message = None
                        self.input_graft_ack_message = None
                        self.output_graft_ack_message = None
                        self.input_candidate_rp_advertisement = None
                        self.output_candidate_rp_advertisement = None
                        self.input_df_election = None
                        self.output_df_election = None
                        self.input_miscellaneous = None
                        self._segment_path = lambda: "interface-statistic" + "[interface-name='" + str(self.interface_name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/interface-statistics/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.InterfaceStatistics.InterfaceStatistic, ['interface_name', 'input_hello', 'output_hello', 'input_register', 'output_register', 'input_register_stop', 'output_register_stop', 'input_jp', 'output_jp', 'input_bsr_message', 'output_bsr_message', 'input_assert', 'output_assert', 'input_graft_message', 'output_graft_message', 'input_graft_ack_message', 'output_graft_ack_message', 'input_candidate_rp_advertisement', 'output_candidate_rp_advertisement', 'input_df_election', 'output_df_election', 'input_miscellaneous'], name, value)


            class TopologyRouteCount(Entity):
                """
                Topology route count information from PIM
                topology table
                
                .. attribute:: group_ranges
                
                	No. of (\*,G/M) routes
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: active_group_ranges
                
                	No. of (\*,G/M) routes active in mrib
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: groute_count
                
                	No. of (\*,G) routes
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: sg_route_count
                
                	No. of (S,G) routes
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: sgr_route_count
                
                	No. of (S,G)RPT routes
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_node_low_memory
                
                	Is node in low memory condition
                	**type**\: bool
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Active.DefaultContext.TopologyRouteCount, self).__init__()

                    self.yang_name = "topology-route-count"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('group_ranges', (YLeaf(YType.uint32, 'group-ranges'), ['int'])),
                        ('active_group_ranges', (YLeaf(YType.uint32, 'active-group-ranges'), ['int'])),
                        ('groute_count', (YLeaf(YType.uint32, 'groute-count'), ['int'])),
                        ('sg_route_count', (YLeaf(YType.uint32, 'sg-route-count'), ['int'])),
                        ('sgr_route_count', (YLeaf(YType.uint32, 'sgr-route-count'), ['int'])),
                        ('is_node_low_memory', (YLeaf(YType.boolean, 'is-node-low-memory'), ['bool'])),
                    ])
                    self.group_ranges = None
                    self.active_group_ranges = None
                    self.groute_count = None
                    self.sg_route_count = None
                    self.sgr_route_count = None
                    self.is_node_low_memory = None
                    self._segment_path = lambda: "topology-route-count"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.DefaultContext.TopologyRouteCount, ['group_ranges', 'active_group_ranges', 'groute_count', 'sg_route_count', 'sgr_route_count', 'is_node_low_memory'], name, value)


            class JpStatistics(Entity):
                """
                PIM join prune statistics table
                
                .. attribute:: jp_statistic
                
                	PIM Join Prune Statistics
                	**type**\: list of  		 :py:class:`JpStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.JpStatistics.JpStatistic>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Active.DefaultContext.JpStatistics, self).__init__()

                    self.yang_name = "jp-statistics"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("jp-statistic", ("jp_statistic", Pim.Active.DefaultContext.JpStatistics.JpStatistic))])
                    self._leafs = OrderedDict()

                    self.jp_statistic = YList(self)
                    self._segment_path = lambda: "jp-statistics"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.DefaultContext.JpStatistics, [], name, value)


                class JpStatistic(Entity):
                    """
                    PIM Join Prune Statistics
                    
                    .. attribute:: interface_name  (key)
                    
                    	Interface name
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identifier
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: mtu
                    
                    	Interface MTU
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: transmitted
                    
                    	Transmitted
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: transmitted100
                    
                    	Transmitted 100 average
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: transmitted_1k
                    
                    	Transmitted 1K average
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: transmitted_10k
                    
                    	Transmitted 10K average
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: transmitted_50k
                    
                    	Deprecated by Transmitted100
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: received
                    
                    	Received
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: received100
                    
                    	Received 100 average
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: received_1k
                    
                    	Received 1K average
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: received_10k
                    
                    	Received 10K average
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: received_50k
                    
                    	Deprecated by Received100
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.JpStatistics.JpStatistic, self).__init__()

                        self.yang_name = "jp-statistic"
                        self.yang_parent_name = "jp-statistics"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['interface_name']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                            ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                            ('mtu', (YLeaf(YType.uint32, 'mtu'), ['int'])),
                            ('transmitted', (YLeaf(YType.uint32, 'transmitted'), ['int'])),
                            ('transmitted100', (YLeaf(YType.uint16, 'transmitted100'), ['int'])),
                            ('transmitted_1k', (YLeaf(YType.uint16, 'transmitted-1k'), ['int'])),
                            ('transmitted_10k', (YLeaf(YType.uint16, 'transmitted-10k'), ['int'])),
                            ('transmitted_50k', (YLeaf(YType.uint16, 'transmitted-50k'), ['int'])),
                            ('received', (YLeaf(YType.uint32, 'received'), ['int'])),
                            ('received100', (YLeaf(YType.uint16, 'received100'), ['int'])),
                            ('received_1k', (YLeaf(YType.uint16, 'received-1k'), ['int'])),
                            ('received_10k', (YLeaf(YType.uint16, 'received-10k'), ['int'])),
                            ('received_50k', (YLeaf(YType.uint16, 'received-50k'), ['int'])),
                        ])
                        self.interface_name = None
                        self.interface_name_xr = None
                        self.mtu = None
                        self.transmitted = None
                        self.transmitted100 = None
                        self.transmitted_1k = None
                        self.transmitted_10k = None
                        self.transmitted_50k = None
                        self.received = None
                        self.received100 = None
                        self.received_1k = None
                        self.received_10k = None
                        self.received_50k = None
                        self._segment_path = lambda: "jp-statistic" + "[interface-name='" + str(self.interface_name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/jp-statistics/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.JpStatistics.JpStatistic, ['interface_name', 'interface_name_xr', 'mtu', 'transmitted', 'transmitted100', 'transmitted_1k', 'transmitted_10k', 'transmitted_50k', 'received', 'received100', 'received_1k', 'received_10k', 'received_50k'], name, value)


            class MibDatabases(Entity):
                """
                PIM group database for mroute mibs table
                
                .. attribute:: mib_database
                
                	PIM multicast static route information
                	**type**\: list of  		 :py:class:`MibDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.MibDatabases.MibDatabase>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Active.DefaultContext.MibDatabases, self).__init__()

                    self.yang_name = "mib-databases"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("mib-database", ("mib_database", Pim.Active.DefaultContext.MibDatabases.MibDatabase))])
                    self._leafs = OrderedDict()

                    self.mib_database = YList(self)
                    self._segment_path = lambda: "mib-databases"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.DefaultContext.MibDatabases, [], name, value)


                class MibDatabase(Entity):
                    """
                    PIM multicast static route information
                    
                    .. attribute:: source_address
                    
                    	Multicast static route source address
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: group_address
                    
                    	Multicast satic route group address
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: source_netmask
                    
                    	Source mask
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: source_address_xr
                    
                    	Source Address
                    	**type**\:  :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr>`
                    
                    .. attribute:: group_address_xr
                    
                    	Group Address
                    	**type**\:  :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr>`
                    
                    .. attribute:: rpf_neighbor
                    
                    	The RPF Neighbor
                    	**type**\:  :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor>`
                    
                    .. attribute:: rpf_root
                    
                    	Root of this mcast tree
                    	**type**\:  :py:class:`RpfRoot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfRoot>`
                    
                    .. attribute:: upstream_assert_timer
                    
                    	Upstream Assert Timer
                    	**type**\: int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: assert_metric
                    
                    	Assert Metric
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: assert_metric_preference
                    
                    	Assert Metric Preference
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: assert_rpt_bit
                    
                    	Assert RPT Bit
                    	**type**\: bool
                    
                    .. attribute:: spt_bit
                    
                    	Is SPT bit set ?
                    	**type**\: bool
                    
                    .. attribute:: rpf_mask
                    
                    	Mask of the multicast root
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rpf_safi
                    
                    	Unicast or mcast
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: rpf_table_name
                    
                    	RPF Table name
                    	**type**\: str
                    
                    .. attribute:: rpf_drop
                    
                    	RPF route\-policy drop
                    	**type**\: bool
                    
                    .. attribute:: rpf_extranet
                    
                    	Extranet RPF route\-policy
                    	**type**\: bool
                    
                    .. attribute:: rpf_interface_name
                    
                    	RPF interface name 
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: rpf_vrf_name
                    
                    	RPF VRF Name
                    	**type**\: str
                    
                    	**length:** 0..33
                    
                    .. attribute:: bidirectional_route
                    
                    	Is this Bidir ?
                    	**type**\: bool
                    
                    .. attribute:: uptime
                    
                    	Uptime of route
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: protocol
                    
                    	The PIM protocol
                    	**type**\:  :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.MibDatabases.MibDatabase, self).__init__()

                        self.yang_name = "mib-database"
                        self.yang_parent_name = "mib-databases"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("source-address-xr", ("source_address_xr", Pim.Active.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr)), ("group-address-xr", ("group_address_xr", Pim.Active.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr)), ("rpf-neighbor", ("rpf_neighbor", Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor)), ("rpf-root", ("rpf_root", Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfRoot))])
                        self._leafs = OrderedDict([
                            ('source_address', (YLeaf(YType.str, 'source-address'), ['str','str'])),
                            ('group_address', (YLeaf(YType.str, 'group-address'), ['str','str'])),
                            ('source_netmask', (YLeaf(YType.uint32, 'source-netmask'), ['int'])),
                            ('upstream_assert_timer', (YLeaf(YType.int32, 'upstream-assert-timer'), ['int'])),
                            ('assert_metric', (YLeaf(YType.uint32, 'assert-metric'), ['int'])),
                            ('assert_metric_preference', (YLeaf(YType.uint32, 'assert-metric-preference'), ['int'])),
                            ('assert_rpt_bit', (YLeaf(YType.boolean, 'assert-rpt-bit'), ['bool'])),
                            ('spt_bit', (YLeaf(YType.boolean, 'spt-bit'), ['bool'])),
                            ('rpf_mask', (YLeaf(YType.uint32, 'rpf-mask'), ['int'])),
                            ('rpf_safi', (YLeaf(YType.uint8, 'rpf-safi'), ['int'])),
                            ('rpf_table_name', (YLeaf(YType.str, 'rpf-table-name'), ['str'])),
                            ('rpf_drop', (YLeaf(YType.boolean, 'rpf-drop'), ['bool'])),
                            ('rpf_extranet', (YLeaf(YType.boolean, 'rpf-extranet'), ['bool'])),
                            ('rpf_interface_name', (YLeaf(YType.str, 'rpf-interface-name'), ['str'])),
                            ('rpf_vrf_name', (YLeaf(YType.str, 'rpf-vrf-name'), ['str'])),
                            ('bidirectional_route', (YLeaf(YType.boolean, 'bidirectional-route'), ['bool'])),
                            ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                            ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowProtocol', '')])),
                        ])
                        self.source_address = None
                        self.group_address = None
                        self.source_netmask = None
                        self.upstream_assert_timer = None
                        self.assert_metric = None
                        self.assert_metric_preference = None
                        self.assert_rpt_bit = None
                        self.spt_bit = None
                        self.rpf_mask = None
                        self.rpf_safi = None
                        self.rpf_table_name = None
                        self.rpf_drop = None
                        self.rpf_extranet = None
                        self.rpf_interface_name = None
                        self.rpf_vrf_name = None
                        self.bidirectional_route = None
                        self.uptime = None
                        self.protocol = None

                        self.source_address_xr = Pim.Active.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr()
                        self.source_address_xr.parent = self
                        self._children_name_map["source_address_xr"] = "source-address-xr"

                        self.group_address_xr = Pim.Active.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr()
                        self.group_address_xr.parent = self
                        self._children_name_map["group_address_xr"] = "group-address-xr"

                        self.rpf_neighbor = Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor()
                        self.rpf_neighbor.parent = self
                        self._children_name_map["rpf_neighbor"] = "rpf-neighbor"

                        self.rpf_root = Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfRoot()
                        self.rpf_root.parent = self
                        self._children_name_map["rpf_root"] = "rpf-root"
                        self._segment_path = lambda: "mib-database"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/mib-databases/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.MibDatabases.MibDatabase, ['source_address', 'group_address', 'source_netmask', 'upstream_assert_timer', 'assert_metric', 'assert_metric_preference', 'assert_rpt_bit', 'spt_bit', 'rpf_mask', 'rpf_safi', 'rpf_table_name', 'rpf_drop', 'rpf_extranet', 'rpf_interface_name', 'rpf_vrf_name', 'bidirectional_route', 'uptime', 'protocol'], name, value)


                    class SourceAddressXr(Entity):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr, self).__init__()

                            self.yang_name = "source-address-xr"
                            self.yang_parent_name = "mib-database"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "source-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/mib-databases/mib-database/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class GroupAddressXr(Entity):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr, self).__init__()

                            self.yang_name = "group-address-xr"
                            self.yang_parent_name = "mib-database"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "group-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/mib-databases/mib-database/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class RpfNeighbor(Entity):
                        """
                        The RPF Neighbor
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor, self).__init__()

                            self.yang_name = "rpf-neighbor"
                            self.yang_parent_name = "mib-database"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "rpf-neighbor"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/mib-databases/mib-database/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class RpfRoot(Entity):
                        """
                        Root of this mcast tree
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfRoot, self).__init__()

                            self.yang_name = "rpf-root"
                            self.yang_parent_name = "mib-database"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "rpf-root"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/mib-databases/mib-database/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfRoot, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class NeighborOldFormats(Entity):
                """
                PIM neighbor table old format
                
                .. attribute:: neighbor_old_format
                
                	PIM neighbor information
                	**type**\: list of  		 :py:class:`NeighborOldFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.NeighborOldFormats.NeighborOldFormat>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Active.DefaultContext.NeighborOldFormats, self).__init__()

                    self.yang_name = "neighbor-old-formats"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("neighbor-old-format", ("neighbor_old_format", Pim.Active.DefaultContext.NeighborOldFormats.NeighborOldFormat))])
                    self._leafs = OrderedDict()

                    self.neighbor_old_format = YList(self)
                    self._segment_path = lambda: "neighbor-old-formats"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.DefaultContext.NeighborOldFormats, [], name, value)


                class NeighborOldFormat(Entity):
                    """
                    PIM neighbor information
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: neighbor_address
                    
                    	Neighbor address
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identifier
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: expires
                    
                    	Neighbor expiry in seconds
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: expiry_timer
                    
                    	Expiry timer in seconds
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: is_this_neighbor_us
                    
                    	Is this neighbor us ?
                    	**type**\: bool
                    
                    .. attribute:: is_this_neighbor_dr
                    
                    	Is this neighbor the DR
                    	**type**\: bool
                    
                    .. attribute:: is_dr_priority_capable
                    
                    	Is this neighbor DR priority capable ?
                    	**type**\: bool
                    
                    .. attribute:: dr_priority
                    
                    	DR priority
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Is this neighbor bidir capable ?
                    	**type**\: bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Is this neighbor proxy capable?
                    	**type**\: bool
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Is this neighbor capable of batching asserts?
                    	**type**\: bool
                    
                    .. attribute:: is_ecmp_redirect_capable
                    
                    	Is this neighbor capable of Ecmp Redirect?
                    	**type**\: bool
                    
                    .. attribute:: is_bfd_state
                    
                    	Is the neighbor bfd session created
                    	**type**\: bool
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_address_xr
                    
                    	List of Neighbor Addresses
                    	**type**\: list of  		 :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.NeighborOldFormats.NeighborOldFormat, self).__init__()

                        self.yang_name = "neighbor-old-format"
                        self.yang_parent_name = "neighbor-old-formats"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("neighbor-address-xr", ("neighbor_address_xr", Pim.Active.DefaultContext.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr))])
                        self._leafs = OrderedDict([
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                            ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                            ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                            ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                            ('expires', (YLeaf(YType.uint64, 'expires'), ['int'])),
                            ('expiry_timer', (YLeaf(YType.uint64, 'expiry-timer'), ['int'])),
                            ('is_this_neighbor_us', (YLeaf(YType.boolean, 'is-this-neighbor-us'), ['bool'])),
                            ('is_this_neighbor_dr', (YLeaf(YType.boolean, 'is-this-neighbor-dr'), ['bool'])),
                            ('is_dr_priority_capable', (YLeaf(YType.boolean, 'is-dr-priority-capable'), ['bool'])),
                            ('dr_priority', (YLeaf(YType.uint32, 'dr-priority'), ['int'])),
                            ('is_bidirectional_capable', (YLeaf(YType.boolean, 'is-bidirectional-capable'), ['bool'])),
                            ('is_proxy_capable', (YLeaf(YType.boolean, 'is-proxy-capable'), ['bool'])),
                            ('is_batch_asserts_capable', (YLeaf(YType.boolean, 'is-batch-asserts-capable'), ['bool'])),
                            ('is_ecmp_redirect_capable', (YLeaf(YType.boolean, 'is-ecmp-redirect-capable'), ['bool'])),
                            ('is_bfd_state', (YLeaf(YType.boolean, 'is-bfd-state'), ['bool'])),
                            ('propagation_delay', (YLeaf(YType.uint16, 'propagation-delay'), ['int'])),
                            ('override_interval', (YLeaf(YType.uint16, 'override-interval'), ['int'])),
                        ])
                        self.interface_name = None
                        self.neighbor_address = None
                        self.interface_name_xr = None
                        self.uptime = None
                        self.expires = None
                        self.expiry_timer = None
                        self.is_this_neighbor_us = None
                        self.is_this_neighbor_dr = None
                        self.is_dr_priority_capable = None
                        self.dr_priority = None
                        self.is_bidirectional_capable = None
                        self.is_proxy_capable = None
                        self.is_batch_asserts_capable = None
                        self.is_ecmp_redirect_capable = None
                        self.is_bfd_state = None
                        self.propagation_delay = None
                        self.override_interval = None

                        self.neighbor_address_xr = YList(self)
                        self._segment_path = lambda: "neighbor-old-format"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/neighbor-old-formats/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.NeighborOldFormats.NeighborOldFormat, ['interface_name', 'neighbor_address', 'interface_name_xr', 'uptime', 'expires', 'expiry_timer', 'is_this_neighbor_us', 'is_this_neighbor_dr', 'is_dr_priority_capable', 'dr_priority', 'is_bidirectional_capable', 'is_proxy_capable', 'is_batch_asserts_capable', 'is_ecmp_redirect_capable', 'is_bfd_state', 'propagation_delay', 'override_interval'], name, value)


                    class NeighborAddressXr(Entity):
                        """
                        List of Neighbor Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr, self).__init__()

                            self.yang_name = "neighbor-address-xr"
                            self.yang_parent_name = "neighbor-old-format"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "neighbor-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/neighbor-old-formats/neighbor-old-format/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class IfrsSummary(Entity):
                """
                PIM interfaces in forward reference store
                summary
                
                .. attribute:: interface_count
                
                	Number of interfaces
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: configuration_count
                
                	Configuration counts
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Active.DefaultContext.IfrsSummary, self).__init__()

                    self.yang_name = "ifrs-summary"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('interface_count', (YLeaf(YType.uint32, 'interface-count'), ['int'])),
                        ('configuration_count', (YLeaf(YType.uint32, 'configuration-count'), ['int'])),
                    ])
                    self.interface_count = None
                    self.configuration_count = None
                    self._segment_path = lambda: "ifrs-summary"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.DefaultContext.IfrsSummary, ['interface_count', 'configuration_count'], name, value)


            class Ranges(Entity):
                """
                PIM range list information
                
                .. attribute:: range
                
                	PIM range list information
                	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Ranges.Range>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Active.DefaultContext.Ranges, self).__init__()

                    self.yang_name = "ranges"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("range", ("range", Pim.Active.DefaultContext.Ranges.Range))])
                    self._leafs = OrderedDict()

                    self.range = YList(self)
                    self._segment_path = lambda: "ranges"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.DefaultContext.Ranges, [], name, value)


                class Range(Entity):
                    """
                    PIM range list information
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: client
                    
                    	Client
                    	**type**\:  :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                    
                    .. attribute:: rp_address_xr
                    
                    	Rendezvous point address
                    	**type**\:  :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Ranges.Range.RpAddressXr>`
                    
                    .. attribute:: source_of_information
                    
                    	Source of information
                    	**type**\:  :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Ranges.Range.SourceOfInformation>`
                    
                    .. attribute:: protocol
                    
                    	PIM protocol
                    	**type**\:  :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                    
                    .. attribute:: client_xr
                    
                    	Client mapping learnt via
                    	**type**\:  :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                    
                    .. attribute:: expires
                    
                    	When mapping expires
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: group_range
                    
                    	List of group ranges
                    	**type**\: list of  		 :py:class:`GroupRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Ranges.Range.GroupRange>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.Ranges.Range, self).__init__()

                        self.yang_name = "range"
                        self.yang_parent_name = "ranges"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("rp-address-xr", ("rp_address_xr", Pim.Active.DefaultContext.Ranges.Range.RpAddressXr)), ("source-of-information", ("source_of_information", Pim.Active.DefaultContext.Ranges.Range.SourceOfInformation)), ("group-range", ("group_range", Pim.Active.DefaultContext.Ranges.Range.GroupRange))])
                        self._leafs = OrderedDict([
                            ('rp_address', (YLeaf(YType.str, 'rp-address'), ['str','str'])),
                            ('client', (YLeaf(YType.enumeration, 'client'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimClient', '')])),
                            ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowProtocol', '')])),
                            ('client_xr', (YLeaf(YType.enumeration, 'client-xr'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowRangeClient', '')])),
                            ('expires', (YLeaf(YType.uint64, 'expires'), ['int'])),
                        ])
                        self.rp_address = None
                        self.client = None
                        self.protocol = None
                        self.client_xr = None
                        self.expires = None

                        self.rp_address_xr = Pim.Active.DefaultContext.Ranges.Range.RpAddressXr()
                        self.rp_address_xr.parent = self
                        self._children_name_map["rp_address_xr"] = "rp-address-xr"

                        self.source_of_information = Pim.Active.DefaultContext.Ranges.Range.SourceOfInformation()
                        self.source_of_information.parent = self
                        self._children_name_map["source_of_information"] = "source-of-information"

                        self.group_range = YList(self)
                        self._segment_path = lambda: "range"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/ranges/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.Ranges.Range, ['rp_address', 'client', 'protocol', 'client_xr', 'expires'], name, value)


                    class RpAddressXr(Entity):
                        """
                        Rendezvous point address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Ranges.Range.RpAddressXr, self).__init__()

                            self.yang_name = "rp-address-xr"
                            self.yang_parent_name = "range"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "rp-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/ranges/range/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.Ranges.Range.RpAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class SourceOfInformation(Entity):
                        """
                        Source of information
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Ranges.Range.SourceOfInformation, self).__init__()

                            self.yang_name = "source-of-information"
                            self.yang_parent_name = "range"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "source-of-information"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/ranges/range/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.Ranges.Range.SourceOfInformation, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class GroupRange(Entity):
                        """
                        List of group ranges
                        
                        .. attribute:: prefix
                        
                        	Group range prefix
                        	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Ranges.Range.GroupRange.Prefix>`
                        
                        .. attribute:: source_of_information
                        
                        	Source of information
                        	**type**\:  :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation>`
                        
                        .. attribute:: prefix_length
                        
                        	Group range prefix length
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: expires
                        
                        	When mapping expires
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Ranges.Range.GroupRange, self).__init__()

                            self.yang_name = "group-range"
                            self.yang_parent_name = "range"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("prefix", ("prefix", Pim.Active.DefaultContext.Ranges.Range.GroupRange.Prefix)), ("source-of-information", ("source_of_information", Pim.Active.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation))])
                            self._leafs = OrderedDict([
                                ('prefix_length', (YLeaf(YType.int32, 'prefix-length'), ['int'])),
                                ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                                ('expires', (YLeaf(YType.uint64, 'expires'), ['int'])),
                            ])
                            self.prefix_length = None
                            self.uptime = None
                            self.expires = None

                            self.prefix = Pim.Active.DefaultContext.Ranges.Range.GroupRange.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"

                            self.source_of_information = Pim.Active.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation()
                            self.source_of_information.parent = self
                            self._children_name_map["source_of_information"] = "source-of-information"
                            self._segment_path = lambda: "group-range"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/ranges/range/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.Ranges.Range.GroupRange, ['prefix_length', 'uptime', 'expires'], name, value)


                        class Prefix(Entity):
                            """
                            Group range prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.Ranges.Range.GroupRange.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "group-range"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "prefix"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/ranges/range/group-range/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.DefaultContext.Ranges.Range.GroupRange.Prefix, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class SourceOfInformation(Entity):
                            """
                            Source of information
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation, self).__init__()

                                self.yang_name = "source-of-information"
                                self.yang_parent_name = "group-range"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "source-of-information"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/ranges/range/group-range/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class InterfaceOldFormats(Entity):
                """
                PIM interfaces in old format
                
                .. attribute:: interface_old_format
                
                	PIM interface name
                	**type**\: list of  		 :py:class:`InterfaceOldFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Active.DefaultContext.InterfaceOldFormats, self).__init__()

                    self.yang_name = "interface-old-formats"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("interface-old-format", ("interface_old_format", Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat))])
                    self._leafs = OrderedDict()

                    self.interface_old_format = YList(self)
                    self._segment_path = lambda: "interface-old-formats"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.DefaultContext.InterfaceOldFormats, [], name, value)


                class InterfaceOldFormat(Entity):
                    """
                    PIM interface name
                    
                    .. attribute:: interface_name  (key)
                    
                    	Interface name
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: dr_address
                    
                    	PIM Designated Router
                    	**type**\:  :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress>`
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identfier
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: interface_address_mask
                    
                    	Interface IP Address Mask
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: is_enabled
                    
                    	Is PIM enabled on this IF ?
                    	**type**\: bool
                    
                    .. attribute:: neighbor_count
                    
                    	No. of neighbors on this IF
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: external_neighbor_count
                    
                    	No. of external neighbors on this IF
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: hello_interval
                    
                    	Hello Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dr_priority
                    
                    	DR Priority
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_expiry
                    
                    	Hello Timer Expiry
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: are_we_dr
                    
                    	Are we the DR on this IF ?
                    	**type**\: bool
                    
                    .. attribute:: bfd_enabled
                    
                    	BFD state
                    	**type**\: bool
                    
                    .. attribute:: bfd_interval
                    
                    	BFD Interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bfd_multiplier
                    
                    	BFD Multiplier
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_interface
                    
                    	 is this a Virtual Interfaces ?
                    	**type**\: bool
                    
                    .. attribute:: passive_interface
                    
                    	Passive PIM interface
                    	**type**\: bool
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\: str
                    
                    .. attribute:: join_prune_interval
                    
                    	Join\-Prune Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: prune_delay_enabled
                    
                    	Prune Delay Enabled
                    	**type**\: bool
                    
                    .. attribute:: configured_propagation_delay
                    
                    	Configured Propagation Delay
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_override_interval
                    
                    	Configured Override Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: generation_id
                    
                    	Generation Identifier
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Bidir Capable
                    	**type**\: bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Proxy Capable
                    	**type**\: bool
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Batch Asserts Capable
                    	**type**\: bool
                    
                    .. attribute:: idb_oor_enabled
                    
                    	Interface oor enabled
                    	**type**\: bool
                    
                    .. attribute:: idb_acl_provided
                    
                    	ACL name provided
                    	**type**\: bool
                    
                    .. attribute:: idb_max_count
                    
                    	Interface ole max count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_threshold_count
                    
                    	Interface ole threshold count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_current_count
                    
                    	Interface ole current count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_acl_name
                    
                    	Interface ole ACL Name
                    	**type**\: str
                    
                    	**length:** 0..64
                    
                    .. attribute:: interface_address
                    
                    	List of Interface IP Addresses
                    	**type**\: list of  		 :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat, self).__init__()

                        self.yang_name = "interface-old-format"
                        self.yang_parent_name = "interface-old-formats"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['interface_name']
                        self._child_classes = OrderedDict([("dr-address", ("dr_address", Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress)), ("interface-address", ("interface_address", Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress))])
                        self._leafs = OrderedDict([
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                            ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                            ('interface_address_mask', (YLeaf(YType.uint8, 'interface-address-mask'), ['int'])),
                            ('is_enabled', (YLeaf(YType.boolean, 'is-enabled'), ['bool'])),
                            ('neighbor_count', (YLeaf(YType.uint16, 'neighbor-count'), ['int'])),
                            ('external_neighbor_count', (YLeaf(YType.uint16, 'external-neighbor-count'), ['int'])),
                            ('hello_interval', (YLeaf(YType.uint16, 'hello-interval'), ['int'])),
                            ('dr_priority', (YLeaf(YType.uint32, 'dr-priority'), ['int'])),
                            ('hello_expiry', (YLeaf(YType.uint64, 'hello-expiry'), ['int'])),
                            ('are_we_dr', (YLeaf(YType.boolean, 'are-we-dr'), ['bool'])),
                            ('bfd_enabled', (YLeaf(YType.boolean, 'bfd-enabled'), ['bool'])),
                            ('bfd_interval', (YLeaf(YType.uint32, 'bfd-interval'), ['int'])),
                            ('bfd_multiplier', (YLeaf(YType.uint32, 'bfd-multiplier'), ['int'])),
                            ('virtual_interface', (YLeaf(YType.boolean, 'virtual-interface'), ['bool'])),
                            ('passive_interface', (YLeaf(YType.boolean, 'passive-interface'), ['bool'])),
                            ('neighbor_filter_name', (YLeaf(YType.str, 'neighbor-filter-name'), ['str'])),
                            ('join_prune_interval', (YLeaf(YType.uint16, 'join-prune-interval'), ['int'])),
                            ('prune_delay_enabled', (YLeaf(YType.boolean, 'prune-delay-enabled'), ['bool'])),
                            ('configured_propagation_delay', (YLeaf(YType.uint16, 'configured-propagation-delay'), ['int'])),
                            ('propagation_delay', (YLeaf(YType.uint16, 'propagation-delay'), ['int'])),
                            ('configured_override_interval', (YLeaf(YType.uint16, 'configured-override-interval'), ['int'])),
                            ('override_interval', (YLeaf(YType.uint16, 'override-interval'), ['int'])),
                            ('generation_id', (YLeaf(YType.uint32, 'generation-id'), ['int'])),
                            ('is_bidirectional_capable', (YLeaf(YType.boolean, 'is-bidirectional-capable'), ['bool'])),
                            ('is_proxy_capable', (YLeaf(YType.boolean, 'is-proxy-capable'), ['bool'])),
                            ('is_batch_asserts_capable', (YLeaf(YType.boolean, 'is-batch-asserts-capable'), ['bool'])),
                            ('idb_oor_enabled', (YLeaf(YType.boolean, 'idb-oor-enabled'), ['bool'])),
                            ('idb_acl_provided', (YLeaf(YType.boolean, 'idb-acl-provided'), ['bool'])),
                            ('idb_max_count', (YLeaf(YType.uint32, 'idb-max-count'), ['int'])),
                            ('idb_threshold_count', (YLeaf(YType.uint32, 'idb-threshold-count'), ['int'])),
                            ('idb_current_count', (YLeaf(YType.uint32, 'idb-current-count'), ['int'])),
                            ('idb_acl_name', (YLeaf(YType.str, 'idb-acl-name'), ['str'])),
                        ])
                        self.interface_name = None
                        self.interface_name_xr = None
                        self.interface_address_mask = None
                        self.is_enabled = None
                        self.neighbor_count = None
                        self.external_neighbor_count = None
                        self.hello_interval = None
                        self.dr_priority = None
                        self.hello_expiry = None
                        self.are_we_dr = None
                        self.bfd_enabled = None
                        self.bfd_interval = None
                        self.bfd_multiplier = None
                        self.virtual_interface = None
                        self.passive_interface = None
                        self.neighbor_filter_name = None
                        self.join_prune_interval = None
                        self.prune_delay_enabled = None
                        self.configured_propagation_delay = None
                        self.propagation_delay = None
                        self.configured_override_interval = None
                        self.override_interval = None
                        self.generation_id = None
                        self.is_bidirectional_capable = None
                        self.is_proxy_capable = None
                        self.is_batch_asserts_capable = None
                        self.idb_oor_enabled = None
                        self.idb_acl_provided = None
                        self.idb_max_count = None
                        self.idb_threshold_count = None
                        self.idb_current_count = None
                        self.idb_acl_name = None

                        self.dr_address = Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress()
                        self.dr_address.parent = self
                        self._children_name_map["dr_address"] = "dr-address"

                        self.interface_address = YList(self)
                        self._segment_path = lambda: "interface-old-format" + "[interface-name='" + str(self.interface_name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/interface-old-formats/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat, ['interface_name', 'interface_name_xr', 'interface_address_mask', 'is_enabled', 'neighbor_count', 'external_neighbor_count', 'hello_interval', 'dr_priority', 'hello_expiry', 'are_we_dr', 'bfd_enabled', 'bfd_interval', 'bfd_multiplier', 'virtual_interface', 'passive_interface', 'neighbor_filter_name', 'join_prune_interval', 'prune_delay_enabled', 'configured_propagation_delay', 'propagation_delay', 'configured_override_interval', 'override_interval', 'generation_id', 'is_bidirectional_capable', 'is_proxy_capable', 'is_batch_asserts_capable', 'idb_oor_enabled', 'idb_acl_provided', 'idb_max_count', 'idb_threshold_count', 'idb_current_count', 'idb_acl_name'], name, value)


                    class DrAddress(Entity):
                        """
                        PIM Designated Router
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress, self).__init__()

                            self.yang_name = "dr-address"
                            self.yang_parent_name = "interface-old-format"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "dr-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class InterfaceAddress(Entity):
                        """
                        List of Interface IP Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress, self).__init__()

                            self.yang_name = "interface-address"
                            self.yang_parent_name = "interface-old-format"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "interface-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class Bsr(Entity):
                """
                PIM BSR information
                
                .. attribute:: rp_caches
                
                	PIM BSR RP cache table
                	**type**\:  :py:class:`RpCaches <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Bsr.RpCaches>`
                
                .. attribute:: candidate_rps
                
                	PIM candidate\-RP
                	**type**\:  :py:class:`CandidateRps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Bsr.CandidateRps>`
                
                .. attribute:: bsr_elections
                
                	PIM BSR election state
                	**type**\:  :py:class:`BsrElections <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Bsr.BsrElections>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Active.DefaultContext.Bsr, self).__init__()

                    self.yang_name = "bsr"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("rp-caches", ("rp_caches", Pim.Active.DefaultContext.Bsr.RpCaches)), ("candidate-rps", ("candidate_rps", Pim.Active.DefaultContext.Bsr.CandidateRps)), ("bsr-elections", ("bsr_elections", Pim.Active.DefaultContext.Bsr.BsrElections))])
                    self._leafs = OrderedDict()

                    self.rp_caches = Pim.Active.DefaultContext.Bsr.RpCaches()
                    self.rp_caches.parent = self
                    self._children_name_map["rp_caches"] = "rp-caches"

                    self.candidate_rps = Pim.Active.DefaultContext.Bsr.CandidateRps()
                    self.candidate_rps.parent = self
                    self._children_name_map["candidate_rps"] = "candidate-rps"

                    self.bsr_elections = Pim.Active.DefaultContext.Bsr.BsrElections()
                    self.bsr_elections.parent = self
                    self._children_name_map["bsr_elections"] = "bsr-elections"
                    self._segment_path = lambda: "bsr"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.DefaultContext.Bsr, [], name, value)


                class RpCaches(Entity):
                    """
                    PIM BSR RP cache table
                    
                    .. attribute:: rp_cache
                    
                    	PIM BSR RP cache
                    	**type**\: list of  		 :py:class:`RpCache <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Bsr.RpCaches.RpCache>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.Bsr.RpCaches, self).__init__()

                        self.yang_name = "rp-caches"
                        self.yang_parent_name = "bsr"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("rp-cache", ("rp_cache", Pim.Active.DefaultContext.Bsr.RpCaches.RpCache))])
                        self._leafs = OrderedDict()

                        self.rp_cache = YList(self)
                        self._segment_path = lambda: "rp-caches"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/bsr/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.Bsr.RpCaches, [], name, value)


                    class RpCache(Entity):
                        """
                        PIM BSR RP cache
                        
                        .. attribute:: group_prefix  (key)
                        
                        	Group prefix
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: group_prefix_xr
                        
                        	Group Prefix
                        	**type**\:  :py:class:`GroupPrefixXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr>`
                        
                        .. attribute:: candidate_rp_list
                        
                        	C\-RP list for this prefix
                        	**type**\:  :py:class:`CandidateRpList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList>`
                        
                        .. attribute:: group_prefix_length
                        
                        	Group Prefix Length
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: candidate_rp_group_count
                        
                        	C\-RP count for this Prefix
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Bsr.RpCaches.RpCache, self).__init__()

                            self.yang_name = "rp-cache"
                            self.yang_parent_name = "rp-caches"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['group_prefix']
                            self._child_classes = OrderedDict([("group-prefix-xr", ("group_prefix_xr", Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr)), ("candidate-rp-list", ("candidate_rp_list", Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList))])
                            self._leafs = OrderedDict([
                                ('group_prefix', (YLeaf(YType.str, 'group-prefix'), ['str','str'])),
                                ('group_prefix_length', (YLeaf(YType.uint32, 'group-prefix-length'), ['int'])),
                                ('candidate_rp_group_count', (YLeaf(YType.uint32, 'candidate-rp-group-count'), ['int'])),
                            ])
                            self.group_prefix = None
                            self.group_prefix_length = None
                            self.candidate_rp_group_count = None

                            self.group_prefix_xr = Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr()
                            self.group_prefix_xr.parent = self
                            self._children_name_map["group_prefix_xr"] = "group-prefix-xr"

                            self.candidate_rp_list = Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList()
                            self.candidate_rp_list.parent = self
                            self._children_name_map["candidate_rp_list"] = "candidate-rp-list"
                            self._segment_path = lambda: "rp-cache" + "[group-prefix='" + str(self.group_prefix) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/bsr/rp-caches/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.Bsr.RpCaches.RpCache, ['group_prefix', 'group_prefix_length', 'candidate_rp_group_count'], name, value)


                        class GroupPrefixXr(Entity):
                            """
                            Group Prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr, self).__init__()

                                self.yang_name = "group-prefix-xr"
                                self.yang_parent_name = "rp-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "group-prefix-xr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class CandidateRpList(Entity):
                            """
                            C\-RP list for this prefix
                            
                            .. attribute:: pim_bsr_crp_bag
                            
                            	pim bsr crp bag
                            	**type**\: list of  		 :py:class:`PimBsrCrpBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList, self).__init__()

                                self.yang_name = "candidate-rp-list"
                                self.yang_parent_name = "rp-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("pim-bsr-crp-bag", ("pim_bsr_crp_bag", Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag))])
                                self._leafs = OrderedDict()

                                self.pim_bsr_crp_bag = YList(self)
                                self._segment_path = lambda: "candidate-rp-list"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList, [], name, value)


                            class PimBsrCrpBag(Entity):
                                """
                                pim bsr crp bag
                                
                                .. attribute:: candidate_rp_address
                                
                                	C\-RP address
                                	**type**\:  :py:class:`CandidateRpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress>`
                                
                                .. attribute:: candidate_rp_holdtime
                                
                                	C\-RP Holdtime
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: candidate_rp_priority
                                
                                	C\-RP Priority
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: candidate_rp_up_time
                                
                                	C\-RP Uptime
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: candidate_rp_expires
                                
                                	C\-RP Expires
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: protocol
                                
                                	PIM Protocol
                                	**type**\:  :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag, self).__init__()

                                    self.yang_name = "pim-bsr-crp-bag"
                                    self.yang_parent_name = "candidate-rp-list"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("candidate-rp-address", ("candidate_rp_address", Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress))])
                                    self._leafs = OrderedDict([
                                        ('candidate_rp_holdtime', (YLeaf(YType.uint16, 'candidate-rp-holdtime'), ['int'])),
                                        ('candidate_rp_priority', (YLeaf(YType.uint8, 'candidate-rp-priority'), ['int'])),
                                        ('candidate_rp_up_time', (YLeaf(YType.uint16, 'candidate-rp-up-time'), ['int'])),
                                        ('candidate_rp_expires', (YLeaf(YType.uint16, 'candidate-rp-expires'), ['int'])),
                                        ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowProtocol', '')])),
                                    ])
                                    self.candidate_rp_holdtime = None
                                    self.candidate_rp_priority = None
                                    self.candidate_rp_up_time = None
                                    self.candidate_rp_expires = None
                                    self.protocol = None

                                    self.candidate_rp_address = Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress()
                                    self.candidate_rp_address.parent = self
                                    self._children_name_map["candidate_rp_address"] = "candidate-rp-address"
                                    self._segment_path = lambda: "pim-bsr-crp-bag"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag, ['candidate_rp_holdtime', 'candidate_rp_priority', 'candidate_rp_up_time', 'candidate_rp_expires', 'protocol'], name, value)


                                class CandidateRpAddress(Entity):
                                    """
                                    C\-RP address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress, self).__init__()

                                        self.yang_name = "candidate-rp-address"
                                        self.yang_parent_name = "pim-bsr-crp-bag"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ])
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None
                                        self._segment_path = lambda: "candidate-rp-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class CandidateRps(Entity):
                    """
                    PIM candidate\-RP
                    
                    .. attribute:: candidate_rp
                    
                    	PIM BSR candidate RP information
                    	**type**\: list of  		 :py:class:`CandidateRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.Bsr.CandidateRps, self).__init__()

                        self.yang_name = "candidate-rps"
                        self.yang_parent_name = "bsr"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("candidate-rp", ("candidate_rp", Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp))])
                        self._leafs = OrderedDict()

                        self.candidate_rp = YList(self)
                        self._segment_path = lambda: "candidate-rps"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/bsr/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.Bsr.CandidateRps, [], name, value)


                    class CandidateRp(Entity):
                        """
                        PIM BSR candidate RP information
                        
                        .. attribute:: rp_address  (key)
                        
                        	Candidate\-RP address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: candidate_rp
                        
                        	Cand\-RP Address
                        	**type**\:  :py:class:`CandidateRp_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp_>`
                        
                        .. attribute:: candidate_rp_mode
                        
                        	Cand\-RP Mode
                        	**type**\:  :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: candidate_rp_scope
                        
                        	Cand\-RP Scope
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: crp_priority
                        
                        	Cand\-RP Priority
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: crp_holdtime
                        
                        	Cand\-RP Holdtime
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: candidate_rp_advance_interval
                        
                        	Cand\-RP Adv Interval in seconds
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        	**units**\: second
                        
                        .. attribute:: candidate_rp_uptime
                        
                        	Cand\-RP uptime
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: acl_name
                        
                        	Group Access\-List Name
                        	**type**\: str
                        
                        	**length:** 0..33
                        
                        .. attribute:: crp_access
                        
                        	Group Ranges Using this Cand\-RP
                        	**type**\: list of  		 :py:class:`CrpAccess <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CrpAccess>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp, self).__init__()

                            self.yang_name = "candidate-rp"
                            self.yang_parent_name = "candidate-rps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['rp_address']
                            self._child_classes = OrderedDict([("candidate-rp", ("candidate_rp", Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp_)), ("crp-access", ("crp_access", Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CrpAccess))])
                            self._leafs = OrderedDict([
                                ('rp_address', (YLeaf(YType.str, 'rp-address'), ['str','str'])),
                                ('candidate_rp_mode', (YLeaf(YType.enumeration, 'candidate-rp-mode'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowProtocol', '')])),
                                ('candidate_rp_scope', (YLeaf(YType.int32, 'candidate-rp-scope'), ['int'])),
                                ('crp_priority', (YLeaf(YType.uint8, 'crp-priority'), ['int'])),
                                ('crp_holdtime', (YLeaf(YType.uint16, 'crp-holdtime'), ['int'])),
                                ('candidate_rp_advance_interval', (YLeaf(YType.uint16, 'candidate-rp-advance-interval'), ['int'])),
                                ('candidate_rp_uptime', (YLeaf(YType.uint16, 'candidate-rp-uptime'), ['int'])),
                                ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                            ])
                            self.rp_address = None
                            self.candidate_rp_mode = None
                            self.candidate_rp_scope = None
                            self.crp_priority = None
                            self.crp_holdtime = None
                            self.candidate_rp_advance_interval = None
                            self.candidate_rp_uptime = None
                            self.acl_name = None

                            self.candidate_rp = Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp_()
                            self.candidate_rp.parent = self
                            self._children_name_map["candidate_rp"] = "candidate-rp"

                            self.crp_access = YList(self)
                            self._segment_path = lambda: "candidate-rp" + "[rp-address='" + str(self.rp_address) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/bsr/candidate-rps/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp, ['rp_address', 'candidate_rp_mode', 'candidate_rp_scope', 'crp_priority', 'crp_holdtime', 'candidate_rp_advance_interval', 'candidate_rp_uptime', 'acl_name'], name, value)


                        class CandidateRp_(Entity):
                            """
                            Cand\-RP Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp_, self).__init__()

                                self.yang_name = "candidate-rp"
                                self.yang_parent_name = "candidate-rp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "candidate-rp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp_, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class CrpAccess(Entity):
                            """
                            Group Ranges Using this Cand\-RP
                            
                            .. attribute:: candidate_rp_mode
                            
                            	Cand\-RP Mode
                            	**type**\:  :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                            
                            .. attribute:: acl_name
                            
                            	Group Access\-List Name
                            	**type**\: str
                            
                            	**length:** 0..33
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CrpAccess, self).__init__()

                                self.yang_name = "crp-access"
                                self.yang_parent_name = "candidate-rp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('candidate_rp_mode', (YLeaf(YType.enumeration, 'candidate-rp-mode'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowProtocol', '')])),
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                                ])
                                self.candidate_rp_mode = None
                                self.acl_name = None
                                self._segment_path = lambda: "crp-access"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CrpAccess, ['candidate_rp_mode', 'acl_name'], name, value)


                class BsrElections(Entity):
                    """
                    PIM BSR election state
                    
                    .. attribute:: bsr_election
                    
                    	PIM BSR information
                    	**type**\: list of  		 :py:class:`BsrElection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.Bsr.BsrElections, self).__init__()

                        self.yang_name = "bsr-elections"
                        self.yang_parent_name = "bsr"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("bsr-election", ("bsr_election", Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection))])
                        self._leafs = OrderedDict()

                        self.bsr_election = YList(self)
                        self._segment_path = lambda: "bsr-elections"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/bsr/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.Bsr.BsrElections, [], name, value)


                    class BsrElection(Entity):
                        """
                        PIM BSR information
                        
                        .. attribute:: pim_scope  (key)
                        
                        	BSR information
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bsr_address
                        
                        	BSR address
                        	**type**\:  :py:class:`BsrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress>`
                        
                        .. attribute:: candidate_bsr_address
                        
                        	C\-BSR address
                        	**type**\:  :py:class:`CandidateBsrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress>`
                        
                        .. attribute:: bsr_priority
                        
                        	BSR Priority
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: bsr_mask_length
                        
                        	Hash Function Mask Length
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: bsr_up_time
                        
                        	BSR Uptime
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: bootstrap_timeout
                        
                        	Bootstrap Timeout
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: candidate_bsr_state
                        
                        	BSR Candidate State
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bsr_election_state
                        
                        	BSR Election State
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bsr_scope
                        
                        	BSR Scope
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: candidate_bsr_flag
                        
                        	BSR Candidate Config Flag
                        	**type**\: bool
                        
                        .. attribute:: candidate_bsr_priority
                        
                        	C\-BSR Priority
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: candidate_bsr_mask_length
                        
                        	C\-BSR Hash Func. Mask Len
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection, self).__init__()

                            self.yang_name = "bsr-election"
                            self.yang_parent_name = "bsr-elections"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['pim_scope']
                            self._child_classes = OrderedDict([("bsr-address", ("bsr_address", Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress)), ("candidate-bsr-address", ("candidate_bsr_address", Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress))])
                            self._leafs = OrderedDict([
                                ('pim_scope', (YLeaf(YType.uint32, 'pim-scope'), ['int'])),
                                ('bsr_priority', (YLeaf(YType.uint8, 'bsr-priority'), ['int'])),
                                ('bsr_mask_length', (YLeaf(YType.uint8, 'bsr-mask-length'), ['int'])),
                                ('bsr_up_time', (YLeaf(YType.uint16, 'bsr-up-time'), ['int'])),
                                ('bootstrap_timeout', (YLeaf(YType.uint16, 'bootstrap-timeout'), ['int'])),
                                ('candidate_bsr_state', (YLeaf(YType.uint32, 'candidate-bsr-state'), ['int'])),
                                ('bsr_election_state', (YLeaf(YType.uint32, 'bsr-election-state'), ['int'])),
                                ('bsr_scope', (YLeaf(YType.uint16, 'bsr-scope'), ['int'])),
                                ('candidate_bsr_flag', (YLeaf(YType.boolean, 'candidate-bsr-flag'), ['bool'])),
                                ('candidate_bsr_priority', (YLeaf(YType.uint8, 'candidate-bsr-priority'), ['int'])),
                                ('candidate_bsr_mask_length', (YLeaf(YType.uint8, 'candidate-bsr-mask-length'), ['int'])),
                            ])
                            self.pim_scope = None
                            self.bsr_priority = None
                            self.bsr_mask_length = None
                            self.bsr_up_time = None
                            self.bootstrap_timeout = None
                            self.candidate_bsr_state = None
                            self.bsr_election_state = None
                            self.bsr_scope = None
                            self.candidate_bsr_flag = None
                            self.candidate_bsr_priority = None
                            self.candidate_bsr_mask_length = None

                            self.bsr_address = Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress()
                            self.bsr_address.parent = self
                            self._children_name_map["bsr_address"] = "bsr-address"

                            self.candidate_bsr_address = Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress()
                            self.candidate_bsr_address.parent = self
                            self._children_name_map["candidate_bsr_address"] = "candidate-bsr-address"
                            self._segment_path = lambda: "bsr-election" + "[pim-scope='" + str(self.pim_scope) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/bsr/bsr-elections/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection, ['pim_scope', 'bsr_priority', 'bsr_mask_length', 'bsr_up_time', 'bootstrap_timeout', 'candidate_bsr_state', 'bsr_election_state', 'bsr_scope', 'candidate_bsr_flag', 'candidate_bsr_priority', 'candidate_bsr_mask_length'], name, value)


                        class BsrAddress(Entity):
                            """
                            BSR address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress, self).__init__()

                                self.yang_name = "bsr-address"
                                self.yang_parent_name = "bsr-election"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "bsr-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class CandidateBsrAddress(Entity):
                            """
                            C\-BSR address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress, self).__init__()

                                self.yang_name = "candidate-bsr-address"
                                self.yang_parent_name = "bsr-election"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "candidate-bsr-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class RoutePolicy(Entity):
                """
                PIM route policy
                
                .. attribute:: route_policy_statistics
                
                	PIM route policy statistics
                	**type**\:  :py:class:`RoutePolicyStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.RoutePolicy.RoutePolicyStatistics>`
                
                .. attribute:: route_policy_tests
                
                	PIM route policy test run table
                	**type**\:  :py:class:`RoutePolicyTests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Active.DefaultContext.RoutePolicy, self).__init__()

                    self.yang_name = "route-policy"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("route-policy-statistics", ("route_policy_statistics", Pim.Active.DefaultContext.RoutePolicy.RoutePolicyStatistics)), ("route-policy-tests", ("route_policy_tests", Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests))])
                    self._leafs = OrderedDict()

                    self.route_policy_statistics = Pim.Active.DefaultContext.RoutePolicy.RoutePolicyStatistics()
                    self.route_policy_statistics.parent = self
                    self._children_name_map["route_policy_statistics"] = "route-policy-statistics"

                    self.route_policy_tests = Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests()
                    self.route_policy_tests.parent = self
                    self._children_name_map["route_policy_tests"] = "route-policy-tests"
                    self._segment_path = lambda: "route-policy"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.DefaultContext.RoutePolicy, [], name, value)


                class RoutePolicyStatistics(Entity):
                    """
                    PIM route policy statistics
                    
                    .. attribute:: policy_name
                    
                    	RPF policy name
                    	**type**\: str
                    
                    .. attribute:: requests
                    
                    	Number of RPF lookup requests
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pass_
                    
                    	Number of RPF pass
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: drop
                    
                    	Number of RPF drops
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: default_table
                    
                    	Number of RPF lookup in default\-only Table
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: any_table
                    
                    	Number of RPF lookup in any Table
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.RoutePolicy.RoutePolicyStatistics, self).__init__()

                        self.yang_name = "route-policy-statistics"
                        self.yang_parent_name = "route-policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('policy_name', (YLeaf(YType.str, 'policy-name'), ['str'])),
                            ('requests', (YLeaf(YType.uint32, 'requests'), ['int'])),
                            ('pass_', (YLeaf(YType.uint32, 'pass'), ['int'])),
                            ('drop', (YLeaf(YType.uint32, 'drop'), ['int'])),
                            ('default_table', (YLeaf(YType.uint32, 'default-table'), ['int'])),
                            ('any_table', (YLeaf(YType.uint32, 'any-table'), ['int'])),
                        ])
                        self.policy_name = None
                        self.requests = None
                        self.pass_ = None
                        self.drop = None
                        self.default_table = None
                        self.any_table = None
                        self._segment_path = lambda: "route-policy-statistics"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/route-policy/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.RoutePolicy.RoutePolicyStatistics, ['policy_name', 'requests', 'pass_', 'drop', 'default_table', 'any_table'], name, value)


                class RoutePolicyTests(Entity):
                    """
                    PIM route policy test run table
                    
                    .. attribute:: route_policy_test
                    
                    	PIM route policy test run
                    	**type**\: list of  		 :py:class:`RoutePolicyTest <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests, self).__init__()

                        self.yang_name = "route-policy-tests"
                        self.yang_parent_name = "route-policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("route-policy-test", ("route_policy_test", Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest))])
                        self._leafs = OrderedDict()

                        self.route_policy_test = YList(self)
                        self._segment_path = lambda: "route-policy-tests"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/route-policy/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests, [], name, value)


                    class RoutePolicyTest(Entity):
                        """
                        PIM route policy test run
                        
                        .. attribute:: source_address
                        
                        	Source IP address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: group_address
                        
                        	Group IP address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ext_comm
                        
                        	Extended Community
                        	**type**\: str
                        
                        	**length:** 1..8
                        
                        .. attribute:: source_address_xr
                        
                        	Source address
                        	**type**\:  :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr>`
                        
                        .. attribute:: group_address_xr
                        
                        	Source address
                        	**type**\:  :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr>`
                        
                        .. attribute:: policy_name
                        
                        	RPF policy name
                        	**type**\: str
                        
                        .. attribute:: extended_community_rt
                        
                        	Route Target
                        	**type**\: str
                        
                        	**length:** 0..33
                        
                        .. attribute:: pass_
                        
                        	Pass
                        	**type**\: bool
                        
                        .. attribute:: default_table
                        
                        	Default table selected
                        	**type**\: bool
                        
                        .. attribute:: vrf_name
                        
                        	VRF name
                        	**type**\: str
                        
                        	**length:** 0..33
                        
                        .. attribute:: afi
                        
                        	AFI
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: safi
                        
                        	SAFI
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_name
                        
                        	Table name
                        	**type**\: str
                        
                        .. attribute:: table_exists
                        
                        	Table exists
                        	**type**\: bool
                        
                        .. attribute:: table_active
                        
                        	Table active
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest, self).__init__()

                            self.yang_name = "route-policy-test"
                            self.yang_parent_name = "route-policy-tests"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("source-address-xr", ("source_address_xr", Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr)), ("group-address-xr", ("group_address_xr", Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr))])
                            self._leafs = OrderedDict([
                                ('source_address', (YLeaf(YType.str, 'source-address'), ['str','str'])),
                                ('group_address', (YLeaf(YType.str, 'group-address'), ['str','str'])),
                                ('ext_comm', (YLeaf(YType.str, 'ext-comm'), ['str'])),
                                ('policy_name', (YLeaf(YType.str, 'policy-name'), ['str'])),
                                ('extended_community_rt', (YLeaf(YType.str, 'extended-community-rt'), ['str'])),
                                ('pass_', (YLeaf(YType.boolean, 'pass'), ['bool'])),
                                ('default_table', (YLeaf(YType.boolean, 'default-table'), ['bool'])),
                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                ('afi', (YLeaf(YType.uint32, 'afi'), ['int'])),
                                ('safi', (YLeaf(YType.uint32, 'safi'), ['int'])),
                                ('table_name', (YLeaf(YType.str, 'table-name'), ['str'])),
                                ('table_exists', (YLeaf(YType.boolean, 'table-exists'), ['bool'])),
                                ('table_active', (YLeaf(YType.boolean, 'table-active'), ['bool'])),
                            ])
                            self.source_address = None
                            self.group_address = None
                            self.ext_comm = None
                            self.policy_name = None
                            self.extended_community_rt = None
                            self.pass_ = None
                            self.default_table = None
                            self.vrf_name = None
                            self.afi = None
                            self.safi = None
                            self.table_name = None
                            self.table_exists = None
                            self.table_active = None

                            self.source_address_xr = Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr()
                            self.source_address_xr.parent = self
                            self._children_name_map["source_address_xr"] = "source-address-xr"

                            self.group_address_xr = Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._segment_path = lambda: "route-policy-test"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/route-policy/route-policy-tests/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest, ['source_address', 'group_address', 'ext_comm', 'policy_name', 'extended_community_rt', 'pass_', 'default_table', 'vrf_name', 'afi', 'safi', 'table_name', 'table_exists', 'table_active'], name, value)


                        class SourceAddressXr(Entity):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr, self).__init__()

                                self.yang_name = "source-address-xr"
                                self.yang_parent_name = "route-policy-test"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "source-address-xr"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/route-policy/route-policy-tests/route-policy-test/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class GroupAddressXr(Entity):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "route-policy-test"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "group-address-xr"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/route-policy/route-policy-tests/route-policy-test/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class RpfSummary(Entity):
                """
                PIM RPF registration summary
                
                .. attribute:: default_safi
                
                	Default RPF Table SAFI
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: default_table_name
                
                	Default RPF Table Name
                	**type**\: str
                
                .. attribute:: is_mbgp_configured
                
                	Is MBGP configured?
                	**type**\: bool
                
                .. attribute:: is_ospf_te_configured
                
                	Is OSPF TE configured?
                	**type**\: bool
                
                .. attribute:: is_isis_te_configured
                
                	Is ISIS TE configured?
                	**type**\: bool
                
                .. attribute:: is_isis_mtr_configured
                
                	Is ISIS MTR configured?
                	**type**\: bool
                
                .. attribute:: mo_frr_configured
                
                	Is MoFRR configured?
                	**type**\: bool
                
                .. attribute:: rib_mo_frr_configured
                
                	Is MoFRR RIB configured?
                	**type**\: bool
                
                .. attribute:: rump_enabled
                
                	Is RUMP MuRIB enabled?
                	**type**\: bool
                
                .. attribute:: rib_convergence_timeout
                
                	RIB convergence timeout in seconds
                	**type**\: int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: rib_convergence_time_left
                
                	RIB convergence time left in seconds
                	**type**\: int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: is_multipath_enabled
                
                	Is Multipath Enabled ?
                	**type**\: bool
                
                .. attribute:: is_multipath_interface_hash_enabled
                
                	Is Multipath Interface Hash Extension Enabled ?
                	**type**\: bool
                
                .. attribute:: is_multipath_source_hash_enabled
                
                	Is Multipath Source based Hash Enabled ?
                	**type**\: bool
                
                .. attribute:: is_multipath_source_next_hop_hash_enabled
                
                	Is Multipath Source\-Nexthop Hash Enabled ?
                	**type**\: bool
                
                .. attribute:: rpf_registrations
                
                	RPF Registration count
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_rib_convergence
                
                	RIB Convergence status
                	**type**\: bool
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Active.DefaultContext.RpfSummary, self).__init__()

                    self.yang_name = "rpf-summary"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('default_safi', (YLeaf(YType.uint32, 'default-safi'), ['int'])),
                        ('default_table_name', (YLeaf(YType.str, 'default-table-name'), ['str'])),
                        ('is_mbgp_configured', (YLeaf(YType.boolean, 'is-mbgp-configured'), ['bool'])),
                        ('is_ospf_te_configured', (YLeaf(YType.boolean, 'is-ospf-te-configured'), ['bool'])),
                        ('is_isis_te_configured', (YLeaf(YType.boolean, 'is-isis-te-configured'), ['bool'])),
                        ('is_isis_mtr_configured', (YLeaf(YType.boolean, 'is-isis-mtr-configured'), ['bool'])),
                        ('mo_frr_configured', (YLeaf(YType.boolean, 'mo-frr-configured'), ['bool'])),
                        ('rib_mo_frr_configured', (YLeaf(YType.boolean, 'rib-mo-frr-configured'), ['bool'])),
                        ('rump_enabled', (YLeaf(YType.boolean, 'rump-enabled'), ['bool'])),
                        ('rib_convergence_timeout', (YLeaf(YType.uint32, 'rib-convergence-timeout'), ['int'])),
                        ('rib_convergence_time_left', (YLeaf(YType.uint32, 'rib-convergence-time-left'), ['int'])),
                        ('is_multipath_enabled', (YLeaf(YType.boolean, 'is-multipath-enabled'), ['bool'])),
                        ('is_multipath_interface_hash_enabled', (YLeaf(YType.boolean, 'is-multipath-interface-hash-enabled'), ['bool'])),
                        ('is_multipath_source_hash_enabled', (YLeaf(YType.boolean, 'is-multipath-source-hash-enabled'), ['bool'])),
                        ('is_multipath_source_next_hop_hash_enabled', (YLeaf(YType.boolean, 'is-multipath-source-next-hop-hash-enabled'), ['bool'])),
                        ('rpf_registrations', (YLeaf(YType.uint32, 'rpf-registrations'), ['int'])),
                        ('is_rib_convergence', (YLeaf(YType.boolean, 'is-rib-convergence'), ['bool'])),
                    ])
                    self.default_safi = None
                    self.default_table_name = None
                    self.is_mbgp_configured = None
                    self.is_ospf_te_configured = None
                    self.is_isis_te_configured = None
                    self.is_isis_mtr_configured = None
                    self.mo_frr_configured = None
                    self.rib_mo_frr_configured = None
                    self.rump_enabled = None
                    self.rib_convergence_timeout = None
                    self.rib_convergence_time_left = None
                    self.is_multipath_enabled = None
                    self.is_multipath_interface_hash_enabled = None
                    self.is_multipath_source_hash_enabled = None
                    self.is_multipath_source_next_hop_hash_enabled = None
                    self.rpf_registrations = None
                    self.is_rib_convergence = None
                    self._segment_path = lambda: "rpf-summary"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.DefaultContext.RpfSummary, ['default_safi', 'default_table_name', 'is_mbgp_configured', 'is_ospf_te_configured', 'is_isis_te_configured', 'is_isis_mtr_configured', 'mo_frr_configured', 'rib_mo_frr_configured', 'rump_enabled', 'rib_convergence_timeout', 'rib_convergence_time_left', 'is_multipath_enabled', 'is_multipath_interface_hash_enabled', 'is_multipath_source_hash_enabled', 'is_multipath_source_next_hop_hash_enabled', 'rpf_registrations', 'is_rib_convergence'], name, value)


            class Interfaces(Entity):
                """
                PIM interfaces
                
                .. attribute:: interface
                
                	PIM interface name
                	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Interfaces.Interface>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Active.DefaultContext.Interfaces, self).__init__()

                    self.yang_name = "interfaces"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("interface", ("interface", Pim.Active.DefaultContext.Interfaces.Interface))])
                    self._leafs = OrderedDict()

                    self.interface = YList(self)
                    self._segment_path = lambda: "interfaces"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.DefaultContext.Interfaces, [], name, value)


                class Interface(Entity):
                    """
                    PIM interface name
                    
                    .. attribute:: interface_name  (key)
                    
                    	Interface name
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: dr_address
                    
                    	PIM Designated Router
                    	**type**\:  :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Interfaces.Interface.DrAddress>`
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identfier
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: interface_address_mask
                    
                    	Interface IP Address Mask
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: is_enabled
                    
                    	Is PIM enabled on this IF ?
                    	**type**\: bool
                    
                    .. attribute:: neighbor_count
                    
                    	No. of neighbors on this IF
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: external_neighbor_count
                    
                    	No. of external neighbors on this IF
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: hello_interval
                    
                    	Hello Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dr_priority
                    
                    	DR Priority
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_expiry
                    
                    	Hello Timer Expiry
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: are_we_dr
                    
                    	Are we the DR on this IF ?
                    	**type**\: bool
                    
                    .. attribute:: bfd_enabled
                    
                    	BFD state
                    	**type**\: bool
                    
                    .. attribute:: bfd_interval
                    
                    	BFD Interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bfd_multiplier
                    
                    	BFD Multiplier
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_interface
                    
                    	 is this a Virtual Interfaces ?
                    	**type**\: bool
                    
                    .. attribute:: passive_interface
                    
                    	Passive PIM interface
                    	**type**\: bool
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\: str
                    
                    .. attribute:: join_prune_interval
                    
                    	Join\-Prune Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: prune_delay_enabled
                    
                    	Prune Delay Enabled
                    	**type**\: bool
                    
                    .. attribute:: configured_propagation_delay
                    
                    	Configured Propagation Delay
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_override_interval
                    
                    	Configured Override Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: generation_id
                    
                    	Generation Identifier
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Bidir Capable
                    	**type**\: bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Proxy Capable
                    	**type**\: bool
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Batch Asserts Capable
                    	**type**\: bool
                    
                    .. attribute:: idb_oor_enabled
                    
                    	Interface oor enabled
                    	**type**\: bool
                    
                    .. attribute:: idb_acl_provided
                    
                    	ACL name provided
                    	**type**\: bool
                    
                    .. attribute:: idb_max_count
                    
                    	Interface ole max count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_threshold_count
                    
                    	Interface ole threshold count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_current_count
                    
                    	Interface ole current count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_acl_name
                    
                    	Interface ole ACL Name
                    	**type**\: str
                    
                    	**length:** 0..64
                    
                    .. attribute:: interface_address
                    
                    	List of Interface IP Addresses
                    	**type**\: list of  		 :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Interfaces.Interface.InterfaceAddress>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.Interfaces.Interface, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "interfaces"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['interface_name']
                        self._child_classes = OrderedDict([("dr-address", ("dr_address", Pim.Active.DefaultContext.Interfaces.Interface.DrAddress)), ("interface-address", ("interface_address", Pim.Active.DefaultContext.Interfaces.Interface.InterfaceAddress))])
                        self._leafs = OrderedDict([
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                            ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                            ('interface_address_mask', (YLeaf(YType.uint8, 'interface-address-mask'), ['int'])),
                            ('is_enabled', (YLeaf(YType.boolean, 'is-enabled'), ['bool'])),
                            ('neighbor_count', (YLeaf(YType.uint16, 'neighbor-count'), ['int'])),
                            ('external_neighbor_count', (YLeaf(YType.uint16, 'external-neighbor-count'), ['int'])),
                            ('hello_interval', (YLeaf(YType.uint16, 'hello-interval'), ['int'])),
                            ('dr_priority', (YLeaf(YType.uint32, 'dr-priority'), ['int'])),
                            ('hello_expiry', (YLeaf(YType.uint64, 'hello-expiry'), ['int'])),
                            ('are_we_dr', (YLeaf(YType.boolean, 'are-we-dr'), ['bool'])),
                            ('bfd_enabled', (YLeaf(YType.boolean, 'bfd-enabled'), ['bool'])),
                            ('bfd_interval', (YLeaf(YType.uint32, 'bfd-interval'), ['int'])),
                            ('bfd_multiplier', (YLeaf(YType.uint32, 'bfd-multiplier'), ['int'])),
                            ('virtual_interface', (YLeaf(YType.boolean, 'virtual-interface'), ['bool'])),
                            ('passive_interface', (YLeaf(YType.boolean, 'passive-interface'), ['bool'])),
                            ('neighbor_filter_name', (YLeaf(YType.str, 'neighbor-filter-name'), ['str'])),
                            ('join_prune_interval', (YLeaf(YType.uint16, 'join-prune-interval'), ['int'])),
                            ('prune_delay_enabled', (YLeaf(YType.boolean, 'prune-delay-enabled'), ['bool'])),
                            ('configured_propagation_delay', (YLeaf(YType.uint16, 'configured-propagation-delay'), ['int'])),
                            ('propagation_delay', (YLeaf(YType.uint16, 'propagation-delay'), ['int'])),
                            ('configured_override_interval', (YLeaf(YType.uint16, 'configured-override-interval'), ['int'])),
                            ('override_interval', (YLeaf(YType.uint16, 'override-interval'), ['int'])),
                            ('generation_id', (YLeaf(YType.uint32, 'generation-id'), ['int'])),
                            ('is_bidirectional_capable', (YLeaf(YType.boolean, 'is-bidirectional-capable'), ['bool'])),
                            ('is_proxy_capable', (YLeaf(YType.boolean, 'is-proxy-capable'), ['bool'])),
                            ('is_batch_asserts_capable', (YLeaf(YType.boolean, 'is-batch-asserts-capable'), ['bool'])),
                            ('idb_oor_enabled', (YLeaf(YType.boolean, 'idb-oor-enabled'), ['bool'])),
                            ('idb_acl_provided', (YLeaf(YType.boolean, 'idb-acl-provided'), ['bool'])),
                            ('idb_max_count', (YLeaf(YType.uint32, 'idb-max-count'), ['int'])),
                            ('idb_threshold_count', (YLeaf(YType.uint32, 'idb-threshold-count'), ['int'])),
                            ('idb_current_count', (YLeaf(YType.uint32, 'idb-current-count'), ['int'])),
                            ('idb_acl_name', (YLeaf(YType.str, 'idb-acl-name'), ['str'])),
                        ])
                        self.interface_name = None
                        self.interface_name_xr = None
                        self.interface_address_mask = None
                        self.is_enabled = None
                        self.neighbor_count = None
                        self.external_neighbor_count = None
                        self.hello_interval = None
                        self.dr_priority = None
                        self.hello_expiry = None
                        self.are_we_dr = None
                        self.bfd_enabled = None
                        self.bfd_interval = None
                        self.bfd_multiplier = None
                        self.virtual_interface = None
                        self.passive_interface = None
                        self.neighbor_filter_name = None
                        self.join_prune_interval = None
                        self.prune_delay_enabled = None
                        self.configured_propagation_delay = None
                        self.propagation_delay = None
                        self.configured_override_interval = None
                        self.override_interval = None
                        self.generation_id = None
                        self.is_bidirectional_capable = None
                        self.is_proxy_capable = None
                        self.is_batch_asserts_capable = None
                        self.idb_oor_enabled = None
                        self.idb_acl_provided = None
                        self.idb_max_count = None
                        self.idb_threshold_count = None
                        self.idb_current_count = None
                        self.idb_acl_name = None

                        self.dr_address = Pim.Active.DefaultContext.Interfaces.Interface.DrAddress()
                        self.dr_address.parent = self
                        self._children_name_map["dr_address"] = "dr-address"

                        self.interface_address = YList(self)
                        self._segment_path = lambda: "interface" + "[interface-name='" + str(self.interface_name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/interfaces/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.Interfaces.Interface, ['interface_name', 'interface_name_xr', 'interface_address_mask', 'is_enabled', 'neighbor_count', 'external_neighbor_count', 'hello_interval', 'dr_priority', 'hello_expiry', 'are_we_dr', 'bfd_enabled', 'bfd_interval', 'bfd_multiplier', 'virtual_interface', 'passive_interface', 'neighbor_filter_name', 'join_prune_interval', 'prune_delay_enabled', 'configured_propagation_delay', 'propagation_delay', 'configured_override_interval', 'override_interval', 'generation_id', 'is_bidirectional_capable', 'is_proxy_capable', 'is_batch_asserts_capable', 'idb_oor_enabled', 'idb_acl_provided', 'idb_max_count', 'idb_threshold_count', 'idb_current_count', 'idb_acl_name'], name, value)


                    class DrAddress(Entity):
                        """
                        PIM Designated Router
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Interfaces.Interface.DrAddress, self).__init__()

                            self.yang_name = "dr-address"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "dr-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.Interfaces.Interface.DrAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class InterfaceAddress(Entity):
                        """
                        List of Interface IP Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Interfaces.Interface.InterfaceAddress, self).__init__()

                            self.yang_name = "interface-address"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "interface-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.Interfaces.Interface.InterfaceAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class NetIoTunnels(Entity):
                """
                Tunnel information that NETIO has 
                
                .. attribute:: net_io_tunnel
                
                	PIM netio tunnel information
                	**type**\: list of  		 :py:class:`NetIoTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Active.DefaultContext.NetIoTunnels, self).__init__()

                    self.yang_name = "net-io-tunnels"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("net-io-tunnel", ("net_io_tunnel", Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel))])
                    self._leafs = OrderedDict()

                    self.net_io_tunnel = YList(self)
                    self._segment_path = lambda: "net-io-tunnels"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.DefaultContext.NetIoTunnels, [], name, value)


                class NetIoTunnel(Entity):
                    """
                    PIM netio tunnel information
                    
                    .. attribute:: tunnel_name  (key)
                    
                    	Tunnel name
                    	**type**\: str
                    
                    	**length:** 1..64
                    
                    .. attribute:: source_address
                    
                    	Source addr known to PIM
                    	**type**\:  :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress>`
                    
                    .. attribute:: rp_address
                    
                    	RP addr known to PIM
                    	**type**\:  :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress>`
                    
                    .. attribute:: source_address_netio
                    
                    	Source addr from netio
                    	**type**\:  :py:class:`SourceAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio>`
                    
                    .. attribute:: group_address_netio
                    
                    	Group addr from netio
                    	**type**\:  :py:class:`GroupAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio>`
                    
                    .. attribute:: vrf_name
                    
                    	VRF Name
                    	**type**\: str
                    
                    	**length:** 0..33
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel, self).__init__()

                        self.yang_name = "net-io-tunnel"
                        self.yang_parent_name = "net-io-tunnels"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['tunnel_name']
                        self._child_classes = OrderedDict([("source-address", ("source_address", Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress)), ("rp-address", ("rp_address", Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress)), ("source-address-netio", ("source_address_netio", Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio)), ("group-address-netio", ("group_address_netio", Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio))])
                        self._leafs = OrderedDict([
                            ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                        ])
                        self.tunnel_name = None
                        self.vrf_name = None

                        self.source_address = Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress()
                        self.source_address.parent = self
                        self._children_name_map["source_address"] = "source-address"

                        self.rp_address = Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress()
                        self.rp_address.parent = self
                        self._children_name_map["rp_address"] = "rp-address"

                        self.source_address_netio = Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio()
                        self.source_address_netio.parent = self
                        self._children_name_map["source_address_netio"] = "source-address-netio"

                        self.group_address_netio = Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio()
                        self.group_address_netio.parent = self
                        self._children_name_map["group_address_netio"] = "group-address-netio"
                        self._segment_path = lambda: "net-io-tunnel" + "[tunnel-name='" + str(self.tunnel_name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/net-io-tunnels/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel, ['tunnel_name', 'vrf_name'], name, value)


                    class SourceAddress(Entity):
                        """
                        Source addr known to PIM
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress, self).__init__()

                            self.yang_name = "source-address"
                            self.yang_parent_name = "net-io-tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "source-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class RpAddress(Entity):
                        """
                        RP addr known to PIM
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress, self).__init__()

                            self.yang_name = "rp-address"
                            self.yang_parent_name = "net-io-tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "rp-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class SourceAddressNetio(Entity):
                        """
                        Source addr from netio
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio, self).__init__()

                            self.yang_name = "source-address-netio"
                            self.yang_parent_name = "net-io-tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "source-address-netio"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class GroupAddressNetio(Entity):
                        """
                        Group addr from netio
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio, self).__init__()

                            self.yang_name = "group-address-netio"
                            self.yang_parent_name = "net-io-tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "group-address-netio"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class BidirDfStates(Entity):
                """
                Bidirectional PIM DF election state table
                
                .. attribute:: bidir_df_state
                
                	Bidirectional PIM DF Election Table Entry
                	**type**\: list of  		 :py:class:`BidirDfState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.BidirDfStates.BidirDfState>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Active.DefaultContext.BidirDfStates, self).__init__()

                    self.yang_name = "bidir-df-states"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("bidir-df-state", ("bidir_df_state", Pim.Active.DefaultContext.BidirDfStates.BidirDfState))])
                    self._leafs = OrderedDict()

                    self.bidir_df_state = YList(self)
                    self._segment_path = lambda: "bidir-df-states"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.DefaultContext.BidirDfStates, [], name, value)


                class BidirDfState(Entity):
                    """
                    Bidirectional PIM DF Election Table Entry
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: rp_address_xr
                    
                    	RP Address
                    	**type**\:  :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr>`
                    
                    .. attribute:: pim_interface_name
                    
                    	Interface Name
                    	**type**\: str
                    
                    .. attribute:: election_state
                    
                    	DF Election State
                    	**type**\: str
                    
                    .. attribute:: time_seconds
                    
                    	Timer expires (seconds)
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: time_nano_seconds
                    
                    	Timer expires (nseconds)
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: nanosecond
                    
                    .. attribute:: our_metric
                    
                    	Metric
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: our_metric_preference
                    
                    	MetricPreference
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.BidirDfStates.BidirDfState, self).__init__()

                        self.yang_name = "bidir-df-state"
                        self.yang_parent_name = "bidir-df-states"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("rp-address-xr", ("rp_address_xr", Pim.Active.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr))])
                        self._leafs = OrderedDict([
                            ('rp_address', (YLeaf(YType.str, 'rp-address'), ['str','str'])),
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                            ('pim_interface_name', (YLeaf(YType.str, 'pim-interface-name'), ['str'])),
                            ('election_state', (YLeaf(YType.str, 'election-state'), ['str'])),
                            ('time_seconds', (YLeaf(YType.uint64, 'time-seconds'), ['int'])),
                            ('time_nano_seconds', (YLeaf(YType.uint64, 'time-nano-seconds'), ['int'])),
                            ('our_metric', (YLeaf(YType.uint32, 'our-metric'), ['int'])),
                            ('our_metric_preference', (YLeaf(YType.uint32, 'our-metric-preference'), ['int'])),
                        ])
                        self.rp_address = None
                        self.interface_name = None
                        self.pim_interface_name = None
                        self.election_state = None
                        self.time_seconds = None
                        self.time_nano_seconds = None
                        self.our_metric = None
                        self.our_metric_preference = None

                        self.rp_address_xr = Pim.Active.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr()
                        self.rp_address_xr.parent = self
                        self._children_name_map["rp_address_xr"] = "rp-address-xr"
                        self._segment_path = lambda: "bidir-df-state"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/bidir-df-states/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.BidirDfStates.BidirDfState, ['rp_address', 'interface_name', 'pim_interface_name', 'election_state', 'time_seconds', 'time_nano_seconds', 'our_metric', 'our_metric_preference'], name, value)


                    class RpAddressXr(Entity):
                        """
                        RP Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr, self).__init__()

                            self.yang_name = "rp-address-xr"
                            self.yang_parent_name = "bidir-df-state"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "rp-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/bidir-df-states/bidir-df-state/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class Topologies(Entity):
                """
                PIM topology table
                
                .. attribute:: topology
                
                	PIM topology information
                	**type**\: list of  		 :py:class:`Topology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Topologies.Topology>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Active.DefaultContext.Topologies, self).__init__()

                    self.yang_name = "topologies"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("topology", ("topology", Pim.Active.DefaultContext.Topologies.Topology))])
                    self._leafs = OrderedDict()

                    self.topology = YList(self)
                    self._segment_path = lambda: "topologies"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.DefaultContext.Topologies, [], name, value)


                class Topology(Entity):
                    """
                    PIM topology information
                    
                    .. attribute:: source_address
                    
                    	Source address
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: group_address
                    
                    	Group address
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: rpt
                    
                    	RPT bit
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_address_xr
                    
                    	Group Address
                    	**type**\:  :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Topologies.Topology.GroupAddressXr>`
                    
                    .. attribute:: source_address_xr
                    
                    	Source Address
                    	**type**\:  :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Topologies.Topology.SourceAddressXr>`
                    
                    .. attribute:: rp_address
                    
                    	RP Address (If rpt)
                    	**type**\:  :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Topologies.Topology.RpAddress>`
                    
                    .. attribute:: rpf_neighbor
                    
                    	RPF Neighbor
                    	**type**\:  :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Topologies.Topology.RpfNeighbor>`
                    
                    .. attribute:: secondary_rpf_neighbor
                    
                    	Secondary RPF Neighbor
                    	**type**\:  :py:class:`SecondaryRpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor>`
                    
                    .. attribute:: rpf_root
                    
                    	Root of this mcast tree
                    	**type**\:  :py:class:`RpfRoot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Topologies.Topology.RpfRoot>`
                    
                    .. attribute:: proxy_address
                    
                    	RPF Proxy address
                    	**type**\:  :py:class:`ProxyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Topologies.Topology.ProxyAddress>`
                    
                    .. attribute:: orig_src_address
                    
                    	Orig Src Address
                    	**type**\:  :py:class:`OrigSrcAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Topologies.Topology.OrigSrcAddress>`
                    
                    .. attribute:: limit_reached
                    
                    	Have we throttled the creation of routes or interfaces ?
                    	**type**\: bool
                    
                    .. attribute:: low_memory
                    
                    	Node is running low on memory
                    	**type**\: bool
                    
                    .. attribute:: protocol
                    
                    	The PIM protocol
                    	**type**\:  :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                    
                    .. attribute:: wildcard
                    
                    	WC \-Wildcard
                    	**type**\: bool
                    
                    .. attribute:: rpt_xr
                    
                    	Is this on the RPT ?
                    	**type**\: bool
                    
                    .. attribute:: spt
                    
                    	Is this on the SPT ?
                    	**type**\: bool
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: expiry
                    
                    	When this entry expires
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: alive
                    
                    	Alive time in seconds (\-1 if never)
                    	**type**\: int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    .. attribute:: register_received_timer
                    
                    	Register Received Timer in seconds (\-1 if never)
                    	**type**\: int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    .. attribute:: remote_source
                    
                    	MSDP told us
                    	**type**\: bool
                    
                    .. attribute:: crossed_threshold
                    
                    	Incoming traffic crossed threshold. MT flag set
                    	**type**\: bool
                    
                    .. attribute:: data_mdt_addr_assigned
                    
                    	PIM has assigned a Data MDT Address
                    	**type**\: bool
                    
                    .. attribute:: rpf_interface_name
                    
                    	Interface Identifier
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: rpf_vrf_name
                    
                    	RPF VRF Name
                    	**type**\: str
                    
                    	**length:** 0..33
                    
                    .. attribute:: rpf_safi
                    
                    	Unicast or mcast
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: rpf_table_name
                    
                    	RPF Table name
                    	**type**\: str
                    
                    .. attribute:: rpf_drop
                    
                    	RPF route\-policy drop
                    	**type**\: bool
                    
                    .. attribute:: rpf_extranet
                    
                    	Extranet RPF route\-policy
                    	**type**\: bool
                    
                    .. attribute:: is_via_lsm
                    
                    	Via LSM
                    	**type**\: bool
                    
                    .. attribute:: secondary_rpf_interface_name
                    
                    	Secondary Interface Identifier
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: connected
                    
                    	Is Connected ?
                    	**type**\: bool
                    
                    .. attribute:: proxy
                    
                    	Is the RPF target a proxy?
                    	**type**\: bool
                    
                    .. attribute:: rpf_proxy_enabled
                    
                    	Is rpf if proxy enabled?
                    	**type**\: bool
                    
                    .. attribute:: mofrr_enabled
                    
                    	Is this SG MoFRR enabled?
                    	**type**\: bool
                    
                    .. attribute:: rib_mo_frr_enabled
                    
                    	Is this SG MoFRR enabled?
                    	**type**\: bool
                    
                    .. attribute:: jp_timer
                    
                    	Join\-Prune Timer
                    	**type**\: int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: jp_status
                    
                    	Join\-Prune Status
                    	**type**\: int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: suppress_registers
                    
                    	When the Null register probe expires
                    	**type**\: int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: assume_alive
                    
                    	The Assume Alive Bit
                    	**type**\: bool
                    
                    .. attribute:: probe_alive
                    
                    	The Probe Alive Bit
                    	**type**\: bool
                    
                    .. attribute:: really_alive
                    
                    	The Really Alive Bit
                    	**type**\: bool
                    
                    .. attribute:: inherit_alive
                    
                    	The Inherit Alive Bit
                    	**type**\: bool
                    
                    .. attribute:: inherit_spt
                    
                    	The Inherit SPT Bit
                    	**type**\: bool
                    
                    .. attribute:: signal_sources
                    
                    	Signal Sources on route?
                    	**type**\: bool
                    
                    .. attribute:: dont_check_connected
                    
                    	Do we need to make the connected check on this route ?
                    	**type**\: bool
                    
                    .. attribute:: register_received
                    
                    	Have registers been received for this source ?
                    	**type**\: bool
                    
                    .. attribute:: last_hop
                    
                    	Are we last hop ?
                    	**type**\: bool
                    
                    .. attribute:: sending_registers
                    
                    	Are we sending registers for this route ?
                    	**type**\: bool
                    
                    .. attribute:: sending_null_registers
                    
                    	Are we sending null registers for this route ?
                    	**type**\: bool
                    
                    .. attribute:: sa_sent
                    
                    	BGP SA sent
                    	**type**\: bool
                    
                    .. attribute:: sa_received
                    
                    	BGP SA received
                    	**type**\: bool
                    
                    .. attribute:: sa_joined
                    
                    	BGP SA join
                    	**type**\: bool
                    
                    .. attribute:: anycast_rp_match
                    
                    	Group matches Anycast\-RP policy
                    	**type**\: bool
                    
                    .. attribute:: anycast_rp_route_target
                    
                    	Anycast\-RP RT
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: bgp_join
                    
                    	BGP C JOIN
                    	**type**\: bool
                    
                    .. attribute:: bgp_jp_time
                    
                    	BGP C JP Time
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: customer_routing_type
                    
                    	Type of Customer Routing in the MVPN
                    	**type**\: int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: extranet_route
                    
                    	Is a Extranet route ?
                    	**type**\: bool
                    
                    .. attribute:: mofrr_active
                    
                    	Is MoFRR Active?
                    	**type**\: bool
                    
                    .. attribute:: mofrr_primary
                    
                    	Is this Mofrr Primary?
                    	**type**\: bool
                    
                    .. attribute:: mofrr_backup
                    
                    	Is this Mofrr Backup?
                    	**type**\: bool
                    
                    .. attribute:: vxlan
                    
                    	Is this VXLAN?
                    	**type**\: bool
                    
                    .. attribute:: kat_state
                    
                    	Keep Alive Timer State
                    	**type**\: bool
                    
                    .. attribute:: outgoing_interface
                    
                    	Outgoing interface list
                    	**type**\: list of  		 :py:class:`OutgoingInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.Topologies.Topology, self).__init__()

                        self.yang_name = "topology"
                        self.yang_parent_name = "topologies"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("group-address-xr", ("group_address_xr", Pim.Active.DefaultContext.Topologies.Topology.GroupAddressXr)), ("source-address-xr", ("source_address_xr", Pim.Active.DefaultContext.Topologies.Topology.SourceAddressXr)), ("rp-address", ("rp_address", Pim.Active.DefaultContext.Topologies.Topology.RpAddress)), ("rpf-neighbor", ("rpf_neighbor", Pim.Active.DefaultContext.Topologies.Topology.RpfNeighbor)), ("secondary-rpf-neighbor", ("secondary_rpf_neighbor", Pim.Active.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor)), ("rpf-root", ("rpf_root", Pim.Active.DefaultContext.Topologies.Topology.RpfRoot)), ("proxy-address", ("proxy_address", Pim.Active.DefaultContext.Topologies.Topology.ProxyAddress)), ("orig-src-address", ("orig_src_address", Pim.Active.DefaultContext.Topologies.Topology.OrigSrcAddress)), ("outgoing-interface", ("outgoing_interface", Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface))])
                        self._leafs = OrderedDict([
                            ('source_address', (YLeaf(YType.str, 'source-address'), ['str','str'])),
                            ('group_address', (YLeaf(YType.str, 'group-address'), ['str','str'])),
                            ('rpt', (YLeaf(YType.uint32, 'rpt'), ['int'])),
                            ('limit_reached', (YLeaf(YType.boolean, 'limit-reached'), ['bool'])),
                            ('low_memory', (YLeaf(YType.boolean, 'low-memory'), ['bool'])),
                            ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowProtocol', '')])),
                            ('wildcard', (YLeaf(YType.boolean, 'wildcard'), ['bool'])),
                            ('rpt_xr', (YLeaf(YType.boolean, 'rpt-xr'), ['bool'])),
                            ('spt', (YLeaf(YType.boolean, 'spt'), ['bool'])),
                            ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                            ('expiry', (YLeaf(YType.uint64, 'expiry'), ['int'])),
                            ('alive', (YLeaf(YType.int32, 'alive'), ['int'])),
                            ('register_received_timer', (YLeaf(YType.int32, 'register-received-timer'), ['int'])),
                            ('remote_source', (YLeaf(YType.boolean, 'remote-source'), ['bool'])),
                            ('crossed_threshold', (YLeaf(YType.boolean, 'crossed-threshold'), ['bool'])),
                            ('data_mdt_addr_assigned', (YLeaf(YType.boolean, 'data-mdt-addr-assigned'), ['bool'])),
                            ('rpf_interface_name', (YLeaf(YType.str, 'rpf-interface-name'), ['str'])),
                            ('rpf_vrf_name', (YLeaf(YType.str, 'rpf-vrf-name'), ['str'])),
                            ('rpf_safi', (YLeaf(YType.uint8, 'rpf-safi'), ['int'])),
                            ('rpf_table_name', (YLeaf(YType.str, 'rpf-table-name'), ['str'])),
                            ('rpf_drop', (YLeaf(YType.boolean, 'rpf-drop'), ['bool'])),
                            ('rpf_extranet', (YLeaf(YType.boolean, 'rpf-extranet'), ['bool'])),
                            ('is_via_lsm', (YLeaf(YType.boolean, 'is-via-lsm'), ['bool'])),
                            ('secondary_rpf_interface_name', (YLeaf(YType.str, 'secondary-rpf-interface-name'), ['str'])),
                            ('connected', (YLeaf(YType.boolean, 'connected'), ['bool'])),
                            ('proxy', (YLeaf(YType.boolean, 'proxy'), ['bool'])),
                            ('rpf_proxy_enabled', (YLeaf(YType.boolean, 'rpf-proxy-enabled'), ['bool'])),
                            ('mofrr_enabled', (YLeaf(YType.boolean, 'mofrr-enabled'), ['bool'])),
                            ('rib_mo_frr_enabled', (YLeaf(YType.boolean, 'rib-mo-frr-enabled'), ['bool'])),
                            ('jp_timer', (YLeaf(YType.int32, 'jp-timer'), ['int'])),
                            ('jp_status', (YLeaf(YType.int32, 'jp-status'), ['int'])),
                            ('suppress_registers', (YLeaf(YType.int32, 'suppress-registers'), ['int'])),
                            ('assume_alive', (YLeaf(YType.boolean, 'assume-alive'), ['bool'])),
                            ('probe_alive', (YLeaf(YType.boolean, 'probe-alive'), ['bool'])),
                            ('really_alive', (YLeaf(YType.boolean, 'really-alive'), ['bool'])),
                            ('inherit_alive', (YLeaf(YType.boolean, 'inherit-alive'), ['bool'])),
                            ('inherit_spt', (YLeaf(YType.boolean, 'inherit-spt'), ['bool'])),
                            ('signal_sources', (YLeaf(YType.boolean, 'signal-sources'), ['bool'])),
                            ('dont_check_connected', (YLeaf(YType.boolean, 'dont-check-connected'), ['bool'])),
                            ('register_received', (YLeaf(YType.boolean, 'register-received'), ['bool'])),
                            ('last_hop', (YLeaf(YType.boolean, 'last-hop'), ['bool'])),
                            ('sending_registers', (YLeaf(YType.boolean, 'sending-registers'), ['bool'])),
                            ('sending_null_registers', (YLeaf(YType.boolean, 'sending-null-registers'), ['bool'])),
                            ('sa_sent', (YLeaf(YType.boolean, 'sa-sent'), ['bool'])),
                            ('sa_received', (YLeaf(YType.boolean, 'sa-received'), ['bool'])),
                            ('sa_joined', (YLeaf(YType.boolean, 'sa-joined'), ['bool'])),
                            ('anycast_rp_match', (YLeaf(YType.boolean, 'anycast-rp-match'), ['bool'])),
                            ('anycast_rp_route_target', (YLeaf(YType.str, 'anycast-rp-route-target'), ['str'])),
                            ('bgp_join', (YLeaf(YType.boolean, 'bgp-join'), ['bool'])),
                            ('bgp_jp_time', (YLeaf(YType.uint64, 'bgp-jp-time'), ['int'])),
                            ('customer_routing_type', (YLeaf(YType.int32, 'customer-routing-type'), ['int'])),
                            ('extranet_route', (YLeaf(YType.boolean, 'extranet-route'), ['bool'])),
                            ('mofrr_active', (YLeaf(YType.boolean, 'mofrr-active'), ['bool'])),
                            ('mofrr_primary', (YLeaf(YType.boolean, 'mofrr-primary'), ['bool'])),
                            ('mofrr_backup', (YLeaf(YType.boolean, 'mofrr-backup'), ['bool'])),
                            ('vxlan', (YLeaf(YType.boolean, 'vxlan'), ['bool'])),
                            ('kat_state', (YLeaf(YType.boolean, 'kat-state'), ['bool'])),
                        ])
                        self.source_address = None
                        self.group_address = None
                        self.rpt = None
                        self.limit_reached = None
                        self.low_memory = None
                        self.protocol = None
                        self.wildcard = None
                        self.rpt_xr = None
                        self.spt = None
                        self.uptime = None
                        self.expiry = None
                        self.alive = None
                        self.register_received_timer = None
                        self.remote_source = None
                        self.crossed_threshold = None
                        self.data_mdt_addr_assigned = None
                        self.rpf_interface_name = None
                        self.rpf_vrf_name = None
                        self.rpf_safi = None
                        self.rpf_table_name = None
                        self.rpf_drop = None
                        self.rpf_extranet = None
                        self.is_via_lsm = None
                        self.secondary_rpf_interface_name = None
                        self.connected = None
                        self.proxy = None
                        self.rpf_proxy_enabled = None
                        self.mofrr_enabled = None
                        self.rib_mo_frr_enabled = None
                        self.jp_timer = None
                        self.jp_status = None
                        self.suppress_registers = None
                        self.assume_alive = None
                        self.probe_alive = None
                        self.really_alive = None
                        self.inherit_alive = None
                        self.inherit_spt = None
                        self.signal_sources = None
                        self.dont_check_connected = None
                        self.register_received = None
                        self.last_hop = None
                        self.sending_registers = None
                        self.sending_null_registers = None
                        self.sa_sent = None
                        self.sa_received = None
                        self.sa_joined = None
                        self.anycast_rp_match = None
                        self.anycast_rp_route_target = None
                        self.bgp_join = None
                        self.bgp_jp_time = None
                        self.customer_routing_type = None
                        self.extranet_route = None
                        self.mofrr_active = None
                        self.mofrr_primary = None
                        self.mofrr_backup = None
                        self.vxlan = None
                        self.kat_state = None

                        self.group_address_xr = Pim.Active.DefaultContext.Topologies.Topology.GroupAddressXr()
                        self.group_address_xr.parent = self
                        self._children_name_map["group_address_xr"] = "group-address-xr"

                        self.source_address_xr = Pim.Active.DefaultContext.Topologies.Topology.SourceAddressXr()
                        self.source_address_xr.parent = self
                        self._children_name_map["source_address_xr"] = "source-address-xr"

                        self.rp_address = Pim.Active.DefaultContext.Topologies.Topology.RpAddress()
                        self.rp_address.parent = self
                        self._children_name_map["rp_address"] = "rp-address"

                        self.rpf_neighbor = Pim.Active.DefaultContext.Topologies.Topology.RpfNeighbor()
                        self.rpf_neighbor.parent = self
                        self._children_name_map["rpf_neighbor"] = "rpf-neighbor"

                        self.secondary_rpf_neighbor = Pim.Active.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor()
                        self.secondary_rpf_neighbor.parent = self
                        self._children_name_map["secondary_rpf_neighbor"] = "secondary-rpf-neighbor"

                        self.rpf_root = Pim.Active.DefaultContext.Topologies.Topology.RpfRoot()
                        self.rpf_root.parent = self
                        self._children_name_map["rpf_root"] = "rpf-root"

                        self.proxy_address = Pim.Active.DefaultContext.Topologies.Topology.ProxyAddress()
                        self.proxy_address.parent = self
                        self._children_name_map["proxy_address"] = "proxy-address"

                        self.orig_src_address = Pim.Active.DefaultContext.Topologies.Topology.OrigSrcAddress()
                        self.orig_src_address.parent = self
                        self._children_name_map["orig_src_address"] = "orig-src-address"

                        self.outgoing_interface = YList(self)
                        self._segment_path = lambda: "topology"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/topologies/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.Topologies.Topology, ['source_address', 'group_address', 'rpt', 'limit_reached', 'low_memory', 'protocol', 'wildcard', 'rpt_xr', 'spt', 'uptime', 'expiry', 'alive', 'register_received_timer', 'remote_source', 'crossed_threshold', 'data_mdt_addr_assigned', 'rpf_interface_name', 'rpf_vrf_name', 'rpf_safi', 'rpf_table_name', 'rpf_drop', 'rpf_extranet', 'is_via_lsm', 'secondary_rpf_interface_name', 'connected', 'proxy', 'rpf_proxy_enabled', 'mofrr_enabled', 'rib_mo_frr_enabled', 'jp_timer', 'jp_status', 'suppress_registers', 'assume_alive', 'probe_alive', 'really_alive', 'inherit_alive', 'inherit_spt', 'signal_sources', 'dont_check_connected', 'register_received', 'last_hop', 'sending_registers', 'sending_null_registers', 'sa_sent', 'sa_received', 'sa_joined', 'anycast_rp_match', 'anycast_rp_route_target', 'bgp_join', 'bgp_jp_time', 'customer_routing_type', 'extranet_route', 'mofrr_active', 'mofrr_primary', 'mofrr_backup', 'vxlan', 'kat_state'], name, value)


                    class GroupAddressXr(Entity):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Topologies.Topology.GroupAddressXr, self).__init__()

                            self.yang_name = "group-address-xr"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "group-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/topologies/topology/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.Topologies.Topology.GroupAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class SourceAddressXr(Entity):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Topologies.Topology.SourceAddressXr, self).__init__()

                            self.yang_name = "source-address-xr"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "source-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/topologies/topology/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.Topologies.Topology.SourceAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class RpAddress(Entity):
                        """
                        RP Address (If rpt)
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Topologies.Topology.RpAddress, self).__init__()

                            self.yang_name = "rp-address"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "rp-address"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/topologies/topology/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.Topologies.Topology.RpAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class RpfNeighbor(Entity):
                        """
                        RPF Neighbor
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Topologies.Topology.RpfNeighbor, self).__init__()

                            self.yang_name = "rpf-neighbor"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "rpf-neighbor"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/topologies/topology/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.Topologies.Topology.RpfNeighbor, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class SecondaryRpfNeighbor(Entity):
                        """
                        Secondary RPF Neighbor
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor, self).__init__()

                            self.yang_name = "secondary-rpf-neighbor"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "secondary-rpf-neighbor"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/topologies/topology/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class RpfRoot(Entity):
                        """
                        Root of this mcast tree
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Topologies.Topology.RpfRoot, self).__init__()

                            self.yang_name = "rpf-root"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "rpf-root"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/topologies/topology/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.Topologies.Topology.RpfRoot, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class ProxyAddress(Entity):
                        """
                        RPF Proxy address.
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Topologies.Topology.ProxyAddress, self).__init__()

                            self.yang_name = "proxy-address"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "proxy-address"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/topologies/topology/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.Topologies.Topology.ProxyAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class OrigSrcAddress(Entity):
                        """
                        Orig Src Address.
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Topologies.Topology.OrigSrcAddress, self).__init__()

                            self.yang_name = "orig-src-address"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "orig-src-address"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/topologies/topology/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.Topologies.Topology.OrigSrcAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class OutgoingInterface(Entity):
                        """
                        Outgoing interface list
                        
                        .. attribute:: assert_winner
                        
                        	Assert Winner
                        	**type**\:  :py:class:`AssertWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner>`
                        
                        .. attribute:: interface_name
                        
                        	Interface Identifier
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: expiry
                        
                        	Expiry in seconds
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: bgp_c_mcast_prune_delay_timer
                        
                        	BGP C\-MCAST Prune Suppression in seconds
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: jp_timer
                        
                        	Join\-Prune Timer (secs)
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: jp_state
                        
                        	Join\-Prune State
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: assert_timer
                        
                        	Assert Timer in seconds
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: local_members
                        
                        	Local Information. Deprecated \- use 'local\-members\-information' instead
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: internal_interest_info
                        
                        	Internal Interest. Deprecated \- use 'internal\-interest\-information' instead
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: forwarding_state
                        
                        	Forward or Prune
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: immediate_state
                        
                        	Immediate fwding state
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: last_hop
                        
                        	Are we last hop ?
                        	**type**\: bool
                        
                        .. attribute:: mldp_inband_mdt
                        
                        	MLDP Inband MDT interface
                        	**type**\: bool
                        
                        .. attribute:: mldp_stale
                        
                        	OLE is stale
                        	**type**\: bool
                        
                        .. attribute:: sa_prune
                        
                        	BGP SA Prune state
                        	**type**\: bool
                        
                        .. attribute:: admin_boundary
                        
                        	Is this an administrative boundary ?
                        	**type**\: bool
                        
                        .. attribute:: igmp_membership
                        
                        	IGMP membership
                        	**type**\: bool
                        
                        .. attribute:: mdt_safi_join
                        
                        	MDT Safi join
                        	**type**\: bool
                        
                        .. attribute:: mvpn_safi_join
                        
                        	MVPN Safi join
                        	**type**\: bool
                        
                        .. attribute:: local_mdt_join
                        
                        	Default MDT Join
                        	**type**\: bool
                        
                        .. attribute:: data_mdt_join
                        
                        	Data MDT join
                        	**type**\: bool
                        
                        .. attribute:: mvpnv6_safi_join
                        
                        	MVPN IPv6 Safi join
                        	**type**\: bool
                        
                        .. attribute:: bgp_c_mcast_join
                        
                        	BGP C\-Mcast join
                        	**type**\: bool
                        
                        .. attribute:: vrf_name
                        
                        	VRF which physically owns
                        	**type**\: str
                        
                        	**length:** 0..33
                        
                        .. attribute:: extranet_interface
                        
                        	Is this an Extranet Interface ?
                        	**type**\: bool
                        
                        .. attribute:: internal_interest_information
                        
                        	Internal Interest. Replaces internal\-interest\-info
                        	**type**\:  :py:class:`PimInternalInterestInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimInternalInterestInfo>`
                        
                        .. attribute:: local_members_information
                        
                        	Local Information. Replaces local\-members
                        	**type**\:  :py:class:`PimShowLocalInterest <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowLocalInterest>`
                        
                        .. attribute:: assert_state
                        
                        	Assert State
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface, self).__init__()

                            self.yang_name = "outgoing-interface"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("assert-winner", ("assert_winner", Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner))])
                            self._leafs = OrderedDict([
                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                                ('expiry', (YLeaf(YType.uint64, 'expiry'), ['int'])),
                                ('bgp_c_mcast_prune_delay_timer', (YLeaf(YType.uint64, 'bgp-c-mcast-prune-delay-timer'), ['int'])),
                                ('jp_timer', (YLeaf(YType.int32, 'jp-timer'), ['int'])),
                                ('jp_state', (YLeaf(YType.int32, 'jp-state'), ['int'])),
                                ('assert_timer', (YLeaf(YType.int32, 'assert-timer'), ['int'])),
                                ('local_members', (YLeaf(YType.int32, 'local-members'), ['int'])),
                                ('internal_interest_info', (YLeaf(YType.int32, 'internal-interest-info'), ['int'])),
                                ('forwarding_state', (YLeaf(YType.int32, 'forwarding-state'), ['int'])),
                                ('immediate_state', (YLeaf(YType.int32, 'immediate-state'), ['int'])),
                                ('last_hop', (YLeaf(YType.boolean, 'last-hop'), ['bool'])),
                                ('mldp_inband_mdt', (YLeaf(YType.boolean, 'mldp-inband-mdt'), ['bool'])),
                                ('mldp_stale', (YLeaf(YType.boolean, 'mldp-stale'), ['bool'])),
                                ('sa_prune', (YLeaf(YType.boolean, 'sa-prune'), ['bool'])),
                                ('admin_boundary', (YLeaf(YType.boolean, 'admin-boundary'), ['bool'])),
                                ('igmp_membership', (YLeaf(YType.boolean, 'igmp-membership'), ['bool'])),
                                ('mdt_safi_join', (YLeaf(YType.boolean, 'mdt-safi-join'), ['bool'])),
                                ('mvpn_safi_join', (YLeaf(YType.boolean, 'mvpn-safi-join'), ['bool'])),
                                ('local_mdt_join', (YLeaf(YType.boolean, 'local-mdt-join'), ['bool'])),
                                ('data_mdt_join', (YLeaf(YType.boolean, 'data-mdt-join'), ['bool'])),
                                ('mvpnv6_safi_join', (YLeaf(YType.boolean, 'mvpnv6-safi-join'), ['bool'])),
                                ('bgp_c_mcast_join', (YLeaf(YType.boolean, 'bgp-c-mcast-join'), ['bool'])),
                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                ('extranet_interface', (YLeaf(YType.boolean, 'extranet-interface'), ['bool'])),
                                ('internal_interest_information', (YLeaf(YType.enumeration, 'internal-interest-information'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimInternalInterestInfo', '')])),
                                ('local_members_information', (YLeaf(YType.enumeration, 'local-members-information'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowLocalInterest', '')])),
                                ('assert_state', (YLeaf(YType.boolean, 'assert-state'), ['bool'])),
                            ])
                            self.interface_name = None
                            self.uptime = None
                            self.expiry = None
                            self.bgp_c_mcast_prune_delay_timer = None
                            self.jp_timer = None
                            self.jp_state = None
                            self.assert_timer = None
                            self.local_members = None
                            self.internal_interest_info = None
                            self.forwarding_state = None
                            self.immediate_state = None
                            self.last_hop = None
                            self.mldp_inband_mdt = None
                            self.mldp_stale = None
                            self.sa_prune = None
                            self.admin_boundary = None
                            self.igmp_membership = None
                            self.mdt_safi_join = None
                            self.mvpn_safi_join = None
                            self.local_mdt_join = None
                            self.data_mdt_join = None
                            self.mvpnv6_safi_join = None
                            self.bgp_c_mcast_join = None
                            self.vrf_name = None
                            self.extranet_interface = None
                            self.internal_interest_information = None
                            self.local_members_information = None
                            self.assert_state = None

                            self.assert_winner = Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner()
                            self.assert_winner.parent = self
                            self._children_name_map["assert_winner"] = "assert-winner"
                            self._segment_path = lambda: "outgoing-interface"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/topologies/topology/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface, ['interface_name', 'uptime', 'expiry', 'bgp_c_mcast_prune_delay_timer', 'jp_timer', 'jp_state', 'assert_timer', 'local_members', 'internal_interest_info', 'forwarding_state', 'immediate_state', 'last_hop', 'mldp_inband_mdt', 'mldp_stale', 'sa_prune', 'admin_boundary', 'igmp_membership', 'mdt_safi_join', 'mvpn_safi_join', 'local_mdt_join', 'data_mdt_join', 'mvpnv6_safi_join', 'bgp_c_mcast_join', 'vrf_name', 'extranet_interface', 'internal_interest_information', 'local_members_information', 'assert_state'], name, value)


                        class AssertWinner(Entity):
                            """
                            Assert Winner
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner, self).__init__()

                                self.yang_name = "assert-winner"
                                self.yang_parent_name = "outgoing-interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "assert-winner"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/topologies/topology/outgoing-interface/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class BgpAfs(Entity):
                """
                PIM BGP SAFI table
                
                .. attribute:: bgp_af
                
                	PIM BGP SAFI information
                	**type**\: list of  		 :py:class:`BgpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.BgpAfs.BgpAf>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Active.DefaultContext.BgpAfs, self).__init__()

                    self.yang_name = "bgp-afs"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("bgp-af", ("bgp_af", Pim.Active.DefaultContext.BgpAfs.BgpAf))])
                    self._leafs = OrderedDict()

                    self.bgp_af = YList(self)
                    self._segment_path = lambda: "bgp-afs"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.DefaultContext.BgpAfs, [], name, value)


                class BgpAf(Entity):
                    """
                    PIM BGP SAFI information
                    
                    .. attribute:: source_address
                    
                    	Source IP address
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: group_address
                    
                    	Group IP address
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: source
                    
                    	Source address
                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.BgpAfs.BgpAf.Source>`
                    
                    .. attribute:: group
                    
                    	Group address
                    	**type**\:  :py:class:`Group <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.BgpAfs.BgpAf.Group>`
                    
                    .. attribute:: next_hop
                    
                    	Next hop address
                    	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.BgpAfs.BgpAf.NextHop>`
                    
                    .. attribute:: route_distinguisher
                    
                    	Router ID
                    	**type**\: str
                    
                    	**length:** 0..256
                    
                    .. attribute:: extranet_path_count
                    
                    	Count of dependent extranet paths
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_bgp_added
                    
                    	SAFI learnt from BGP
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.BgpAfs.BgpAf, self).__init__()

                        self.yang_name = "bgp-af"
                        self.yang_parent_name = "bgp-afs"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("source", ("source", Pim.Active.DefaultContext.BgpAfs.BgpAf.Source)), ("group", ("group", Pim.Active.DefaultContext.BgpAfs.BgpAf.Group)), ("next-hop", ("next_hop", Pim.Active.DefaultContext.BgpAfs.BgpAf.NextHop))])
                        self._leafs = OrderedDict([
                            ('source_address', (YLeaf(YType.str, 'source-address'), ['str','str'])),
                            ('group_address', (YLeaf(YType.str, 'group-address'), ['str','str'])),
                            ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                            ('extranet_path_count', (YLeaf(YType.uint32, 'extranet-path-count'), ['int'])),
                            ('is_bgp_added', (YLeaf(YType.boolean, 'is-bgp-added'), ['bool'])),
                        ])
                        self.source_address = None
                        self.group_address = None
                        self.route_distinguisher = None
                        self.extranet_path_count = None
                        self.is_bgp_added = None

                        self.source = Pim.Active.DefaultContext.BgpAfs.BgpAf.Source()
                        self.source.parent = self
                        self._children_name_map["source"] = "source"

                        self.group = Pim.Active.DefaultContext.BgpAfs.BgpAf.Group()
                        self.group.parent = self
                        self._children_name_map["group"] = "group"

                        self.next_hop = Pim.Active.DefaultContext.BgpAfs.BgpAf.NextHop()
                        self.next_hop.parent = self
                        self._children_name_map["next_hop"] = "next-hop"
                        self._segment_path = lambda: "bgp-af"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/bgp-afs/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.BgpAfs.BgpAf, ['source_address', 'group_address', 'route_distinguisher', 'extranet_path_count', 'is_bgp_added'], name, value)


                    class Source(Entity):
                        """
                        Source address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.BgpAfs.BgpAf.Source, self).__init__()

                            self.yang_name = "source"
                            self.yang_parent_name = "bgp-af"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "source"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/bgp-afs/bgp-af/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.BgpAfs.BgpAf.Source, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class Group(Entity):
                        """
                        Group address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.BgpAfs.BgpAf.Group, self).__init__()

                            self.yang_name = "group"
                            self.yang_parent_name = "bgp-af"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "group"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/bgp-afs/bgp-af/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.BgpAfs.BgpAf.Group, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class NextHop(Entity):
                        """
                        Next hop address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.BgpAfs.BgpAf.NextHop, self).__init__()

                            self.yang_name = "next-hop"
                            self.yang_parent_name = "bgp-af"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "next-hop"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/bgp-afs/bgp-af/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.BgpAfs.BgpAf.NextHop, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class AutoRp(Entity):
                """
                PIM Auto\-RP information
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Active.DefaultContext.AutoRp, self).__init__()

                    self.yang_name = "auto-rp"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "auto-rp"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True


            class TopologyInterfaceFlagRouteCounts(Entity):
                """
                Route count for topology with interface flag set
                
                .. attribute:: topology_interface_flag_route_count
                
                	Route count for topology with interface flag set
                	**type**\: list of  		 :py:class:`TopologyInterfaceFlagRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts, self).__init__()

                    self.yang_name = "topology-interface-flag-route-counts"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("topology-interface-flag-route-count", ("topology_interface_flag_route_count", Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount))])
                    self._leafs = OrderedDict()

                    self.topology_interface_flag_route_count = YList(self)
                    self._segment_path = lambda: "topology-interface-flag-route-counts"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts, [], name, value)


                class TopologyInterfaceFlagRouteCount(Entity):
                    """
                    Route count for topology with interface flag
                    set
                    
                    .. attribute:: interface_flag  (key)
                    
                    	Interface flag
                    	**type**\:  :py:class:`PimTopologyInterfaceFlag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimTopologyInterfaceFlag>`
                    
                    .. attribute:: group_ranges
                    
                    	No. of (\*,G/M) routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: active_group_ranges
                    
                    	No. of (\*,G/M) routes active in mrib
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: groute_count
                    
                    	No. of (\*,G) routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sg_route_count
                    
                    	No. of (S,G) routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sgr_route_count
                    
                    	No. of (S,G)RPT routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount, self).__init__()

                        self.yang_name = "topology-interface-flag-route-count"
                        self.yang_parent_name = "topology-interface-flag-route-counts"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['interface_flag']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('interface_flag', (YLeaf(YType.enumeration, 'interface-flag'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimTopologyInterfaceFlag', '')])),
                            ('group_ranges', (YLeaf(YType.uint32, 'group-ranges'), ['int'])),
                            ('active_group_ranges', (YLeaf(YType.uint32, 'active-group-ranges'), ['int'])),
                            ('groute_count', (YLeaf(YType.uint32, 'groute-count'), ['int'])),
                            ('sg_route_count', (YLeaf(YType.uint32, 'sg-route-count'), ['int'])),
                            ('sgr_route_count', (YLeaf(YType.uint32, 'sgr-route-count'), ['int'])),
                            ('is_node_low_memory', (YLeaf(YType.boolean, 'is-node-low-memory'), ['bool'])),
                        ])
                        self.interface_flag = None
                        self.group_ranges = None
                        self.active_group_ranges = None
                        self.groute_count = None
                        self.sg_route_count = None
                        self.sgr_route_count = None
                        self.is_node_low_memory = None
                        self._segment_path = lambda: "topology-interface-flag-route-count" + "[interface-flag='" + str(self.interface_flag) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/topology-interface-flag-route-counts/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount, ['interface_flag', 'group_ranges', 'active_group_ranges', 'groute_count', 'sg_route_count', 'sgr_route_count', 'is_node_low_memory'], name, value)


            class GroupMapSources(Entity):
                """
                PIM group\-mapping with source information
                
                .. attribute:: group_map_source
                
                	PIM Group Mapping Entry with source information
                	**type**\: list of  		 :py:class:`GroupMapSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapSources.GroupMapSource>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Active.DefaultContext.GroupMapSources, self).__init__()

                    self.yang_name = "group-map-sources"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("group-map-source", ("group_map_source", Pim.Active.DefaultContext.GroupMapSources.GroupMapSource))])
                    self._leafs = OrderedDict()

                    self.group_map_source = YList(self)
                    self._segment_path = lambda: "group-map-sources"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.DefaultContext.GroupMapSources, [], name, value)


                class GroupMapSource(Entity):
                    """
                    PIM Group Mapping Entry with source information
                    
                    .. attribute:: prefix
                    
                    	Prefix
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: client
                    
                    	Client
                    	**type**\:  :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                    
                    .. attribute:: protocol
                    
                    	Protocol
                    	**type**\:  :py:class:`PimProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimProtocol>`
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: priority
                    
                    	RP Priority
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: source_of_information
                    
                    	The source of information
                    	**type**\:  :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation>`
                    
                    .. attribute:: group_map_information
                    
                    	Group Mapping information
                    	**type**\:  :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation>`
                    
                    .. attribute:: holdtime
                    
                    	Holdtime in seconds
                    	**type**\: int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    .. attribute:: expires
                    
                    	Mapping expiry time in seconds
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: uptime
                    
                    	Mapping uptime in seconds
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.GroupMapSources.GroupMapSource, self).__init__()

                        self.yang_name = "group-map-source"
                        self.yang_parent_name = "group-map-sources"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("source-of-information", ("source_of_information", Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation)), ("group-map-information", ("group_map_information", Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation))])
                        self._leafs = OrderedDict([
                            ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                            ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                            ('client', (YLeaf(YType.enumeration, 'client'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimClient', '')])),
                            ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimProtocol', '')])),
                            ('rp_address', (YLeaf(YType.str, 'rp-address'), ['str','str'])),
                            ('priority', (YLeaf(YType.uint32, 'priority'), ['int'])),
                            ('holdtime', (YLeaf(YType.int32, 'holdtime'), ['int'])),
                            ('expires', (YLeaf(YType.uint64, 'expires'), ['int'])),
                            ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                        ])
                        self.prefix = None
                        self.prefix_length = None
                        self.client = None
                        self.protocol = None
                        self.rp_address = None
                        self.priority = None
                        self.holdtime = None
                        self.expires = None
                        self.uptime = None

                        self.source_of_information = Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation()
                        self.source_of_information.parent = self
                        self._children_name_map["source_of_information"] = "source-of-information"

                        self.group_map_information = Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation()
                        self.group_map_information.parent = self
                        self._children_name_map["group_map_information"] = "group-map-information"
                        self._segment_path = lambda: "group-map-source"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/group-map-sources/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.GroupMapSources.GroupMapSource, ['prefix', 'prefix_length', 'client', 'protocol', 'rp_address', 'priority', 'holdtime', 'expires', 'uptime'], name, value)


                    class SourceOfInformation(Entity):
                        """
                        The source of information
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation, self).__init__()

                            self.yang_name = "source-of-information"
                            self.yang_parent_name = "group-map-source"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "source-of-information"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/group-map-sources/group-map-source/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class GroupMapInformation(Entity):
                        """
                        Group Mapping information
                        
                        .. attribute:: prefix
                        
                        	Group range prefix
                        	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix>`
                        
                        .. attribute:: rp_address
                        
                        	Rendezvous Point Address
                        	**type**\:  :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress>`
                        
                        .. attribute:: prefix_length
                        
                        	Group range prefix length
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: client
                        
                        	Client mapping learnt from
                        	**type**\:  :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                        
                        .. attribute:: protocol
                        
                        	Protocol mode of the range
                        	**type**\:  :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: group_count
                        
                        	No. of groups in this range
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_used
                        
                        	Is this mapping being used?
                        	**type**\: bool
                        
                        .. attribute:: mrib_active
                        
                        	Is this mapping active in MRIB?
                        	**type**\: bool
                        
                        .. attribute:: is_override
                        
                        	Is this the override range?
                        	**type**\: bool
                        
                        .. attribute:: priority
                        
                        	Bootstrap priority
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation, self).__init__()

                            self.yang_name = "group-map-information"
                            self.yang_parent_name = "group-map-source"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("prefix", ("prefix", Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix)), ("rp-address", ("rp_address", Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress))])
                            self._leafs = OrderedDict([
                                ('prefix_length', (YLeaf(YType.int32, 'prefix-length'), ['int'])),
                                ('client', (YLeaf(YType.enumeration, 'client'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowRangeClient', '')])),
                                ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowProtocol', '')])),
                                ('group_count', (YLeaf(YType.uint32, 'group-count'), ['int'])),
                                ('is_used', (YLeaf(YType.boolean, 'is-used'), ['bool'])),
                                ('mrib_active', (YLeaf(YType.boolean, 'mrib-active'), ['bool'])),
                                ('is_override', (YLeaf(YType.boolean, 'is-override'), ['bool'])),
                                ('priority', (YLeaf(YType.uint32, 'priority'), ['int'])),
                            ])
                            self.prefix_length = None
                            self.client = None
                            self.protocol = None
                            self.group_count = None
                            self.is_used = None
                            self.mrib_active = None
                            self.is_override = None
                            self.priority = None

                            self.prefix = Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"

                            self.rp_address = Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"
                            self._segment_path = lambda: "group-map-information"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/group-map-sources/group-map-source/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation, ['prefix_length', 'client', 'protocol', 'group_count', 'is_used', 'mrib_active', 'is_override', 'priority'], name, value)


                        class Prefix(Entity):
                            """
                            Group range prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "group-map-information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "prefix"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/group-map-sources/group-map-source/group-map-information/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class RpAddress(Entity):
                            """
                            Rendezvous Point Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "group-map-information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "rp-address"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/group-map-sources/group-map-source/group-map-information/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class TrafficCounters(Entity):
                """
                PIM message traffic counters
                
                .. attribute:: elapsed_time
                
                	Running time for counters in seconds
                	**type**\: int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: inputs
                
                	Packets in
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: outputs
                
                	Packets out
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: format_error
                
                	Malformed packets in
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: pakman_error
                
                	Pakman packets dropped
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: standby_packets_error
                
                	Packets received in standby state
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: checksum_error
                
                	Checksum errors
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: socket_error
                
                	Socket errors
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: send_queue_full
                
                	Packets dropped since send queue was full
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: boundary_acl_rx_drop
                
                	Inc. JP dropped since boundary ACL confg
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: boundary_acl_tx_drop
                
                	Out JP dropped since boundary ACL confg
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: no_socket_connection
                
                	Packets dropped since no socket connection
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: no_source_address
                
                	Packets dropped since no source address
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_hello
                
                	Hello packets in
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_hello
                
                	Hello packets out
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_jp
                
                	Join Prune packets in
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_jp
                
                	Join Prune packets out
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_data_register
                
                	Data Register packets in
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_null_register
                
                	Null Register packets in
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_null_register
                
                	Null Register packets out
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_register_stop
                
                	Register Stop packets in
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_register_stop
                
                	Register Stop packets out
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_assert
                
                	Assert packets in
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_assert_batched
                
                	Batched Assert packets in
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_assert
                
                	Assert packets out
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_assert_batched
                
                	Batched Assert packets out
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_df_election
                
                	DF Election packets in
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_df_election
                
                	DF Election packets out
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_bsr_message
                
                	Input BSR Messages
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_bsr_message
                
                	Output BSR Messages
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_candidate_rp_advertisement
                
                	Input Candidate\-RP Advertisment
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_candidate_rp_advertisement
                
                	Output Candidate\-RP Advertisment
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_ecmp_redirect
                
                	Input Ecmp Redirect
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_ecmp_redirect
                
                	Output Ecmp Redirect
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_loop_error
                
                	Output on loopback error
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_invalid_lsm_identifier
                
                	 Invalid LSM ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_idb_error
                
                	No IDB for intf error
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_vrf_error
                
                	No VRF for idb error
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_pim_error
                
                	PIM Disabled on intf error
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_pim_version_error
                
                	Invalid PIM version error
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_join_group
                
                	Output Join Groups
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_prune_group
                
                	Output Prune Groups
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_join_prune_bytes
                
                	Output JP Bytes
                	**type**\: int
                
                	**range:** 0..4294967295
                
                	**units**\: byte
                
                .. attribute:: output_hello_bytes
                
                	Output Hello Bytes
                	**type**\: int
                
                	**range:** 0..4294967295
                
                	**units**\: byte
                
                .. attribute:: non_supported_packets
                
                	PIM non supported pckets
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: invalid_registers
                
                	PIM invalid registers received
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: invalid_join_prunes
                
                	PIM invalid Join/Prunes received
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_packman_error
                
                	Packets Dropped due to Pakman Error
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_read_socket_error
                
                	Packet Read Socket Error
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_queue_last_clear
                
                	Time in seconds since the last clear of all packet queues stats
                	**type**\: int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: packets_standby
                
                	Packets Dropped due to Standby Error
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: no_mdt_socket_connection
                
                	Packets dropped since no mdt socket connection
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_send_queue_full
                
                	Packets dropped since mdt send queue was full
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_socket_error
                
                	MDT Socket errors
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_join_tlv_sent
                
                	Data MDT Join Msgs sent
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_join_tlv_received
                
                	Data MDT Join Msgs received
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_join_bad_type
                
                	Data MDT TLV bad type
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_drop_local_source_address
                
                	Data MDT Join msgs dropped due to local source addr
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_drop_null_local_address
                
                	Data MDT Join msgs dropped due to null local addr
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_drop_no_idb
                
                	Data MDT Join msgs dropped due to idb missing
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_drop_no_vrf
                
                	Data MDT Join msgs dropped due to vrf missing
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: invalid_destination_packets
                
                	Control Packets with Invalid Destination
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_joins_drop_multiple_encapsulation
                
                	MDT Join msgs dropped due to multiple Encap limitation
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: truncated_pim_packets
                
                	Packets dropped due to truncated Joins or Prunes
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: invalid_source_encodings
                
                	Number of invalid source encodings received
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: invalid_hello_options
                
                	Number of invalid hello options received
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_queue
                
                	Packet queue state and statistics
                	**type**\: list of  		 :py:class:`PacketQueue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.TrafficCounters.PacketQueue>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Active.DefaultContext.TrafficCounters, self).__init__()

                    self.yang_name = "traffic-counters"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("packet-queue", ("packet_queue", Pim.Active.DefaultContext.TrafficCounters.PacketQueue))])
                    self._leafs = OrderedDict([
                        ('elapsed_time', (YLeaf(YType.uint32, 'elapsed-time'), ['int'])),
                        ('inputs', (YLeaf(YType.uint32, 'inputs'), ['int'])),
                        ('outputs', (YLeaf(YType.uint32, 'outputs'), ['int'])),
                        ('format_error', (YLeaf(YType.uint32, 'format-error'), ['int'])),
                        ('pakman_error', (YLeaf(YType.uint32, 'pakman-error'), ['int'])),
                        ('standby_packets_error', (YLeaf(YType.uint32, 'standby-packets-error'), ['int'])),
                        ('checksum_error', (YLeaf(YType.uint32, 'checksum-error'), ['int'])),
                        ('socket_error', (YLeaf(YType.uint32, 'socket-error'), ['int'])),
                        ('send_queue_full', (YLeaf(YType.uint32, 'send-queue-full'), ['int'])),
                        ('boundary_acl_rx_drop', (YLeaf(YType.uint32, 'boundary-acl-rx-drop'), ['int'])),
                        ('boundary_acl_tx_drop', (YLeaf(YType.uint32, 'boundary-acl-tx-drop'), ['int'])),
                        ('no_socket_connection', (YLeaf(YType.uint32, 'no-socket-connection'), ['int'])),
                        ('no_source_address', (YLeaf(YType.uint32, 'no-source-address'), ['int'])),
                        ('input_hello', (YLeaf(YType.uint32, 'input-hello'), ['int'])),
                        ('output_hello', (YLeaf(YType.uint32, 'output-hello'), ['int'])),
                        ('input_jp', (YLeaf(YType.uint32, 'input-jp'), ['int'])),
                        ('output_jp', (YLeaf(YType.uint32, 'output-jp'), ['int'])),
                        ('input_data_register', (YLeaf(YType.uint32, 'input-data-register'), ['int'])),
                        ('input_null_register', (YLeaf(YType.uint32, 'input-null-register'), ['int'])),
                        ('output_null_register', (YLeaf(YType.uint32, 'output-null-register'), ['int'])),
                        ('input_register_stop', (YLeaf(YType.uint32, 'input-register-stop'), ['int'])),
                        ('output_register_stop', (YLeaf(YType.uint32, 'output-register-stop'), ['int'])),
                        ('input_assert', (YLeaf(YType.uint32, 'input-assert'), ['int'])),
                        ('input_assert_batched', (YLeaf(YType.uint32, 'input-assert-batched'), ['int'])),
                        ('output_assert', (YLeaf(YType.uint32, 'output-assert'), ['int'])),
                        ('output_assert_batched', (YLeaf(YType.uint32, 'output-assert-batched'), ['int'])),
                        ('input_df_election', (YLeaf(YType.uint32, 'input-df-election'), ['int'])),
                        ('output_df_election', (YLeaf(YType.uint32, 'output-df-election'), ['int'])),
                        ('input_bsr_message', (YLeaf(YType.uint32, 'input-bsr-message'), ['int'])),
                        ('output_bsr_message', (YLeaf(YType.uint32, 'output-bsr-message'), ['int'])),
                        ('input_candidate_rp_advertisement', (YLeaf(YType.uint32, 'input-candidate-rp-advertisement'), ['int'])),
                        ('output_candidate_rp_advertisement', (YLeaf(YType.uint32, 'output-candidate-rp-advertisement'), ['int'])),
                        ('input_ecmp_redirect', (YLeaf(YType.uint32, 'input-ecmp-redirect'), ['int'])),
                        ('output_ecmp_redirect', (YLeaf(YType.uint32, 'output-ecmp-redirect'), ['int'])),
                        ('output_loop_error', (YLeaf(YType.uint32, 'output-loop-error'), ['int'])),
                        ('mldp_mdt_invalid_lsm_identifier', (YLeaf(YType.uint32, 'mldp-mdt-invalid-lsm-identifier'), ['int'])),
                        ('input_no_idb_error', (YLeaf(YType.uint32, 'input-no-idb-error'), ['int'])),
                        ('input_no_vrf_error', (YLeaf(YType.uint32, 'input-no-vrf-error'), ['int'])),
                        ('input_no_pim_error', (YLeaf(YType.uint32, 'input-no-pim-error'), ['int'])),
                        ('input_pim_version_error', (YLeaf(YType.uint32, 'input-pim-version-error'), ['int'])),
                        ('output_join_group', (YLeaf(YType.uint32, 'output-join-group'), ['int'])),
                        ('output_prune_group', (YLeaf(YType.uint32, 'output-prune-group'), ['int'])),
                        ('output_join_prune_bytes', (YLeaf(YType.uint32, 'output-join-prune-bytes'), ['int'])),
                        ('output_hello_bytes', (YLeaf(YType.uint32, 'output-hello-bytes'), ['int'])),
                        ('non_supported_packets', (YLeaf(YType.uint32, 'non-supported-packets'), ['int'])),
                        ('invalid_registers', (YLeaf(YType.uint32, 'invalid-registers'), ['int'])),
                        ('invalid_join_prunes', (YLeaf(YType.uint32, 'invalid-join-prunes'), ['int'])),
                        ('packet_packman_error', (YLeaf(YType.uint32, 'packet-packman-error'), ['int'])),
                        ('packet_read_socket_error', (YLeaf(YType.uint32, 'packet-read-socket-error'), ['int'])),
                        ('packet_queue_last_clear', (YLeaf(YType.uint32, 'packet-queue-last-clear'), ['int'])),
                        ('packets_standby', (YLeaf(YType.uint32, 'packets-standby'), ['int'])),
                        ('no_mdt_socket_connection', (YLeaf(YType.uint32, 'no-mdt-socket-connection'), ['int'])),
                        ('mdt_send_queue_full', (YLeaf(YType.uint32, 'mdt-send-queue-full'), ['int'])),
                        ('mdt_socket_error', (YLeaf(YType.uint32, 'mdt-socket-error'), ['int'])),
                        ('mdt_join_tlv_sent', (YLeaf(YType.uint32, 'mdt-join-tlv-sent'), ['int'])),
                        ('mdt_join_tlv_received', (YLeaf(YType.uint32, 'mdt-join-tlv-received'), ['int'])),
                        ('mdt_join_bad_type', (YLeaf(YType.uint32, 'mdt-join-bad-type'), ['int'])),
                        ('mdt_drop_local_source_address', (YLeaf(YType.uint32, 'mdt-drop-local-source-address'), ['int'])),
                        ('mdt_drop_null_local_address', (YLeaf(YType.uint32, 'mdt-drop-null-local-address'), ['int'])),
                        ('mdt_drop_no_idb', (YLeaf(YType.uint32, 'mdt-drop-no-idb'), ['int'])),
                        ('mdt_drop_no_vrf', (YLeaf(YType.uint32, 'mdt-drop-no-vrf'), ['int'])),
                        ('invalid_destination_packets', (YLeaf(YType.uint32, 'invalid-destination-packets'), ['int'])),
                        ('mdt_joins_drop_multiple_encapsulation', (YLeaf(YType.uint32, 'mdt-joins-drop-multiple-encapsulation'), ['int'])),
                        ('truncated_pim_packets', (YLeaf(YType.uint32, 'truncated-pim-packets'), ['int'])),
                        ('invalid_source_encodings', (YLeaf(YType.uint32, 'invalid-source-encodings'), ['int'])),
                        ('invalid_hello_options', (YLeaf(YType.uint32, 'invalid-hello-options'), ['int'])),
                    ])
                    self.elapsed_time = None
                    self.inputs = None
                    self.outputs = None
                    self.format_error = None
                    self.pakman_error = None
                    self.standby_packets_error = None
                    self.checksum_error = None
                    self.socket_error = None
                    self.send_queue_full = None
                    self.boundary_acl_rx_drop = None
                    self.boundary_acl_tx_drop = None
                    self.no_socket_connection = None
                    self.no_source_address = None
                    self.input_hello = None
                    self.output_hello = None
                    self.input_jp = None
                    self.output_jp = None
                    self.input_data_register = None
                    self.input_null_register = None
                    self.output_null_register = None
                    self.input_register_stop = None
                    self.output_register_stop = None
                    self.input_assert = None
                    self.input_assert_batched = None
                    self.output_assert = None
                    self.output_assert_batched = None
                    self.input_df_election = None
                    self.output_df_election = None
                    self.input_bsr_message = None
                    self.output_bsr_message = None
                    self.input_candidate_rp_advertisement = None
                    self.output_candidate_rp_advertisement = None
                    self.input_ecmp_redirect = None
                    self.output_ecmp_redirect = None
                    self.output_loop_error = None
                    self.mldp_mdt_invalid_lsm_identifier = None
                    self.input_no_idb_error = None
                    self.input_no_vrf_error = None
                    self.input_no_pim_error = None
                    self.input_pim_version_error = None
                    self.output_join_group = None
                    self.output_prune_group = None
                    self.output_join_prune_bytes = None
                    self.output_hello_bytes = None
                    self.non_supported_packets = None
                    self.invalid_registers = None
                    self.invalid_join_prunes = None
                    self.packet_packman_error = None
                    self.packet_read_socket_error = None
                    self.packet_queue_last_clear = None
                    self.packets_standby = None
                    self.no_mdt_socket_connection = None
                    self.mdt_send_queue_full = None
                    self.mdt_socket_error = None
                    self.mdt_join_tlv_sent = None
                    self.mdt_join_tlv_received = None
                    self.mdt_join_bad_type = None
                    self.mdt_drop_local_source_address = None
                    self.mdt_drop_null_local_address = None
                    self.mdt_drop_no_idb = None
                    self.mdt_drop_no_vrf = None
                    self.invalid_destination_packets = None
                    self.mdt_joins_drop_multiple_encapsulation = None
                    self.truncated_pim_packets = None
                    self.invalid_source_encodings = None
                    self.invalid_hello_options = None

                    self.packet_queue = YList(self)
                    self._segment_path = lambda: "traffic-counters"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.DefaultContext.TrafficCounters, ['elapsed_time', 'inputs', 'outputs', 'format_error', 'pakman_error', 'standby_packets_error', 'checksum_error', 'socket_error', 'send_queue_full', 'boundary_acl_rx_drop', 'boundary_acl_tx_drop', 'no_socket_connection', 'no_source_address', 'input_hello', 'output_hello', 'input_jp', 'output_jp', 'input_data_register', 'input_null_register', 'output_null_register', 'input_register_stop', 'output_register_stop', 'input_assert', 'input_assert_batched', 'output_assert', 'output_assert_batched', 'input_df_election', 'output_df_election', 'input_bsr_message', 'output_bsr_message', 'input_candidate_rp_advertisement', 'output_candidate_rp_advertisement', 'input_ecmp_redirect', 'output_ecmp_redirect', 'output_loop_error', 'mldp_mdt_invalid_lsm_identifier', 'input_no_idb_error', 'input_no_vrf_error', 'input_no_pim_error', 'input_pim_version_error', 'output_join_group', 'output_prune_group', 'output_join_prune_bytes', 'output_hello_bytes', 'non_supported_packets', 'invalid_registers', 'invalid_join_prunes', 'packet_packman_error', 'packet_read_socket_error', 'packet_queue_last_clear', 'packets_standby', 'no_mdt_socket_connection', 'mdt_send_queue_full', 'mdt_socket_error', 'mdt_join_tlv_sent', 'mdt_join_tlv_received', 'mdt_join_bad_type', 'mdt_drop_local_source_address', 'mdt_drop_null_local_address', 'mdt_drop_no_idb', 'mdt_drop_no_vrf', 'invalid_destination_packets', 'mdt_joins_drop_multiple_encapsulation', 'truncated_pim_packets', 'invalid_source_encodings', 'invalid_hello_options'], name, value)


                class PacketQueue(Entity):
                    """
                    Packet queue state and statistics
                    
                    .. attribute:: packet_queue_state
                    
                    	State of the queue
                    	**type**\:  :py:class:`PacketQueueState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState>`
                    
                    .. attribute:: packet_queue_stats
                    
                    	Statistics about the queue
                    	**type**\:  :py:class:`PacketQueueStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats>`
                    
                    .. attribute:: packet_queue_priority
                    
                    	Priority of this packet queue
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.TrafficCounters.PacketQueue, self).__init__()

                        self.yang_name = "packet-queue"
                        self.yang_parent_name = "traffic-counters"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("packet-queue-state", ("packet_queue_state", Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState)), ("packet-queue-stats", ("packet_queue_stats", Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats))])
                        self._leafs = OrderedDict([
                            ('packet_queue_priority', (YLeaf(YType.uint32, 'packet-queue-priority'), ['int'])),
                        ])
                        self.packet_queue_priority = None

                        self.packet_queue_state = Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState()
                        self.packet_queue_state.parent = self
                        self._children_name_map["packet_queue_state"] = "packet-queue-state"

                        self.packet_queue_stats = Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats()
                        self.packet_queue_stats.parent = self
                        self._children_name_map["packet_queue_stats"] = "packet-queue-stats"
                        self._segment_path = lambda: "packet-queue"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/traffic-counters/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.TrafficCounters.PacketQueue, ['packet_queue_priority'], name, value)


                    class PacketQueueState(Entity):
                        """
                        State of the queue
                        
                        .. attribute:: max_queue_size
                        
                        	Maximum size of queue in bytes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: byte
                        
                        .. attribute:: queue_size_bytes
                        
                        	Size of queue in bytes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: byte
                        
                        .. attribute:: queue_size_packets
                        
                        	Size of queue in number of packets
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState, self).__init__()

                            self.yang_name = "packet-queue-state"
                            self.yang_parent_name = "packet-queue"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('max_queue_size', (YLeaf(YType.uint32, 'max-queue-size'), ['int'])),
                                ('queue_size_bytes', (YLeaf(YType.uint32, 'queue-size-bytes'), ['int'])),
                                ('queue_size_packets', (YLeaf(YType.uint32, 'queue-size-packets'), ['int'])),
                            ])
                            self.max_queue_size = None
                            self.queue_size_bytes = None
                            self.queue_size_packets = None
                            self._segment_path = lambda: "packet-queue-state"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/traffic-counters/packet-queue/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState, ['max_queue_size', 'queue_size_bytes', 'queue_size_packets'], name, value)


                    class PacketQueueStats(Entity):
                        """
                        Statistics about the queue
                        
                        .. attribute:: enqueued_packets
                        
                        	Total number of packets enqueued to this queue
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: dequeued_packets
                        
                        	Total number of packets dequeued from this queue
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: high_water_mark_packets
                        
                        	Highest number of packets enqueued in this queue
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: high_water_mark_bytes
                        
                        	Highest number of bytes enqueued in this queue
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: byte
                        
                        .. attribute:: tail_drops
                        
                        	Number packets dropped from this queue due to max size
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats, self).__init__()

                            self.yang_name = "packet-queue-stats"
                            self.yang_parent_name = "packet-queue"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('enqueued_packets', (YLeaf(YType.uint32, 'enqueued-packets'), ['int'])),
                                ('dequeued_packets', (YLeaf(YType.uint32, 'dequeued-packets'), ['int'])),
                                ('high_water_mark_packets', (YLeaf(YType.uint32, 'high-water-mark-packets'), ['int'])),
                                ('high_water_mark_bytes', (YLeaf(YType.uint32, 'high-water-mark-bytes'), ['int'])),
                                ('tail_drops', (YLeaf(YType.uint32, 'tail-drops'), ['int'])),
                            ])
                            self.enqueued_packets = None
                            self.dequeued_packets = None
                            self.high_water_mark_packets = None
                            self.high_water_mark_bytes = None
                            self.tail_drops = None
                            self._segment_path = lambda: "packet-queue-stats"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/traffic-counters/packet-queue/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats, ['enqueued_packets', 'dequeued_packets', 'high_water_mark_packets', 'high_water_mark_bytes', 'tail_drops'], name, value)


            class GroupMapRpfs(Entity):
                """
                PIM group mapping information
                
                .. attribute:: group_map_rpf
                
                	PIM group mapping entry
                	**type**\: list of  		 :py:class:`GroupMapRpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Active.DefaultContext.GroupMapRpfs, self).__init__()

                    self.yang_name = "group-map-rpfs"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("group-map-rpf", ("group_map_rpf", Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf))])
                    self._leafs = OrderedDict()

                    self.group_map_rpf = YList(self)
                    self._segment_path = lambda: "group-map-rpfs"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.DefaultContext.GroupMapRpfs, [], name, value)


                class GroupMapRpf(Entity):
                    """
                    PIM group mapping entry
                    
                    .. attribute:: prefix
                    
                    	Prefix
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: client
                    
                    	Client
                    	**type**\:  :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                    
                    .. attribute:: protocol
                    
                    	Protocol
                    	**type**\:  :py:class:`PimProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimProtocol>`
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: rp_priority
                    
                    	RP priority
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rpf_neighbor
                    
                    	RPF neighbor to the RP
                    	**type**\:  :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor>`
                    
                    .. attribute:: group_map_information
                    
                    	Group Mapping information
                    	**type**\:  :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation>`
                    
                    .. attribute:: are_we_rp
                    
                    	Are we the RP?
                    	**type**\: bool
                    
                    .. attribute:: rpf_interface_name
                    
                    	RPF interface to the RP
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: rpf_vrf_name
                    
                    	RPF VRF Name
                    	**type**\: str
                    
                    	**length:** 0..33
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf, self).__init__()

                        self.yang_name = "group-map-rpf"
                        self.yang_parent_name = "group-map-rpfs"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("rpf-neighbor", ("rpf_neighbor", Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor)), ("group-map-information", ("group_map_information", Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation))])
                        self._leafs = OrderedDict([
                            ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                            ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                            ('client', (YLeaf(YType.enumeration, 'client'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimClient', '')])),
                            ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimProtocol', '')])),
                            ('rp_address', (YLeaf(YType.str, 'rp-address'), ['str','str'])),
                            ('rp_priority', (YLeaf(YType.uint32, 'rp-priority'), ['int'])),
                            ('are_we_rp', (YLeaf(YType.boolean, 'are-we-rp'), ['bool'])),
                            ('rpf_interface_name', (YLeaf(YType.str, 'rpf-interface-name'), ['str'])),
                            ('rpf_vrf_name', (YLeaf(YType.str, 'rpf-vrf-name'), ['str'])),
                        ])
                        self.prefix = None
                        self.prefix_length = None
                        self.client = None
                        self.protocol = None
                        self.rp_address = None
                        self.rp_priority = None
                        self.are_we_rp = None
                        self.rpf_interface_name = None
                        self.rpf_vrf_name = None

                        self.rpf_neighbor = Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor()
                        self.rpf_neighbor.parent = self
                        self._children_name_map["rpf_neighbor"] = "rpf-neighbor"

                        self.group_map_information = Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation()
                        self.group_map_information.parent = self
                        self._children_name_map["group_map_information"] = "group-map-information"
                        self._segment_path = lambda: "group-map-rpf"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/group-map-rpfs/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf, ['prefix', 'prefix_length', 'client', 'protocol', 'rp_address', 'rp_priority', 'are_we_rp', 'rpf_interface_name', 'rpf_vrf_name'], name, value)


                    class RpfNeighbor(Entity):
                        """
                        RPF neighbor to the RP
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor, self).__init__()

                            self.yang_name = "rpf-neighbor"
                            self.yang_parent_name = "group-map-rpf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "rpf-neighbor"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/group-map-rpfs/group-map-rpf/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class GroupMapInformation(Entity):
                        """
                        Group Mapping information
                        
                        .. attribute:: prefix
                        
                        	Group range prefix
                        	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix>`
                        
                        .. attribute:: rp_address
                        
                        	Rendezvous Point Address
                        	**type**\:  :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress>`
                        
                        .. attribute:: prefix_length
                        
                        	Group range prefix length
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: client
                        
                        	Client mapping learnt from
                        	**type**\:  :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                        
                        .. attribute:: protocol
                        
                        	Protocol mode of the range
                        	**type**\:  :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: group_count
                        
                        	No. of groups in this range
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_used
                        
                        	Is this mapping being used?
                        	**type**\: bool
                        
                        .. attribute:: mrib_active
                        
                        	Is this mapping active in MRIB?
                        	**type**\: bool
                        
                        .. attribute:: is_override
                        
                        	Is this the override range?
                        	**type**\: bool
                        
                        .. attribute:: priority
                        
                        	Bootstrap priority
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation, self).__init__()

                            self.yang_name = "group-map-information"
                            self.yang_parent_name = "group-map-rpf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("prefix", ("prefix", Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix)), ("rp-address", ("rp_address", Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress))])
                            self._leafs = OrderedDict([
                                ('prefix_length', (YLeaf(YType.int32, 'prefix-length'), ['int'])),
                                ('client', (YLeaf(YType.enumeration, 'client'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowRangeClient', '')])),
                                ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowProtocol', '')])),
                                ('group_count', (YLeaf(YType.uint32, 'group-count'), ['int'])),
                                ('is_used', (YLeaf(YType.boolean, 'is-used'), ['bool'])),
                                ('mrib_active', (YLeaf(YType.boolean, 'mrib-active'), ['bool'])),
                                ('is_override', (YLeaf(YType.boolean, 'is-override'), ['bool'])),
                                ('priority', (YLeaf(YType.uint32, 'priority'), ['int'])),
                            ])
                            self.prefix_length = None
                            self.client = None
                            self.protocol = None
                            self.group_count = None
                            self.is_used = None
                            self.mrib_active = None
                            self.is_override = None
                            self.priority = None

                            self.prefix = Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"

                            self.rp_address = Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"
                            self._segment_path = lambda: "group-map-information"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/group-map-rpfs/group-map-rpf/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation, ['prefix_length', 'client', 'protocol', 'group_count', 'is_used', 'mrib_active', 'is_override', 'priority'], name, value)


                        class Prefix(Entity):
                            """
                            Group range prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "group-map-information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "prefix"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/group-map-rpfs/group-map-rpf/group-map-information/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class RpAddress(Entity):
                            """
                            Rendezvous Point Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "group-map-information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "rp-address"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/group-map-rpfs/group-map-rpf/group-map-information/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class Summary(Entity):
                """
                PIM summary
                
                .. attribute:: route_limit
                
                	Maximum routes
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_count
                
                	Current routes
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_low_water_mark
                
                	The number of routes below which the throttle on route creation will be lifted
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_route_limit_reached
                
                	Is route creation throttled
                	**type**\: bool
                
                .. attribute:: topology_interface_state_limit
                
                	Maximum Topology Interface State count
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_count
                
                	Current Topology Interface State count
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: rxi_low_water_mark
                
                	The rxi below which the throttle on interface creation will be lifted
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: rxi_limit_reached
                
                	Is interface creation throttled
                	**type**\: bool
                
                .. attribute:: register_limit
                
                	Maximum registers
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_count
                
                	Current registers
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_limit_reached
                
                	Is PIM SM register handling throttled
                	**type**\: bool
                
                .. attribute:: ranges_limit
                
                	Maximum group ranges from Autorp
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: ranges_count
                
                	Current group ranges from Autorp
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: ranges_threshold
                
                	OOR theshold of grange ranges from AutoRP
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_ranges_limit_reached
                
                	Is Auto\-RP group\-to\-RP mapping range creation throttled
                	**type**\: bool
                
                .. attribute:: bsr_ranges_limit
                
                	Maximum group ranges from BSR
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_ranges_count
                
                	Current group ranges from BSR
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_range_threshold
                
                	Threshold group range from BSR
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_bsr_ranges_threshold_reached
                
                	Is VRF\-specific BSR group\-to\-RP mapping range creation throttled
                	**type**\: bool
                
                .. attribute:: bsr_candidate_rp_set_limit
                
                	Maximum crp\-set from BSR
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_candidate_rp_set_count
                
                	Current crp\-set count from BSR
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_candidate_rp_set_threshold
                
                	Threshold crp\-set from BSR
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_maximum_enforcement_disabled
                
                	Is maximum enforcement disabled
                	**type**\: bool
                
                .. attribute:: is_node_low_memory
                
                	Is node in low memory condition
                	**type**\: bool
                
                .. attribute:: route_threshold
                
                	Threshold routes
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_auto_rp_ranges_limit
                
                	Global Auto\-RP maximum group ranges
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_global_auto_rp_ranges_limit_reached
                
                	Is global AutoRP group\-to\-RP mapping range creation throttled
                	**type**\: bool
                
                .. attribute:: global_bsr_ranges_limit
                
                	Global BSR maximum group ranges
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_count
                
                	Global BSR current group ranges
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_threshold
                
                	Global BSR Threshold group ranges
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_global_bsr_ranges_limit_reached
                
                	Is global BSR group\-to\-RP mapping range creation throttled
                	**type**\: bool
                
                .. attribute:: global_bsr_candidate_rp_set_limit
                
                	Global BSR maximum crp\-set
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_count
                
                	Global BSR current crp\-set count
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_threshold
                
                	Global BSR Threshold crp\-set
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_global_route_limit_reached
                
                	Is global route creation throttled
                	**type**\: bool
                
                .. attribute:: topology_interface_state_threshold
                
                	Topology Interface State threshold
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_global_rxi_limit_reached
                
                	Is global interface creation throttled
                	**type**\: bool
                
                .. attribute:: register_threshold
                
                	Threshold registers
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_register_limit
                
                	Maximum global registers
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_global_register_limit_reached
                
                	Is global PIM SM register handling throttled
                	**type**\: bool
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Active.DefaultContext.Summary, self).__init__()

                    self.yang_name = "summary"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('route_limit', (YLeaf(YType.uint32, 'route-limit'), ['int'])),
                        ('route_count', (YLeaf(YType.uint32, 'route-count'), ['int'])),
                        ('route_low_water_mark', (YLeaf(YType.uint32, 'route-low-water-mark'), ['int'])),
                        ('is_route_limit_reached', (YLeaf(YType.boolean, 'is-route-limit-reached'), ['bool'])),
                        ('topology_interface_state_limit', (YLeaf(YType.uint32, 'topology-interface-state-limit'), ['int'])),
                        ('topology_interface_state_count', (YLeaf(YType.uint32, 'topology-interface-state-count'), ['int'])),
                        ('rxi_low_water_mark', (YLeaf(YType.uint32, 'rxi-low-water-mark'), ['int'])),
                        ('rxi_limit_reached', (YLeaf(YType.boolean, 'rxi-limit-reached'), ['bool'])),
                        ('register_limit', (YLeaf(YType.uint32, 'register-limit'), ['int'])),
                        ('register_count', (YLeaf(YType.uint32, 'register-count'), ['int'])),
                        ('register_limit_reached', (YLeaf(YType.boolean, 'register-limit-reached'), ['bool'])),
                        ('ranges_limit', (YLeaf(YType.uint32, 'ranges-limit'), ['int'])),
                        ('ranges_count', (YLeaf(YType.uint32, 'ranges-count'), ['int'])),
                        ('ranges_threshold', (YLeaf(YType.uint32, 'ranges-threshold'), ['int'])),
                        ('is_ranges_limit_reached', (YLeaf(YType.boolean, 'is-ranges-limit-reached'), ['bool'])),
                        ('bsr_ranges_limit', (YLeaf(YType.uint32, 'bsr-ranges-limit'), ['int'])),
                        ('bsr_ranges_count', (YLeaf(YType.uint32, 'bsr-ranges-count'), ['int'])),
                        ('bsr_range_threshold', (YLeaf(YType.uint32, 'bsr-range-threshold'), ['int'])),
                        ('is_bsr_ranges_threshold_reached', (YLeaf(YType.boolean, 'is-bsr-ranges-threshold-reached'), ['bool'])),
                        ('bsr_candidate_rp_set_limit', (YLeaf(YType.uint32, 'bsr-candidate-rp-set-limit'), ['int'])),
                        ('bsr_candidate_rp_set_count', (YLeaf(YType.uint32, 'bsr-candidate-rp-set-count'), ['int'])),
                        ('bsr_candidate_rp_set_threshold', (YLeaf(YType.uint32, 'bsr-candidate-rp-set-threshold'), ['int'])),
                        ('is_maximum_enforcement_disabled', (YLeaf(YType.boolean, 'is-maximum-enforcement-disabled'), ['bool'])),
                        ('is_node_low_memory', (YLeaf(YType.boolean, 'is-node-low-memory'), ['bool'])),
                        ('route_threshold', (YLeaf(YType.uint32, 'route-threshold'), ['int'])),
                        ('global_auto_rp_ranges_limit', (YLeaf(YType.uint32, 'global-auto-rp-ranges-limit'), ['int'])),
                        ('is_global_auto_rp_ranges_limit_reached', (YLeaf(YType.boolean, 'is-global-auto-rp-ranges-limit-reached'), ['bool'])),
                        ('global_bsr_ranges_limit', (YLeaf(YType.uint32, 'global-bsr-ranges-limit'), ['int'])),
                        ('global_bsr_ranges_count', (YLeaf(YType.uint32, 'global-bsr-ranges-count'), ['int'])),
                        ('global_bsr_ranges_threshold', (YLeaf(YType.uint32, 'global-bsr-ranges-threshold'), ['int'])),
                        ('is_global_bsr_ranges_limit_reached', (YLeaf(YType.boolean, 'is-global-bsr-ranges-limit-reached'), ['bool'])),
                        ('global_bsr_candidate_rp_set_limit', (YLeaf(YType.uint32, 'global-bsr-candidate-rp-set-limit'), ['int'])),
                        ('global_bsr_candidate_rp_set_count', (YLeaf(YType.uint32, 'global-bsr-candidate-rp-set-count'), ['int'])),
                        ('global_bsr_candidate_rp_set_threshold', (YLeaf(YType.uint32, 'global-bsr-candidate-rp-set-threshold'), ['int'])),
                        ('is_global_route_limit_reached', (YLeaf(YType.boolean, 'is-global-route-limit-reached'), ['bool'])),
                        ('topology_interface_state_threshold', (YLeaf(YType.uint32, 'topology-interface-state-threshold'), ['int'])),
                        ('is_global_rxi_limit_reached', (YLeaf(YType.boolean, 'is-global-rxi-limit-reached'), ['bool'])),
                        ('register_threshold', (YLeaf(YType.uint32, 'register-threshold'), ['int'])),
                        ('global_register_limit', (YLeaf(YType.uint32, 'global-register-limit'), ['int'])),
                        ('is_global_register_limit_reached', (YLeaf(YType.boolean, 'is-global-register-limit-reached'), ['bool'])),
                    ])
                    self.route_limit = None
                    self.route_count = None
                    self.route_low_water_mark = None
                    self.is_route_limit_reached = None
                    self.topology_interface_state_limit = None
                    self.topology_interface_state_count = None
                    self.rxi_low_water_mark = None
                    self.rxi_limit_reached = None
                    self.register_limit = None
                    self.register_count = None
                    self.register_limit_reached = None
                    self.ranges_limit = None
                    self.ranges_count = None
                    self.ranges_threshold = None
                    self.is_ranges_limit_reached = None
                    self.bsr_ranges_limit = None
                    self.bsr_ranges_count = None
                    self.bsr_range_threshold = None
                    self.is_bsr_ranges_threshold_reached = None
                    self.bsr_candidate_rp_set_limit = None
                    self.bsr_candidate_rp_set_count = None
                    self.bsr_candidate_rp_set_threshold = None
                    self.is_maximum_enforcement_disabled = None
                    self.is_node_low_memory = None
                    self.route_threshold = None
                    self.global_auto_rp_ranges_limit = None
                    self.is_global_auto_rp_ranges_limit_reached = None
                    self.global_bsr_ranges_limit = None
                    self.global_bsr_ranges_count = None
                    self.global_bsr_ranges_threshold = None
                    self.is_global_bsr_ranges_limit_reached = None
                    self.global_bsr_candidate_rp_set_limit = None
                    self.global_bsr_candidate_rp_set_count = None
                    self.global_bsr_candidate_rp_set_threshold = None
                    self.is_global_route_limit_reached = None
                    self.topology_interface_state_threshold = None
                    self.is_global_rxi_limit_reached = None
                    self.register_threshold = None
                    self.global_register_limit = None
                    self.is_global_register_limit_reached = None
                    self._segment_path = lambda: "summary"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.DefaultContext.Summary, ['route_limit', 'route_count', 'route_low_water_mark', 'is_route_limit_reached', 'topology_interface_state_limit', 'topology_interface_state_count', 'rxi_low_water_mark', 'rxi_limit_reached', 'register_limit', 'register_count', 'register_limit_reached', 'ranges_limit', 'ranges_count', 'ranges_threshold', 'is_ranges_limit_reached', 'bsr_ranges_limit', 'bsr_ranges_count', 'bsr_range_threshold', 'is_bsr_ranges_threshold_reached', 'bsr_candidate_rp_set_limit', 'bsr_candidate_rp_set_count', 'bsr_candidate_rp_set_threshold', 'is_maximum_enforcement_disabled', 'is_node_low_memory', 'route_threshold', 'global_auto_rp_ranges_limit', 'is_global_auto_rp_ranges_limit_reached', 'global_bsr_ranges_limit', 'global_bsr_ranges_count', 'global_bsr_ranges_threshold', 'is_global_bsr_ranges_limit_reached', 'global_bsr_candidate_rp_set_limit', 'global_bsr_candidate_rp_set_count', 'global_bsr_candidate_rp_set_threshold', 'is_global_route_limit_reached', 'topology_interface_state_threshold', 'is_global_rxi_limit_reached', 'register_threshold', 'global_register_limit', 'is_global_register_limit_reached'], name, value)


            class Gre(Entity):
                """
                GRE information
                
                .. attribute:: gre_hashes
                
                	GRE hash
                	**type**\:  :py:class:`GreHashes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Gre.GreHashes>`
                
                .. attribute:: gre_next_hops
                
                	GRE destination neighbor table
                	**type**\:  :py:class:`GreNextHops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Gre.GreNextHops>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Active.DefaultContext.Gre, self).__init__()

                    self.yang_name = "gre"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("gre-hashes", ("gre_hashes", Pim.Active.DefaultContext.Gre.GreHashes)), ("gre-next-hops", ("gre_next_hops", Pim.Active.DefaultContext.Gre.GreNextHops))])
                    self._leafs = OrderedDict()

                    self.gre_hashes = Pim.Active.DefaultContext.Gre.GreHashes()
                    self.gre_hashes.parent = self
                    self._children_name_map["gre_hashes"] = "gre-hashes"

                    self.gre_next_hops = Pim.Active.DefaultContext.Gre.GreNextHops()
                    self.gre_next_hops.parent = self
                    self._children_name_map["gre_next_hops"] = "gre-next-hops"
                    self._segment_path = lambda: "gre"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.DefaultContext.Gre, [], name, value)


                class GreHashes(Entity):
                    """
                    GRE hash
                    
                    .. attribute:: gre_hash
                    
                    	PIM GRE Hashed Underlying Interface
                    	**type**\: list of  		 :py:class:`GreHash <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Gre.GreHashes.GreHash>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.Gre.GreHashes, self).__init__()

                        self.yang_name = "gre-hashes"
                        self.yang_parent_name = "gre"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("gre-hash", ("gre_hash", Pim.Active.DefaultContext.Gre.GreHashes.GreHash))])
                        self._leafs = OrderedDict()

                        self.gre_hash = YList(self)
                        self._segment_path = lambda: "gre-hashes"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/gre/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.Gre.GreHashes, [], name, value)


                    class GreHash(Entity):
                        """
                        PIM GRE Hashed Underlying Interface
                        
                        .. attribute:: source_address  (key)
                        
                        	Source address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: destination_address  (key)
                        
                        	Destination address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ifname  (key)
                        
                        	GRE Tunnel Interface
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: next_hop_interface
                        
                        	Next hop neighbor interface
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Gre.GreHashes.GreHash, self).__init__()

                            self.yang_name = "gre-hash"
                            self.yang_parent_name = "gre-hashes"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['source_address','destination_address','ifname']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('source_address', (YLeaf(YType.str, 'source-address'), ['str','str'])),
                                ('destination_address', (YLeaf(YType.str, 'destination-address'), ['str','str'])),
                                ('ifname', (YLeaf(YType.str, 'ifname'), ['str'])),
                                ('next_hop_interface', (YLeaf(YType.str, 'next-hop-interface'), ['str'])),
                            ])
                            self.source_address = None
                            self.destination_address = None
                            self.ifname = None
                            self.next_hop_interface = None
                            self._segment_path = lambda: "gre-hash" + "[source-address='" + str(self.source_address) + "']" + "[destination-address='" + str(self.destination_address) + "']" + "[ifname='" + str(self.ifname) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/gre/gre-hashes/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.Gre.GreHashes.GreHash, ['source_address', 'destination_address', 'ifname', 'next_hop_interface'], name, value)


                class GreNextHops(Entity):
                    """
                    GRE destination neighbor table
                    
                    .. attribute:: gre_next_hop
                    
                    	PIM GRE address next\-hop information
                    	**type**\: list of  		 :py:class:`GreNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.Gre.GreNextHops, self).__init__()

                        self.yang_name = "gre-next-hops"
                        self.yang_parent_name = "gre"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("gre-next-hop", ("gre_next_hop", Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop))])
                        self._leafs = OrderedDict()

                        self.gre_next_hop = YList(self)
                        self._segment_path = lambda: "gre-next-hops"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/gre/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.Gre.GreNextHops, [], name, value)


                    class GreNextHop(Entity):
                        """
                        PIM GRE address next\-hop information
                        
                        .. attribute:: destination_address  (key)
                        
                        	GRE destination address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: registered_address
                        
                        	Address registered
                        	**type**\:  :py:class:`RegisteredAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress>`
                        
                        .. attribute:: metric
                        
                        	Metric
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: metric_preference
                        
                        	Metric preference
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_connected
                        
                        	Are we connected ?
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: gre_path
                        
                        	GRE Paths list
                        	**type**\: list of  		 :py:class:`GrePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop, self).__init__()

                            self.yang_name = "gre-next-hop"
                            self.yang_parent_name = "gre-next-hops"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['destination_address']
                            self._child_classes = OrderedDict([("registered-address", ("registered_address", Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress)), ("gre-path", ("gre_path", Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath))])
                            self._leafs = OrderedDict([
                                ('destination_address', (YLeaf(YType.str, 'destination-address'), ['str','str'])),
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                ('metric_preference', (YLeaf(YType.uint32, 'metric-preference'), ['int'])),
                                ('is_connected', (YLeaf(YType.uint8, 'is-connected'), ['int'])),
                            ])
                            self.destination_address = None
                            self.metric = None
                            self.metric_preference = None
                            self.is_connected = None

                            self.registered_address = Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress()
                            self.registered_address.parent = self
                            self._children_name_map["registered_address"] = "registered-address"

                            self.gre_path = YList(self)
                            self._segment_path = lambda: "gre-next-hop" + "[destination-address='" + str(self.destination_address) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/gre/gre-next-hops/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop, ['destination_address', 'metric', 'metric_preference', 'is_connected'], name, value)


                        class RegisteredAddress(Entity):
                            """
                            Address registered
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress, self).__init__()

                                self.yang_name = "registered-address"
                                self.yang_parent_name = "gre-next-hop"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "registered-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class GrePath(Entity):
                            """
                            GRE Paths list
                            
                            .. attribute:: gre_neighbor
                            
                            	GRE neighbor
                            	**type**\:  :py:class:`GreNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor>`
                            
                            .. attribute:: gre_next_hop
                            
                            	GRE nexthop
                            	**type**\:  :py:class:`GreNextHop_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop_>`
                            
                            .. attribute:: gre_interface_name
                            
                            	GRE Interface
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: is_gre_interface_disabled
                            
                            	Is the gre interface disabled ?
                            	**type**\: bool
                            
                            .. attribute:: is_via_lsm
                            
                            	Via LSM
                            	**type**\: bool
                            
                            .. attribute:: is_connector_attribute_present
                            
                            	Connector attribute present
                            	**type**\: bool
                            
                            .. attribute:: extranet_vrf_name
                            
                            	Extranet VRF name
                            	**type**\: str
                            
                            	**length:** 0..33
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath, self).__init__()

                                self.yang_name = "gre-path"
                                self.yang_parent_name = "gre-next-hop"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("gre-neighbor", ("gre_neighbor", Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor)), ("gre-next-hop", ("gre_next_hop", Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop_))])
                                self._leafs = OrderedDict([
                                    ('gre_interface_name', (YLeaf(YType.str, 'gre-interface-name'), ['str'])),
                                    ('is_gre_interface_disabled', (YLeaf(YType.boolean, 'is-gre-interface-disabled'), ['bool'])),
                                    ('is_via_lsm', (YLeaf(YType.boolean, 'is-via-lsm'), ['bool'])),
                                    ('is_connector_attribute_present', (YLeaf(YType.boolean, 'is-connector-attribute-present'), ['bool'])),
                                    ('extranet_vrf_name', (YLeaf(YType.str, 'extranet-vrf-name'), ['str'])),
                                ])
                                self.gre_interface_name = None
                                self.is_gre_interface_disabled = None
                                self.is_via_lsm = None
                                self.is_connector_attribute_present = None
                                self.extranet_vrf_name = None

                                self.gre_neighbor = Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor()
                                self.gre_neighbor.parent = self
                                self._children_name_map["gre_neighbor"] = "gre-neighbor"

                                self.gre_next_hop = Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop_()
                                self.gre_next_hop.parent = self
                                self._children_name_map["gre_next_hop"] = "gre-next-hop"
                                self._segment_path = lambda: "gre-path"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath, ['gre_interface_name', 'is_gre_interface_disabled', 'is_via_lsm', 'is_connector_attribute_present', 'extranet_vrf_name'], name, value)


                            class GreNeighbor(Entity):
                                """
                                GRE neighbor
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor, self).__init__()

                                    self.yang_name = "gre-neighbor"
                                    self.yang_parent_name = "gre-path"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "gre-neighbor"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                            class GreNextHop_(Entity):
                                """
                                GRE nexthop
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop_, self).__init__()

                                    self.yang_name = "gre-next-hop"
                                    self.yang_parent_name = "gre-path"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "gre-next-hop"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop_, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class BidirDfWinners(Entity):
                """
                Bidirectional PIM DF election winner table
                
                .. attribute:: bidir_df_winner
                
                	Bidirectional PIM DF election table entry
                	**type**\: list of  		 :py:class:`BidirDfWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Active.DefaultContext.BidirDfWinners, self).__init__()

                    self.yang_name = "bidir-df-winners"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("bidir-df-winner", ("bidir_df_winner", Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner))])
                    self._leafs = OrderedDict()

                    self.bidir_df_winner = YList(self)
                    self._segment_path = lambda: "bidir-df-winners"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.DefaultContext.BidirDfWinners, [], name, value)


                class BidirDfWinner(Entity):
                    """
                    Bidirectional PIM DF election table entry
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: rp_address_xr
                    
                    	RP Address
                    	**type**\:  :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr>`
                    
                    .. attribute:: df_winner
                    
                    	DF Winner
                    	**type**\:  :py:class:`DfWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner>`
                    
                    .. attribute:: pim_interface_name
                    
                    	Interface Name
                    	**type**\: str
                    
                    .. attribute:: are_we_df
                    
                    	Are we DF
                    	**type**\: bool
                    
                    .. attribute:: rp_lan
                    
                    	Is this the RP LAN
                    	**type**\: bool
                    
                    .. attribute:: metric
                    
                    	Metric
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: metric_preference
                    
                    	Metric Preference
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner, self).__init__()

                        self.yang_name = "bidir-df-winner"
                        self.yang_parent_name = "bidir-df-winners"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("rp-address-xr", ("rp_address_xr", Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr)), ("df-winner", ("df_winner", Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner))])
                        self._leafs = OrderedDict([
                            ('rp_address', (YLeaf(YType.str, 'rp-address'), ['str','str'])),
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                            ('pim_interface_name', (YLeaf(YType.str, 'pim-interface-name'), ['str'])),
                            ('are_we_df', (YLeaf(YType.boolean, 'are-we-df'), ['bool'])),
                            ('rp_lan', (YLeaf(YType.boolean, 'rp-lan'), ['bool'])),
                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                            ('metric_preference', (YLeaf(YType.uint32, 'metric-preference'), ['int'])),
                            ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                        ])
                        self.rp_address = None
                        self.interface_name = None
                        self.pim_interface_name = None
                        self.are_we_df = None
                        self.rp_lan = None
                        self.metric = None
                        self.metric_preference = None
                        self.uptime = None

                        self.rp_address_xr = Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr()
                        self.rp_address_xr.parent = self
                        self._children_name_map["rp_address_xr"] = "rp-address-xr"

                        self.df_winner = Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner()
                        self.df_winner.parent = self
                        self._children_name_map["df_winner"] = "df-winner"
                        self._segment_path = lambda: "bidir-df-winner"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/bidir-df-winners/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner, ['rp_address', 'interface_name', 'pim_interface_name', 'are_we_df', 'rp_lan', 'metric', 'metric_preference', 'uptime'], name, value)


                    class RpAddressXr(Entity):
                        """
                        RP Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr, self).__init__()

                            self.yang_name = "rp-address-xr"
                            self.yang_parent_name = "bidir-df-winner"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "rp-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/bidir-df-winners/bidir-df-winner/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class DfWinner(Entity):
                        """
                        DF Winner
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner, self).__init__()

                            self.yang_name = "df-winner"
                            self.yang_parent_name = "bidir-df-winner"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "df-winner"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/bidir-df-winners/bidir-df-winner/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class TableContexts(Entity):
                """
                PIM table context list
                
                .. attribute:: table_context
                
                	PIM table context information
                	**type**\: list of  		 :py:class:`TableContext <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.TableContexts.TableContext>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Active.DefaultContext.TableContexts, self).__init__()

                    self.yang_name = "table-contexts"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("table-context", ("table_context", Pim.Active.DefaultContext.TableContexts.TableContext))])
                    self._leafs = OrderedDict()

                    self.table_context = YList(self)
                    self._segment_path = lambda: "table-contexts"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.DefaultContext.TableContexts, [], name, value)


                class TableContext(Entity):
                    """
                    PIM table context information
                    
                    .. attribute:: saf_name
                    
                    	SAF name
                    	**type**\:  :py:class:`PimSafi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimSafi>`
                    
                    .. attribute:: topology_name
                    
                    	Topology name
                    	**type**\: str
                    
                    	**length:** 1..32
                    
                    .. attribute:: afi
                    
                    	AFI
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: safi
                    
                    	SAFI
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_name
                    
                    	Table name
                    	**type**\: str
                    
                    .. attribute:: vrf_id
                    
                    	VRF ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_id
                    
                    	Table ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_active
                    
                    	Active status
                    	**type**\: bool
                    
                    .. attribute:: is_ital_registration_done
                    
                    	ITAL reg status
                    	**type**\: bool
                    
                    .. attribute:: is_rib_registration_done
                    
                    	RIB reg status
                    	**type**\: bool
                    
                    .. attribute:: is_rib_convergence_received
                    
                    	RIB Convergence receive status
                    	**type**\: bool
                    
                    .. attribute:: is_rib_convergence
                    
                    	RIB Convergence status
                    	**type**\: bool
                    
                    .. attribute:: rpf_registrations
                    
                    	RPF Registration count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.TableContexts.TableContext, self).__init__()

                        self.yang_name = "table-context"
                        self.yang_parent_name = "table-contexts"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('saf_name', (YLeaf(YType.enumeration, 'saf-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimSafi', '')])),
                            ('topology_name', (YLeaf(YType.str, 'topology-name'), ['str'])),
                            ('afi', (YLeaf(YType.uint32, 'afi'), ['int'])),
                            ('safi', (YLeaf(YType.uint32, 'safi'), ['int'])),
                            ('table_name', (YLeaf(YType.str, 'table-name'), ['str'])),
                            ('vrf_id', (YLeaf(YType.uint32, 'vrf-id'), ['int'])),
                            ('table_id', (YLeaf(YType.uint32, 'table-id'), ['int'])),
                            ('is_active', (YLeaf(YType.boolean, 'is-active'), ['bool'])),
                            ('is_ital_registration_done', (YLeaf(YType.boolean, 'is-ital-registration-done'), ['bool'])),
                            ('is_rib_registration_done', (YLeaf(YType.boolean, 'is-rib-registration-done'), ['bool'])),
                            ('is_rib_convergence_received', (YLeaf(YType.boolean, 'is-rib-convergence-received'), ['bool'])),
                            ('is_rib_convergence', (YLeaf(YType.boolean, 'is-rib-convergence'), ['bool'])),
                            ('rpf_registrations', (YLeaf(YType.uint32, 'rpf-registrations'), ['int'])),
                        ])
                        self.saf_name = None
                        self.topology_name = None
                        self.afi = None
                        self.safi = None
                        self.table_name = None
                        self.vrf_id = None
                        self.table_id = None
                        self.is_active = None
                        self.is_ital_registration_done = None
                        self.is_rib_registration_done = None
                        self.is_rib_convergence_received = None
                        self.is_rib_convergence = None
                        self.rpf_registrations = None
                        self._segment_path = lambda: "table-context"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/table-contexts/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.TableContexts.TableContext, ['saf_name', 'topology_name', 'afi', 'safi', 'table_name', 'vrf_id', 'table_id', 'is_active', 'is_ital_registration_done', 'is_rib_registration_done', 'is_rib_convergence_received', 'is_rib_convergence', 'rpf_registrations'], name, value)


            class NeighborSummaries(Entity):
                """
                PIM neighbor summary table
                
                .. attribute:: neighbor_summary
                
                	PIM neighbor summary information
                	**type**\: list of  		 :py:class:`NeighborSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.NeighborSummaries.NeighborSummary>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Active.DefaultContext.NeighborSummaries, self).__init__()

                    self.yang_name = "neighbor-summaries"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("neighbor-summary", ("neighbor_summary", Pim.Active.DefaultContext.NeighborSummaries.NeighborSummary))])
                    self._leafs = OrderedDict()

                    self.neighbor_summary = YList(self)
                    self._segment_path = lambda: "neighbor-summaries"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.DefaultContext.NeighborSummaries, [], name, value)


                class NeighborSummary(Entity):
                    """
                    PIM neighbor summary information
                    
                    .. attribute:: interface_name  (key)
                    
                    	Interface name
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: number_of_neighbors
                    
                    	Number of neighbors
                    	**type**\: int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: number_of_external_neighbors
                    
                    	Number of external neighbors
                    	**type**\: int
                    
                    	**range:** \-2147483648..2147483647
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.NeighborSummaries.NeighborSummary, self).__init__()

                        self.yang_name = "neighbor-summary"
                        self.yang_parent_name = "neighbor-summaries"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['interface_name']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                            ('number_of_neighbors', (YLeaf(YType.int32, 'number-of-neighbors'), ['int'])),
                            ('number_of_external_neighbors', (YLeaf(YType.int32, 'number-of-external-neighbors'), ['int'])),
                        ])
                        self.interface_name = None
                        self.number_of_neighbors = None
                        self.number_of_external_neighbors = None
                        self._segment_path = lambda: "neighbor-summary" + "[interface-name='" + str(self.interface_name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/neighbor-summaries/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.NeighborSummaries.NeighborSummary, ['interface_name', 'number_of_neighbors', 'number_of_external_neighbors'], name, value)


            class Context(Entity):
                """
                PIM context information
                
                .. attribute:: remote_default_group
                
                	Remote Default Group
                	**type**\:  :py:class:`RemoteDefaultGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Context.RemoteDefaultGroup>`
                
                .. attribute:: rpf_default_table
                
                	RPF Default Table
                	**type**\:  :py:class:`RpfDefaultTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Context.RpfDefaultTable>`
                
                .. attribute:: vrf_id
                
                	VRF ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: table_id
                
                	Table ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: murib_id
                
                	MURIB ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: rpf_id
                
                	RPF ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: remote_table_id
                
                	Remote Table ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_default_group
                
                	MDT Default group
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: mdt_source
                
                	MDT source
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: mdt_source_interface
                
                	MDT Source Interface Name
                	**type**\: str
                
                .. attribute:: mdt_interface
                
                	MDT handle
                	**type**\: str
                
                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                
                .. attribute:: mdt_gre_rpf_identifier
                
                	GRE\-MDT RPF Identifier
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_gre_remote_rpf_identifier
                
                	GRE\-MDT Remote RPF Identifier
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_unicast_rib_registration
                
                	Ucast RIB Registration
                	**type**\: bool
                
                .. attribute:: is_multicast_rib_registration
                
                	Mcast RIB Registration
                	**type**\: bool
                
                .. attribute:: is_active
                
                	Active
                	**type**\: bool
                
                .. attribute:: is_active_ital
                
                	Active ITAL
                	**type**\: bool
                
                .. attribute:: is_mrib_register
                
                	MRIB Register
                	**type**\: bool
                
                .. attribute:: is_mdt_owner
                
                	MDT Owner
                	**type**\: bool
                
                .. attribute:: is_routing_enabled
                
                	Routing Enabled
                	**type**\: bool
                
                .. attribute:: is_socket_add_required
                
                	VRF required on Socket
                	**type**\: bool
                
                .. attribute:: is_socket_added
                
                	VRF added on Socket
                	**type**\: bool
                
                .. attribute:: is_lpts_socket_add_required
                
                	VRF LPTS filter required on Socket
                	**type**\: bool
                
                .. attribute:: is_lpts_socket_added
                
                	VRF LPTS filter added on Socket
                	**type**\: bool
                
                .. attribute:: is_udp_socket_add_required
                
                	VRF added on UDP Socket
                	**type**\: bool
                
                .. attribute:: is_udp_socket_added
                
                	VRF added on UDP Socket
                	**type**\: bool
                
                .. attribute:: is_udp_socket_bind_required
                
                	VRF bind required on UDP Socket
                	**type**\: bool
                
                .. attribute:: is_udp_socket_bind
                
                	VRF bound on UDP Socket
                	**type**\: bool
                
                .. attribute:: is_register_injection_socket_add_required
                
                	VRF required on Register Injection Socket
                	**type**\: bool
                
                .. attribute:: is_register_injection_socket_added
                
                	VRF added on Register Injection Socket
                	**type**\: bool
                
                .. attribute:: is_register_injection_lpts_socket_add_required
                
                	VRF LPTS filter required on Register Injection Socket
                	**type**\: bool
                
                .. attribute:: is_register_injection_lpts_socket_added
                
                	VRF LPTS filter added on Register Injection Socket
                	**type**\: bool
                
                .. attribute:: is_m_host_publish_pending
                
                	Publish pending for MHost Default interface
                	**type**\: bool
                
                .. attribute:: mhost_interface
                
                	MHost handle
                	**type**\: str
                
                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                
                .. attribute:: mhost_default_interface_config
                
                	Configured Mhost Defint
                	**type**\: str
                
                .. attribute:: mdt_mtu
                
                	MDT MTU
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: maximum_mdt_aggregation
                
                	MDT max aggregation
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_data_switchover_interval
                
                	Data MDT Switchover interval
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_data_announce_interval
                
                	Data MDT Announce interval
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: non_default_vrf_count_on_socket
                
                	Count of non\-default vrfs on raw socket
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: neighbor_filter_name
                
                	Neighbor Filter Name
                	**type**\: str
                
                .. attribute:: mdt_neighbor_filter_name
                
                	MDT Neighbor Filter Name
                	**type**\: str
                
                .. attribute:: allow_rp_configured
                
                	Allow RP Configured
                	**type**\: bool
                
                .. attribute:: allow_rp_group_list
                
                	Allow RP Group\-List ACL Name
                	**type**\: str
                
                	**length:** 0..64
                
                .. attribute:: allow_rp_rp_list
                
                	Allow RP RP\-list ACL Name
                	**type**\: str
                
                	**length:** 0..64
                
                .. attribute:: sg_expiry_timer_configured
                
                	S,G Expiry Timer Configured
                	**type**\: bool
                
                .. attribute:: sg_expiry_time
                
                	S,G Expiry Time Configured, in seconds
                	**type**\: int
                
                	**range:** 0..65535
                
                	**units**\: second
                
                .. attribute:: sg_expiry_timer_sg_list
                
                	S,G expiry timer ACL name
                	**type**\: str
                
                	**length:** 0..64
                
                .. attribute:: mldp_mdt_name
                
                	MLDP MDT Name
                	**type**\: str
                
                .. attribute:: mldp_mdt_interface
                
                	MLDP MDT handle
                	**type**\: str
                
                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                
                .. attribute:: mldp_mdt_mtu
                
                	MLDP MDT MTU
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_maximum_mdt_aggregation
                
                	MLDP MDT max aggregation
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_data_switchover_interval
                
                	MLDP Data MDT Switchover interval
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_data_announce_interval
                
                	MLDP Data MDT Announce interval
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_rpf_identifier
                
                	MLDP RPF\-ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_remote_rpf_identifier
                
                	MLDP Remote RPF\-ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_create_mldp_mdt_interface
                
                	Create MLDP MDT interface
                	**type**\: bool
                
                .. attribute:: is_mldp_mdt_owner
                
                	MLDP MDT Owner
                	**type**\: bool
                
                .. attribute:: mldp_root_count
                
                	MLDP Root count
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_head_lsm_identifier
                
                	MLDP Head LSM\-ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_remote_head_lsm_identifier
                
                	MLDP Remote Head LSM\-ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: organization_unique_identifier
                
                	OUI for VPN\-ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: vpn_index
                
                	VPN Index
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_partitioned_mdt_configured
                
                	MLDP Partitioned MDT
                	**type**\: bool
                
                .. attribute:: mldp_remote_partitioned_mdt_configured
                
                	MLDP Remote Partitioned MDT
                	**type**\: bool
                
                .. attribute:: mldp_partioned_mp2m_ptree
                
                	MP2MP Partitioned MDT tree
                	**type**\: bool
                
                .. attribute:: mldp_partitioned_head_lsm_identifier
                
                	Partitioned MDT Head LSM\-ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_head_local_label
                
                	Partitioned MDT Head local label
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_partitioned_mdt_identifier
                
                	MLDP Partitioned MDT Identifier
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: bgp_auto_discovery_configured
                
                	BGP Auto\-Discovery configured
                	**type**\: bool
                
                .. attribute:: suppress_pim_data_mdt_tlv
                
                	Suppress PIM Data\-MDT TLV Announcements
                	**type**\: bool
                
                .. attribute:: inter_autonomous_system_enabled
                
                	Inter\-AS Enabled
                	**type**\: bool
                
                .. attribute:: bgp_source_active_announce
                
                	Send BGP Source\-Active Announcements
                	**type**\: bool
                
                .. attribute:: bgp_i_pmsi_added
                
                	BGP I\-PMSI Added
                	**type**\: bool
                
                .. attribute:: mldp_bsr_control_tree_added
                
                	MLDP BSR Control tree added
                	**type**\: bool
                
                .. attribute:: mldp_auto_rp_discovery_tree_added
                
                	MLDP Autorp Discovery Control tree added
                	**type**\: bool
                
                .. attribute:: mldp_auto_rp_announce_tree_added
                
                	MLDP Autorp Announce Control tree added
                	**type**\: bool
                
                .. attribute:: bgp_auto_discovery_type
                
                	BGP Auto Discovery Type
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_partitioned_mdt_control_identifier
                
                	Partitioned MDT Control Identifier
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_partitioned_ir_control_identifier
                
                	Partitioned IR MDT Control Identifier
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_control_head_lsm_identifier
                
                	MLDP MVPN Identifier
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: umh
                
                	Join UMH Core\-Tree
                	**type**\: bool
                
                .. attribute:: suppress_shared_tree_join
                
                	Suppress Shared\-Tree Joins
                	**type**\: bool
                
                .. attribute:: rsvp_te_mdt_name
                
                	RSVP\-TE MDT Name
                	**type**\: str
                
                .. attribute:: rsvp_te_mdt_interface
                
                	RSVP\-TEMDT handle
                	**type**\: str
                
                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                
                .. attribute:: rsvp_te_mdt_mtu
                
                	RSVP\-TEMDT MTU
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_maximum_mdt_aggregation
                
                	RSVP\-TE MDT max aggregation
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_data_switchover_interval
                
                	RSVP\-TE Data MDT Switchover interval
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_data_announce_interval
                
                	RSVP\-TE Data MDT Announce interval
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_rpf_identifier
                
                	RSVP\-TE RPF\-ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_create_rsvp_te_mdt_interface
                
                	Create RSVP\-TE MDT interface
                	**type**\: bool
                
                .. attribute:: is_rsvp_te_mdt_owner
                
                	RSVP\-TE MDT Owner
                	**type**\: bool
                
                .. attribute:: rsvp_te_mdt_static_p2mp_count
                
                	Number of Static P2MP\-TE MDT
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: p2mpte_li_drop
                
                	Route LI updates dropped for P2MP
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_name
                
                	IR MDT Name
                	**type**\: str
                
                .. attribute:: ir_mdt_interface
                
                	IRMDT handle
                	**type**\: str
                
                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                
                .. attribute:: ir_mdt_mtu
                
                	IRMDT MTU
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_maximum_mdt_aggregation
                
                	IR MDT max aggregation
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_data_switchover_interval
                
                	IR Data MDT Switchover interval
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_data_announce_interval
                
                	IR Data MDT Announce interval
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_rpf_identifier
                
                	IR RPF\-ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_tail_label
                
                	IR Tail Label
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_create_ir_mdt_interface
                
                	Create IR MDT interface
                	**type**\: bool
                
                .. attribute:: is_ir_mdt_owner
                
                	IR MDT Owner
                	**type**\: bool
                
                .. attribute:: in_b_and_mdt_name
                
                	Inband MDT Name
                	**type**\: str
                
                .. attribute:: in_b_and_mdt_interface
                
                	Inband MDT handle
                	**type**\: str
                
                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                
                .. attribute:: in_b_and_mdt_mtu
                
                	Inband MDT MTU
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_band_maximum_mdt_aggregation
                
                	Inband MDT max aggregation
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_b_and_mdt_data_switchover_interval
                
                	Inband Data MDT Switchover interval
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_b_and_mdt_data_announce_interval
                
                	Inband Data MDT Announce interval
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_b_and_mdt_rpf_identifier
                
                	Inband RPF\-ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_create_in_b_and_mdt_interface
                
                	Create Inband MDT interface
                	**type**\: bool
                
                .. attribute:: is_in_b_and_mdt_owner
                
                	Inband MDT Owner
                	**type**\: bool
                
                .. attribute:: in_band_signaling_local_enabled
                
                	Inband signaling Local enabled
                	**type**\: bool
                
                .. attribute:: in_band_signaling_remote_enabled
                
                	Inband signaling Remote enabled
                	**type**\: bool
                
                .. attribute:: valid_rd_present
                
                	RD is valid
                	**type**\: bool
                
                .. attribute:: stale_rd_present
                
                	RD is stale
                	**type**\: bool
                
                .. attribute:: route_distinguisher
                
                	RD value
                	**type**\: str
                
                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                
                .. attribute:: gin_b_and_mdt_name
                
                	Inband MDT Name
                	**type**\: str
                
                .. attribute:: gin_b_and_mdt_interface
                
                	Inband MDT handle
                	**type**\: str
                
                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                
                .. attribute:: gin_b_and_mdt_mtu
                
                	Inband MDT MTU
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: gin_band_maximum_mdt_aggregation
                
                	Inband MDT max aggregation
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: gin_b_and_mdt_data_switchover_interval
                
                	Inband Data MDT Switchover interval
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: gin_b_and_mdt_data_announce_interval
                
                	Inband Data MDT Announce interval
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: gin_b_and_mdt_rpf_identifier
                
                	Inband RPF\-ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_create_gin_b_and_mdt_interface
                
                	Create Inband MDT interface
                	**type**\: bool
                
                .. attribute:: is_gin_b_and_mdt_owner
                
                	Inband MDT Owner
                	**type**\: bool
                
                .. attribute:: is_pim_nsf_rib_converged
                
                	PIM NSF RIB converged
                	**type**\: bool
                
                .. attribute:: is_pim_nsf_rib_converge_received
                
                	PIM NSF RIB converge received
                	**type**\: bool
                
                .. attribute:: is_rib_multipath_enabled
                
                	PIM RIB multiplath enabled
                	**type**\: bool
                
                .. attribute:: is_rib_multipath_interface_hash
                
                	PIM RIB multipath interface hash
                	**type**\: bool
                
                .. attribute:: is_rib_multipath_source_hash
                
                	PIM RIB multipath source based hash
                	**type**\: bool
                
                .. attribute:: is_rib_multipath_source_next_hop_hash
                
                	PIM RIB multipath source\-nexthop hash
                	**type**\: bool
                
                .. attribute:: rump_enabled
                
                	PIM is using MuRIB
                	**type**\: bool
                
                .. attribute:: is_create_mdt_interface
                
                	Create MDT interface
                	**type**\: bool
                
                .. attribute:: is_auto_rp_listen_enabled
                
                	Auto RP Listen Enabled
                	**type**\: bool
                
                .. attribute:: is_all_interface_disable_operation
                
                	PIM all interface disable operation
                	**type**\: bool
                
                .. attribute:: is_default_granges
                
                	Default granges
                	**type**\: bool
                
                .. attribute:: is_auto_rp_listen_sock_add
                
                	Auto RP listen sock add
                	**type**\: bool
                
                .. attribute:: is_redistribution_reset
                
                	Pending redist reset
                	**type**\: bool
                
                .. attribute:: redistribution_reset_count
                
                	Redist reset count
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: rpf_policy_name
                
                	RPF topology selection route\-policy name
                	**type**\: str
                
                .. attribute:: table_count
                
                	Number of configured Tables
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: active_table_count
                
                	Number of active Tables
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: anycast_rp_policy_name
                
                	Anycast\-RP Policy Name
                	**type**\: str
                
                .. attribute:: anycast_rp_configured
                
                	Anycast\-RP config
                	**type**\: bool
                
                .. attribute:: bgp_remote_on
                
                	BGP remote interface status
                	**type**\: bool
                
                .. attribute:: bgp_remote_interface_name
                
                	BGP remote interface name
                	**type**\: str
                
                .. attribute:: bgp_remote_interface
                
                	BGP remote interface handle
                	**type**\: str
                
                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                
                .. attribute:: bgp_remote_address
                
                	BGP remote interface address
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: bgp_remote_state
                
                	BGP remote interface state
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: physical_interface_count
                
                	Enabled Physical Interface Count
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: virtual_interface_count
                
                	Enabled Virtual Interface Count
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: virtual_mlc_interface_name
                
                	Virtual master line card Interface
                	**type**\: str
                
                .. attribute:: mdt_immediate_switch
                
                	MDT Immediate Switch
                	**type**\: bool
                
                .. attribute:: mldp_root_address
                
                	MLDP Root addresses
                	**type**\: list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: export_route_target
                
                	Export Route Targets
                	**type**\: list of  		 :py:class:`ExportRouteTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Context.ExportRouteTarget>`
                
                .. attribute:: import_route_target
                
                	Import Route Targets
                	**type**\: list of  		 :py:class:`ImportRouteTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Context.ImportRouteTarget>`
                
                .. attribute:: anycast_rp_range
                
                	Anycast\-RP Ranges
                	**type**\: list of  		 :py:class:`AnycastRpRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Context.AnycastRpRange>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Active.DefaultContext.Context, self).__init__()

                    self.yang_name = "context"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("remote-default-group", ("remote_default_group", Pim.Active.DefaultContext.Context.RemoteDefaultGroup)), ("rpf-default-table", ("rpf_default_table", Pim.Active.DefaultContext.Context.RpfDefaultTable)), ("export-route-target", ("export_route_target", Pim.Active.DefaultContext.Context.ExportRouteTarget)), ("import-route-target", ("import_route_target", Pim.Active.DefaultContext.Context.ImportRouteTarget)), ("anycast-rp-range", ("anycast_rp_range", Pim.Active.DefaultContext.Context.AnycastRpRange))])
                    self._leafs = OrderedDict([
                        ('vrf_id', (YLeaf(YType.uint32, 'vrf-id'), ['int'])),
                        ('table_id', (YLeaf(YType.uint32, 'table-id'), ['int'])),
                        ('murib_id', (YLeaf(YType.uint32, 'murib-id'), ['int'])),
                        ('rpf_id', (YLeaf(YType.uint32, 'rpf-id'), ['int'])),
                        ('remote_table_id', (YLeaf(YType.uint32, 'remote-table-id'), ['int'])),
                        ('mdt_default_group', (YLeaf(YType.str, 'mdt-default-group'), ['str'])),
                        ('mdt_source', (YLeaf(YType.str, 'mdt-source'), ['str'])),
                        ('mdt_source_interface', (YLeaf(YType.str, 'mdt-source-interface'), ['str'])),
                        ('mdt_interface', (YLeaf(YType.str, 'mdt-interface'), ['str'])),
                        ('mdt_gre_rpf_identifier', (YLeaf(YType.uint32, 'mdt-gre-rpf-identifier'), ['int'])),
                        ('mdt_gre_remote_rpf_identifier', (YLeaf(YType.uint32, 'mdt-gre-remote-rpf-identifier'), ['int'])),
                        ('is_unicast_rib_registration', (YLeaf(YType.boolean, 'is-unicast-rib-registration'), ['bool'])),
                        ('is_multicast_rib_registration', (YLeaf(YType.boolean, 'is-multicast-rib-registration'), ['bool'])),
                        ('is_active', (YLeaf(YType.boolean, 'is-active'), ['bool'])),
                        ('is_active_ital', (YLeaf(YType.boolean, 'is-active-ital'), ['bool'])),
                        ('is_mrib_register', (YLeaf(YType.boolean, 'is-mrib-register'), ['bool'])),
                        ('is_mdt_owner', (YLeaf(YType.boolean, 'is-mdt-owner'), ['bool'])),
                        ('is_routing_enabled', (YLeaf(YType.boolean, 'is-routing-enabled'), ['bool'])),
                        ('is_socket_add_required', (YLeaf(YType.boolean, 'is-socket-add-required'), ['bool'])),
                        ('is_socket_added', (YLeaf(YType.boolean, 'is-socket-added'), ['bool'])),
                        ('is_lpts_socket_add_required', (YLeaf(YType.boolean, 'is-lpts-socket-add-required'), ['bool'])),
                        ('is_lpts_socket_added', (YLeaf(YType.boolean, 'is-lpts-socket-added'), ['bool'])),
                        ('is_udp_socket_add_required', (YLeaf(YType.boolean, 'is-udp-socket-add-required'), ['bool'])),
                        ('is_udp_socket_added', (YLeaf(YType.boolean, 'is-udp-socket-added'), ['bool'])),
                        ('is_udp_socket_bind_required', (YLeaf(YType.boolean, 'is-udp-socket-bind-required'), ['bool'])),
                        ('is_udp_socket_bind', (YLeaf(YType.boolean, 'is-udp-socket-bind'), ['bool'])),
                        ('is_register_injection_socket_add_required', (YLeaf(YType.boolean, 'is-register-injection-socket-add-required'), ['bool'])),
                        ('is_register_injection_socket_added', (YLeaf(YType.boolean, 'is-register-injection-socket-added'), ['bool'])),
                        ('is_register_injection_lpts_socket_add_required', (YLeaf(YType.boolean, 'is-register-injection-lpts-socket-add-required'), ['bool'])),
                        ('is_register_injection_lpts_socket_added', (YLeaf(YType.boolean, 'is-register-injection-lpts-socket-added'), ['bool'])),
                        ('is_m_host_publish_pending', (YLeaf(YType.boolean, 'is-m-host-publish-pending'), ['bool'])),
                        ('mhost_interface', (YLeaf(YType.str, 'mhost-interface'), ['str'])),
                        ('mhost_default_interface_config', (YLeaf(YType.str, 'mhost-default-interface-config'), ['str'])),
                        ('mdt_mtu', (YLeaf(YType.uint32, 'mdt-mtu'), ['int'])),
                        ('maximum_mdt_aggregation', (YLeaf(YType.uint32, 'maximum-mdt-aggregation'), ['int'])),
                        ('mdt_data_switchover_interval', (YLeaf(YType.uint32, 'mdt-data-switchover-interval'), ['int'])),
                        ('mdt_data_announce_interval', (YLeaf(YType.uint32, 'mdt-data-announce-interval'), ['int'])),
                        ('non_default_vrf_count_on_socket', (YLeaf(YType.uint32, 'non-default-vrf-count-on-socket'), ['int'])),
                        ('neighbor_filter_name', (YLeaf(YType.str, 'neighbor-filter-name'), ['str'])),
                        ('mdt_neighbor_filter_name', (YLeaf(YType.str, 'mdt-neighbor-filter-name'), ['str'])),
                        ('allow_rp_configured', (YLeaf(YType.boolean, 'allow-rp-configured'), ['bool'])),
                        ('allow_rp_group_list', (YLeaf(YType.str, 'allow-rp-group-list'), ['str'])),
                        ('allow_rp_rp_list', (YLeaf(YType.str, 'allow-rp-rp-list'), ['str'])),
                        ('sg_expiry_timer_configured', (YLeaf(YType.boolean, 'sg-expiry-timer-configured'), ['bool'])),
                        ('sg_expiry_time', (YLeaf(YType.uint16, 'sg-expiry-time'), ['int'])),
                        ('sg_expiry_timer_sg_list', (YLeaf(YType.str, 'sg-expiry-timer-sg-list'), ['str'])),
                        ('mldp_mdt_name', (YLeaf(YType.str, 'mldp-mdt-name'), ['str'])),
                        ('mldp_mdt_interface', (YLeaf(YType.str, 'mldp-mdt-interface'), ['str'])),
                        ('mldp_mdt_mtu', (YLeaf(YType.uint32, 'mldp-mdt-mtu'), ['int'])),
                        ('mldp_maximum_mdt_aggregation', (YLeaf(YType.uint32, 'mldp-maximum-mdt-aggregation'), ['int'])),
                        ('mldp_mdt_data_switchover_interval', (YLeaf(YType.uint32, 'mldp-mdt-data-switchover-interval'), ['int'])),
                        ('mldp_mdt_data_announce_interval', (YLeaf(YType.uint32, 'mldp-mdt-data-announce-interval'), ['int'])),
                        ('mldp_mdt_rpf_identifier', (YLeaf(YType.uint32, 'mldp-mdt-rpf-identifier'), ['int'])),
                        ('mldp_mdt_remote_rpf_identifier', (YLeaf(YType.uint32, 'mldp-mdt-remote-rpf-identifier'), ['int'])),
                        ('is_create_mldp_mdt_interface', (YLeaf(YType.boolean, 'is-create-mldp-mdt-interface'), ['bool'])),
                        ('is_mldp_mdt_owner', (YLeaf(YType.boolean, 'is-mldp-mdt-owner'), ['bool'])),
                        ('mldp_root_count', (YLeaf(YType.uint32, 'mldp-root-count'), ['int'])),
                        ('mldp_head_lsm_identifier', (YLeaf(YType.uint32, 'mldp-head-lsm-identifier'), ['int'])),
                        ('mldp_remote_head_lsm_identifier', (YLeaf(YType.uint32, 'mldp-remote-head-lsm-identifier'), ['int'])),
                        ('organization_unique_identifier', (YLeaf(YType.uint32, 'organization-unique-identifier'), ['int'])),
                        ('vpn_index', (YLeaf(YType.uint32, 'vpn-index'), ['int'])),
                        ('mldp_partitioned_mdt_configured', (YLeaf(YType.boolean, 'mldp-partitioned-mdt-configured'), ['bool'])),
                        ('mldp_remote_partitioned_mdt_configured', (YLeaf(YType.boolean, 'mldp-remote-partitioned-mdt-configured'), ['bool'])),
                        ('mldp_partioned_mp2m_ptree', (YLeaf(YType.boolean, 'mldp-partioned-mp2m-ptree'), ['bool'])),
                        ('mldp_partitioned_head_lsm_identifier', (YLeaf(YType.uint32, 'mldp-partitioned-head-lsm-identifier'), ['int'])),
                        ('mldp_head_local_label', (YLeaf(YType.uint32, 'mldp-head-local-label'), ['int'])),
                        ('mldp_partitioned_mdt_identifier', (YLeaf(YType.uint32, 'mldp-partitioned-mdt-identifier'), ['int'])),
                        ('bgp_auto_discovery_configured', (YLeaf(YType.boolean, 'bgp-auto-discovery-configured'), ['bool'])),
                        ('suppress_pim_data_mdt_tlv', (YLeaf(YType.boolean, 'suppress-pim-data-mdt-tlv'), ['bool'])),
                        ('inter_autonomous_system_enabled', (YLeaf(YType.boolean, 'inter-autonomous-system-enabled'), ['bool'])),
                        ('bgp_source_active_announce', (YLeaf(YType.boolean, 'bgp-source-active-announce'), ['bool'])),
                        ('bgp_i_pmsi_added', (YLeaf(YType.boolean, 'bgp-i-pmsi-added'), ['bool'])),
                        ('mldp_bsr_control_tree_added', (YLeaf(YType.boolean, 'mldp-bsr-control-tree-added'), ['bool'])),
                        ('mldp_auto_rp_discovery_tree_added', (YLeaf(YType.boolean, 'mldp-auto-rp-discovery-tree-added'), ['bool'])),
                        ('mldp_auto_rp_announce_tree_added', (YLeaf(YType.boolean, 'mldp-auto-rp-announce-tree-added'), ['bool'])),
                        ('bgp_auto_discovery_type', (YLeaf(YType.uint32, 'bgp-auto-discovery-type'), ['int'])),
                        ('mdt_partitioned_mdt_control_identifier', (YLeaf(YType.uint32, 'mdt-partitioned-mdt-control-identifier'), ['int'])),
                        ('mdt_partitioned_ir_control_identifier', (YLeaf(YType.uint32, 'mdt-partitioned-ir-control-identifier'), ['int'])),
                        ('mldp_control_head_lsm_identifier', (YLeaf(YType.uint32, 'mldp-control-head-lsm-identifier'), ['int'])),
                        ('umh', (YLeaf(YType.boolean, 'umh'), ['bool'])),
                        ('suppress_shared_tree_join', (YLeaf(YType.boolean, 'suppress-shared-tree-join'), ['bool'])),
                        ('rsvp_te_mdt_name', (YLeaf(YType.str, 'rsvp-te-mdt-name'), ['str'])),
                        ('rsvp_te_mdt_interface', (YLeaf(YType.str, 'rsvp-te-mdt-interface'), ['str'])),
                        ('rsvp_te_mdt_mtu', (YLeaf(YType.uint32, 'rsvp-te-mdt-mtu'), ['int'])),
                        ('rsvp_te_maximum_mdt_aggregation', (YLeaf(YType.uint32, 'rsvp-te-maximum-mdt-aggregation'), ['int'])),
                        ('rsvp_te_mdt_data_switchover_interval', (YLeaf(YType.uint32, 'rsvp-te-mdt-data-switchover-interval'), ['int'])),
                        ('rsvp_te_mdt_data_announce_interval', (YLeaf(YType.uint32, 'rsvp-te-mdt-data-announce-interval'), ['int'])),
                        ('rsvp_te_mdt_rpf_identifier', (YLeaf(YType.uint32, 'rsvp-te-mdt-rpf-identifier'), ['int'])),
                        ('is_create_rsvp_te_mdt_interface', (YLeaf(YType.boolean, 'is-create-rsvp-te-mdt-interface'), ['bool'])),
                        ('is_rsvp_te_mdt_owner', (YLeaf(YType.boolean, 'is-rsvp-te-mdt-owner'), ['bool'])),
                        ('rsvp_te_mdt_static_p2mp_count', (YLeaf(YType.uint32, 'rsvp-te-mdt-static-p2mp-count'), ['int'])),
                        ('p2mpte_li_drop', (YLeaf(YType.uint32, 'p2mpte-li-drop'), ['int'])),
                        ('ir_mdt_name', (YLeaf(YType.str, 'ir-mdt-name'), ['str'])),
                        ('ir_mdt_interface', (YLeaf(YType.str, 'ir-mdt-interface'), ['str'])),
                        ('ir_mdt_mtu', (YLeaf(YType.uint32, 'ir-mdt-mtu'), ['int'])),
                        ('ir_maximum_mdt_aggregation', (YLeaf(YType.uint32, 'ir-maximum-mdt-aggregation'), ['int'])),
                        ('ir_mdt_data_switchover_interval', (YLeaf(YType.uint32, 'ir-mdt-data-switchover-interval'), ['int'])),
                        ('ir_mdt_data_announce_interval', (YLeaf(YType.uint32, 'ir-mdt-data-announce-interval'), ['int'])),
                        ('ir_mdt_rpf_identifier', (YLeaf(YType.uint32, 'ir-mdt-rpf-identifier'), ['int'])),
                        ('ir_mdt_tail_label', (YLeaf(YType.uint32, 'ir-mdt-tail-label'), ['int'])),
                        ('is_create_ir_mdt_interface', (YLeaf(YType.boolean, 'is-create-ir-mdt-interface'), ['bool'])),
                        ('is_ir_mdt_owner', (YLeaf(YType.boolean, 'is-ir-mdt-owner'), ['bool'])),
                        ('in_b_and_mdt_name', (YLeaf(YType.str, 'in-b-and-mdt-name'), ['str'])),
                        ('in_b_and_mdt_interface', (YLeaf(YType.str, 'in-b-and-mdt-interface'), ['str'])),
                        ('in_b_and_mdt_mtu', (YLeaf(YType.uint32, 'in-b-and-mdt-mtu'), ['int'])),
                        ('in_band_maximum_mdt_aggregation', (YLeaf(YType.uint32, 'in-band-maximum-mdt-aggregation'), ['int'])),
                        ('in_b_and_mdt_data_switchover_interval', (YLeaf(YType.uint32, 'in-b-and-mdt-data-switchover-interval'), ['int'])),
                        ('in_b_and_mdt_data_announce_interval', (YLeaf(YType.uint32, 'in-b-and-mdt-data-announce-interval'), ['int'])),
                        ('in_b_and_mdt_rpf_identifier', (YLeaf(YType.uint32, 'in-b-and-mdt-rpf-identifier'), ['int'])),
                        ('is_create_in_b_and_mdt_interface', (YLeaf(YType.boolean, 'is-create-in-b-and-mdt-interface'), ['bool'])),
                        ('is_in_b_and_mdt_owner', (YLeaf(YType.boolean, 'is-in-b-and-mdt-owner'), ['bool'])),
                        ('in_band_signaling_local_enabled', (YLeaf(YType.boolean, 'in-band-signaling-local-enabled'), ['bool'])),
                        ('in_band_signaling_remote_enabled', (YLeaf(YType.boolean, 'in-band-signaling-remote-enabled'), ['bool'])),
                        ('valid_rd_present', (YLeaf(YType.boolean, 'valid-rd-present'), ['bool'])),
                        ('stale_rd_present', (YLeaf(YType.boolean, 'stale-rd-present'), ['bool'])),
                        ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                        ('gin_b_and_mdt_name', (YLeaf(YType.str, 'gin-b-and-mdt-name'), ['str'])),
                        ('gin_b_and_mdt_interface', (YLeaf(YType.str, 'gin-b-and-mdt-interface'), ['str'])),
                        ('gin_b_and_mdt_mtu', (YLeaf(YType.uint32, 'gin-b-and-mdt-mtu'), ['int'])),
                        ('gin_band_maximum_mdt_aggregation', (YLeaf(YType.uint32, 'gin-band-maximum-mdt-aggregation'), ['int'])),
                        ('gin_b_and_mdt_data_switchover_interval', (YLeaf(YType.uint32, 'gin-b-and-mdt-data-switchover-interval'), ['int'])),
                        ('gin_b_and_mdt_data_announce_interval', (YLeaf(YType.uint32, 'gin-b-and-mdt-data-announce-interval'), ['int'])),
                        ('gin_b_and_mdt_rpf_identifier', (YLeaf(YType.uint32, 'gin-b-and-mdt-rpf-identifier'), ['int'])),
                        ('is_create_gin_b_and_mdt_interface', (YLeaf(YType.boolean, 'is-create-gin-b-and-mdt-interface'), ['bool'])),
                        ('is_gin_b_and_mdt_owner', (YLeaf(YType.boolean, 'is-gin-b-and-mdt-owner'), ['bool'])),
                        ('is_pim_nsf_rib_converged', (YLeaf(YType.boolean, 'is-pim-nsf-rib-converged'), ['bool'])),
                        ('is_pim_nsf_rib_converge_received', (YLeaf(YType.boolean, 'is-pim-nsf-rib-converge-received'), ['bool'])),
                        ('is_rib_multipath_enabled', (YLeaf(YType.boolean, 'is-rib-multipath-enabled'), ['bool'])),
                        ('is_rib_multipath_interface_hash', (YLeaf(YType.boolean, 'is-rib-multipath-interface-hash'), ['bool'])),
                        ('is_rib_multipath_source_hash', (YLeaf(YType.boolean, 'is-rib-multipath-source-hash'), ['bool'])),
                        ('is_rib_multipath_source_next_hop_hash', (YLeaf(YType.boolean, 'is-rib-multipath-source-next-hop-hash'), ['bool'])),
                        ('rump_enabled', (YLeaf(YType.boolean, 'rump-enabled'), ['bool'])),
                        ('is_create_mdt_interface', (YLeaf(YType.boolean, 'is-create-mdt-interface'), ['bool'])),
                        ('is_auto_rp_listen_enabled', (YLeaf(YType.boolean, 'is-auto-rp-listen-enabled'), ['bool'])),
                        ('is_all_interface_disable_operation', (YLeaf(YType.boolean, 'is-all-interface-disable-operation'), ['bool'])),
                        ('is_default_granges', (YLeaf(YType.boolean, 'is-default-granges'), ['bool'])),
                        ('is_auto_rp_listen_sock_add', (YLeaf(YType.boolean, 'is-auto-rp-listen-sock-add'), ['bool'])),
                        ('is_redistribution_reset', (YLeaf(YType.boolean, 'is-redistribution-reset'), ['bool'])),
                        ('redistribution_reset_count', (YLeaf(YType.uint32, 'redistribution-reset-count'), ['int'])),
                        ('rpf_policy_name', (YLeaf(YType.str, 'rpf-policy-name'), ['str'])),
                        ('table_count', (YLeaf(YType.uint32, 'table-count'), ['int'])),
                        ('active_table_count', (YLeaf(YType.uint32, 'active-table-count'), ['int'])),
                        ('anycast_rp_policy_name', (YLeaf(YType.str, 'anycast-rp-policy-name'), ['str'])),
                        ('anycast_rp_configured', (YLeaf(YType.boolean, 'anycast-rp-configured'), ['bool'])),
                        ('bgp_remote_on', (YLeaf(YType.boolean, 'bgp-remote-on'), ['bool'])),
                        ('bgp_remote_interface_name', (YLeaf(YType.str, 'bgp-remote-interface-name'), ['str'])),
                        ('bgp_remote_interface', (YLeaf(YType.str, 'bgp-remote-interface'), ['str'])),
                        ('bgp_remote_address', (YLeaf(YType.str, 'bgp-remote-address'), ['str'])),
                        ('bgp_remote_state', (YLeaf(YType.uint32, 'bgp-remote-state'), ['int'])),
                        ('physical_interface_count', (YLeaf(YType.uint64, 'physical-interface-count'), ['int'])),
                        ('virtual_interface_count', (YLeaf(YType.uint64, 'virtual-interface-count'), ['int'])),
                        ('virtual_mlc_interface_name', (YLeaf(YType.str, 'virtual-mlc-interface-name'), ['str'])),
                        ('mdt_immediate_switch', (YLeaf(YType.boolean, 'mdt-immediate-switch'), ['bool'])),
                        ('mldp_root_address', (YLeafList(YType.uint32, 'mldp-root-address'), ['int'])),
                    ])
                    self.vrf_id = None
                    self.table_id = None
                    self.murib_id = None
                    self.rpf_id = None
                    self.remote_table_id = None
                    self.mdt_default_group = None
                    self.mdt_source = None
                    self.mdt_source_interface = None
                    self.mdt_interface = None
                    self.mdt_gre_rpf_identifier = None
                    self.mdt_gre_remote_rpf_identifier = None
                    self.is_unicast_rib_registration = None
                    self.is_multicast_rib_registration = None
                    self.is_active = None
                    self.is_active_ital = None
                    self.is_mrib_register = None
                    self.is_mdt_owner = None
                    self.is_routing_enabled = None
                    self.is_socket_add_required = None
                    self.is_socket_added = None
                    self.is_lpts_socket_add_required = None
                    self.is_lpts_socket_added = None
                    self.is_udp_socket_add_required = None
                    self.is_udp_socket_added = None
                    self.is_udp_socket_bind_required = None
                    self.is_udp_socket_bind = None
                    self.is_register_injection_socket_add_required = None
                    self.is_register_injection_socket_added = None
                    self.is_register_injection_lpts_socket_add_required = None
                    self.is_register_injection_lpts_socket_added = None
                    self.is_m_host_publish_pending = None
                    self.mhost_interface = None
                    self.mhost_default_interface_config = None
                    self.mdt_mtu = None
                    self.maximum_mdt_aggregation = None
                    self.mdt_data_switchover_interval = None
                    self.mdt_data_announce_interval = None
                    self.non_default_vrf_count_on_socket = None
                    self.neighbor_filter_name = None
                    self.mdt_neighbor_filter_name = None
                    self.allow_rp_configured = None
                    self.allow_rp_group_list = None
                    self.allow_rp_rp_list = None
                    self.sg_expiry_timer_configured = None
                    self.sg_expiry_time = None
                    self.sg_expiry_timer_sg_list = None
                    self.mldp_mdt_name = None
                    self.mldp_mdt_interface = None
                    self.mldp_mdt_mtu = None
                    self.mldp_maximum_mdt_aggregation = None
                    self.mldp_mdt_data_switchover_interval = None
                    self.mldp_mdt_data_announce_interval = None
                    self.mldp_mdt_rpf_identifier = None
                    self.mldp_mdt_remote_rpf_identifier = None
                    self.is_create_mldp_mdt_interface = None
                    self.is_mldp_mdt_owner = None
                    self.mldp_root_count = None
                    self.mldp_head_lsm_identifier = None
                    self.mldp_remote_head_lsm_identifier = None
                    self.organization_unique_identifier = None
                    self.vpn_index = None
                    self.mldp_partitioned_mdt_configured = None
                    self.mldp_remote_partitioned_mdt_configured = None
                    self.mldp_partioned_mp2m_ptree = None
                    self.mldp_partitioned_head_lsm_identifier = None
                    self.mldp_head_local_label = None
                    self.mldp_partitioned_mdt_identifier = None
                    self.bgp_auto_discovery_configured = None
                    self.suppress_pim_data_mdt_tlv = None
                    self.inter_autonomous_system_enabled = None
                    self.bgp_source_active_announce = None
                    self.bgp_i_pmsi_added = None
                    self.mldp_bsr_control_tree_added = None
                    self.mldp_auto_rp_discovery_tree_added = None
                    self.mldp_auto_rp_announce_tree_added = None
                    self.bgp_auto_discovery_type = None
                    self.mdt_partitioned_mdt_control_identifier = None
                    self.mdt_partitioned_ir_control_identifier = None
                    self.mldp_control_head_lsm_identifier = None
                    self.umh = None
                    self.suppress_shared_tree_join = None
                    self.rsvp_te_mdt_name = None
                    self.rsvp_te_mdt_interface = None
                    self.rsvp_te_mdt_mtu = None
                    self.rsvp_te_maximum_mdt_aggregation = None
                    self.rsvp_te_mdt_data_switchover_interval = None
                    self.rsvp_te_mdt_data_announce_interval = None
                    self.rsvp_te_mdt_rpf_identifier = None
                    self.is_create_rsvp_te_mdt_interface = None
                    self.is_rsvp_te_mdt_owner = None
                    self.rsvp_te_mdt_static_p2mp_count = None
                    self.p2mpte_li_drop = None
                    self.ir_mdt_name = None
                    self.ir_mdt_interface = None
                    self.ir_mdt_mtu = None
                    self.ir_maximum_mdt_aggregation = None
                    self.ir_mdt_data_switchover_interval = None
                    self.ir_mdt_data_announce_interval = None
                    self.ir_mdt_rpf_identifier = None
                    self.ir_mdt_tail_label = None
                    self.is_create_ir_mdt_interface = None
                    self.is_ir_mdt_owner = None
                    self.in_b_and_mdt_name = None
                    self.in_b_and_mdt_interface = None
                    self.in_b_and_mdt_mtu = None
                    self.in_band_maximum_mdt_aggregation = None
                    self.in_b_and_mdt_data_switchover_interval = None
                    self.in_b_and_mdt_data_announce_interval = None
                    self.in_b_and_mdt_rpf_identifier = None
                    self.is_create_in_b_and_mdt_interface = None
                    self.is_in_b_and_mdt_owner = None
                    self.in_band_signaling_local_enabled = None
                    self.in_band_signaling_remote_enabled = None
                    self.valid_rd_present = None
                    self.stale_rd_present = None
                    self.route_distinguisher = None
                    self.gin_b_and_mdt_name = None
                    self.gin_b_and_mdt_interface = None
                    self.gin_b_and_mdt_mtu = None
                    self.gin_band_maximum_mdt_aggregation = None
                    self.gin_b_and_mdt_data_switchover_interval = None
                    self.gin_b_and_mdt_data_announce_interval = None
                    self.gin_b_and_mdt_rpf_identifier = None
                    self.is_create_gin_b_and_mdt_interface = None
                    self.is_gin_b_and_mdt_owner = None
                    self.is_pim_nsf_rib_converged = None
                    self.is_pim_nsf_rib_converge_received = None
                    self.is_rib_multipath_enabled = None
                    self.is_rib_multipath_interface_hash = None
                    self.is_rib_multipath_source_hash = None
                    self.is_rib_multipath_source_next_hop_hash = None
                    self.rump_enabled = None
                    self.is_create_mdt_interface = None
                    self.is_auto_rp_listen_enabled = None
                    self.is_all_interface_disable_operation = None
                    self.is_default_granges = None
                    self.is_auto_rp_listen_sock_add = None
                    self.is_redistribution_reset = None
                    self.redistribution_reset_count = None
                    self.rpf_policy_name = None
                    self.table_count = None
                    self.active_table_count = None
                    self.anycast_rp_policy_name = None
                    self.anycast_rp_configured = None
                    self.bgp_remote_on = None
                    self.bgp_remote_interface_name = None
                    self.bgp_remote_interface = None
                    self.bgp_remote_address = None
                    self.bgp_remote_state = None
                    self.physical_interface_count = None
                    self.virtual_interface_count = None
                    self.virtual_mlc_interface_name = None
                    self.mdt_immediate_switch = None
                    self.mldp_root_address = []

                    self.remote_default_group = Pim.Active.DefaultContext.Context.RemoteDefaultGroup()
                    self.remote_default_group.parent = self
                    self._children_name_map["remote_default_group"] = "remote-default-group"

                    self.rpf_default_table = Pim.Active.DefaultContext.Context.RpfDefaultTable()
                    self.rpf_default_table.parent = self
                    self._children_name_map["rpf_default_table"] = "rpf-default-table"

                    self.export_route_target = YList(self)
                    self.import_route_target = YList(self)
                    self.anycast_rp_range = YList(self)
                    self._segment_path = lambda: "context"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.DefaultContext.Context, ['vrf_id', 'table_id', 'murib_id', 'rpf_id', 'remote_table_id', 'mdt_default_group', 'mdt_source', 'mdt_source_interface', 'mdt_interface', 'mdt_gre_rpf_identifier', 'mdt_gre_remote_rpf_identifier', 'is_unicast_rib_registration', 'is_multicast_rib_registration', 'is_active', 'is_active_ital', 'is_mrib_register', 'is_mdt_owner', 'is_routing_enabled', 'is_socket_add_required', 'is_socket_added', 'is_lpts_socket_add_required', 'is_lpts_socket_added', 'is_udp_socket_add_required', 'is_udp_socket_added', 'is_udp_socket_bind_required', 'is_udp_socket_bind', 'is_register_injection_socket_add_required', 'is_register_injection_socket_added', 'is_register_injection_lpts_socket_add_required', 'is_register_injection_lpts_socket_added', 'is_m_host_publish_pending', 'mhost_interface', 'mhost_default_interface_config', 'mdt_mtu', 'maximum_mdt_aggregation', 'mdt_data_switchover_interval', 'mdt_data_announce_interval', 'non_default_vrf_count_on_socket', 'neighbor_filter_name', 'mdt_neighbor_filter_name', 'allow_rp_configured', 'allow_rp_group_list', 'allow_rp_rp_list', 'sg_expiry_timer_configured', 'sg_expiry_time', 'sg_expiry_timer_sg_list', 'mldp_mdt_name', 'mldp_mdt_interface', 'mldp_mdt_mtu', 'mldp_maximum_mdt_aggregation', 'mldp_mdt_data_switchover_interval', 'mldp_mdt_data_announce_interval', 'mldp_mdt_rpf_identifier', 'mldp_mdt_remote_rpf_identifier', 'is_create_mldp_mdt_interface', 'is_mldp_mdt_owner', 'mldp_root_count', 'mldp_head_lsm_identifier', 'mldp_remote_head_lsm_identifier', 'organization_unique_identifier', 'vpn_index', 'mldp_partitioned_mdt_configured', 'mldp_remote_partitioned_mdt_configured', 'mldp_partioned_mp2m_ptree', 'mldp_partitioned_head_lsm_identifier', 'mldp_head_local_label', 'mldp_partitioned_mdt_identifier', 'bgp_auto_discovery_configured', 'suppress_pim_data_mdt_tlv', 'inter_autonomous_system_enabled', 'bgp_source_active_announce', 'bgp_i_pmsi_added', 'mldp_bsr_control_tree_added', 'mldp_auto_rp_discovery_tree_added', 'mldp_auto_rp_announce_tree_added', 'bgp_auto_discovery_type', 'mdt_partitioned_mdt_control_identifier', 'mdt_partitioned_ir_control_identifier', 'mldp_control_head_lsm_identifier', 'umh', 'suppress_shared_tree_join', 'rsvp_te_mdt_name', 'rsvp_te_mdt_interface', 'rsvp_te_mdt_mtu', 'rsvp_te_maximum_mdt_aggregation', 'rsvp_te_mdt_data_switchover_interval', 'rsvp_te_mdt_data_announce_interval', 'rsvp_te_mdt_rpf_identifier', 'is_create_rsvp_te_mdt_interface', 'is_rsvp_te_mdt_owner', 'rsvp_te_mdt_static_p2mp_count', 'p2mpte_li_drop', 'ir_mdt_name', 'ir_mdt_interface', 'ir_mdt_mtu', 'ir_maximum_mdt_aggregation', 'ir_mdt_data_switchover_interval', 'ir_mdt_data_announce_interval', 'ir_mdt_rpf_identifier', 'ir_mdt_tail_label', 'is_create_ir_mdt_interface', 'is_ir_mdt_owner', 'in_b_and_mdt_name', 'in_b_and_mdt_interface', 'in_b_and_mdt_mtu', 'in_band_maximum_mdt_aggregation', 'in_b_and_mdt_data_switchover_interval', 'in_b_and_mdt_data_announce_interval', 'in_b_and_mdt_rpf_identifier', 'is_create_in_b_and_mdt_interface', 'is_in_b_and_mdt_owner', 'in_band_signaling_local_enabled', 'in_band_signaling_remote_enabled', 'valid_rd_present', 'stale_rd_present', 'route_distinguisher', 'gin_b_and_mdt_name', 'gin_b_and_mdt_interface', 'gin_b_and_mdt_mtu', 'gin_band_maximum_mdt_aggregation', 'gin_b_and_mdt_data_switchover_interval', 'gin_b_and_mdt_data_announce_interval', 'gin_b_and_mdt_rpf_identifier', 'is_create_gin_b_and_mdt_interface', 'is_gin_b_and_mdt_owner', 'is_pim_nsf_rib_converged', 'is_pim_nsf_rib_converge_received', 'is_rib_multipath_enabled', 'is_rib_multipath_interface_hash', 'is_rib_multipath_source_hash', 'is_rib_multipath_source_next_hop_hash', 'rump_enabled', 'is_create_mdt_interface', 'is_auto_rp_listen_enabled', 'is_all_interface_disable_operation', 'is_default_granges', 'is_auto_rp_listen_sock_add', 'is_redistribution_reset', 'redistribution_reset_count', 'rpf_policy_name', 'table_count', 'active_table_count', 'anycast_rp_policy_name', 'anycast_rp_configured', 'bgp_remote_on', 'bgp_remote_interface_name', 'bgp_remote_interface', 'bgp_remote_address', 'bgp_remote_state', 'physical_interface_count', 'virtual_interface_count', 'virtual_mlc_interface_name', 'mdt_immediate_switch', 'mldp_root_address'], name, value)


                class RemoteDefaultGroup(Entity):
                    """
                    Remote Default Group
                    
                    .. attribute:: af_name
                    
                    	AFName
                    	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                    
                    .. attribute:: ipv4_address
                    
                    	IPv4 Address
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: ipv6_address
                    
                    	IPV6 Address
                    	**type**\: str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.Context.RemoteDefaultGroup, self).__init__()

                        self.yang_name = "remote-default-group"
                        self.yang_parent_name = "context"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                        ])
                        self.af_name = None
                        self.ipv4_address = None
                        self.ipv6_address = None
                        self._segment_path = lambda: "remote-default-group"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/context/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.Context.RemoteDefaultGroup, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class RpfDefaultTable(Entity):
                    """
                    RPF Default Table
                    
                    .. attribute:: afi
                    
                    	AFI
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: safi
                    
                    	SAFI
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_name
                    
                    	Table name
                    	**type**\: str
                    
                    .. attribute:: vrf_id
                    
                    	VRF ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_id
                    
                    	Table ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_active
                    
                    	Active status
                    	**type**\: bool
                    
                    .. attribute:: is_ital_registration_done
                    
                    	ITAL reg status
                    	**type**\: bool
                    
                    .. attribute:: is_rib_registration_done
                    
                    	RIB reg status
                    	**type**\: bool
                    
                    .. attribute:: is_rib_convergence_received
                    
                    	RIB Convergence receive status
                    	**type**\: bool
                    
                    .. attribute:: is_rib_convergence
                    
                    	RIB Convergence status
                    	**type**\: bool
                    
                    .. attribute:: rpf_registrations
                    
                    	RPF Registration count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.Context.RpfDefaultTable, self).__init__()

                        self.yang_name = "rpf-default-table"
                        self.yang_parent_name = "context"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('afi', (YLeaf(YType.uint32, 'afi'), ['int'])),
                            ('safi', (YLeaf(YType.uint32, 'safi'), ['int'])),
                            ('table_name', (YLeaf(YType.str, 'table-name'), ['str'])),
                            ('vrf_id', (YLeaf(YType.uint32, 'vrf-id'), ['int'])),
                            ('table_id', (YLeaf(YType.uint32, 'table-id'), ['int'])),
                            ('is_active', (YLeaf(YType.boolean, 'is-active'), ['bool'])),
                            ('is_ital_registration_done', (YLeaf(YType.boolean, 'is-ital-registration-done'), ['bool'])),
                            ('is_rib_registration_done', (YLeaf(YType.boolean, 'is-rib-registration-done'), ['bool'])),
                            ('is_rib_convergence_received', (YLeaf(YType.boolean, 'is-rib-convergence-received'), ['bool'])),
                            ('is_rib_convergence', (YLeaf(YType.boolean, 'is-rib-convergence'), ['bool'])),
                            ('rpf_registrations', (YLeaf(YType.uint32, 'rpf-registrations'), ['int'])),
                        ])
                        self.afi = None
                        self.safi = None
                        self.table_name = None
                        self.vrf_id = None
                        self.table_id = None
                        self.is_active = None
                        self.is_ital_registration_done = None
                        self.is_rib_registration_done = None
                        self.is_rib_convergence_received = None
                        self.is_rib_convergence = None
                        self.rpf_registrations = None
                        self._segment_path = lambda: "rpf-default-table"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/context/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.Context.RpfDefaultTable, ['afi', 'safi', 'table_name', 'vrf_id', 'table_id', 'is_active', 'is_ital_registration_done', 'is_rib_registration_done', 'is_rib_convergence_received', 'is_rib_convergence', 'rpf_registrations'], name, value)


                class ExportRouteTarget(Entity):
                    """
                    Export Route Targets
                    
                    .. attribute:: route_target
                    
                    	Route Target Extended community value
                    	**type**\: str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: configured
                    
                    	Configured Route Target
                    	**type**\: bool
                    
                    .. attribute:: anycast_rp
                    
                    	Anycast\-RP Group
                    	**type**\: bool
                    
                    .. attribute:: anycast_rp_marked
                    
                    	Anycast\-RP Group marked
                    	**type**\: bool
                    
                    .. attribute:: update_pending
                    
                    	Update Pending to BGP
                    	**type**\: bool
                    
                    .. attribute:: bgp_auto_discovery
                    
                    	BGP Auto Discovery
                    	**type**\: bool
                    
                    .. attribute:: segment_border
                    
                    	Segment Border
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.Context.ExportRouteTarget, self).__init__()

                        self.yang_name = "export-route-target"
                        self.yang_parent_name = "context"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_target', (YLeaf(YType.str, 'route-target'), ['str'])),
                            ('configured', (YLeaf(YType.boolean, 'configured'), ['bool'])),
                            ('anycast_rp', (YLeaf(YType.boolean, 'anycast-rp'), ['bool'])),
                            ('anycast_rp_marked', (YLeaf(YType.boolean, 'anycast-rp-marked'), ['bool'])),
                            ('update_pending', (YLeaf(YType.boolean, 'update-pending'), ['bool'])),
                            ('bgp_auto_discovery', (YLeaf(YType.boolean, 'bgp-auto-discovery'), ['bool'])),
                            ('segment_border', (YLeaf(YType.boolean, 'segment-border'), ['bool'])),
                        ])
                        self.route_target = None
                        self.configured = None
                        self.anycast_rp = None
                        self.anycast_rp_marked = None
                        self.update_pending = None
                        self.bgp_auto_discovery = None
                        self.segment_border = None
                        self._segment_path = lambda: "export-route-target"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/context/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.Context.ExportRouteTarget, ['route_target', 'configured', 'anycast_rp', 'anycast_rp_marked', 'update_pending', 'bgp_auto_discovery', 'segment_border'], name, value)


                class ImportRouteTarget(Entity):
                    """
                    Import Route Targets
                    
                    .. attribute:: route_target
                    
                    	Route Target Extended community value
                    	**type**\: str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: configured
                    
                    	Configured Route Target
                    	**type**\: bool
                    
                    .. attribute:: anycast_rp
                    
                    	Anycast\-RP Group
                    	**type**\: bool
                    
                    .. attribute:: anycast_rp_marked
                    
                    	Anycast\-RP Group marked
                    	**type**\: bool
                    
                    .. attribute:: update_pending
                    
                    	Update Pending to BGP
                    	**type**\: bool
                    
                    .. attribute:: bgp_auto_discovery
                    
                    	BGP Auto Discovery
                    	**type**\: bool
                    
                    .. attribute:: segment_border
                    
                    	Segment Border
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.Context.ImportRouteTarget, self).__init__()

                        self.yang_name = "import-route-target"
                        self.yang_parent_name = "context"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_target', (YLeaf(YType.str, 'route-target'), ['str'])),
                            ('configured', (YLeaf(YType.boolean, 'configured'), ['bool'])),
                            ('anycast_rp', (YLeaf(YType.boolean, 'anycast-rp'), ['bool'])),
                            ('anycast_rp_marked', (YLeaf(YType.boolean, 'anycast-rp-marked'), ['bool'])),
                            ('update_pending', (YLeaf(YType.boolean, 'update-pending'), ['bool'])),
                            ('bgp_auto_discovery', (YLeaf(YType.boolean, 'bgp-auto-discovery'), ['bool'])),
                            ('segment_border', (YLeaf(YType.boolean, 'segment-border'), ['bool'])),
                        ])
                        self.route_target = None
                        self.configured = None
                        self.anycast_rp = None
                        self.anycast_rp_marked = None
                        self.update_pending = None
                        self.bgp_auto_discovery = None
                        self.segment_border = None
                        self._segment_path = lambda: "import-route-target"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/context/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.Context.ImportRouteTarget, ['route_target', 'configured', 'anycast_rp', 'anycast_rp_marked', 'update_pending', 'bgp_auto_discovery', 'segment_border'], name, value)


                class AnycastRpRange(Entity):
                    """
                    Anycast\-RP Ranges
                    
                    .. attribute:: prefix
                    
                    	Anycast\-RP Range Prefix
                    	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Context.AnycastRpRange.Prefix>`
                    
                    .. attribute:: prefix_length
                    
                    	Anycast\-RP Range Prefix Length
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: ancast_rp_marked
                    
                    	Anycast\-RP Range marked
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.Context.AnycastRpRange, self).__init__()

                        self.yang_name = "anycast-rp-range"
                        self.yang_parent_name = "context"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("prefix", ("prefix", Pim.Active.DefaultContext.Context.AnycastRpRange.Prefix))])
                        self._leafs = OrderedDict([
                            ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                            ('ancast_rp_marked', (YLeaf(YType.boolean, 'ancast-rp-marked'), ['bool'])),
                        ])
                        self.prefix_length = None
                        self.ancast_rp_marked = None

                        self.prefix = Pim.Active.DefaultContext.Context.AnycastRpRange.Prefix()
                        self.prefix.parent = self
                        self._children_name_map["prefix"] = "prefix"
                        self._segment_path = lambda: "anycast-rp-range"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/context/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.Context.AnycastRpRange, ['prefix_length', 'ancast_rp_marked'], name, value)


                    class Prefix(Entity):
                        """
                        Anycast\-RP Range Prefix
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Context.AnycastRpRange.Prefix, self).__init__()

                            self.yang_name = "prefix"
                            self.yang_parent_name = "anycast-rp-range"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "prefix"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/context/anycast-rp-range/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.Context.AnycastRpRange.Prefix, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class TopologyEntryFlagRouteCounts(Entity):
                """
                Route count for topology with entry flag set
                
                .. attribute:: topology_entry_flag_route_count
                
                	Route count for topology with entry flag set
                	**type**\: list of  		 :py:class:`TopologyEntryFlagRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts, self).__init__()

                    self.yang_name = "topology-entry-flag-route-counts"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("topology-entry-flag-route-count", ("topology_entry_flag_route_count", Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount))])
                    self._leafs = OrderedDict()

                    self.topology_entry_flag_route_count = YList(self)
                    self._segment_path = lambda: "topology-entry-flag-route-counts"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts, [], name, value)


                class TopologyEntryFlagRouteCount(Entity):
                    """
                    Route count for topology with entry flag set
                    
                    .. attribute:: entry_flag  (key)
                    
                    	entry flag
                    	**type**\:  :py:class:`PimTopologyEntryFlag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimTopologyEntryFlag>`
                    
                    .. attribute:: group_ranges
                    
                    	No. of (\*,G/M) routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: active_group_ranges
                    
                    	No. of (\*,G/M) routes active in mrib
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: groute_count
                    
                    	No. of (\*,G) routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sg_route_count
                    
                    	No. of (S,G) routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sgr_route_count
                    
                    	No. of (S,G)RPT routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount, self).__init__()

                        self.yang_name = "topology-entry-flag-route-count"
                        self.yang_parent_name = "topology-entry-flag-route-counts"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['entry_flag']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('entry_flag', (YLeaf(YType.enumeration, 'entry-flag'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimTopologyEntryFlag', '')])),
                            ('group_ranges', (YLeaf(YType.uint32, 'group-ranges'), ['int'])),
                            ('active_group_ranges', (YLeaf(YType.uint32, 'active-group-ranges'), ['int'])),
                            ('groute_count', (YLeaf(YType.uint32, 'groute-count'), ['int'])),
                            ('sg_route_count', (YLeaf(YType.uint32, 'sg-route-count'), ['int'])),
                            ('sgr_route_count', (YLeaf(YType.uint32, 'sgr-route-count'), ['int'])),
                            ('is_node_low_memory', (YLeaf(YType.boolean, 'is-node-low-memory'), ['bool'])),
                        ])
                        self.entry_flag = None
                        self.group_ranges = None
                        self.active_group_ranges = None
                        self.groute_count = None
                        self.sg_route_count = None
                        self.sgr_route_count = None
                        self.is_node_low_memory = None
                        self._segment_path = lambda: "topology-entry-flag-route-count" + "[entry-flag='" + str(self.entry_flag) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/topology-entry-flag-route-counts/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount, ['entry_flag', 'group_ranges', 'active_group_ranges', 'groute_count', 'sg_route_count', 'sgr_route_count', 'is_node_low_memory'], name, value)


            class RpfRedirect(Entity):
                """
                PIM ECMP RPF\-redirect bundle
                
                .. attribute:: redirect_route_databases
                
                	PIM ECMP RPF\-redirect route database
                	**type**\:  :py:class:`RedirectRouteDatabases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases>`
                
                .. attribute:: bundle_interfaces
                
                	PIM ECMP RPF\-redirect bundle information
                	**type**\:  :py:class:`BundleInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Active.DefaultContext.RpfRedirect, self).__init__()

                    self.yang_name = "rpf-redirect"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("redirect-route-databases", ("redirect_route_databases", Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases)), ("bundle-interfaces", ("bundle_interfaces", Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces))])
                    self._leafs = OrderedDict()

                    self.redirect_route_databases = Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases()
                    self.redirect_route_databases.parent = self
                    self._children_name_map["redirect_route_databases"] = "redirect-route-databases"

                    self.bundle_interfaces = Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces()
                    self.bundle_interfaces.parent = self
                    self._children_name_map["bundle_interfaces"] = "bundle-interfaces"
                    self._segment_path = lambda: "rpf-redirect"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.DefaultContext.RpfRedirect, [], name, value)


                class RedirectRouteDatabases(Entity):
                    """
                    PIM ECMP RPF\-redirect route database
                    
                    .. attribute:: redirect_route_database
                    
                    	PIM ECMP RPF\-redirect route information
                    	**type**\: list of  		 :py:class:`RedirectRouteDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases, self).__init__()

                        self.yang_name = "redirect-route-databases"
                        self.yang_parent_name = "rpf-redirect"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("redirect-route-database", ("redirect_route_database", Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase))])
                        self._leafs = OrderedDict()

                        self.redirect_route_database = YList(self)
                        self._segment_path = lambda: "redirect-route-databases"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/rpf-redirect/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases, [], name, value)


                    class RedirectRouteDatabase(Entity):
                        """
                        PIM ECMP RPF\-redirect route information
                        
                        .. attribute:: source_address
                        
                        	Source address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: group_address
                        
                        	Group address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: group_address_xr
                        
                        	Group ddress
                        	**type**\:  :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr>`
                        
                        .. attribute:: source_address_xr
                        
                        	Source address
                        	**type**\:  :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr>`
                        
                        .. attribute:: bandwidth
                        
                        	Bandwidth in Kbps
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: interface
                        
                        	Outgoing interface list
                        	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase, self).__init__()

                            self.yang_name = "redirect-route-database"
                            self.yang_parent_name = "redirect-route-databases"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("group-address-xr", ("group_address_xr", Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr)), ("source-address-xr", ("source_address_xr", Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr)), ("interface", ("interface", Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface))])
                            self._leafs = OrderedDict([
                                ('source_address', (YLeaf(YType.str, 'source-address'), ['str','str'])),
                                ('group_address', (YLeaf(YType.str, 'group-address'), ['str','str'])),
                                ('bandwidth', (YLeaf(YType.uint32, 'bandwidth'), ['int'])),
                                ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                            ])
                            self.source_address = None
                            self.group_address = None
                            self.bandwidth = None
                            self.uptime = None

                            self.group_address_xr = Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"

                            self.source_address_xr = Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr()
                            self.source_address_xr.parent = self
                            self._children_name_map["source_address_xr"] = "source-address-xr"

                            self.interface = YList(self)
                            self._segment_path = lambda: "redirect-route-database"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/rpf-redirect/redirect-route-databases/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase, ['source_address', 'group_address', 'bandwidth', 'uptime'], name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group ddress
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "redirect-route-database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "group-address-xr"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/rpf-redirect/redirect-route-databases/redirect-route-database/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class SourceAddressXr(Entity):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr, self).__init__()

                                self.yang_name = "source-address-xr"
                                self.yang_parent_name = "redirect-route-database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "source-address-xr"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/rpf-redirect/redirect-route-databases/redirect-route-database/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class Interface(Entity):
                            """
                            Outgoing interface list
                            
                            .. attribute:: rpf_address
                            
                            	RPF Address
                            	**type**\:  :py:class:`RpfAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress>`
                            
                            .. attribute:: interface_name
                            
                            	Interface name
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: expiry
                            
                            	Expiry in seconds
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: is_rpf_interface
                            
                            	Is RPF Interface
                            	**type**\: bool
                            
                            .. attribute:: is_outgoing_interface
                            
                            	Is outgoing Interface
                            	**type**\: bool
                            
                            .. attribute:: is_snoop_interface
                            
                            	Is snooping Interface
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface, self).__init__()

                                self.yang_name = "interface"
                                self.yang_parent_name = "redirect-route-database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("rpf-address", ("rpf_address", Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress))])
                                self._leafs = OrderedDict([
                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                    ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                                    ('expiry', (YLeaf(YType.uint64, 'expiry'), ['int'])),
                                    ('is_rpf_interface', (YLeaf(YType.boolean, 'is-rpf-interface'), ['bool'])),
                                    ('is_outgoing_interface', (YLeaf(YType.boolean, 'is-outgoing-interface'), ['bool'])),
                                    ('is_snoop_interface', (YLeaf(YType.boolean, 'is-snoop-interface'), ['bool'])),
                                ])
                                self.interface_name = None
                                self.uptime = None
                                self.expiry = None
                                self.is_rpf_interface = None
                                self.is_outgoing_interface = None
                                self.is_snoop_interface = None

                                self.rpf_address = Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress()
                                self.rpf_address.parent = self
                                self._children_name_map["rpf_address"] = "rpf-address"
                                self._segment_path = lambda: "interface"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/rpf-redirect/redirect-route-databases/redirect-route-database/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface, ['interface_name', 'uptime', 'expiry', 'is_rpf_interface', 'is_outgoing_interface', 'is_snoop_interface'], name, value)


                            class RpfAddress(Entity):
                                """
                                RPF Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress, self).__init__()

                                    self.yang_name = "rpf-address"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "rpf-address"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/rpf-redirect/redirect-route-databases/redirect-route-database/interface/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class BundleInterfaces(Entity):
                    """
                    PIM ECMP RPF\-redirect bundle information
                    
                    .. attribute:: bundle_interface
                    
                    	PIM ECMP RPF\-redirect bundle interface information
                    	**type**\: list of  		 :py:class:`BundleInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces.BundleInterface>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces, self).__init__()

                        self.yang_name = "bundle-interfaces"
                        self.yang_parent_name = "rpf-redirect"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("bundle-interface", ("bundle_interface", Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces.BundleInterface))])
                        self._leafs = OrderedDict()

                        self.bundle_interface = YList(self)
                        self._segment_path = lambda: "bundle-interfaces"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/rpf-redirect/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces, [], name, value)


                    class BundleInterface(Entity):
                        """
                        PIM ECMP RPF\-redirect bundle interface
                        information
                        
                        .. attribute:: bundle_name
                        
                        	Bundle name
                        	**type**\: str
                        
                        	**length:** 1..32
                        
                        .. attribute:: interface_name
                        
                        	Bundle interface name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: rpf_redirect_bundle_name
                        
                        	RPF redirect bundle name
                        	**type**\: str
                        
                        	**length:** 0..33
                        
                        .. attribute:: rpf_redirect_interface_name
                        
                        	RPF redirect interface name
                        	**type**\: str
                        
                        	**length:** 0..33
                        
                        .. attribute:: available_bandwidth
                        
                        	Bandwidth available in Kbps
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: allocated_bandwidth
                        
                        	Bandwidth allocated in Kbps
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: total_bandwidth
                        
                        	Total bandwidth used in Kbps
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: topology_bandwidth_used
                        
                        	Bandwidth used by topology in Kbps
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: snooping_bandwidth_used
                        
                        	Bandwidth used by snooped entries in Kbps
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: allocated_threshold_bandwidth
                        
                        	Configured threshold in Kbps
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: available_threshold_bandwidth
                        
                        	Available threshold in Kbps
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces.BundleInterface, self).__init__()

                            self.yang_name = "bundle-interface"
                            self.yang_parent_name = "bundle-interfaces"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('bundle_name', (YLeaf(YType.str, 'bundle-name'), ['str'])),
                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ('rpf_redirect_bundle_name', (YLeaf(YType.str, 'rpf-redirect-bundle-name'), ['str'])),
                                ('rpf_redirect_interface_name', (YLeaf(YType.str, 'rpf-redirect-interface-name'), ['str'])),
                                ('available_bandwidth', (YLeaf(YType.int32, 'available-bandwidth'), ['int'])),
                                ('allocated_bandwidth', (YLeaf(YType.int32, 'allocated-bandwidth'), ['int'])),
                                ('total_bandwidth', (YLeaf(YType.int32, 'total-bandwidth'), ['int'])),
                                ('topology_bandwidth_used', (YLeaf(YType.int32, 'topology-bandwidth-used'), ['int'])),
                                ('snooping_bandwidth_used', (YLeaf(YType.int32, 'snooping-bandwidth-used'), ['int'])),
                                ('allocated_threshold_bandwidth', (YLeaf(YType.int32, 'allocated-threshold-bandwidth'), ['int'])),
                                ('available_threshold_bandwidth', (YLeaf(YType.int32, 'available-threshold-bandwidth'), ['int'])),
                            ])
                            self.bundle_name = None
                            self.interface_name = None
                            self.rpf_redirect_bundle_name = None
                            self.rpf_redirect_interface_name = None
                            self.available_bandwidth = None
                            self.allocated_bandwidth = None
                            self.total_bandwidth = None
                            self.topology_bandwidth_used = None
                            self.snooping_bandwidth_used = None
                            self.allocated_threshold_bandwidth = None
                            self.available_threshold_bandwidth = None
                            self._segment_path = lambda: "bundle-interface"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/rpf-redirect/bundle-interfaces/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces.BundleInterface, ['bundle_name', 'interface_name', 'rpf_redirect_bundle_name', 'rpf_redirect_interface_name', 'available_bandwidth', 'allocated_bandwidth', 'total_bandwidth', 'topology_bandwidth_used', 'snooping_bandwidth_used', 'allocated_threshold_bandwidth', 'available_threshold_bandwidth'], name, value)


            class Tunnels(Entity):
                """
                Tunnels information that PIM has
                
                .. attribute:: tunnel
                
                	PIM tunnel information
                	**type**\: list of  		 :py:class:`Tunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Tunnels.Tunnel>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Active.DefaultContext.Tunnels, self).__init__()

                    self.yang_name = "tunnels"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("tunnel", ("tunnel", Pim.Active.DefaultContext.Tunnels.Tunnel))])
                    self._leafs = OrderedDict()

                    self.tunnel = YList(self)
                    self._segment_path = lambda: "tunnels"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.DefaultContext.Tunnels, [], name, value)


                class Tunnel(Entity):
                    """
                    PIM tunnel information
                    
                    .. attribute:: tunnel_name  (key)
                    
                    	Tunnel name
                    	**type**\: str
                    
                    	**length:** 1..64
                    
                    .. attribute:: source_address
                    
                    	Source addr known to PIM
                    	**type**\:  :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddress>`
                    
                    .. attribute:: rp_address
                    
                    	RP addr known to PIM
                    	**type**\:  :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Tunnels.Tunnel.RpAddress>`
                    
                    .. attribute:: source_address_netio
                    
                    	Source addr from netio
                    	**type**\:  :py:class:`SourceAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddressNetio>`
                    
                    .. attribute:: group_address_netio
                    
                    	Group addr from netio
                    	**type**\:  :py:class:`GroupAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Tunnels.Tunnel.GroupAddressNetio>`
                    
                    .. attribute:: vrf_name
                    
                    	VRF Name
                    	**type**\: str
                    
                    	**length:** 0..33
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.Tunnels.Tunnel, self).__init__()

                        self.yang_name = "tunnel"
                        self.yang_parent_name = "tunnels"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['tunnel_name']
                        self._child_classes = OrderedDict([("source-address", ("source_address", Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddress)), ("rp-address", ("rp_address", Pim.Active.DefaultContext.Tunnels.Tunnel.RpAddress)), ("source-address-netio", ("source_address_netio", Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddressNetio)), ("group-address-netio", ("group_address_netio", Pim.Active.DefaultContext.Tunnels.Tunnel.GroupAddressNetio))])
                        self._leafs = OrderedDict([
                            ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                        ])
                        self.tunnel_name = None
                        self.vrf_name = None

                        self.source_address = Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddress()
                        self.source_address.parent = self
                        self._children_name_map["source_address"] = "source-address"

                        self.rp_address = Pim.Active.DefaultContext.Tunnels.Tunnel.RpAddress()
                        self.rp_address.parent = self
                        self._children_name_map["rp_address"] = "rp-address"

                        self.source_address_netio = Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddressNetio()
                        self.source_address_netio.parent = self
                        self._children_name_map["source_address_netio"] = "source-address-netio"

                        self.group_address_netio = Pim.Active.DefaultContext.Tunnels.Tunnel.GroupAddressNetio()
                        self.group_address_netio.parent = self
                        self._children_name_map["group_address_netio"] = "group-address-netio"
                        self._segment_path = lambda: "tunnel" + "[tunnel-name='" + str(self.tunnel_name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/tunnels/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.Tunnels.Tunnel, ['tunnel_name', 'vrf_name'], name, value)


                    class SourceAddress(Entity):
                        """
                        Source addr known to PIM
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddress, self).__init__()

                            self.yang_name = "source-address"
                            self.yang_parent_name = "tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "source-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class RpAddress(Entity):
                        """
                        RP addr known to PIM
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Tunnels.Tunnel.RpAddress, self).__init__()

                            self.yang_name = "rp-address"
                            self.yang_parent_name = "tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "rp-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.Tunnels.Tunnel.RpAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class SourceAddressNetio(Entity):
                        """
                        Source addr from netio
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddressNetio, self).__init__()

                            self.yang_name = "source-address-netio"
                            self.yang_parent_name = "tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "source-address-netio"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddressNetio, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class GroupAddressNetio(Entity):
                        """
                        Group addr from netio
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Tunnels.Tunnel.GroupAddressNetio, self).__init__()

                            self.yang_name = "group-address-netio"
                            self.yang_parent_name = "tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "group-address-netio"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.Tunnels.Tunnel.GroupAddressNetio, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class MulticastStaticRoutes(Entity):
                """
                PIM multicast static route table
                
                .. attribute:: multicast_static_route
                
                	PIM multicast static route information
                	**type**\: list of  		 :py:class:`MulticastStaticRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Active.DefaultContext.MulticastStaticRoutes, self).__init__()

                    self.yang_name = "multicast-static-routes"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("multicast-static-route", ("multicast_static_route", Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute))])
                    self._leafs = OrderedDict()

                    self.multicast_static_route = YList(self)
                    self._segment_path = lambda: "multicast-static-routes"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.DefaultContext.MulticastStaticRoutes, [], name, value)


                class MulticastStaticRoute(Entity):
                    """
                    PIM multicast static route information
                    
                    .. attribute:: address
                    
                    	Network address
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: prefix
                    
                    	Prefix
                    	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix>`
                    
                    .. attribute:: nexthop
                    
                    	Next Hop
                    	**type**\:  :py:class:`Nexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop>`
                    
                    .. attribute:: interface_name
                    
                    	Interface Handle
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: distance
                    
                    	Distance
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: prefix_length_xr
                    
                    	Prefix Length
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: is_via_lsm
                    
                    	LSM flag
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute, self).__init__()

                        self.yang_name = "multicast-static-route"
                        self.yang_parent_name = "multicast-static-routes"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("prefix", ("prefix", Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix)), ("nexthop", ("nexthop", Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop))])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str','str'])),
                            ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                            ('distance', (YLeaf(YType.uint32, 'distance'), ['int'])),
                            ('prefix_length_xr', (YLeaf(YType.uint8, 'prefix-length-xr'), ['int'])),
                            ('is_via_lsm', (YLeaf(YType.boolean, 'is-via-lsm'), ['bool'])),
                        ])
                        self.address = None
                        self.prefix_length = None
                        self.interface_name = None
                        self.distance = None
                        self.prefix_length_xr = None
                        self.is_via_lsm = None

                        self.prefix = Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix()
                        self.prefix.parent = self
                        self._children_name_map["prefix"] = "prefix"

                        self.nexthop = Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop()
                        self.nexthop.parent = self
                        self._children_name_map["nexthop"] = "nexthop"
                        self._segment_path = lambda: "multicast-static-route"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/multicast-static-routes/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute, ['address', 'prefix_length', 'interface_name', 'distance', 'prefix_length_xr', 'is_via_lsm'], name, value)


                    class Prefix(Entity):
                        """
                        Prefix
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix, self).__init__()

                            self.yang_name = "prefix"
                            self.yang_parent_name = "multicast-static-route"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "prefix"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/multicast-static-routes/multicast-static-route/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class Nexthop(Entity):
                        """
                        Next Hop
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop, self).__init__()

                            self.yang_name = "nexthop"
                            self.yang_parent_name = "multicast-static-route"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "nexthop"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/multicast-static-routes/multicast-static-route/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class Neighbors(Entity):
                """
                PIM neighbor table
                
                .. attribute:: neighbor
                
                	PIM neighbor information
                	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Neighbors.Neighbor>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Active.DefaultContext.Neighbors, self).__init__()

                    self.yang_name = "neighbors"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("neighbor", ("neighbor", Pim.Active.DefaultContext.Neighbors.Neighbor))])
                    self._leafs = OrderedDict()

                    self.neighbor = YList(self)
                    self._segment_path = lambda: "neighbors"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.DefaultContext.Neighbors, [], name, value)


                class Neighbor(Entity):
                    """
                    PIM neighbor information
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: neighbor_address
                    
                    	Neighbor address
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identifier
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: expires
                    
                    	Neighbor expiry in seconds
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: expiry_timer
                    
                    	Expiry timer in seconds
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: is_this_neighbor_us
                    
                    	Is this neighbor us ?
                    	**type**\: bool
                    
                    .. attribute:: is_this_neighbor_dr
                    
                    	Is this neighbor the DR
                    	**type**\: bool
                    
                    .. attribute:: is_dr_priority_capable
                    
                    	Is this neighbor DR priority capable ?
                    	**type**\: bool
                    
                    .. attribute:: dr_priority
                    
                    	DR priority
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Is this neighbor bidir capable ?
                    	**type**\: bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Is this neighbor proxy capable?
                    	**type**\: bool
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Is this neighbor capable of batching asserts?
                    	**type**\: bool
                    
                    .. attribute:: is_ecmp_redirect_capable
                    
                    	Is this neighbor capable of Ecmp Redirect?
                    	**type**\: bool
                    
                    .. attribute:: is_bfd_state
                    
                    	Is the neighbor bfd session created
                    	**type**\: bool
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_address_xr
                    
                    	List of Neighbor Addresses
                    	**type**\: list of  		 :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Neighbors.Neighbor.NeighborAddressXr>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.Neighbors.Neighbor, self).__init__()

                        self.yang_name = "neighbor"
                        self.yang_parent_name = "neighbors"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("neighbor-address-xr", ("neighbor_address_xr", Pim.Active.DefaultContext.Neighbors.Neighbor.NeighborAddressXr))])
                        self._leafs = OrderedDict([
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                            ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                            ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                            ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                            ('expires', (YLeaf(YType.uint64, 'expires'), ['int'])),
                            ('expiry_timer', (YLeaf(YType.uint64, 'expiry-timer'), ['int'])),
                            ('is_this_neighbor_us', (YLeaf(YType.boolean, 'is-this-neighbor-us'), ['bool'])),
                            ('is_this_neighbor_dr', (YLeaf(YType.boolean, 'is-this-neighbor-dr'), ['bool'])),
                            ('is_dr_priority_capable', (YLeaf(YType.boolean, 'is-dr-priority-capable'), ['bool'])),
                            ('dr_priority', (YLeaf(YType.uint32, 'dr-priority'), ['int'])),
                            ('is_bidirectional_capable', (YLeaf(YType.boolean, 'is-bidirectional-capable'), ['bool'])),
                            ('is_proxy_capable', (YLeaf(YType.boolean, 'is-proxy-capable'), ['bool'])),
                            ('is_batch_asserts_capable', (YLeaf(YType.boolean, 'is-batch-asserts-capable'), ['bool'])),
                            ('is_ecmp_redirect_capable', (YLeaf(YType.boolean, 'is-ecmp-redirect-capable'), ['bool'])),
                            ('is_bfd_state', (YLeaf(YType.boolean, 'is-bfd-state'), ['bool'])),
                            ('propagation_delay', (YLeaf(YType.uint16, 'propagation-delay'), ['int'])),
                            ('override_interval', (YLeaf(YType.uint16, 'override-interval'), ['int'])),
                        ])
                        self.interface_name = None
                        self.neighbor_address = None
                        self.interface_name_xr = None
                        self.uptime = None
                        self.expires = None
                        self.expiry_timer = None
                        self.is_this_neighbor_us = None
                        self.is_this_neighbor_dr = None
                        self.is_dr_priority_capable = None
                        self.dr_priority = None
                        self.is_bidirectional_capable = None
                        self.is_proxy_capable = None
                        self.is_batch_asserts_capable = None
                        self.is_ecmp_redirect_capable = None
                        self.is_bfd_state = None
                        self.propagation_delay = None
                        self.override_interval = None

                        self.neighbor_address_xr = YList(self)
                        self._segment_path = lambda: "neighbor"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/neighbors/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.DefaultContext.Neighbors.Neighbor, ['interface_name', 'neighbor_address', 'interface_name_xr', 'uptime', 'expires', 'expiry_timer', 'is_this_neighbor_us', 'is_this_neighbor_dr', 'is_dr_priority_capable', 'dr_priority', 'is_bidirectional_capable', 'is_proxy_capable', 'is_batch_asserts_capable', 'is_ecmp_redirect_capable', 'is_bfd_state', 'propagation_delay', 'override_interval'], name, value)


                    class NeighborAddressXr(Entity):
                        """
                        List of Neighbor Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Neighbors.Neighbor.NeighborAddressXr, self).__init__()

                            self.yang_name = "neighbor-address-xr"
                            self.yang_parent_name = "neighbor"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "neighbor-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/neighbors/neighbor/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.DefaultContext.Neighbors.Neighbor.NeighborAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


        class Process(Entity):
            """
            Process
            
            .. attribute:: nsr
            
            	NSR Information
            	**type**\:  :py:class:`Nsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Process.Nsr>`
            
            .. attribute:: summary
            
            	PIM Global Summary
            	**type**\:  :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Process.Summary>`
            
            .. attribute:: nsf
            
            	PIM NSF information
            	**type**\:  :py:class:`Nsf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Process.Nsf>`
            
            .. attribute:: issu
            
            	ISSU Information
            	**type**\:  :py:class:`Issu <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Process.Issu>`
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(Pim.Active.Process, self).__init__()

                self.yang_name = "process"
                self.yang_parent_name = "active"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("nsr", ("nsr", Pim.Active.Process.Nsr)), ("summary", ("summary", Pim.Active.Process.Summary)), ("nsf", ("nsf", Pim.Active.Process.Nsf)), ("issu", ("issu", Pim.Active.Process.Issu))])
                self._leafs = OrderedDict()

                self.nsr = Pim.Active.Process.Nsr()
                self.nsr.parent = self
                self._children_name_map["nsr"] = "nsr"

                self.summary = Pim.Active.Process.Summary()
                self.summary.parent = self
                self._children_name_map["summary"] = "summary"

                self.nsf = Pim.Active.Process.Nsf()
                self.nsf.parent = self
                self._children_name_map["nsf"] = "nsf"

                self.issu = Pim.Active.Process.Issu()
                self.issu.parent = self
                self._children_name_map["issu"] = "issu"
                self._segment_path = lambda: "process"
                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Pim.Active.Process, [], name, value)


            class Nsr(Entity):
                """
                NSR Information
                
                .. attribute:: state
                
                	NSR state
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: partner_connected
                
                	Partner process connected
                	**type**\: bool
                
                .. attribute:: rmf_notification_done
                
                	RMF Notification done
                	**type**\: bool
                
                .. attribute:: rmf_timer_valid
                
                	Is RMF timer running ?
                	**type**\: bool
                
                .. attribute:: rmf_timer_expiry
                
                	Time for RMF timer to expire
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_connection_up
                
                	Time when connection went up
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_connection_dn
                
                	Time when connection went down
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_rmf_ready
                
                	Time when RMF Rdy notif was sent
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_rmf_not_ready
                
                	Time when RMF Not\-Rdy notif was sent
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: count_connection_up
                
                	No. of times connection went up
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_connection_dn
                
                	No. of times connection went down
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_rmf_ready
                
                	No. of times RMF Ready notif was sent
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_rmf_not_ready
                
                	No. of times RMF Not Ready notif was sent
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Active.Process.Nsr, self).__init__()

                    self.yang_name = "nsr"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('state', (YLeaf(YType.uint8, 'state'), ['int'])),
                        ('partner_connected', (YLeaf(YType.boolean, 'partner-connected'), ['bool'])),
                        ('rmf_notification_done', (YLeaf(YType.boolean, 'rmf-notification-done'), ['bool'])),
                        ('rmf_timer_valid', (YLeaf(YType.boolean, 'rmf-timer-valid'), ['bool'])),
                        ('rmf_timer_expiry', (YLeaf(YType.uint64, 'rmf-timer-expiry'), ['int'])),
                        ('last_connection_up', (YLeaf(YType.uint64, 'last-connection-up'), ['int'])),
                        ('last_connection_dn', (YLeaf(YType.uint64, 'last-connection-dn'), ['int'])),
                        ('last_rmf_ready', (YLeaf(YType.uint64, 'last-rmf-ready'), ['int'])),
                        ('last_rmf_not_ready', (YLeaf(YType.uint64, 'last-rmf-not-ready'), ['int'])),
                        ('count_connection_up', (YLeaf(YType.uint32, 'count-connection-up'), ['int'])),
                        ('count_connection_dn', (YLeaf(YType.uint32, 'count-connection-dn'), ['int'])),
                        ('count_rmf_ready', (YLeaf(YType.uint32, 'count-rmf-ready'), ['int'])),
                        ('count_rmf_not_ready', (YLeaf(YType.uint32, 'count-rmf-not-ready'), ['int'])),
                    ])
                    self.state = None
                    self.partner_connected = None
                    self.rmf_notification_done = None
                    self.rmf_timer_valid = None
                    self.rmf_timer_expiry = None
                    self.last_connection_up = None
                    self.last_connection_dn = None
                    self.last_rmf_ready = None
                    self.last_rmf_not_ready = None
                    self.count_connection_up = None
                    self.count_connection_dn = None
                    self.count_rmf_ready = None
                    self.count_rmf_not_ready = None
                    self._segment_path = lambda: "nsr"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/process/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.Process.Nsr, ['state', 'partner_connected', 'rmf_notification_done', 'rmf_timer_valid', 'rmf_timer_expiry', 'last_connection_up', 'last_connection_dn', 'last_rmf_ready', 'last_rmf_not_ready', 'count_connection_up', 'count_connection_dn', 'count_rmf_ready', 'count_rmf_not_ready'], name, value)


            class Summary(Entity):
                """
                PIM Global Summary
                
                .. attribute:: route_limit
                
                	Maximum routes
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_count
                
                	Current routes
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_low_water_mark
                
                	The number of routes below which the throttle on route creation will be lifted
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_route_limit_reached
                
                	Is route creation throttled
                	**type**\: bool
                
                .. attribute:: topology_interface_state_limit
                
                	Maximum Topology Interface State count
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_count
                
                	Current Topology Interface State count
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: rxi_low_water_mark
                
                	The rxi below which the throttle on interface creation will be lifted
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: rxi_limit_reached
                
                	Is interface creation throttled
                	**type**\: bool
                
                .. attribute:: register_limit
                
                	Maximum registers
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_count
                
                	Current registers
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_limit_reached
                
                	Is PIM SM register handling throttled
                	**type**\: bool
                
                .. attribute:: ranges_limit
                
                	Maximum group ranges from Autorp
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: ranges_count
                
                	Current group ranges from Autorp
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: ranges_threshold
                
                	OOR theshold of grange ranges from AutoRP
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_ranges_limit_reached
                
                	Is Auto\-RP group\-to\-RP mapping range creation throttled
                	**type**\: bool
                
                .. attribute:: bsr_ranges_limit
                
                	Maximum group ranges from BSR
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_ranges_count
                
                	Current group ranges from BSR
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_range_threshold
                
                	Threshold group range from BSR
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_bsr_ranges_threshold_reached
                
                	Is VRF\-specific BSR group\-to\-RP mapping range creation throttled
                	**type**\: bool
                
                .. attribute:: bsr_candidate_rp_set_limit
                
                	Maximum crp\-set from BSR
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_candidate_rp_set_count
                
                	Current crp\-set count from BSR
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_candidate_rp_set_threshold
                
                	Threshold crp\-set from BSR
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_maximum_enforcement_disabled
                
                	Is maximum enforcement disabled
                	**type**\: bool
                
                .. attribute:: is_node_low_memory
                
                	Is node in low memory condition
                	**type**\: bool
                
                .. attribute:: route_threshold
                
                	Threshold routes
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_auto_rp_ranges_limit
                
                	Global Auto\-RP maximum group ranges
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_global_auto_rp_ranges_limit_reached
                
                	Is global AutoRP group\-to\-RP mapping range creation throttled
                	**type**\: bool
                
                .. attribute:: global_bsr_ranges_limit
                
                	Global BSR maximum group ranges
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_count
                
                	Global BSR current group ranges
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_threshold
                
                	Global BSR Threshold group ranges
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_global_bsr_ranges_limit_reached
                
                	Is global BSR group\-to\-RP mapping range creation throttled
                	**type**\: bool
                
                .. attribute:: global_bsr_candidate_rp_set_limit
                
                	Global BSR maximum crp\-set
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_count
                
                	Global BSR current crp\-set count
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_threshold
                
                	Global BSR Threshold crp\-set
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_global_route_limit_reached
                
                	Is global route creation throttled
                	**type**\: bool
                
                .. attribute:: topology_interface_state_threshold
                
                	Topology Interface State threshold
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_global_rxi_limit_reached
                
                	Is global interface creation throttled
                	**type**\: bool
                
                .. attribute:: register_threshold
                
                	Threshold registers
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_register_limit
                
                	Maximum global registers
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_global_register_limit_reached
                
                	Is global PIM SM register handling throttled
                	**type**\: bool
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Active.Process.Summary, self).__init__()

                    self.yang_name = "summary"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('route_limit', (YLeaf(YType.uint32, 'route-limit'), ['int'])),
                        ('route_count', (YLeaf(YType.uint32, 'route-count'), ['int'])),
                        ('route_low_water_mark', (YLeaf(YType.uint32, 'route-low-water-mark'), ['int'])),
                        ('is_route_limit_reached', (YLeaf(YType.boolean, 'is-route-limit-reached'), ['bool'])),
                        ('topology_interface_state_limit', (YLeaf(YType.uint32, 'topology-interface-state-limit'), ['int'])),
                        ('topology_interface_state_count', (YLeaf(YType.uint32, 'topology-interface-state-count'), ['int'])),
                        ('rxi_low_water_mark', (YLeaf(YType.uint32, 'rxi-low-water-mark'), ['int'])),
                        ('rxi_limit_reached', (YLeaf(YType.boolean, 'rxi-limit-reached'), ['bool'])),
                        ('register_limit', (YLeaf(YType.uint32, 'register-limit'), ['int'])),
                        ('register_count', (YLeaf(YType.uint32, 'register-count'), ['int'])),
                        ('register_limit_reached', (YLeaf(YType.boolean, 'register-limit-reached'), ['bool'])),
                        ('ranges_limit', (YLeaf(YType.uint32, 'ranges-limit'), ['int'])),
                        ('ranges_count', (YLeaf(YType.uint32, 'ranges-count'), ['int'])),
                        ('ranges_threshold', (YLeaf(YType.uint32, 'ranges-threshold'), ['int'])),
                        ('is_ranges_limit_reached', (YLeaf(YType.boolean, 'is-ranges-limit-reached'), ['bool'])),
                        ('bsr_ranges_limit', (YLeaf(YType.uint32, 'bsr-ranges-limit'), ['int'])),
                        ('bsr_ranges_count', (YLeaf(YType.uint32, 'bsr-ranges-count'), ['int'])),
                        ('bsr_range_threshold', (YLeaf(YType.uint32, 'bsr-range-threshold'), ['int'])),
                        ('is_bsr_ranges_threshold_reached', (YLeaf(YType.boolean, 'is-bsr-ranges-threshold-reached'), ['bool'])),
                        ('bsr_candidate_rp_set_limit', (YLeaf(YType.uint32, 'bsr-candidate-rp-set-limit'), ['int'])),
                        ('bsr_candidate_rp_set_count', (YLeaf(YType.uint32, 'bsr-candidate-rp-set-count'), ['int'])),
                        ('bsr_candidate_rp_set_threshold', (YLeaf(YType.uint32, 'bsr-candidate-rp-set-threshold'), ['int'])),
                        ('is_maximum_enforcement_disabled', (YLeaf(YType.boolean, 'is-maximum-enforcement-disabled'), ['bool'])),
                        ('is_node_low_memory', (YLeaf(YType.boolean, 'is-node-low-memory'), ['bool'])),
                        ('route_threshold', (YLeaf(YType.uint32, 'route-threshold'), ['int'])),
                        ('global_auto_rp_ranges_limit', (YLeaf(YType.uint32, 'global-auto-rp-ranges-limit'), ['int'])),
                        ('is_global_auto_rp_ranges_limit_reached', (YLeaf(YType.boolean, 'is-global-auto-rp-ranges-limit-reached'), ['bool'])),
                        ('global_bsr_ranges_limit', (YLeaf(YType.uint32, 'global-bsr-ranges-limit'), ['int'])),
                        ('global_bsr_ranges_count', (YLeaf(YType.uint32, 'global-bsr-ranges-count'), ['int'])),
                        ('global_bsr_ranges_threshold', (YLeaf(YType.uint32, 'global-bsr-ranges-threshold'), ['int'])),
                        ('is_global_bsr_ranges_limit_reached', (YLeaf(YType.boolean, 'is-global-bsr-ranges-limit-reached'), ['bool'])),
                        ('global_bsr_candidate_rp_set_limit', (YLeaf(YType.uint32, 'global-bsr-candidate-rp-set-limit'), ['int'])),
                        ('global_bsr_candidate_rp_set_count', (YLeaf(YType.uint32, 'global-bsr-candidate-rp-set-count'), ['int'])),
                        ('global_bsr_candidate_rp_set_threshold', (YLeaf(YType.uint32, 'global-bsr-candidate-rp-set-threshold'), ['int'])),
                        ('is_global_route_limit_reached', (YLeaf(YType.boolean, 'is-global-route-limit-reached'), ['bool'])),
                        ('topology_interface_state_threshold', (YLeaf(YType.uint32, 'topology-interface-state-threshold'), ['int'])),
                        ('is_global_rxi_limit_reached', (YLeaf(YType.boolean, 'is-global-rxi-limit-reached'), ['bool'])),
                        ('register_threshold', (YLeaf(YType.uint32, 'register-threshold'), ['int'])),
                        ('global_register_limit', (YLeaf(YType.uint32, 'global-register-limit'), ['int'])),
                        ('is_global_register_limit_reached', (YLeaf(YType.boolean, 'is-global-register-limit-reached'), ['bool'])),
                    ])
                    self.route_limit = None
                    self.route_count = None
                    self.route_low_water_mark = None
                    self.is_route_limit_reached = None
                    self.topology_interface_state_limit = None
                    self.topology_interface_state_count = None
                    self.rxi_low_water_mark = None
                    self.rxi_limit_reached = None
                    self.register_limit = None
                    self.register_count = None
                    self.register_limit_reached = None
                    self.ranges_limit = None
                    self.ranges_count = None
                    self.ranges_threshold = None
                    self.is_ranges_limit_reached = None
                    self.bsr_ranges_limit = None
                    self.bsr_ranges_count = None
                    self.bsr_range_threshold = None
                    self.is_bsr_ranges_threshold_reached = None
                    self.bsr_candidate_rp_set_limit = None
                    self.bsr_candidate_rp_set_count = None
                    self.bsr_candidate_rp_set_threshold = None
                    self.is_maximum_enforcement_disabled = None
                    self.is_node_low_memory = None
                    self.route_threshold = None
                    self.global_auto_rp_ranges_limit = None
                    self.is_global_auto_rp_ranges_limit_reached = None
                    self.global_bsr_ranges_limit = None
                    self.global_bsr_ranges_count = None
                    self.global_bsr_ranges_threshold = None
                    self.is_global_bsr_ranges_limit_reached = None
                    self.global_bsr_candidate_rp_set_limit = None
                    self.global_bsr_candidate_rp_set_count = None
                    self.global_bsr_candidate_rp_set_threshold = None
                    self.is_global_route_limit_reached = None
                    self.topology_interface_state_threshold = None
                    self.is_global_rxi_limit_reached = None
                    self.register_threshold = None
                    self.global_register_limit = None
                    self.is_global_register_limit_reached = None
                    self._segment_path = lambda: "summary"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/process/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.Process.Summary, ['route_limit', 'route_count', 'route_low_water_mark', 'is_route_limit_reached', 'topology_interface_state_limit', 'topology_interface_state_count', 'rxi_low_water_mark', 'rxi_limit_reached', 'register_limit', 'register_count', 'register_limit_reached', 'ranges_limit', 'ranges_count', 'ranges_threshold', 'is_ranges_limit_reached', 'bsr_ranges_limit', 'bsr_ranges_count', 'bsr_range_threshold', 'is_bsr_ranges_threshold_reached', 'bsr_candidate_rp_set_limit', 'bsr_candidate_rp_set_count', 'bsr_candidate_rp_set_threshold', 'is_maximum_enforcement_disabled', 'is_node_low_memory', 'route_threshold', 'global_auto_rp_ranges_limit', 'is_global_auto_rp_ranges_limit_reached', 'global_bsr_ranges_limit', 'global_bsr_ranges_count', 'global_bsr_ranges_threshold', 'is_global_bsr_ranges_limit_reached', 'global_bsr_candidate_rp_set_limit', 'global_bsr_candidate_rp_set_count', 'global_bsr_candidate_rp_set_threshold', 'is_global_route_limit_reached', 'topology_interface_state_threshold', 'is_global_rxi_limit_reached', 'register_threshold', 'global_register_limit', 'is_global_register_limit_reached'], name, value)


            class Nsf(Entity):
                """
                PIM NSF information
                
                .. attribute:: configured_state
                
                	Is Multicast NSF Configured
                	**type**\: bool
                
                .. attribute:: nsf_state
                
                	Are we currently in NSF
                	**type**\: bool
                
                .. attribute:: nsf_timeout
                
                	Multicast NSF timeout in seconds
                	**type**\: int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: nsf_time_left
                
                	Multicast NSF time left in seconds
                	**type**\: int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: waiting_timer
                
                	Waiting for NSF timer expiry
                	**type**\: bool
                
                .. attribute:: waiting_membership
                
                	Waiting for IGMP/MLD
                	**type**\: bool
                
                .. attribute:: respawn_count
                
                	Respawn Count
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: last_nsf_on
                
                	Last NSF time ON
                	**type**\: int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_nsf_off
                
                	Last NSF time off
                	**type**\: int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_nsf_on_sec
                
                	Last NSF time ON in Seconds
                	**type**\: int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: last_nsf_off_sec
                
                	Last NSF time OFF in Seconds
                	**type**\: int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: last_icd_notif_recv
                
                	Last ICD Notif Recv
                	**type**\: int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_icd_notif_recv_sec
                
                	Last ICD Notif Recv in Seconds
                	**type**\: int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Active.Process.Nsf, self).__init__()

                    self.yang_name = "nsf"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('configured_state', (YLeaf(YType.boolean, 'configured-state'), ['bool'])),
                        ('nsf_state', (YLeaf(YType.boolean, 'nsf-state'), ['bool'])),
                        ('nsf_timeout', (YLeaf(YType.uint32, 'nsf-timeout'), ['int'])),
                        ('nsf_time_left', (YLeaf(YType.uint32, 'nsf-time-left'), ['int'])),
                        ('waiting_timer', (YLeaf(YType.boolean, 'waiting-timer'), ['bool'])),
                        ('waiting_membership', (YLeaf(YType.boolean, 'waiting-membership'), ['bool'])),
                        ('respawn_count', (YLeaf(YType.uint32, 'respawn-count'), ['int'])),
                        ('last_nsf_on', (YLeaf(YType.int64, 'last-nsf-on'), ['int'])),
                        ('last_nsf_off', (YLeaf(YType.int64, 'last-nsf-off'), ['int'])),
                        ('last_nsf_on_sec', (YLeaf(YType.int32, 'last-nsf-on-sec'), ['int'])),
                        ('last_nsf_off_sec', (YLeaf(YType.int32, 'last-nsf-off-sec'), ['int'])),
                        ('last_icd_notif_recv', (YLeaf(YType.int64, 'last-icd-notif-recv'), ['int'])),
                        ('last_icd_notif_recv_sec', (YLeaf(YType.int32, 'last-icd-notif-recv-sec'), ['int'])),
                    ])
                    self.configured_state = None
                    self.nsf_state = None
                    self.nsf_timeout = None
                    self.nsf_time_left = None
                    self.waiting_timer = None
                    self.waiting_membership = None
                    self.respawn_count = None
                    self.last_nsf_on = None
                    self.last_nsf_off = None
                    self.last_nsf_on_sec = None
                    self.last_nsf_off_sec = None
                    self.last_icd_notif_recv = None
                    self.last_icd_notif_recv_sec = None
                    self._segment_path = lambda: "nsf"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/process/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.Process.Nsf, ['configured_state', 'nsf_state', 'nsf_timeout', 'nsf_time_left', 'waiting_timer', 'waiting_membership', 'respawn_count', 'last_nsf_on', 'last_nsf_off', 'last_nsf_on_sec', 'last_nsf_off_sec', 'last_icd_notif_recv', 'last_icd_notif_recv_sec'], name, value)


            class Issu(Entity):
                """
                ISSU Information
                
                .. attribute:: informationvalid
                
                	Is Information valid ?
                	**type**\: bool
                
                .. attribute:: role_ha
                
                	HA role
                	**type**\: int
                
                	**range:** \-2147483648..2147483647
                
                .. attribute:: role_issu
                
                	ISSU role
                	**type**\: int
                
                	**range:** \-2147483648..2147483647
                
                .. attribute:: phase_issu
                
                	ISSU Phase
                	**type**\: int
                
                	**range:** \-2147483648..2147483647
                
                .. attribute:: last_ha_role_notification_received
                
                	Time when last HA role nfn was received
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_issu_role_notification_received
                
                	Time when last ISSU role nfn was received
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_issu_phase_notification_received
                
                	Time when last ISSU Phase nfn was received
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: is_eoc_received
                
                	Was EOC received ?
                	**type**\: bool
                
                .. attribute:: eoc_received_timestamp
                
                	Time when EOC was received
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: is_ihms_done_received
                
                	Was IHMS done received ?
                	**type**\: bool
                
                .. attribute:: ihms_received_timestamp
                
                	Time when IHMS done was received
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: is_rib_sync_received
                
                	Was RIB Sync received ?
                	**type**\: bool
                
                .. attribute:: rib_sync_received_timestamp
                
                	Time when RIB Sync was received
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: is_nbr_sync_received
                
                	Was NBR Sync achieved ?
                	**type**\: bool
                
                .. attribute:: nbr_sync_received_timestamp
                
                	Time when NBR Sync was achieved
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: is_checkpoint_idt_done
                
                	Was Checkpoint IDT done ?
                	**type**\: bool
                
                .. attribute:: checkpoint_idt_timestamp
                
                	Time when Checkpoint IDT done
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Active.Process.Issu, self).__init__()

                    self.yang_name = "issu"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('informationvalid', (YLeaf(YType.boolean, 'informationvalid'), ['bool'])),
                        ('role_ha', (YLeaf(YType.int32, 'role-ha'), ['int'])),
                        ('role_issu', (YLeaf(YType.int32, 'role-issu'), ['int'])),
                        ('phase_issu', (YLeaf(YType.int32, 'phase-issu'), ['int'])),
                        ('last_ha_role_notification_received', (YLeaf(YType.uint64, 'last-ha-role-notification-received'), ['int'])),
                        ('last_issu_role_notification_received', (YLeaf(YType.uint64, 'last-issu-role-notification-received'), ['int'])),
                        ('last_issu_phase_notification_received', (YLeaf(YType.uint64, 'last-issu-phase-notification-received'), ['int'])),
                        ('is_eoc_received', (YLeaf(YType.boolean, 'is-eoc-received'), ['bool'])),
                        ('eoc_received_timestamp', (YLeaf(YType.uint64, 'eoc-received-timestamp'), ['int'])),
                        ('is_ihms_done_received', (YLeaf(YType.boolean, 'is-ihms-done-received'), ['bool'])),
                        ('ihms_received_timestamp', (YLeaf(YType.uint64, 'ihms-received-timestamp'), ['int'])),
                        ('is_rib_sync_received', (YLeaf(YType.boolean, 'is-rib-sync-received'), ['bool'])),
                        ('rib_sync_received_timestamp', (YLeaf(YType.uint64, 'rib-sync-received-timestamp'), ['int'])),
                        ('is_nbr_sync_received', (YLeaf(YType.boolean, 'is-nbr-sync-received'), ['bool'])),
                        ('nbr_sync_received_timestamp', (YLeaf(YType.uint64, 'nbr-sync-received-timestamp'), ['int'])),
                        ('is_checkpoint_idt_done', (YLeaf(YType.boolean, 'is-checkpoint-idt-done'), ['bool'])),
                        ('checkpoint_idt_timestamp', (YLeaf(YType.uint64, 'checkpoint-idt-timestamp'), ['int'])),
                    ])
                    self.informationvalid = None
                    self.role_ha = None
                    self.role_issu = None
                    self.phase_issu = None
                    self.last_ha_role_notification_received = None
                    self.last_issu_role_notification_received = None
                    self.last_issu_phase_notification_received = None
                    self.is_eoc_received = None
                    self.eoc_received_timestamp = None
                    self.is_ihms_done_received = None
                    self.ihms_received_timestamp = None
                    self.is_rib_sync_received = None
                    self.rib_sync_received_timestamp = None
                    self.is_nbr_sync_received = None
                    self.nbr_sync_received_timestamp = None
                    self.is_checkpoint_idt_done = None
                    self.checkpoint_idt_timestamp = None
                    self._segment_path = lambda: "issu"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/process/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.Process.Issu, ['informationvalid', 'role_ha', 'role_issu', 'phase_issu', 'last_ha_role_notification_received', 'last_issu_role_notification_received', 'last_issu_phase_notification_received', 'is_eoc_received', 'eoc_received_timestamp', 'is_ihms_done_received', 'ihms_received_timestamp', 'is_rib_sync_received', 'rib_sync_received_timestamp', 'is_nbr_sync_received', 'nbr_sync_received_timestamp', 'is_checkpoint_idt_done', 'checkpoint_idt_timestamp'], name, value)


        class Vrfs(Entity):
            """
            VRF Table
            
            .. attribute:: vrf
            
            	VRF name
            	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf>`
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(Pim.Active.Vrfs, self).__init__()

                self.yang_name = "vrfs"
                self.yang_parent_name = "active"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("vrf", ("vrf", Pim.Active.Vrfs.Vrf))])
                self._leafs = OrderedDict()

                self.vrf = YList(self)
                self._segment_path = lambda: "vrfs"
                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Pim.Active.Vrfs, [], name, value)


            class Vrf(Entity):
                """
                VRF name
                
                .. attribute:: vrf_name  (key)
                
                	VRF name 
                	**type**\: str
                
                	**length:** 1..32
                
                .. attribute:: ifrs_interfaces
                
                	PIM interfaces in forward reference store table
                	**type**\:  :py:class:`IfrsInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.IfrsInterfaces>`
                
                .. attribute:: safs
                
                	SAFI table and type
                	**type**\:  :py:class:`Safs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Safs>`
                
                .. attribute:: interface_statistics
                
                	PIM interface statistics
                	**type**\:  :py:class:`InterfaceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.InterfaceStatistics>`
                
                .. attribute:: topology_route_count
                
                	Topology route count information from PIM topology table
                	**type**\:  :py:class:`TopologyRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.TopologyRouteCount>`
                
                .. attribute:: jp_statistics
                
                	PIM join prune statistics table
                	**type**\:  :py:class:`JpStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.JpStatistics>`
                
                .. attribute:: mib_databases
                
                	PIM group database for mroute mibs table
                	**type**\:  :py:class:`MibDatabases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.MibDatabases>`
                
                .. attribute:: neighbor_old_formats
                
                	PIM neighbor table old format
                	**type**\:  :py:class:`NeighborOldFormats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.NeighborOldFormats>`
                
                .. attribute:: ifrs_summary
                
                	PIM interfaces in forward reference store summary
                	**type**\:  :py:class:`IfrsSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.IfrsSummary>`
                
                .. attribute:: ranges
                
                	PIM range list information
                	**type**\:  :py:class:`Ranges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Ranges>`
                
                .. attribute:: interface_old_formats
                
                	PIM interfaces in old format
                	**type**\:  :py:class:`InterfaceOldFormats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.InterfaceOldFormats>`
                
                .. attribute:: bsr
                
                	PIM BSR information
                	**type**\:  :py:class:`Bsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Bsr>`
                
                .. attribute:: route_policy
                
                	PIM route policy
                	**type**\:  :py:class:`RoutePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.RoutePolicy>`
                
                .. attribute:: rpf_summary
                
                	PIM RPF registration summary
                	**type**\:  :py:class:`RpfSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.RpfSummary>`
                
                .. attribute:: interfaces
                
                	PIM interfaces
                	**type**\:  :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Interfaces>`
                
                .. attribute:: net_io_tunnels
                
                	Tunnel information that NETIO has 
                	**type**\:  :py:class:`NetIoTunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.NetIoTunnels>`
                
                .. attribute:: bidir_df_states
                
                	Bidirectional PIM DF election state table
                	**type**\:  :py:class:`BidirDfStates <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.BidirDfStates>`
                
                .. attribute:: topologies
                
                	PIM topology table
                	**type**\:  :py:class:`Topologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Topologies>`
                
                .. attribute:: bgp_afs
                
                	PIM BGP SAFI table
                	**type**\:  :py:class:`BgpAfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.BgpAfs>`
                
                .. attribute:: auto_rp
                
                	PIM Auto\-RP information
                	**type**\:  :py:class:`AutoRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.AutoRp>`
                
                .. attribute:: topology_interface_flag_route_counts
                
                	Route count for topology with interface flag set
                	**type**\:  :py:class:`TopologyInterfaceFlagRouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts>`
                
                .. attribute:: group_map_sources
                
                	PIM group\-mapping with source information
                	**type**\:  :py:class:`GroupMapSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapSources>`
                
                .. attribute:: traffic_counters
                
                	PIM message traffic counters
                	**type**\:  :py:class:`TrafficCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.TrafficCounters>`
                
                .. attribute:: group_map_rpfs
                
                	PIM group mapping information
                	**type**\:  :py:class:`GroupMapRpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapRpfs>`
                
                .. attribute:: summary
                
                	PIM summary
                	**type**\:  :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Summary>`
                
                .. attribute:: gre
                
                	GRE information
                	**type**\:  :py:class:`Gre <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Gre>`
                
                .. attribute:: bidir_df_winners
                
                	Bidirectional PIM DF election winner table
                	**type**\:  :py:class:`BidirDfWinners <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.BidirDfWinners>`
                
                .. attribute:: table_contexts
                
                	PIM table context list
                	**type**\:  :py:class:`TableContexts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.TableContexts>`
                
                .. attribute:: neighbor_summaries
                
                	PIM neighbor summary table
                	**type**\:  :py:class:`NeighborSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.NeighborSummaries>`
                
                .. attribute:: context
                
                	PIM context information
                	**type**\:  :py:class:`Context <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Context>`
                
                .. attribute:: topology_entry_flag_route_counts
                
                	Route count for topology with entry flag set
                	**type**\:  :py:class:`TopologyEntryFlagRouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts>`
                
                .. attribute:: rpf_redirect
                
                	PIM ECMP RPF\-redirect bundle
                	**type**\:  :py:class:`RpfRedirect <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.RpfRedirect>`
                
                .. attribute:: tunnels
                
                	Tunnels information that PIM has
                	**type**\:  :py:class:`Tunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Tunnels>`
                
                .. attribute:: multicast_static_routes
                
                	PIM multicast static route table
                	**type**\:  :py:class:`MulticastStaticRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.MulticastStaticRoutes>`
                
                .. attribute:: neighbors
                
                	PIM neighbor table
                	**type**\:  :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Neighbors>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim.Active.Vrfs.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "vrfs"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['vrf_name']
                    self._child_classes = OrderedDict([("ifrs-interfaces", ("ifrs_interfaces", Pim.Active.Vrfs.Vrf.IfrsInterfaces)), ("safs", ("safs", Pim.Active.Vrfs.Vrf.Safs)), ("interface-statistics", ("interface_statistics", Pim.Active.Vrfs.Vrf.InterfaceStatistics)), ("topology-route-count", ("topology_route_count", Pim.Active.Vrfs.Vrf.TopologyRouteCount)), ("jp-statistics", ("jp_statistics", Pim.Active.Vrfs.Vrf.JpStatistics)), ("mib-databases", ("mib_databases", Pim.Active.Vrfs.Vrf.MibDatabases)), ("neighbor-old-formats", ("neighbor_old_formats", Pim.Active.Vrfs.Vrf.NeighborOldFormats)), ("ifrs-summary", ("ifrs_summary", Pim.Active.Vrfs.Vrf.IfrsSummary)), ("ranges", ("ranges", Pim.Active.Vrfs.Vrf.Ranges)), ("interface-old-formats", ("interface_old_formats", Pim.Active.Vrfs.Vrf.InterfaceOldFormats)), ("bsr", ("bsr", Pim.Active.Vrfs.Vrf.Bsr)), ("route-policy", ("route_policy", Pim.Active.Vrfs.Vrf.RoutePolicy)), ("rpf-summary", ("rpf_summary", Pim.Active.Vrfs.Vrf.RpfSummary)), ("interfaces", ("interfaces", Pim.Active.Vrfs.Vrf.Interfaces)), ("net-io-tunnels", ("net_io_tunnels", Pim.Active.Vrfs.Vrf.NetIoTunnels)), ("bidir-df-states", ("bidir_df_states", Pim.Active.Vrfs.Vrf.BidirDfStates)), ("topologies", ("topologies", Pim.Active.Vrfs.Vrf.Topologies)), ("bgp-afs", ("bgp_afs", Pim.Active.Vrfs.Vrf.BgpAfs)), ("auto-rp", ("auto_rp", Pim.Active.Vrfs.Vrf.AutoRp)), ("topology-interface-flag-route-counts", ("topology_interface_flag_route_counts", Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts)), ("group-map-sources", ("group_map_sources", Pim.Active.Vrfs.Vrf.GroupMapSources)), ("traffic-counters", ("traffic_counters", Pim.Active.Vrfs.Vrf.TrafficCounters)), ("group-map-rpfs", ("group_map_rpfs", Pim.Active.Vrfs.Vrf.GroupMapRpfs)), ("summary", ("summary", Pim.Active.Vrfs.Vrf.Summary)), ("gre", ("gre", Pim.Active.Vrfs.Vrf.Gre)), ("bidir-df-winners", ("bidir_df_winners", Pim.Active.Vrfs.Vrf.BidirDfWinners)), ("table-contexts", ("table_contexts", Pim.Active.Vrfs.Vrf.TableContexts)), ("neighbor-summaries", ("neighbor_summaries", Pim.Active.Vrfs.Vrf.NeighborSummaries)), ("context", ("context", Pim.Active.Vrfs.Vrf.Context)), ("topology-entry-flag-route-counts", ("topology_entry_flag_route_counts", Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts)), ("rpf-redirect", ("rpf_redirect", Pim.Active.Vrfs.Vrf.RpfRedirect)), ("tunnels", ("tunnels", Pim.Active.Vrfs.Vrf.Tunnels)), ("multicast-static-routes", ("multicast_static_routes", Pim.Active.Vrfs.Vrf.MulticastStaticRoutes)), ("neighbors", ("neighbors", Pim.Active.Vrfs.Vrf.Neighbors))])
                    self._leafs = OrderedDict([
                        ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                    ])
                    self.vrf_name = None

                    self.ifrs_interfaces = Pim.Active.Vrfs.Vrf.IfrsInterfaces()
                    self.ifrs_interfaces.parent = self
                    self._children_name_map["ifrs_interfaces"] = "ifrs-interfaces"

                    self.safs = Pim.Active.Vrfs.Vrf.Safs()
                    self.safs.parent = self
                    self._children_name_map["safs"] = "safs"

                    self.interface_statistics = Pim.Active.Vrfs.Vrf.InterfaceStatistics()
                    self.interface_statistics.parent = self
                    self._children_name_map["interface_statistics"] = "interface-statistics"

                    self.topology_route_count = Pim.Active.Vrfs.Vrf.TopologyRouteCount()
                    self.topology_route_count.parent = self
                    self._children_name_map["topology_route_count"] = "topology-route-count"

                    self.jp_statistics = Pim.Active.Vrfs.Vrf.JpStatistics()
                    self.jp_statistics.parent = self
                    self._children_name_map["jp_statistics"] = "jp-statistics"

                    self.mib_databases = Pim.Active.Vrfs.Vrf.MibDatabases()
                    self.mib_databases.parent = self
                    self._children_name_map["mib_databases"] = "mib-databases"

                    self.neighbor_old_formats = Pim.Active.Vrfs.Vrf.NeighborOldFormats()
                    self.neighbor_old_formats.parent = self
                    self._children_name_map["neighbor_old_formats"] = "neighbor-old-formats"

                    self.ifrs_summary = Pim.Active.Vrfs.Vrf.IfrsSummary()
                    self.ifrs_summary.parent = self
                    self._children_name_map["ifrs_summary"] = "ifrs-summary"

                    self.ranges = Pim.Active.Vrfs.Vrf.Ranges()
                    self.ranges.parent = self
                    self._children_name_map["ranges"] = "ranges"

                    self.interface_old_formats = Pim.Active.Vrfs.Vrf.InterfaceOldFormats()
                    self.interface_old_formats.parent = self
                    self._children_name_map["interface_old_formats"] = "interface-old-formats"

                    self.bsr = Pim.Active.Vrfs.Vrf.Bsr()
                    self.bsr.parent = self
                    self._children_name_map["bsr"] = "bsr"

                    self.route_policy = Pim.Active.Vrfs.Vrf.RoutePolicy()
                    self.route_policy.parent = self
                    self._children_name_map["route_policy"] = "route-policy"

                    self.rpf_summary = Pim.Active.Vrfs.Vrf.RpfSummary()
                    self.rpf_summary.parent = self
                    self._children_name_map["rpf_summary"] = "rpf-summary"

                    self.interfaces = Pim.Active.Vrfs.Vrf.Interfaces()
                    self.interfaces.parent = self
                    self._children_name_map["interfaces"] = "interfaces"

                    self.net_io_tunnels = Pim.Active.Vrfs.Vrf.NetIoTunnels()
                    self.net_io_tunnels.parent = self
                    self._children_name_map["net_io_tunnels"] = "net-io-tunnels"

                    self.bidir_df_states = Pim.Active.Vrfs.Vrf.BidirDfStates()
                    self.bidir_df_states.parent = self
                    self._children_name_map["bidir_df_states"] = "bidir-df-states"

                    self.topologies = Pim.Active.Vrfs.Vrf.Topologies()
                    self.topologies.parent = self
                    self._children_name_map["topologies"] = "topologies"

                    self.bgp_afs = Pim.Active.Vrfs.Vrf.BgpAfs()
                    self.bgp_afs.parent = self
                    self._children_name_map["bgp_afs"] = "bgp-afs"

                    self.auto_rp = Pim.Active.Vrfs.Vrf.AutoRp()
                    self.auto_rp.parent = self
                    self._children_name_map["auto_rp"] = "auto-rp"

                    self.topology_interface_flag_route_counts = Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts()
                    self.topology_interface_flag_route_counts.parent = self
                    self._children_name_map["topology_interface_flag_route_counts"] = "topology-interface-flag-route-counts"

                    self.group_map_sources = Pim.Active.Vrfs.Vrf.GroupMapSources()
                    self.group_map_sources.parent = self
                    self._children_name_map["group_map_sources"] = "group-map-sources"

                    self.traffic_counters = Pim.Active.Vrfs.Vrf.TrafficCounters()
                    self.traffic_counters.parent = self
                    self._children_name_map["traffic_counters"] = "traffic-counters"

                    self.group_map_rpfs = Pim.Active.Vrfs.Vrf.GroupMapRpfs()
                    self.group_map_rpfs.parent = self
                    self._children_name_map["group_map_rpfs"] = "group-map-rpfs"

                    self.summary = Pim.Active.Vrfs.Vrf.Summary()
                    self.summary.parent = self
                    self._children_name_map["summary"] = "summary"

                    self.gre = Pim.Active.Vrfs.Vrf.Gre()
                    self.gre.parent = self
                    self._children_name_map["gre"] = "gre"

                    self.bidir_df_winners = Pim.Active.Vrfs.Vrf.BidirDfWinners()
                    self.bidir_df_winners.parent = self
                    self._children_name_map["bidir_df_winners"] = "bidir-df-winners"

                    self.table_contexts = Pim.Active.Vrfs.Vrf.TableContexts()
                    self.table_contexts.parent = self
                    self._children_name_map["table_contexts"] = "table-contexts"

                    self.neighbor_summaries = Pim.Active.Vrfs.Vrf.NeighborSummaries()
                    self.neighbor_summaries.parent = self
                    self._children_name_map["neighbor_summaries"] = "neighbor-summaries"

                    self.context = Pim.Active.Vrfs.Vrf.Context()
                    self.context.parent = self
                    self._children_name_map["context"] = "context"

                    self.topology_entry_flag_route_counts = Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts()
                    self.topology_entry_flag_route_counts.parent = self
                    self._children_name_map["topology_entry_flag_route_counts"] = "topology-entry-flag-route-counts"

                    self.rpf_redirect = Pim.Active.Vrfs.Vrf.RpfRedirect()
                    self.rpf_redirect.parent = self
                    self._children_name_map["rpf_redirect"] = "rpf-redirect"

                    self.tunnels = Pim.Active.Vrfs.Vrf.Tunnels()
                    self.tunnels.parent = self
                    self._children_name_map["tunnels"] = "tunnels"

                    self.multicast_static_routes = Pim.Active.Vrfs.Vrf.MulticastStaticRoutes()
                    self.multicast_static_routes.parent = self
                    self._children_name_map["multicast_static_routes"] = "multicast-static-routes"

                    self.neighbors = Pim.Active.Vrfs.Vrf.Neighbors()
                    self.neighbors.parent = self
                    self._children_name_map["neighbors"] = "neighbors"
                    self._segment_path = lambda: "vrf" + "[vrf-name='" + str(self.vrf_name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim/active/vrfs/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim.Active.Vrfs.Vrf, ['vrf_name'], name, value)


                class IfrsInterfaces(Entity):
                    """
                    PIM interfaces in forward reference store table
                    
                    .. attribute:: ifrs_interface
                    
                    	PIM IFRS interface information
                    	**type**\: list of  		 :py:class:`IfrsInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.IfrsInterfaces, self).__init__()

                        self.yang_name = "ifrs-interfaces"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ifrs-interface", ("ifrs_interface", Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface))])
                        self._leafs = OrderedDict()

                        self.ifrs_interface = YList(self)
                        self._segment_path = lambda: "ifrs-interfaces"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.Vrfs.Vrf.IfrsInterfaces, [], name, value)


                    class IfrsInterface(Entity):
                        """
                        PIM IFRS interface information
                        
                        .. attribute:: interface_name  (key)
                        
                        	Interface name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: dr_address
                        
                        	PIM Designated Router
                        	**type**\:  :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress>`
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identfier
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: interface_address_mask
                        
                        	Interface IP Address Mask
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: is_enabled
                        
                        	Is PIM enabled on this IF ?
                        	**type**\: bool
                        
                        .. attribute:: neighbor_count
                        
                        	No. of neighbors on this IF
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: external_neighbor_count
                        
                        	No. of external neighbors on this IF
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: hello_interval
                        
                        	Hello Interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: dr_priority
                        
                        	DR Priority
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: hello_expiry
                        
                        	Hello Timer Expiry
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: are_we_dr
                        
                        	Are we the DR on this IF ?
                        	**type**\: bool
                        
                        .. attribute:: bfd_enabled
                        
                        	BFD state
                        	**type**\: bool
                        
                        .. attribute:: bfd_interval
                        
                        	BFD Interval
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bfd_multiplier
                        
                        	BFD Multiplier
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_interface
                        
                        	 is this a Virtual Interfaces ?
                        	**type**\: bool
                        
                        .. attribute:: passive_interface
                        
                        	Passive PIM interface
                        	**type**\: bool
                        
                        .. attribute:: neighbor_filter_name
                        
                        	Neighbor Filter Name
                        	**type**\: str
                        
                        .. attribute:: join_prune_interval
                        
                        	Join\-Prune Interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: prune_delay_enabled
                        
                        	Prune Delay Enabled
                        	**type**\: bool
                        
                        .. attribute:: configured_propagation_delay
                        
                        	Configured Propagation Delay
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: configured_override_interval
                        
                        	Configured Override Interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: generation_id
                        
                        	Generation Identifier
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Bidir Capable
                        	**type**\: bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Proxy Capable
                        	**type**\: bool
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Batch Asserts Capable
                        	**type**\: bool
                        
                        .. attribute:: idb_oor_enabled
                        
                        	Interface oor enabled
                        	**type**\: bool
                        
                        .. attribute:: idb_acl_provided
                        
                        	ACL name provided
                        	**type**\: bool
                        
                        .. attribute:: idb_max_count
                        
                        	Interface ole max count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_threshold_count
                        
                        	Interface ole threshold count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_current_count
                        
                        	Interface ole current count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_acl_name
                        
                        	Interface ole ACL Name
                        	**type**\: str
                        
                        	**length:** 0..64
                        
                        .. attribute:: interface_address
                        
                        	List of Interface IP Addresses
                        	**type**\: list of  		 :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.InterfaceAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface, self).__init__()

                            self.yang_name = "ifrs-interface"
                            self.yang_parent_name = "ifrs-interfaces"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['interface_name']
                            self._child_classes = OrderedDict([("dr-address", ("dr_address", Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress)), ("interface-address", ("interface_address", Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.InterfaceAddress))])
                            self._leafs = OrderedDict([
                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                                ('interface_address_mask', (YLeaf(YType.uint8, 'interface-address-mask'), ['int'])),
                                ('is_enabled', (YLeaf(YType.boolean, 'is-enabled'), ['bool'])),
                                ('neighbor_count', (YLeaf(YType.uint16, 'neighbor-count'), ['int'])),
                                ('external_neighbor_count', (YLeaf(YType.uint16, 'external-neighbor-count'), ['int'])),
                                ('hello_interval', (YLeaf(YType.uint16, 'hello-interval'), ['int'])),
                                ('dr_priority', (YLeaf(YType.uint32, 'dr-priority'), ['int'])),
                                ('hello_expiry', (YLeaf(YType.uint64, 'hello-expiry'), ['int'])),
                                ('are_we_dr', (YLeaf(YType.boolean, 'are-we-dr'), ['bool'])),
                                ('bfd_enabled', (YLeaf(YType.boolean, 'bfd-enabled'), ['bool'])),
                                ('bfd_interval', (YLeaf(YType.uint32, 'bfd-interval'), ['int'])),
                                ('bfd_multiplier', (YLeaf(YType.uint32, 'bfd-multiplier'), ['int'])),
                                ('virtual_interface', (YLeaf(YType.boolean, 'virtual-interface'), ['bool'])),
                                ('passive_interface', (YLeaf(YType.boolean, 'passive-interface'), ['bool'])),
                                ('neighbor_filter_name', (YLeaf(YType.str, 'neighbor-filter-name'), ['str'])),
                                ('join_prune_interval', (YLeaf(YType.uint16, 'join-prune-interval'), ['int'])),
                                ('prune_delay_enabled', (YLeaf(YType.boolean, 'prune-delay-enabled'), ['bool'])),
                                ('configured_propagation_delay', (YLeaf(YType.uint16, 'configured-propagation-delay'), ['int'])),
                                ('propagation_delay', (YLeaf(YType.uint16, 'propagation-delay'), ['int'])),
                                ('configured_override_interval', (YLeaf(YType.uint16, 'configured-override-interval'), ['int'])),
                                ('override_interval', (YLeaf(YType.uint16, 'override-interval'), ['int'])),
                                ('generation_id', (YLeaf(YType.uint32, 'generation-id'), ['int'])),
                                ('is_bidirectional_capable', (YLeaf(YType.boolean, 'is-bidirectional-capable'), ['bool'])),
                                ('is_proxy_capable', (YLeaf(YType.boolean, 'is-proxy-capable'), ['bool'])),
                                ('is_batch_asserts_capable', (YLeaf(YType.boolean, 'is-batch-asserts-capable'), ['bool'])),
                                ('idb_oor_enabled', (YLeaf(YType.boolean, 'idb-oor-enabled'), ['bool'])),
                                ('idb_acl_provided', (YLeaf(YType.boolean, 'idb-acl-provided'), ['bool'])),
                                ('idb_max_count', (YLeaf(YType.uint32, 'idb-max-count'), ['int'])),
                                ('idb_threshold_count', (YLeaf(YType.uint32, 'idb-threshold-count'), ['int'])),
                                ('idb_current_count', (YLeaf(YType.uint32, 'idb-current-count'), ['int'])),
                                ('idb_acl_name', (YLeaf(YType.str, 'idb-acl-name'), ['str'])),
                            ])
                            self.interface_name = None
                            self.interface_name_xr = None
                            self.interface_address_mask = None
                            self.is_enabled = None
                            self.neighbor_count = None
                            self.external_neighbor_count = None
                            self.hello_interval = None
                            self.dr_priority = None
                            self.hello_expiry = None
                            self.are_we_dr = None
                            self.bfd_enabled = None
                            self.bfd_interval = None
                            self.bfd_multiplier = None
                            self.virtual_interface = None
                            self.passive_interface = None
                            self.neighbor_filter_name = None
                            self.join_prune_interval = None
                            self.prune_delay_enabled = None
                            self.configured_propagation_delay = None
                            self.propagation_delay = None
                            self.configured_override_interval = None
                            self.override_interval = None
                            self.generation_id = None
                            self.is_bidirectional_capable = None
                            self.is_proxy_capable = None
                            self.is_batch_asserts_capable = None
                            self.idb_oor_enabled = None
                            self.idb_acl_provided = None
                            self.idb_max_count = None
                            self.idb_threshold_count = None
                            self.idb_current_count = None
                            self.idb_acl_name = None

                            self.dr_address = Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress()
                            self.dr_address.parent = self
                            self._children_name_map["dr_address"] = "dr-address"

                            self.interface_address = YList(self)
                            self._segment_path = lambda: "ifrs-interface" + "[interface-name='" + str(self.interface_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface, ['interface_name', 'interface_name_xr', 'interface_address_mask', 'is_enabled', 'neighbor_count', 'external_neighbor_count', 'hello_interval', 'dr_priority', 'hello_expiry', 'are_we_dr', 'bfd_enabled', 'bfd_interval', 'bfd_multiplier', 'virtual_interface', 'passive_interface', 'neighbor_filter_name', 'join_prune_interval', 'prune_delay_enabled', 'configured_propagation_delay', 'propagation_delay', 'configured_override_interval', 'override_interval', 'generation_id', 'is_bidirectional_capable', 'is_proxy_capable', 'is_batch_asserts_capable', 'idb_oor_enabled', 'idb_acl_provided', 'idb_max_count', 'idb_threshold_count', 'idb_current_count', 'idb_acl_name'], name, value)


                        class DrAddress(Entity):
                            """
                            PIM Designated Router
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress, self).__init__()

                                self.yang_name = "dr-address"
                                self.yang_parent_name = "ifrs-interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "dr-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class InterfaceAddress(Entity):
                            """
                            List of Interface IP Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.InterfaceAddress, self).__init__()

                                self.yang_name = "interface-address"
                                self.yang_parent_name = "ifrs-interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "interface-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.InterfaceAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class Safs(Entity):
                    """
                    SAFI table and type
                    
                    .. attribute:: saf
                    
                    	SAF name 
                    	**type**\: list of  		 :py:class:`Saf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Safs.Saf>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.Safs, self).__init__()

                        self.yang_name = "safs"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("saf", ("saf", Pim.Active.Vrfs.Vrf.Safs.Saf))])
                        self._leafs = OrderedDict()

                        self.saf = YList(self)
                        self._segment_path = lambda: "safs"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.Vrfs.Vrf.Safs, [], name, value)


                    class Saf(Entity):
                        """
                        SAF name 
                        
                        .. attribute:: rpf_hash_source_groups
                        
                        	PIM RPF multipath hash outcome
                        	**type**\:  :py:class:`RpfHashSourceGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups>`
                        
                        .. attribute:: rpf_hash_sources
                        
                        	PIM RPF multipath hash outcome
                        	**type**\:  :py:class:`RpfHashSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources>`
                        
                        .. attribute:: rpfs
                        
                        	PIM RPF information table
                        	**type**\:  :py:class:`Rpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs>`
                        
                        .. attribute:: saf_name
                        
                        	SAF name 
                        	**type**\:  :py:class:`PimSafi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimSafi>`
                        
                        .. attribute:: topology_name
                        
                        	Topology name 
                        	**type**\: str
                        
                        	**length:** 1..32
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.Safs.Saf, self).__init__()

                            self.yang_name = "saf"
                            self.yang_parent_name = "safs"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rpf-hash-source-groups", ("rpf_hash_source_groups", Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups)), ("rpf-hash-sources", ("rpf_hash_sources", Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources)), ("rpfs", ("rpfs", Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs))])
                            self._leafs = OrderedDict([
                                ('saf_name', (YLeaf(YType.enumeration, 'saf-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimSafi', '')])),
                                ('topology_name', (YLeaf(YType.str, 'topology-name'), ['str'])),
                            ])
                            self.saf_name = None
                            self.topology_name = None

                            self.rpf_hash_source_groups = Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups()
                            self.rpf_hash_source_groups.parent = self
                            self._children_name_map["rpf_hash_source_groups"] = "rpf-hash-source-groups"

                            self.rpf_hash_sources = Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources()
                            self.rpf_hash_sources.parent = self
                            self._children_name_map["rpf_hash_sources"] = "rpf-hash-sources"

                            self.rpfs = Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs()
                            self.rpfs.parent = self
                            self._children_name_map["rpfs"] = "rpfs"
                            self._segment_path = lambda: "saf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.Safs.Saf, ['saf_name', 'topology_name'], name, value)


                        class RpfHashSourceGroups(Entity):
                            """
                            PIM RPF multipath hash outcome
                            
                            .. attribute:: rpf_hash_source_group
                            
                            	PIM RPF hash outcome for S,G
                            	**type**\: list of  		 :py:class:`RpfHashSourceGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups, self).__init__()

                                self.yang_name = "rpf-hash-source-groups"
                                self.yang_parent_name = "saf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("rpf-hash-source-group", ("rpf_hash_source_group", Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup))])
                                self._leafs = OrderedDict()

                                self.rpf_hash_source_group = YList(self)
                                self._segment_path = lambda: "rpf-hash-source-groups"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups, [], name, value)


                            class RpfHashSourceGroup(Entity):
                                """
                                PIM RPF hash outcome for S,G
                                
                                .. attribute:: source_address
                                
                                	Source address
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: group_address
                                
                                	Group address
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: mask_length
                                
                                	Hash mask length
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: mofrr
                                
                                	MOFRR
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_address
                                
                                	Next hop neighbor address
                                	**type**\:  :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress>`
                                
                                .. attribute:: secondary_next_hop_address
                                
                                	Secondary Next hop neighbor address
                                	**type**\:  :py:class:`SecondaryNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress>`
                                
                                .. attribute:: next_hop_multipath_enabled
                                
                                	Next hop multipath enabled?
                                	**type**\: bool
                                
                                .. attribute:: next_hop_interface
                                
                                	Next hop neighbor interface
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                .. attribute:: secondary_next_hop_interface
                                
                                	Secondary Next hop neighbor interface
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup, self).__init__()

                                    self.yang_name = "rpf-hash-source-group"
                                    self.yang_parent_name = "rpf-hash-source-groups"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("next-hop-address", ("next_hop_address", Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress)), ("secondary-next-hop-address", ("secondary_next_hop_address", Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress))])
                                    self._leafs = OrderedDict([
                                        ('source_address', (YLeaf(YType.str, 'source-address'), ['str','str'])),
                                        ('group_address', (YLeaf(YType.str, 'group-address'), ['str','str'])),
                                        ('mask_length', (YLeaf(YType.uint32, 'mask-length'), ['int'])),
                                        ('mofrr', (YLeaf(YType.uint32, 'mofrr'), ['int'])),
                                        ('next_hop_multipath_enabled', (YLeaf(YType.boolean, 'next-hop-multipath-enabled'), ['bool'])),
                                        ('next_hop_interface', (YLeaf(YType.str, 'next-hop-interface'), ['str'])),
                                        ('secondary_next_hop_interface', (YLeaf(YType.str, 'secondary-next-hop-interface'), ['str'])),
                                    ])
                                    self.source_address = None
                                    self.group_address = None
                                    self.mask_length = None
                                    self.mofrr = None
                                    self.next_hop_multipath_enabled = None
                                    self.next_hop_interface = None
                                    self.secondary_next_hop_interface = None

                                    self.next_hop_address = Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress()
                                    self.next_hop_address.parent = self
                                    self._children_name_map["next_hop_address"] = "next-hop-address"

                                    self.secondary_next_hop_address = Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress()
                                    self.secondary_next_hop_address.parent = self
                                    self._children_name_map["secondary_next_hop_address"] = "secondary-next-hop-address"
                                    self._segment_path = lambda: "rpf-hash-source-group"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup, ['source_address', 'group_address', 'mask_length', 'mofrr', 'next_hop_multipath_enabled', 'next_hop_interface', 'secondary_next_hop_interface'], name, value)


                                class NextHopAddress(Entity):
                                    """
                                    Next hop neighbor address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress, self).__init__()

                                        self.yang_name = "next-hop-address"
                                        self.yang_parent_name = "rpf-hash-source-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ])
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None
                                        self._segment_path = lambda: "next-hop-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                                class SecondaryNextHopAddress(Entity):
                                    """
                                    Secondary Next hop neighbor address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress, self).__init__()

                                        self.yang_name = "secondary-next-hop-address"
                                        self.yang_parent_name = "rpf-hash-source-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ])
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None
                                        self._segment_path = lambda: "secondary-next-hop-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class RpfHashSources(Entity):
                            """
                            PIM RPF multipath hash outcome
                            
                            .. attribute:: rpf_hash_source
                            
                            	PIM RPF hash outcome for S,G
                            	**type**\: list of  		 :py:class:`RpfHashSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources, self).__init__()

                                self.yang_name = "rpf-hash-sources"
                                self.yang_parent_name = "saf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("rpf-hash-source", ("rpf_hash_source", Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource))])
                                self._leafs = OrderedDict()

                                self.rpf_hash_source = YList(self)
                                self._segment_path = lambda: "rpf-hash-sources"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources, [], name, value)


                            class RpfHashSource(Entity):
                                """
                                PIM RPF hash outcome for S,G
                                
                                .. attribute:: source_address
                                
                                	Source address
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: mofrr
                                
                                	MOFRR
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_address
                                
                                	Next hop neighbor address
                                	**type**\:  :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress>`
                                
                                .. attribute:: secondary_next_hop_address
                                
                                	Secondary Next hop neighbor address
                                	**type**\:  :py:class:`SecondaryNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress>`
                                
                                .. attribute:: next_hop_multipath_enabled
                                
                                	Next hop multipath enabled?
                                	**type**\: bool
                                
                                .. attribute:: next_hop_interface
                                
                                	Next hop neighbor interface
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                .. attribute:: secondary_next_hop_interface
                                
                                	Secondary Next hop neighbor interface
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource, self).__init__()

                                    self.yang_name = "rpf-hash-source"
                                    self.yang_parent_name = "rpf-hash-sources"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("next-hop-address", ("next_hop_address", Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress)), ("secondary-next-hop-address", ("secondary_next_hop_address", Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress))])
                                    self._leafs = OrderedDict([
                                        ('source_address', (YLeaf(YType.str, 'source-address'), ['str','str'])),
                                        ('mofrr', (YLeaf(YType.uint32, 'mofrr'), ['int'])),
                                        ('next_hop_multipath_enabled', (YLeaf(YType.boolean, 'next-hop-multipath-enabled'), ['bool'])),
                                        ('next_hop_interface', (YLeaf(YType.str, 'next-hop-interface'), ['str'])),
                                        ('secondary_next_hop_interface', (YLeaf(YType.str, 'secondary-next-hop-interface'), ['str'])),
                                    ])
                                    self.source_address = None
                                    self.mofrr = None
                                    self.next_hop_multipath_enabled = None
                                    self.next_hop_interface = None
                                    self.secondary_next_hop_interface = None

                                    self.next_hop_address = Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress()
                                    self.next_hop_address.parent = self
                                    self._children_name_map["next_hop_address"] = "next-hop-address"

                                    self.secondary_next_hop_address = Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress()
                                    self.secondary_next_hop_address.parent = self
                                    self._children_name_map["secondary_next_hop_address"] = "secondary-next-hop-address"
                                    self._segment_path = lambda: "rpf-hash-source"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource, ['source_address', 'mofrr', 'next_hop_multipath_enabled', 'next_hop_interface', 'secondary_next_hop_interface'], name, value)


                                class NextHopAddress(Entity):
                                    """
                                    Next hop neighbor address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress, self).__init__()

                                        self.yang_name = "next-hop-address"
                                        self.yang_parent_name = "rpf-hash-source"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ])
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None
                                        self._segment_path = lambda: "next-hop-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                                class SecondaryNextHopAddress(Entity):
                                    """
                                    Secondary Next hop neighbor address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress, self).__init__()

                                        self.yang_name = "secondary-next-hop-address"
                                        self.yang_parent_name = "rpf-hash-source"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ])
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None
                                        self._segment_path = lambda: "secondary-next-hop-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class Rpfs(Entity):
                            """
                            PIM RPF information table
                            
                            .. attribute:: rpf
                            
                            	PIM RPF information
                            	**type**\: list of  		 :py:class:`Rpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs, self).__init__()

                                self.yang_name = "rpfs"
                                self.yang_parent_name = "saf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("rpf", ("rpf", Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf))])
                                self._leafs = OrderedDict()

                                self.rpf = YList(self)
                                self._segment_path = lambda: "rpfs"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs, [], name, value)


                            class Rpf(Entity):
                                """
                                PIM RPF information
                                
                                .. attribute:: registered_address  (key)
                                
                                	Address for which RPF lookup
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: registered_address_xr
                                
                                	Address registered
                                	**type**\:  :py:class:`RegisteredAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr>`
                                
                                .. attribute:: metric
                                
                                	Metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_preference
                                
                                	Metric preference
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_connected
                                
                                	Are we connected ?
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: is_rpf_bgp_route
                                
                                	Is RPF through BGP route
                                	**type**\: bool
                                
                                .. attribute:: rpf_path
                                
                                	RPF Paths list
                                	**type**\: list of  		 :py:class:`RpfPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf, self).__init__()

                                    self.yang_name = "rpf"
                                    self.yang_parent_name = "rpfs"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['registered_address']
                                    self._child_classes = OrderedDict([("registered-address-xr", ("registered_address_xr", Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr)), ("rpf-path", ("rpf_path", Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath))])
                                    self._leafs = OrderedDict([
                                        ('registered_address', (YLeaf(YType.str, 'registered-address'), ['str','str'])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_preference', (YLeaf(YType.uint32, 'metric-preference'), ['int'])),
                                        ('is_connected', (YLeaf(YType.uint8, 'is-connected'), ['int'])),
                                        ('is_rpf_bgp_route', (YLeaf(YType.boolean, 'is-rpf-bgp-route'), ['bool'])),
                                    ])
                                    self.registered_address = None
                                    self.metric = None
                                    self.metric_preference = None
                                    self.is_connected = None
                                    self.is_rpf_bgp_route = None

                                    self.registered_address_xr = Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr()
                                    self.registered_address_xr.parent = self
                                    self._children_name_map["registered_address_xr"] = "registered-address-xr"

                                    self.rpf_path = YList(self)
                                    self._segment_path = lambda: "rpf" + "[registered-address='" + str(self.registered_address) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf, ['registered_address', 'metric', 'metric_preference', 'is_connected', 'is_rpf_bgp_route'], name, value)


                                class RegisteredAddressXr(Entity):
                                    """
                                    Address registered
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr, self).__init__()

                                        self.yang_name = "registered-address-xr"
                                        self.yang_parent_name = "rpf"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ])
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None
                                        self._segment_path = lambda: "registered-address-xr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                                class RpfPath(Entity):
                                    """
                                    RPF Paths list
                                    
                                    .. attribute:: rpf_neighbor
                                    
                                    	RPF neighbor
                                    	**type**\:  :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor>`
                                    
                                    .. attribute:: rpf_nexthop
                                    
                                    	RPF nexthop
                                    	**type**\:  :py:class:`RpfNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop>`
                                    
                                    .. attribute:: rpf_interface_name
                                    
                                    	RPF Interface
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: is_rpf_interface_disabled
                                    
                                    	Is the rpf interface disabled ?
                                    	**type**\: bool
                                    
                                    .. attribute:: is_via_lsm
                                    
                                    	Via LSM
                                    	**type**\: bool
                                    
                                    .. attribute:: is_via_mlsm
                                    
                                    	Via Mstatic LSM
                                    	**type**\: bool
                                    
                                    .. attribute:: is_connector_attribute_present
                                    
                                    	Connector attribute present
                                    	**type**\: bool
                                    
                                    .. attribute:: connector
                                    
                                    	Connector Attribute
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    .. attribute:: extranet_vrf_name
                                    
                                    	Extranet VRF name
                                    	**type**\: str
                                    
                                    	**length:** 0..33
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath, self).__init__()

                                        self.yang_name = "rpf-path"
                                        self.yang_parent_name = "rpf"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("rpf-neighbor", ("rpf_neighbor", Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor)), ("rpf-nexthop", ("rpf_nexthop", Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop))])
                                        self._leafs = OrderedDict([
                                            ('rpf_interface_name', (YLeaf(YType.str, 'rpf-interface-name'), ['str'])),
                                            ('is_rpf_interface_disabled', (YLeaf(YType.boolean, 'is-rpf-interface-disabled'), ['bool'])),
                                            ('is_via_lsm', (YLeaf(YType.boolean, 'is-via-lsm'), ['bool'])),
                                            ('is_via_mlsm', (YLeaf(YType.boolean, 'is-via-mlsm'), ['bool'])),
                                            ('is_connector_attribute_present', (YLeaf(YType.boolean, 'is-connector-attribute-present'), ['bool'])),
                                            ('connector', (YLeaf(YType.str, 'connector'), ['str'])),
                                            ('extranet_vrf_name', (YLeaf(YType.str, 'extranet-vrf-name'), ['str'])),
                                        ])
                                        self.rpf_interface_name = None
                                        self.is_rpf_interface_disabled = None
                                        self.is_via_lsm = None
                                        self.is_via_mlsm = None
                                        self.is_connector_attribute_present = None
                                        self.connector = None
                                        self.extranet_vrf_name = None

                                        self.rpf_neighbor = Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor()
                                        self.rpf_neighbor.parent = self
                                        self._children_name_map["rpf_neighbor"] = "rpf-neighbor"

                                        self.rpf_nexthop = Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop()
                                        self.rpf_nexthop.parent = self
                                        self._children_name_map["rpf_nexthop"] = "rpf-nexthop"
                                        self._segment_path = lambda: "rpf-path"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath, ['rpf_interface_name', 'is_rpf_interface_disabled', 'is_via_lsm', 'is_via_mlsm', 'is_connector_attribute_present', 'connector', 'extranet_vrf_name'], name, value)


                                    class RpfNeighbor(Entity):
                                        """
                                        RPF neighbor
                                        
                                        .. attribute:: af_name
                                        
                                        	AFName
                                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Address
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-pim-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor, self).__init__()

                                            self.yang_name = "rpf-neighbor"
                                            self.yang_parent_name = "rpf-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                            ])
                                            self.af_name = None
                                            self.ipv4_address = None
                                            self.ipv6_address = None
                                            self._segment_path = lambda: "rpf-neighbor"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                                    class RpfNexthop(Entity):
                                        """
                                        RPF nexthop
                                        
                                        .. attribute:: af_name
                                        
                                        	AFName
                                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Address
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-pim-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop, self).__init__()

                                            self.yang_name = "rpf-nexthop"
                                            self.yang_parent_name = "rpf-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                            ])
                                            self.af_name = None
                                            self.ipv4_address = None
                                            self.ipv6_address = None
                                            self._segment_path = lambda: "rpf-nexthop"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class InterfaceStatistics(Entity):
                    """
                    PIM interface statistics
                    
                    .. attribute:: interface_statistic
                    
                    	PIM interface statistics
                    	**type**\: list of  		 :py:class:`InterfaceStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.InterfaceStatistics.InterfaceStatistic>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.InterfaceStatistics, self).__init__()

                        self.yang_name = "interface-statistics"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("interface-statistic", ("interface_statistic", Pim.Active.Vrfs.Vrf.InterfaceStatistics.InterfaceStatistic))])
                        self._leafs = OrderedDict()

                        self.interface_statistic = YList(self)
                        self._segment_path = lambda: "interface-statistics"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.Vrfs.Vrf.InterfaceStatistics, [], name, value)


                    class InterfaceStatistic(Entity):
                        """
                        PIM interface statistics
                        
                        .. attribute:: interface_name  (key)
                        
                        	Interface name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: input_hello
                        
                        	Hello packets in
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_hello
                        
                        	Hello packets out
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_register
                        
                        	Register packets in
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_register
                        
                        	Register packets out
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_register_stop
                        
                        	Register Stop packets in
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_register_stop
                        
                        	Register Stop packets out
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_jp
                        
                        	Join Prune packets in
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_jp
                        
                        	Join Prune packets out
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_bsr_message
                        
                        	Input BSR Messages
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_bsr_message
                        
                        	Output BSR Messages
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_assert
                        
                        	Assert packets in
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_assert
                        
                        	Assert packets out
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_graft_message
                        
                        	Input Graft Messages
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_graft_message
                        
                        	Output Graft Messages
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_graft_ack_message
                        
                        	Input Graft Ack Messages
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_graft_ack_message
                        
                        	Output Graft Ack Messages
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_candidate_rp_advertisement
                        
                        	Input Candidate\-RP Advertisment
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_candidate_rp_advertisement
                        
                        	Output Candidate\-RP Advertisment
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_df_election
                        
                        	DF Election packets in
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_df_election
                        
                        	DF Election packets out
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_miscellaneous
                        
                        	Miscellaneous packet in
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.InterfaceStatistics.InterfaceStatistic, self).__init__()

                            self.yang_name = "interface-statistic"
                            self.yang_parent_name = "interface-statistics"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['interface_name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ('input_hello', (YLeaf(YType.uint32, 'input-hello'), ['int'])),
                                ('output_hello', (YLeaf(YType.uint32, 'output-hello'), ['int'])),
                                ('input_register', (YLeaf(YType.uint32, 'input-register'), ['int'])),
                                ('output_register', (YLeaf(YType.uint32, 'output-register'), ['int'])),
                                ('input_register_stop', (YLeaf(YType.uint32, 'input-register-stop'), ['int'])),
                                ('output_register_stop', (YLeaf(YType.uint32, 'output-register-stop'), ['int'])),
                                ('input_jp', (YLeaf(YType.uint32, 'input-jp'), ['int'])),
                                ('output_jp', (YLeaf(YType.uint32, 'output-jp'), ['int'])),
                                ('input_bsr_message', (YLeaf(YType.uint32, 'input-bsr-message'), ['int'])),
                                ('output_bsr_message', (YLeaf(YType.uint32, 'output-bsr-message'), ['int'])),
                                ('input_assert', (YLeaf(YType.uint32, 'input-assert'), ['int'])),
                                ('output_assert', (YLeaf(YType.uint32, 'output-assert'), ['int'])),
                                ('input_graft_message', (YLeaf(YType.uint32, 'input-graft-message'), ['int'])),
                                ('output_graft_message', (YLeaf(YType.uint32, 'output-graft-message'), ['int'])),
                                ('input_graft_ack_message', (YLeaf(YType.uint32, 'input-graft-ack-message'), ['int'])),
                                ('output_graft_ack_message', (YLeaf(YType.uint32, 'output-graft-ack-message'), ['int'])),
                                ('input_candidate_rp_advertisement', (YLeaf(YType.uint32, 'input-candidate-rp-advertisement'), ['int'])),
                                ('output_candidate_rp_advertisement', (YLeaf(YType.uint32, 'output-candidate-rp-advertisement'), ['int'])),
                                ('input_df_election', (YLeaf(YType.uint32, 'input-df-election'), ['int'])),
                                ('output_df_election', (YLeaf(YType.uint32, 'output-df-election'), ['int'])),
                                ('input_miscellaneous', (YLeaf(YType.uint32, 'input-miscellaneous'), ['int'])),
                            ])
                            self.interface_name = None
                            self.input_hello = None
                            self.output_hello = None
                            self.input_register = None
                            self.output_register = None
                            self.input_register_stop = None
                            self.output_register_stop = None
                            self.input_jp = None
                            self.output_jp = None
                            self.input_bsr_message = None
                            self.output_bsr_message = None
                            self.input_assert = None
                            self.output_assert = None
                            self.input_graft_message = None
                            self.output_graft_message = None
                            self.input_graft_ack_message = None
                            self.output_graft_ack_message = None
                            self.input_candidate_rp_advertisement = None
                            self.output_candidate_rp_advertisement = None
                            self.input_df_election = None
                            self.output_df_election = None
                            self.input_miscellaneous = None
                            self._segment_path = lambda: "interface-statistic" + "[interface-name='" + str(self.interface_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.InterfaceStatistics.InterfaceStatistic, ['interface_name', 'input_hello', 'output_hello', 'input_register', 'output_register', 'input_register_stop', 'output_register_stop', 'input_jp', 'output_jp', 'input_bsr_message', 'output_bsr_message', 'input_assert', 'output_assert', 'input_graft_message', 'output_graft_message', 'input_graft_ack_message', 'output_graft_ack_message', 'input_candidate_rp_advertisement', 'output_candidate_rp_advertisement', 'input_df_election', 'output_df_election', 'input_miscellaneous'], name, value)


                class TopologyRouteCount(Entity):
                    """
                    Topology route count information from PIM
                    topology table
                    
                    .. attribute:: group_ranges
                    
                    	No. of (\*,G/M) routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: active_group_ranges
                    
                    	No. of (\*,G/M) routes active in mrib
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: groute_count
                    
                    	No. of (\*,G) routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sg_route_count
                    
                    	No. of (S,G) routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sgr_route_count
                    
                    	No. of (S,G)RPT routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.TopologyRouteCount, self).__init__()

                        self.yang_name = "topology-route-count"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('group_ranges', (YLeaf(YType.uint32, 'group-ranges'), ['int'])),
                            ('active_group_ranges', (YLeaf(YType.uint32, 'active-group-ranges'), ['int'])),
                            ('groute_count', (YLeaf(YType.uint32, 'groute-count'), ['int'])),
                            ('sg_route_count', (YLeaf(YType.uint32, 'sg-route-count'), ['int'])),
                            ('sgr_route_count', (YLeaf(YType.uint32, 'sgr-route-count'), ['int'])),
                            ('is_node_low_memory', (YLeaf(YType.boolean, 'is-node-low-memory'), ['bool'])),
                        ])
                        self.group_ranges = None
                        self.active_group_ranges = None
                        self.groute_count = None
                        self.sg_route_count = None
                        self.sgr_route_count = None
                        self.is_node_low_memory = None
                        self._segment_path = lambda: "topology-route-count"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.Vrfs.Vrf.TopologyRouteCount, ['group_ranges', 'active_group_ranges', 'groute_count', 'sg_route_count', 'sgr_route_count', 'is_node_low_memory'], name, value)


                class JpStatistics(Entity):
                    """
                    PIM join prune statistics table
                    
                    .. attribute:: jp_statistic
                    
                    	PIM Join Prune Statistics
                    	**type**\: list of  		 :py:class:`JpStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.JpStatistics.JpStatistic>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.JpStatistics, self).__init__()

                        self.yang_name = "jp-statistics"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("jp-statistic", ("jp_statistic", Pim.Active.Vrfs.Vrf.JpStatistics.JpStatistic))])
                        self._leafs = OrderedDict()

                        self.jp_statistic = YList(self)
                        self._segment_path = lambda: "jp-statistics"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.Vrfs.Vrf.JpStatistics, [], name, value)


                    class JpStatistic(Entity):
                        """
                        PIM Join Prune Statistics
                        
                        .. attribute:: interface_name  (key)
                        
                        	Interface name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identifier
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: mtu
                        
                        	Interface MTU
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: transmitted
                        
                        	Transmitted
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: transmitted100
                        
                        	Transmitted 100 average
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: transmitted_1k
                        
                        	Transmitted 1K average
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: transmitted_10k
                        
                        	Transmitted 10K average
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: transmitted_50k
                        
                        	Deprecated by Transmitted100
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: received
                        
                        	Received
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: received100
                        
                        	Received 100 average
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: received_1k
                        
                        	Received 1K average
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: received_10k
                        
                        	Received 10K average
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: received_50k
                        
                        	Deprecated by Received100
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.JpStatistics.JpStatistic, self).__init__()

                            self.yang_name = "jp-statistic"
                            self.yang_parent_name = "jp-statistics"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['interface_name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                                ('mtu', (YLeaf(YType.uint32, 'mtu'), ['int'])),
                                ('transmitted', (YLeaf(YType.uint32, 'transmitted'), ['int'])),
                                ('transmitted100', (YLeaf(YType.uint16, 'transmitted100'), ['int'])),
                                ('transmitted_1k', (YLeaf(YType.uint16, 'transmitted-1k'), ['int'])),
                                ('transmitted_10k', (YLeaf(YType.uint16, 'transmitted-10k'), ['int'])),
                                ('transmitted_50k', (YLeaf(YType.uint16, 'transmitted-50k'), ['int'])),
                                ('received', (YLeaf(YType.uint32, 'received'), ['int'])),
                                ('received100', (YLeaf(YType.uint16, 'received100'), ['int'])),
                                ('received_1k', (YLeaf(YType.uint16, 'received-1k'), ['int'])),
                                ('received_10k', (YLeaf(YType.uint16, 'received-10k'), ['int'])),
                                ('received_50k', (YLeaf(YType.uint16, 'received-50k'), ['int'])),
                            ])
                            self.interface_name = None
                            self.interface_name_xr = None
                            self.mtu = None
                            self.transmitted = None
                            self.transmitted100 = None
                            self.transmitted_1k = None
                            self.transmitted_10k = None
                            self.transmitted_50k = None
                            self.received = None
                            self.received100 = None
                            self.received_1k = None
                            self.received_10k = None
                            self.received_50k = None
                            self._segment_path = lambda: "jp-statistic" + "[interface-name='" + str(self.interface_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.JpStatistics.JpStatistic, ['interface_name', 'interface_name_xr', 'mtu', 'transmitted', 'transmitted100', 'transmitted_1k', 'transmitted_10k', 'transmitted_50k', 'received', 'received100', 'received_1k', 'received_10k', 'received_50k'], name, value)


                class MibDatabases(Entity):
                    """
                    PIM group database for mroute mibs table
                    
                    .. attribute:: mib_database
                    
                    	PIM multicast static route information
                    	**type**\: list of  		 :py:class:`MibDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.MibDatabases, self).__init__()

                        self.yang_name = "mib-databases"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("mib-database", ("mib_database", Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase))])
                        self._leafs = OrderedDict()

                        self.mib_database = YList(self)
                        self._segment_path = lambda: "mib-databases"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.Vrfs.Vrf.MibDatabases, [], name, value)


                    class MibDatabase(Entity):
                        """
                        PIM multicast static route information
                        
                        .. attribute:: source_address
                        
                        	Multicast static route source address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: group_address
                        
                        	Multicast satic route group address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source_netmask
                        
                        	Source mask
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: source_address_xr
                        
                        	Source Address
                        	**type**\:  :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr>`
                        
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:  :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr>`
                        
                        .. attribute:: rpf_neighbor
                        
                        	The RPF Neighbor
                        	**type**\:  :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor>`
                        
                        .. attribute:: rpf_root
                        
                        	Root of this mcast tree
                        	**type**\:  :py:class:`RpfRoot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot>`
                        
                        .. attribute:: upstream_assert_timer
                        
                        	Upstream Assert Timer
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: assert_metric
                        
                        	Assert Metric
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: assert_metric_preference
                        
                        	Assert Metric Preference
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: assert_rpt_bit
                        
                        	Assert RPT Bit
                        	**type**\: bool
                        
                        .. attribute:: spt_bit
                        
                        	Is SPT bit set ?
                        	**type**\: bool
                        
                        .. attribute:: rpf_mask
                        
                        	Mask of the multicast root
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rpf_safi
                        
                        	Unicast or mcast
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: rpf_table_name
                        
                        	RPF Table name
                        	**type**\: str
                        
                        .. attribute:: rpf_drop
                        
                        	RPF route\-policy drop
                        	**type**\: bool
                        
                        .. attribute:: rpf_extranet
                        
                        	Extranet RPF route\-policy
                        	**type**\: bool
                        
                        .. attribute:: rpf_interface_name
                        
                        	RPF interface name 
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: rpf_vrf_name
                        
                        	RPF VRF Name
                        	**type**\: str
                        
                        	**length:** 0..33
                        
                        .. attribute:: bidirectional_route
                        
                        	Is this Bidir ?
                        	**type**\: bool
                        
                        .. attribute:: uptime
                        
                        	Uptime of route
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: protocol
                        
                        	The PIM protocol
                        	**type**\:  :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase, self).__init__()

                            self.yang_name = "mib-database"
                            self.yang_parent_name = "mib-databases"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("source-address-xr", ("source_address_xr", Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr)), ("group-address-xr", ("group_address_xr", Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr)), ("rpf-neighbor", ("rpf_neighbor", Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor)), ("rpf-root", ("rpf_root", Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot))])
                            self._leafs = OrderedDict([
                                ('source_address', (YLeaf(YType.str, 'source-address'), ['str','str'])),
                                ('group_address', (YLeaf(YType.str, 'group-address'), ['str','str'])),
                                ('source_netmask', (YLeaf(YType.uint32, 'source-netmask'), ['int'])),
                                ('upstream_assert_timer', (YLeaf(YType.int32, 'upstream-assert-timer'), ['int'])),
                                ('assert_metric', (YLeaf(YType.uint32, 'assert-metric'), ['int'])),
                                ('assert_metric_preference', (YLeaf(YType.uint32, 'assert-metric-preference'), ['int'])),
                                ('assert_rpt_bit', (YLeaf(YType.boolean, 'assert-rpt-bit'), ['bool'])),
                                ('spt_bit', (YLeaf(YType.boolean, 'spt-bit'), ['bool'])),
                                ('rpf_mask', (YLeaf(YType.uint32, 'rpf-mask'), ['int'])),
                                ('rpf_safi', (YLeaf(YType.uint8, 'rpf-safi'), ['int'])),
                                ('rpf_table_name', (YLeaf(YType.str, 'rpf-table-name'), ['str'])),
                                ('rpf_drop', (YLeaf(YType.boolean, 'rpf-drop'), ['bool'])),
                                ('rpf_extranet', (YLeaf(YType.boolean, 'rpf-extranet'), ['bool'])),
                                ('rpf_interface_name', (YLeaf(YType.str, 'rpf-interface-name'), ['str'])),
                                ('rpf_vrf_name', (YLeaf(YType.str, 'rpf-vrf-name'), ['str'])),
                                ('bidirectional_route', (YLeaf(YType.boolean, 'bidirectional-route'), ['bool'])),
                                ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                                ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowProtocol', '')])),
                            ])
                            self.source_address = None
                            self.group_address = None
                            self.source_netmask = None
                            self.upstream_assert_timer = None
                            self.assert_metric = None
                            self.assert_metric_preference = None
                            self.assert_rpt_bit = None
                            self.spt_bit = None
                            self.rpf_mask = None
                            self.rpf_safi = None
                            self.rpf_table_name = None
                            self.rpf_drop = None
                            self.rpf_extranet = None
                            self.rpf_interface_name = None
                            self.rpf_vrf_name = None
                            self.bidirectional_route = None
                            self.uptime = None
                            self.protocol = None

                            self.source_address_xr = Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr()
                            self.source_address_xr.parent = self
                            self._children_name_map["source_address_xr"] = "source-address-xr"

                            self.group_address_xr = Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"

                            self.rpf_neighbor = Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor()
                            self.rpf_neighbor.parent = self
                            self._children_name_map["rpf_neighbor"] = "rpf-neighbor"

                            self.rpf_root = Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot()
                            self.rpf_root.parent = self
                            self._children_name_map["rpf_root"] = "rpf-root"
                            self._segment_path = lambda: "mib-database"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase, ['source_address', 'group_address', 'source_netmask', 'upstream_assert_timer', 'assert_metric', 'assert_metric_preference', 'assert_rpt_bit', 'spt_bit', 'rpf_mask', 'rpf_safi', 'rpf_table_name', 'rpf_drop', 'rpf_extranet', 'rpf_interface_name', 'rpf_vrf_name', 'bidirectional_route', 'uptime', 'protocol'], name, value)


                        class SourceAddressXr(Entity):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr, self).__init__()

                                self.yang_name = "source-address-xr"
                                self.yang_parent_name = "mib-database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "source-address-xr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "mib-database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "group-address-xr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class RpfNeighbor(Entity):
                            """
                            The RPF Neighbor
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor, self).__init__()

                                self.yang_name = "rpf-neighbor"
                                self.yang_parent_name = "mib-database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "rpf-neighbor"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class RpfRoot(Entity):
                            """
                            Root of this mcast tree
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot, self).__init__()

                                self.yang_name = "rpf-root"
                                self.yang_parent_name = "mib-database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "rpf-root"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class NeighborOldFormats(Entity):
                    """
                    PIM neighbor table old format
                    
                    .. attribute:: neighbor_old_format
                    
                    	PIM neighbor information
                    	**type**\: list of  		 :py:class:`NeighborOldFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.NeighborOldFormats, self).__init__()

                        self.yang_name = "neighbor-old-formats"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("neighbor-old-format", ("neighbor_old_format", Pim.Active.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat))])
                        self._leafs = OrderedDict()

                        self.neighbor_old_format = YList(self)
                        self._segment_path = lambda: "neighbor-old-formats"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.Vrfs.Vrf.NeighborOldFormats, [], name, value)


                    class NeighborOldFormat(Entity):
                        """
                        PIM neighbor information
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: neighbor_address
                        
                        	Neighbor address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identifier
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: expires
                        
                        	Neighbor expiry in seconds
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: expiry_timer
                        
                        	Expiry timer in seconds
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: is_this_neighbor_us
                        
                        	Is this neighbor us ?
                        	**type**\: bool
                        
                        .. attribute:: is_this_neighbor_dr
                        
                        	Is this neighbor the DR
                        	**type**\: bool
                        
                        .. attribute:: is_dr_priority_capable
                        
                        	Is this neighbor DR priority capable ?
                        	**type**\: bool
                        
                        .. attribute:: dr_priority
                        
                        	DR priority
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Is this neighbor bidir capable ?
                        	**type**\: bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Is this neighbor proxy capable?
                        	**type**\: bool
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Is this neighbor capable of batching asserts?
                        	**type**\: bool
                        
                        .. attribute:: is_ecmp_redirect_capable
                        
                        	Is this neighbor capable of Ecmp Redirect?
                        	**type**\: bool
                        
                        .. attribute:: is_bfd_state
                        
                        	Is the neighbor bfd session created
                        	**type**\: bool
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_address_xr
                        
                        	List of Neighbor Addresses
                        	**type**\: list of  		 :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat, self).__init__()

                            self.yang_name = "neighbor-old-format"
                            self.yang_parent_name = "neighbor-old-formats"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("neighbor-address-xr", ("neighbor_address_xr", Pim.Active.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr))])
                            self._leafs = OrderedDict([
                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                                ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                                ('expires', (YLeaf(YType.uint64, 'expires'), ['int'])),
                                ('expiry_timer', (YLeaf(YType.uint64, 'expiry-timer'), ['int'])),
                                ('is_this_neighbor_us', (YLeaf(YType.boolean, 'is-this-neighbor-us'), ['bool'])),
                                ('is_this_neighbor_dr', (YLeaf(YType.boolean, 'is-this-neighbor-dr'), ['bool'])),
                                ('is_dr_priority_capable', (YLeaf(YType.boolean, 'is-dr-priority-capable'), ['bool'])),
                                ('dr_priority', (YLeaf(YType.uint32, 'dr-priority'), ['int'])),
                                ('is_bidirectional_capable', (YLeaf(YType.boolean, 'is-bidirectional-capable'), ['bool'])),
                                ('is_proxy_capable', (YLeaf(YType.boolean, 'is-proxy-capable'), ['bool'])),
                                ('is_batch_asserts_capable', (YLeaf(YType.boolean, 'is-batch-asserts-capable'), ['bool'])),
                                ('is_ecmp_redirect_capable', (YLeaf(YType.boolean, 'is-ecmp-redirect-capable'), ['bool'])),
                                ('is_bfd_state', (YLeaf(YType.boolean, 'is-bfd-state'), ['bool'])),
                                ('propagation_delay', (YLeaf(YType.uint16, 'propagation-delay'), ['int'])),
                                ('override_interval', (YLeaf(YType.uint16, 'override-interval'), ['int'])),
                            ])
                            self.interface_name = None
                            self.neighbor_address = None
                            self.interface_name_xr = None
                            self.uptime = None
                            self.expires = None
                            self.expiry_timer = None
                            self.is_this_neighbor_us = None
                            self.is_this_neighbor_dr = None
                            self.is_dr_priority_capable = None
                            self.dr_priority = None
                            self.is_bidirectional_capable = None
                            self.is_proxy_capable = None
                            self.is_batch_asserts_capable = None
                            self.is_ecmp_redirect_capable = None
                            self.is_bfd_state = None
                            self.propagation_delay = None
                            self.override_interval = None

                            self.neighbor_address_xr = YList(self)
                            self._segment_path = lambda: "neighbor-old-format"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat, ['interface_name', 'neighbor_address', 'interface_name_xr', 'uptime', 'expires', 'expiry_timer', 'is_this_neighbor_us', 'is_this_neighbor_dr', 'is_dr_priority_capable', 'dr_priority', 'is_bidirectional_capable', 'is_proxy_capable', 'is_batch_asserts_capable', 'is_ecmp_redirect_capable', 'is_bfd_state', 'propagation_delay', 'override_interval'], name, value)


                        class NeighborAddressXr(Entity):
                            """
                            List of Neighbor Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr, self).__init__()

                                self.yang_name = "neighbor-address-xr"
                                self.yang_parent_name = "neighbor-old-format"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "neighbor-address-xr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class IfrsSummary(Entity):
                    """
                    PIM interfaces in forward reference store
                    summary
                    
                    .. attribute:: interface_count
                    
                    	Number of interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: configuration_count
                    
                    	Configuration counts
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.IfrsSummary, self).__init__()

                        self.yang_name = "ifrs-summary"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('interface_count', (YLeaf(YType.uint32, 'interface-count'), ['int'])),
                            ('configuration_count', (YLeaf(YType.uint32, 'configuration-count'), ['int'])),
                        ])
                        self.interface_count = None
                        self.configuration_count = None
                        self._segment_path = lambda: "ifrs-summary"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.Vrfs.Vrf.IfrsSummary, ['interface_count', 'configuration_count'], name, value)


                class Ranges(Entity):
                    """
                    PIM range list information
                    
                    .. attribute:: range
                    
                    	PIM range list information
                    	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Ranges.Range>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.Ranges, self).__init__()

                        self.yang_name = "ranges"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("range", ("range", Pim.Active.Vrfs.Vrf.Ranges.Range))])
                        self._leafs = OrderedDict()

                        self.range = YList(self)
                        self._segment_path = lambda: "ranges"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.Vrfs.Vrf.Ranges, [], name, value)


                    class Range(Entity):
                        """
                        PIM range list information
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: client
                        
                        	Client
                        	**type**\:  :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                        
                        .. attribute:: rp_address_xr
                        
                        	Rendezvous point address
                        	**type**\:  :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Ranges.Range.RpAddressXr>`
                        
                        .. attribute:: source_of_information
                        
                        	Source of information
                        	**type**\:  :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Ranges.Range.SourceOfInformation>`
                        
                        .. attribute:: protocol
                        
                        	PIM protocol
                        	**type**\:  :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: client_xr
                        
                        	Client mapping learnt via
                        	**type**\:  :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                        
                        .. attribute:: expires
                        
                        	When mapping expires
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: group_range
                        
                        	List of group ranges
                        	**type**\: list of  		 :py:class:`GroupRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.Ranges.Range, self).__init__()

                            self.yang_name = "range"
                            self.yang_parent_name = "ranges"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rp-address-xr", ("rp_address_xr", Pim.Active.Vrfs.Vrf.Ranges.Range.RpAddressXr)), ("source-of-information", ("source_of_information", Pim.Active.Vrfs.Vrf.Ranges.Range.SourceOfInformation)), ("group-range", ("group_range", Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange))])
                            self._leafs = OrderedDict([
                                ('rp_address', (YLeaf(YType.str, 'rp-address'), ['str','str'])),
                                ('client', (YLeaf(YType.enumeration, 'client'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimClient', '')])),
                                ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowProtocol', '')])),
                                ('client_xr', (YLeaf(YType.enumeration, 'client-xr'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowRangeClient', '')])),
                                ('expires', (YLeaf(YType.uint64, 'expires'), ['int'])),
                            ])
                            self.rp_address = None
                            self.client = None
                            self.protocol = None
                            self.client_xr = None
                            self.expires = None

                            self.rp_address_xr = Pim.Active.Vrfs.Vrf.Ranges.Range.RpAddressXr()
                            self.rp_address_xr.parent = self
                            self._children_name_map["rp_address_xr"] = "rp-address-xr"

                            self.source_of_information = Pim.Active.Vrfs.Vrf.Ranges.Range.SourceOfInformation()
                            self.source_of_information.parent = self
                            self._children_name_map["source_of_information"] = "source-of-information"

                            self.group_range = YList(self)
                            self._segment_path = lambda: "range"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.Ranges.Range, ['rp_address', 'client', 'protocol', 'client_xr', 'expires'], name, value)


                        class RpAddressXr(Entity):
                            """
                            Rendezvous point address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Ranges.Range.RpAddressXr, self).__init__()

                                self.yang_name = "rp-address-xr"
                                self.yang_parent_name = "range"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "rp-address-xr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.Ranges.Range.RpAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class SourceOfInformation(Entity):
                            """
                            Source of information
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Ranges.Range.SourceOfInformation, self).__init__()

                                self.yang_name = "source-of-information"
                                self.yang_parent_name = "range"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "source-of-information"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.Ranges.Range.SourceOfInformation, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class GroupRange(Entity):
                            """
                            List of group ranges
                            
                            .. attribute:: prefix
                            
                            	Group range prefix
                            	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix>`
                            
                            .. attribute:: source_of_information
                            
                            	Source of information
                            	**type**\:  :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation>`
                            
                            .. attribute:: prefix_length
                            
                            	Group range prefix length
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: expires
                            
                            	When mapping expires
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange, self).__init__()

                                self.yang_name = "group-range"
                                self.yang_parent_name = "range"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("prefix", ("prefix", Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix)), ("source-of-information", ("source_of_information", Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation))])
                                self._leafs = OrderedDict([
                                    ('prefix_length', (YLeaf(YType.int32, 'prefix-length'), ['int'])),
                                    ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                                    ('expires', (YLeaf(YType.uint64, 'expires'), ['int'])),
                                ])
                                self.prefix_length = None
                                self.uptime = None
                                self.expires = None

                                self.prefix = Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix()
                                self.prefix.parent = self
                                self._children_name_map["prefix"] = "prefix"

                                self.source_of_information = Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation()
                                self.source_of_information.parent = self
                                self._children_name_map["source_of_information"] = "source-of-information"
                                self._segment_path = lambda: "group-range"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange, ['prefix_length', 'uptime', 'expires'], name, value)


                            class Prefix(Entity):
                                """
                                Group range prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix, self).__init__()

                                    self.yang_name = "prefix"
                                    self.yang_parent_name = "group-range"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "prefix"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                            class SourceOfInformation(Entity):
                                """
                                Source of information
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation, self).__init__()

                                    self.yang_name = "source-of-information"
                                    self.yang_parent_name = "group-range"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "source-of-information"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class InterfaceOldFormats(Entity):
                    """
                    PIM interfaces in old format
                    
                    .. attribute:: interface_old_format
                    
                    	PIM interface name
                    	**type**\: list of  		 :py:class:`InterfaceOldFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.InterfaceOldFormats, self).__init__()

                        self.yang_name = "interface-old-formats"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("interface-old-format", ("interface_old_format", Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat))])
                        self._leafs = OrderedDict()

                        self.interface_old_format = YList(self)
                        self._segment_path = lambda: "interface-old-formats"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.Vrfs.Vrf.InterfaceOldFormats, [], name, value)


                    class InterfaceOldFormat(Entity):
                        """
                        PIM interface name
                        
                        .. attribute:: interface_name  (key)
                        
                        	Interface name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: dr_address
                        
                        	PIM Designated Router
                        	**type**\:  :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress>`
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identfier
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: interface_address_mask
                        
                        	Interface IP Address Mask
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: is_enabled
                        
                        	Is PIM enabled on this IF ?
                        	**type**\: bool
                        
                        .. attribute:: neighbor_count
                        
                        	No. of neighbors on this IF
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: external_neighbor_count
                        
                        	No. of external neighbors on this IF
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: hello_interval
                        
                        	Hello Interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: dr_priority
                        
                        	DR Priority
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: hello_expiry
                        
                        	Hello Timer Expiry
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: are_we_dr
                        
                        	Are we the DR on this IF ?
                        	**type**\: bool
                        
                        .. attribute:: bfd_enabled
                        
                        	BFD state
                        	**type**\: bool
                        
                        .. attribute:: bfd_interval
                        
                        	BFD Interval
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bfd_multiplier
                        
                        	BFD Multiplier
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_interface
                        
                        	 is this a Virtual Interfaces ?
                        	**type**\: bool
                        
                        .. attribute:: passive_interface
                        
                        	Passive PIM interface
                        	**type**\: bool
                        
                        .. attribute:: neighbor_filter_name
                        
                        	Neighbor Filter Name
                        	**type**\: str
                        
                        .. attribute:: join_prune_interval
                        
                        	Join\-Prune Interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: prune_delay_enabled
                        
                        	Prune Delay Enabled
                        	**type**\: bool
                        
                        .. attribute:: configured_propagation_delay
                        
                        	Configured Propagation Delay
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: configured_override_interval
                        
                        	Configured Override Interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: generation_id
                        
                        	Generation Identifier
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Bidir Capable
                        	**type**\: bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Proxy Capable
                        	**type**\: bool
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Batch Asserts Capable
                        	**type**\: bool
                        
                        .. attribute:: idb_oor_enabled
                        
                        	Interface oor enabled
                        	**type**\: bool
                        
                        .. attribute:: idb_acl_provided
                        
                        	ACL name provided
                        	**type**\: bool
                        
                        .. attribute:: idb_max_count
                        
                        	Interface ole max count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_threshold_count
                        
                        	Interface ole threshold count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_current_count
                        
                        	Interface ole current count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_acl_name
                        
                        	Interface ole ACL Name
                        	**type**\: str
                        
                        	**length:** 0..64
                        
                        .. attribute:: interface_address
                        
                        	List of Interface IP Addresses
                        	**type**\: list of  		 :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat, self).__init__()

                            self.yang_name = "interface-old-format"
                            self.yang_parent_name = "interface-old-formats"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['interface_name']
                            self._child_classes = OrderedDict([("dr-address", ("dr_address", Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress)), ("interface-address", ("interface_address", Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress))])
                            self._leafs = OrderedDict([
                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                                ('interface_address_mask', (YLeaf(YType.uint8, 'interface-address-mask'), ['int'])),
                                ('is_enabled', (YLeaf(YType.boolean, 'is-enabled'), ['bool'])),
                                ('neighbor_count', (YLeaf(YType.uint16, 'neighbor-count'), ['int'])),
                                ('external_neighbor_count', (YLeaf(YType.uint16, 'external-neighbor-count'), ['int'])),
                                ('hello_interval', (YLeaf(YType.uint16, 'hello-interval'), ['int'])),
                                ('dr_priority', (YLeaf(YType.uint32, 'dr-priority'), ['int'])),
                                ('hello_expiry', (YLeaf(YType.uint64, 'hello-expiry'), ['int'])),
                                ('are_we_dr', (YLeaf(YType.boolean, 'are-we-dr'), ['bool'])),
                                ('bfd_enabled', (YLeaf(YType.boolean, 'bfd-enabled'), ['bool'])),
                                ('bfd_interval', (YLeaf(YType.uint32, 'bfd-interval'), ['int'])),
                                ('bfd_multiplier', (YLeaf(YType.uint32, 'bfd-multiplier'), ['int'])),
                                ('virtual_interface', (YLeaf(YType.boolean, 'virtual-interface'), ['bool'])),
                                ('passive_interface', (YLeaf(YType.boolean, 'passive-interface'), ['bool'])),
                                ('neighbor_filter_name', (YLeaf(YType.str, 'neighbor-filter-name'), ['str'])),
                                ('join_prune_interval', (YLeaf(YType.uint16, 'join-prune-interval'), ['int'])),
                                ('prune_delay_enabled', (YLeaf(YType.boolean, 'prune-delay-enabled'), ['bool'])),
                                ('configured_propagation_delay', (YLeaf(YType.uint16, 'configured-propagation-delay'), ['int'])),
                                ('propagation_delay', (YLeaf(YType.uint16, 'propagation-delay'), ['int'])),
                                ('configured_override_interval', (YLeaf(YType.uint16, 'configured-override-interval'), ['int'])),
                                ('override_interval', (YLeaf(YType.uint16, 'override-interval'), ['int'])),
                                ('generation_id', (YLeaf(YType.uint32, 'generation-id'), ['int'])),
                                ('is_bidirectional_capable', (YLeaf(YType.boolean, 'is-bidirectional-capable'), ['bool'])),
                                ('is_proxy_capable', (YLeaf(YType.boolean, 'is-proxy-capable'), ['bool'])),
                                ('is_batch_asserts_capable', (YLeaf(YType.boolean, 'is-batch-asserts-capable'), ['bool'])),
                                ('idb_oor_enabled', (YLeaf(YType.boolean, 'idb-oor-enabled'), ['bool'])),
                                ('idb_acl_provided', (YLeaf(YType.boolean, 'idb-acl-provided'), ['bool'])),
                                ('idb_max_count', (YLeaf(YType.uint32, 'idb-max-count'), ['int'])),
                                ('idb_threshold_count', (YLeaf(YType.uint32, 'idb-threshold-count'), ['int'])),
                                ('idb_current_count', (YLeaf(YType.uint32, 'idb-current-count'), ['int'])),
                                ('idb_acl_name', (YLeaf(YType.str, 'idb-acl-name'), ['str'])),
                            ])
                            self.interface_name = None
                            self.interface_name_xr = None
                            self.interface_address_mask = None
                            self.is_enabled = None
                            self.neighbor_count = None
                            self.external_neighbor_count = None
                            self.hello_interval = None
                            self.dr_priority = None
                            self.hello_expiry = None
                            self.are_we_dr = None
                            self.bfd_enabled = None
                            self.bfd_interval = None
                            self.bfd_multiplier = None
                            self.virtual_interface = None
                            self.passive_interface = None
                            self.neighbor_filter_name = None
                            self.join_prune_interval = None
                            self.prune_delay_enabled = None
                            self.configured_propagation_delay = None
                            self.propagation_delay = None
                            self.configured_override_interval = None
                            self.override_interval = None
                            self.generation_id = None
                            self.is_bidirectional_capable = None
                            self.is_proxy_capable = None
                            self.is_batch_asserts_capable = None
                            self.idb_oor_enabled = None
                            self.idb_acl_provided = None
                            self.idb_max_count = None
                            self.idb_threshold_count = None
                            self.idb_current_count = None
                            self.idb_acl_name = None

                            self.dr_address = Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress()
                            self.dr_address.parent = self
                            self._children_name_map["dr_address"] = "dr-address"

                            self.interface_address = YList(self)
                            self._segment_path = lambda: "interface-old-format" + "[interface-name='" + str(self.interface_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat, ['interface_name', 'interface_name_xr', 'interface_address_mask', 'is_enabled', 'neighbor_count', 'external_neighbor_count', 'hello_interval', 'dr_priority', 'hello_expiry', 'are_we_dr', 'bfd_enabled', 'bfd_interval', 'bfd_multiplier', 'virtual_interface', 'passive_interface', 'neighbor_filter_name', 'join_prune_interval', 'prune_delay_enabled', 'configured_propagation_delay', 'propagation_delay', 'configured_override_interval', 'override_interval', 'generation_id', 'is_bidirectional_capable', 'is_proxy_capable', 'is_batch_asserts_capable', 'idb_oor_enabled', 'idb_acl_provided', 'idb_max_count', 'idb_threshold_count', 'idb_current_count', 'idb_acl_name'], name, value)


                        class DrAddress(Entity):
                            """
                            PIM Designated Router
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress, self).__init__()

                                self.yang_name = "dr-address"
                                self.yang_parent_name = "interface-old-format"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "dr-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class InterfaceAddress(Entity):
                            """
                            List of Interface IP Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress, self).__init__()

                                self.yang_name = "interface-address"
                                self.yang_parent_name = "interface-old-format"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "interface-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class Bsr(Entity):
                    """
                    PIM BSR information
                    
                    .. attribute:: rp_caches
                    
                    	PIM BSR RP cache table
                    	**type**\:  :py:class:`RpCaches <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Bsr.RpCaches>`
                    
                    .. attribute:: candidate_rps
                    
                    	PIM candidate\-RP
                    	**type**\:  :py:class:`CandidateRps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Bsr.CandidateRps>`
                    
                    .. attribute:: bsr_elections
                    
                    	PIM BSR election state
                    	**type**\:  :py:class:`BsrElections <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Bsr.BsrElections>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.Bsr, self).__init__()

                        self.yang_name = "bsr"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("rp-caches", ("rp_caches", Pim.Active.Vrfs.Vrf.Bsr.RpCaches)), ("candidate-rps", ("candidate_rps", Pim.Active.Vrfs.Vrf.Bsr.CandidateRps)), ("bsr-elections", ("bsr_elections", Pim.Active.Vrfs.Vrf.Bsr.BsrElections))])
                        self._leafs = OrderedDict()

                        self.rp_caches = Pim.Active.Vrfs.Vrf.Bsr.RpCaches()
                        self.rp_caches.parent = self
                        self._children_name_map["rp_caches"] = "rp-caches"

                        self.candidate_rps = Pim.Active.Vrfs.Vrf.Bsr.CandidateRps()
                        self.candidate_rps.parent = self
                        self._children_name_map["candidate_rps"] = "candidate-rps"

                        self.bsr_elections = Pim.Active.Vrfs.Vrf.Bsr.BsrElections()
                        self.bsr_elections.parent = self
                        self._children_name_map["bsr_elections"] = "bsr-elections"
                        self._segment_path = lambda: "bsr"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.Vrfs.Vrf.Bsr, [], name, value)


                    class RpCaches(Entity):
                        """
                        PIM BSR RP cache table
                        
                        .. attribute:: rp_cache
                        
                        	PIM BSR RP cache
                        	**type**\: list of  		 :py:class:`RpCache <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.Bsr.RpCaches, self).__init__()

                            self.yang_name = "rp-caches"
                            self.yang_parent_name = "bsr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rp-cache", ("rp_cache", Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache))])
                            self._leafs = OrderedDict()

                            self.rp_cache = YList(self)
                            self._segment_path = lambda: "rp-caches"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.Bsr.RpCaches, [], name, value)


                        class RpCache(Entity):
                            """
                            PIM BSR RP cache
                            
                            .. attribute:: group_prefix  (key)
                            
                            	Group prefix
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: group_prefix_xr
                            
                            	Group Prefix
                            	**type**\:  :py:class:`GroupPrefixXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr>`
                            
                            .. attribute:: candidate_rp_list
                            
                            	C\-RP list for this prefix
                            	**type**\:  :py:class:`CandidateRpList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList>`
                            
                            .. attribute:: group_prefix_length
                            
                            	Group Prefix Length
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: candidate_rp_group_count
                            
                            	C\-RP count for this Prefix
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache, self).__init__()

                                self.yang_name = "rp-cache"
                                self.yang_parent_name = "rp-caches"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['group_prefix']
                                self._child_classes = OrderedDict([("group-prefix-xr", ("group_prefix_xr", Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr)), ("candidate-rp-list", ("candidate_rp_list", Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList))])
                                self._leafs = OrderedDict([
                                    ('group_prefix', (YLeaf(YType.str, 'group-prefix'), ['str','str'])),
                                    ('group_prefix_length', (YLeaf(YType.uint32, 'group-prefix-length'), ['int'])),
                                    ('candidate_rp_group_count', (YLeaf(YType.uint32, 'candidate-rp-group-count'), ['int'])),
                                ])
                                self.group_prefix = None
                                self.group_prefix_length = None
                                self.candidate_rp_group_count = None

                                self.group_prefix_xr = Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr()
                                self.group_prefix_xr.parent = self
                                self._children_name_map["group_prefix_xr"] = "group-prefix-xr"

                                self.candidate_rp_list = Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList()
                                self.candidate_rp_list.parent = self
                                self._children_name_map["candidate_rp_list"] = "candidate-rp-list"
                                self._segment_path = lambda: "rp-cache" + "[group-prefix='" + str(self.group_prefix) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache, ['group_prefix', 'group_prefix_length', 'candidate_rp_group_count'], name, value)


                            class GroupPrefixXr(Entity):
                                """
                                Group Prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr, self).__init__()

                                    self.yang_name = "group-prefix-xr"
                                    self.yang_parent_name = "rp-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "group-prefix-xr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                            class CandidateRpList(Entity):
                                """
                                C\-RP list for this prefix
                                
                                .. attribute:: pim_bsr_crp_bag
                                
                                	pim bsr crp bag
                                	**type**\: list of  		 :py:class:`PimBsrCrpBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList, self).__init__()

                                    self.yang_name = "candidate-rp-list"
                                    self.yang_parent_name = "rp-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("pim-bsr-crp-bag", ("pim_bsr_crp_bag", Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag))])
                                    self._leafs = OrderedDict()

                                    self.pim_bsr_crp_bag = YList(self)
                                    self._segment_path = lambda: "candidate-rp-list"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList, [], name, value)


                                class PimBsrCrpBag(Entity):
                                    """
                                    pim bsr crp bag
                                    
                                    .. attribute:: candidate_rp_address
                                    
                                    	C\-RP address
                                    	**type**\:  :py:class:`CandidateRpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress>`
                                    
                                    .. attribute:: candidate_rp_holdtime
                                    
                                    	C\-RP Holdtime
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: candidate_rp_priority
                                    
                                    	C\-RP Priority
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: candidate_rp_up_time
                                    
                                    	C\-RP Uptime
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: candidate_rp_expires
                                    
                                    	C\-RP Expires
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: protocol
                                    
                                    	PIM Protocol
                                    	**type**\:  :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag, self).__init__()

                                        self.yang_name = "pim-bsr-crp-bag"
                                        self.yang_parent_name = "candidate-rp-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("candidate-rp-address", ("candidate_rp_address", Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress))])
                                        self._leafs = OrderedDict([
                                            ('candidate_rp_holdtime', (YLeaf(YType.uint16, 'candidate-rp-holdtime'), ['int'])),
                                            ('candidate_rp_priority', (YLeaf(YType.uint8, 'candidate-rp-priority'), ['int'])),
                                            ('candidate_rp_up_time', (YLeaf(YType.uint16, 'candidate-rp-up-time'), ['int'])),
                                            ('candidate_rp_expires', (YLeaf(YType.uint16, 'candidate-rp-expires'), ['int'])),
                                            ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowProtocol', '')])),
                                        ])
                                        self.candidate_rp_holdtime = None
                                        self.candidate_rp_priority = None
                                        self.candidate_rp_up_time = None
                                        self.candidate_rp_expires = None
                                        self.protocol = None

                                        self.candidate_rp_address = Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress()
                                        self.candidate_rp_address.parent = self
                                        self._children_name_map["candidate_rp_address"] = "candidate-rp-address"
                                        self._segment_path = lambda: "pim-bsr-crp-bag"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag, ['candidate_rp_holdtime', 'candidate_rp_priority', 'candidate_rp_up_time', 'candidate_rp_expires', 'protocol'], name, value)


                                    class CandidateRpAddress(Entity):
                                        """
                                        C\-RP address
                                        
                                        .. attribute:: af_name
                                        
                                        	AFName
                                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Address
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-pim-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress, self).__init__()

                                            self.yang_name = "candidate-rp-address"
                                            self.yang_parent_name = "pim-bsr-crp-bag"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                            ])
                                            self.af_name = None
                                            self.ipv4_address = None
                                            self.ipv6_address = None
                                            self._segment_path = lambda: "candidate-rp-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class CandidateRps(Entity):
                        """
                        PIM candidate\-RP
                        
                        .. attribute:: candidate_rp
                        
                        	PIM BSR candidate RP information
                        	**type**\: list of  		 :py:class:`CandidateRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.Bsr.CandidateRps, self).__init__()

                            self.yang_name = "candidate-rps"
                            self.yang_parent_name = "bsr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("candidate-rp", ("candidate_rp", Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp))])
                            self._leafs = OrderedDict()

                            self.candidate_rp = YList(self)
                            self._segment_path = lambda: "candidate-rps"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.Bsr.CandidateRps, [], name, value)


                        class CandidateRp(Entity):
                            """
                            PIM BSR candidate RP information
                            
                            .. attribute:: rp_address  (key)
                            
                            	Candidate\-RP address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: candidate_rp
                            
                            	Cand\-RP Address
                            	**type**\:  :py:class:`CandidateRp_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp_>`
                            
                            .. attribute:: candidate_rp_mode
                            
                            	Cand\-RP Mode
                            	**type**\:  :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                            
                            .. attribute:: candidate_rp_scope
                            
                            	Cand\-RP Scope
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: crp_priority
                            
                            	Cand\-RP Priority
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: crp_holdtime
                            
                            	Cand\-RP Holdtime
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: candidate_rp_advance_interval
                            
                            	Cand\-RP Adv Interval in seconds
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: candidate_rp_uptime
                            
                            	Cand\-RP uptime
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: acl_name
                            
                            	Group Access\-List Name
                            	**type**\: str
                            
                            	**length:** 0..33
                            
                            .. attribute:: crp_access
                            
                            	Group Ranges Using this Cand\-RP
                            	**type**\: list of  		 :py:class:`CrpAccess <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CrpAccess>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp, self).__init__()

                                self.yang_name = "candidate-rp"
                                self.yang_parent_name = "candidate-rps"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['rp_address']
                                self._child_classes = OrderedDict([("candidate-rp", ("candidate_rp", Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp_)), ("crp-access", ("crp_access", Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CrpAccess))])
                                self._leafs = OrderedDict([
                                    ('rp_address', (YLeaf(YType.str, 'rp-address'), ['str','str'])),
                                    ('candidate_rp_mode', (YLeaf(YType.enumeration, 'candidate-rp-mode'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowProtocol', '')])),
                                    ('candidate_rp_scope', (YLeaf(YType.int32, 'candidate-rp-scope'), ['int'])),
                                    ('crp_priority', (YLeaf(YType.uint8, 'crp-priority'), ['int'])),
                                    ('crp_holdtime', (YLeaf(YType.uint16, 'crp-holdtime'), ['int'])),
                                    ('candidate_rp_advance_interval', (YLeaf(YType.uint16, 'candidate-rp-advance-interval'), ['int'])),
                                    ('candidate_rp_uptime', (YLeaf(YType.uint16, 'candidate-rp-uptime'), ['int'])),
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                                ])
                                self.rp_address = None
                                self.candidate_rp_mode = None
                                self.candidate_rp_scope = None
                                self.crp_priority = None
                                self.crp_holdtime = None
                                self.candidate_rp_advance_interval = None
                                self.candidate_rp_uptime = None
                                self.acl_name = None

                                self.candidate_rp = Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp_()
                                self.candidate_rp.parent = self
                                self._children_name_map["candidate_rp"] = "candidate-rp"

                                self.crp_access = YList(self)
                                self._segment_path = lambda: "candidate-rp" + "[rp-address='" + str(self.rp_address) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp, ['rp_address', 'candidate_rp_mode', 'candidate_rp_scope', 'crp_priority', 'crp_holdtime', 'candidate_rp_advance_interval', 'candidate_rp_uptime', 'acl_name'], name, value)


                            class CandidateRp_(Entity):
                                """
                                Cand\-RP Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp_, self).__init__()

                                    self.yang_name = "candidate-rp"
                                    self.yang_parent_name = "candidate-rp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "candidate-rp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp_, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                            class CrpAccess(Entity):
                                """
                                Group Ranges Using this Cand\-RP
                                
                                .. attribute:: candidate_rp_mode
                                
                                	Cand\-RP Mode
                                	**type**\:  :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                                
                                .. attribute:: acl_name
                                
                                	Group Access\-List Name
                                	**type**\: str
                                
                                	**length:** 0..33
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CrpAccess, self).__init__()

                                    self.yang_name = "crp-access"
                                    self.yang_parent_name = "candidate-rp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('candidate_rp_mode', (YLeaf(YType.enumeration, 'candidate-rp-mode'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowProtocol', '')])),
                                        ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                                    ])
                                    self.candidate_rp_mode = None
                                    self.acl_name = None
                                    self._segment_path = lambda: "crp-access"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CrpAccess, ['candidate_rp_mode', 'acl_name'], name, value)


                    class BsrElections(Entity):
                        """
                        PIM BSR election state
                        
                        .. attribute:: bsr_election
                        
                        	PIM BSR information
                        	**type**\: list of  		 :py:class:`BsrElection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.Bsr.BsrElections, self).__init__()

                            self.yang_name = "bsr-elections"
                            self.yang_parent_name = "bsr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("bsr-election", ("bsr_election", Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection))])
                            self._leafs = OrderedDict()

                            self.bsr_election = YList(self)
                            self._segment_path = lambda: "bsr-elections"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.Bsr.BsrElections, [], name, value)


                        class BsrElection(Entity):
                            """
                            PIM BSR information
                            
                            .. attribute:: pim_scope  (key)
                            
                            	BSR information
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bsr_address
                            
                            	BSR address
                            	**type**\:  :py:class:`BsrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress>`
                            
                            .. attribute:: candidate_bsr_address
                            
                            	C\-BSR address
                            	**type**\:  :py:class:`CandidateBsrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress>`
                            
                            .. attribute:: bsr_priority
                            
                            	BSR Priority
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: bsr_mask_length
                            
                            	Hash Function Mask Length
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: bsr_up_time
                            
                            	BSR Uptime
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: bootstrap_timeout
                            
                            	Bootstrap Timeout
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: candidate_bsr_state
                            
                            	BSR Candidate State
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bsr_election_state
                            
                            	BSR Election State
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bsr_scope
                            
                            	BSR Scope
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: candidate_bsr_flag
                            
                            	BSR Candidate Config Flag
                            	**type**\: bool
                            
                            .. attribute:: candidate_bsr_priority
                            
                            	C\-BSR Priority
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: candidate_bsr_mask_length
                            
                            	C\-BSR Hash Func. Mask Len
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection, self).__init__()

                                self.yang_name = "bsr-election"
                                self.yang_parent_name = "bsr-elections"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['pim_scope']
                                self._child_classes = OrderedDict([("bsr-address", ("bsr_address", Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress)), ("candidate-bsr-address", ("candidate_bsr_address", Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress))])
                                self._leafs = OrderedDict([
                                    ('pim_scope', (YLeaf(YType.uint32, 'pim-scope'), ['int'])),
                                    ('bsr_priority', (YLeaf(YType.uint8, 'bsr-priority'), ['int'])),
                                    ('bsr_mask_length', (YLeaf(YType.uint8, 'bsr-mask-length'), ['int'])),
                                    ('bsr_up_time', (YLeaf(YType.uint16, 'bsr-up-time'), ['int'])),
                                    ('bootstrap_timeout', (YLeaf(YType.uint16, 'bootstrap-timeout'), ['int'])),
                                    ('candidate_bsr_state', (YLeaf(YType.uint32, 'candidate-bsr-state'), ['int'])),
                                    ('bsr_election_state', (YLeaf(YType.uint32, 'bsr-election-state'), ['int'])),
                                    ('bsr_scope', (YLeaf(YType.uint16, 'bsr-scope'), ['int'])),
                                    ('candidate_bsr_flag', (YLeaf(YType.boolean, 'candidate-bsr-flag'), ['bool'])),
                                    ('candidate_bsr_priority', (YLeaf(YType.uint8, 'candidate-bsr-priority'), ['int'])),
                                    ('candidate_bsr_mask_length', (YLeaf(YType.uint8, 'candidate-bsr-mask-length'), ['int'])),
                                ])
                                self.pim_scope = None
                                self.bsr_priority = None
                                self.bsr_mask_length = None
                                self.bsr_up_time = None
                                self.bootstrap_timeout = None
                                self.candidate_bsr_state = None
                                self.bsr_election_state = None
                                self.bsr_scope = None
                                self.candidate_bsr_flag = None
                                self.candidate_bsr_priority = None
                                self.candidate_bsr_mask_length = None

                                self.bsr_address = Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress()
                                self.bsr_address.parent = self
                                self._children_name_map["bsr_address"] = "bsr-address"

                                self.candidate_bsr_address = Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress()
                                self.candidate_bsr_address.parent = self
                                self._children_name_map["candidate_bsr_address"] = "candidate-bsr-address"
                                self._segment_path = lambda: "bsr-election" + "[pim-scope='" + str(self.pim_scope) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection, ['pim_scope', 'bsr_priority', 'bsr_mask_length', 'bsr_up_time', 'bootstrap_timeout', 'candidate_bsr_state', 'bsr_election_state', 'bsr_scope', 'candidate_bsr_flag', 'candidate_bsr_priority', 'candidate_bsr_mask_length'], name, value)


                            class BsrAddress(Entity):
                                """
                                BSR address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress, self).__init__()

                                    self.yang_name = "bsr-address"
                                    self.yang_parent_name = "bsr-election"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "bsr-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                            class CandidateBsrAddress(Entity):
                                """
                                C\-BSR address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress, self).__init__()

                                    self.yang_name = "candidate-bsr-address"
                                    self.yang_parent_name = "bsr-election"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "candidate-bsr-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class RoutePolicy(Entity):
                    """
                    PIM route policy
                    
                    .. attribute:: route_policy_statistics
                    
                    	PIM route policy statistics
                    	**type**\:  :py:class:`RoutePolicyStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics>`
                    
                    .. attribute:: route_policy_tests
                    
                    	PIM route policy test run table
                    	**type**\:  :py:class:`RoutePolicyTests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.RoutePolicy, self).__init__()

                        self.yang_name = "route-policy"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("route-policy-statistics", ("route_policy_statistics", Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics)), ("route-policy-tests", ("route_policy_tests", Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests))])
                        self._leafs = OrderedDict()

                        self.route_policy_statistics = Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics()
                        self.route_policy_statistics.parent = self
                        self._children_name_map["route_policy_statistics"] = "route-policy-statistics"

                        self.route_policy_tests = Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests()
                        self.route_policy_tests.parent = self
                        self._children_name_map["route_policy_tests"] = "route-policy-tests"
                        self._segment_path = lambda: "route-policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.Vrfs.Vrf.RoutePolicy, [], name, value)


                    class RoutePolicyStatistics(Entity):
                        """
                        PIM route policy statistics
                        
                        .. attribute:: policy_name
                        
                        	RPF policy name
                        	**type**\: str
                        
                        .. attribute:: requests
                        
                        	Number of RPF lookup requests
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pass_
                        
                        	Number of RPF pass
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: drop
                        
                        	Number of RPF drops
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: default_table
                        
                        	Number of RPF lookup in default\-only Table
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: any_table
                        
                        	Number of RPF lookup in any Table
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics, self).__init__()

                            self.yang_name = "route-policy-statistics"
                            self.yang_parent_name = "route-policy"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('policy_name', (YLeaf(YType.str, 'policy-name'), ['str'])),
                                ('requests', (YLeaf(YType.uint32, 'requests'), ['int'])),
                                ('pass_', (YLeaf(YType.uint32, 'pass'), ['int'])),
                                ('drop', (YLeaf(YType.uint32, 'drop'), ['int'])),
                                ('default_table', (YLeaf(YType.uint32, 'default-table'), ['int'])),
                                ('any_table', (YLeaf(YType.uint32, 'any-table'), ['int'])),
                            ])
                            self.policy_name = None
                            self.requests = None
                            self.pass_ = None
                            self.drop = None
                            self.default_table = None
                            self.any_table = None
                            self._segment_path = lambda: "route-policy-statistics"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics, ['policy_name', 'requests', 'pass_', 'drop', 'default_table', 'any_table'], name, value)


                    class RoutePolicyTests(Entity):
                        """
                        PIM route policy test run table
                        
                        .. attribute:: route_policy_test
                        
                        	PIM route policy test run
                        	**type**\: list of  		 :py:class:`RoutePolicyTest <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests, self).__init__()

                            self.yang_name = "route-policy-tests"
                            self.yang_parent_name = "route-policy"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("route-policy-test", ("route_policy_test", Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest))])
                            self._leafs = OrderedDict()

                            self.route_policy_test = YList(self)
                            self._segment_path = lambda: "route-policy-tests"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests, [], name, value)


                        class RoutePolicyTest(Entity):
                            """
                            PIM route policy test run
                            
                            .. attribute:: source_address
                            
                            	Source IP address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: group_address
                            
                            	Group IP address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ext_comm
                            
                            	Extended Community
                            	**type**\: str
                            
                            	**length:** 1..8
                            
                            .. attribute:: source_address_xr
                            
                            	Source address
                            	**type**\:  :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr>`
                            
                            .. attribute:: group_address_xr
                            
                            	Source address
                            	**type**\:  :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr>`
                            
                            .. attribute:: policy_name
                            
                            	RPF policy name
                            	**type**\: str
                            
                            .. attribute:: extended_community_rt
                            
                            	Route Target
                            	**type**\: str
                            
                            	**length:** 0..33
                            
                            .. attribute:: pass_
                            
                            	Pass
                            	**type**\: bool
                            
                            .. attribute:: default_table
                            
                            	Default table selected
                            	**type**\: bool
                            
                            .. attribute:: vrf_name
                            
                            	VRF name
                            	**type**\: str
                            
                            	**length:** 0..33
                            
                            .. attribute:: afi
                            
                            	AFI
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: safi
                            
                            	SAFI
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: table_name
                            
                            	Table name
                            	**type**\: str
                            
                            .. attribute:: table_exists
                            
                            	Table exists
                            	**type**\: bool
                            
                            .. attribute:: table_active
                            
                            	Table active
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest, self).__init__()

                                self.yang_name = "route-policy-test"
                                self.yang_parent_name = "route-policy-tests"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("source-address-xr", ("source_address_xr", Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr)), ("group-address-xr", ("group_address_xr", Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr))])
                                self._leafs = OrderedDict([
                                    ('source_address', (YLeaf(YType.str, 'source-address'), ['str','str'])),
                                    ('group_address', (YLeaf(YType.str, 'group-address'), ['str','str'])),
                                    ('ext_comm', (YLeaf(YType.str, 'ext-comm'), ['str'])),
                                    ('policy_name', (YLeaf(YType.str, 'policy-name'), ['str'])),
                                    ('extended_community_rt', (YLeaf(YType.str, 'extended-community-rt'), ['str'])),
                                    ('pass_', (YLeaf(YType.boolean, 'pass'), ['bool'])),
                                    ('default_table', (YLeaf(YType.boolean, 'default-table'), ['bool'])),
                                    ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                    ('afi', (YLeaf(YType.uint32, 'afi'), ['int'])),
                                    ('safi', (YLeaf(YType.uint32, 'safi'), ['int'])),
                                    ('table_name', (YLeaf(YType.str, 'table-name'), ['str'])),
                                    ('table_exists', (YLeaf(YType.boolean, 'table-exists'), ['bool'])),
                                    ('table_active', (YLeaf(YType.boolean, 'table-active'), ['bool'])),
                                ])
                                self.source_address = None
                                self.group_address = None
                                self.ext_comm = None
                                self.policy_name = None
                                self.extended_community_rt = None
                                self.pass_ = None
                                self.default_table = None
                                self.vrf_name = None
                                self.afi = None
                                self.safi = None
                                self.table_name = None
                                self.table_exists = None
                                self.table_active = None

                                self.source_address_xr = Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr()
                                self.source_address_xr.parent = self
                                self._children_name_map["source_address_xr"] = "source-address-xr"

                                self.group_address_xr = Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"
                                self._segment_path = lambda: "route-policy-test"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest, ['source_address', 'group_address', 'ext_comm', 'policy_name', 'extended_community_rt', 'pass_', 'default_table', 'vrf_name', 'afi', 'safi', 'table_name', 'table_exists', 'table_active'], name, value)


                            class SourceAddressXr(Entity):
                                """
                                Source address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr, self).__init__()

                                    self.yang_name = "source-address-xr"
                                    self.yang_parent_name = "route-policy-test"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "source-address-xr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                            class GroupAddressXr(Entity):
                                """
                                Source address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr, self).__init__()

                                    self.yang_name = "group-address-xr"
                                    self.yang_parent_name = "route-policy-test"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "group-address-xr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class RpfSummary(Entity):
                    """
                    PIM RPF registration summary
                    
                    .. attribute:: default_safi
                    
                    	Default RPF Table SAFI
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: default_table_name
                    
                    	Default RPF Table Name
                    	**type**\: str
                    
                    .. attribute:: is_mbgp_configured
                    
                    	Is MBGP configured?
                    	**type**\: bool
                    
                    .. attribute:: is_ospf_te_configured
                    
                    	Is OSPF TE configured?
                    	**type**\: bool
                    
                    .. attribute:: is_isis_te_configured
                    
                    	Is ISIS TE configured?
                    	**type**\: bool
                    
                    .. attribute:: is_isis_mtr_configured
                    
                    	Is ISIS MTR configured?
                    	**type**\: bool
                    
                    .. attribute:: mo_frr_configured
                    
                    	Is MoFRR configured?
                    	**type**\: bool
                    
                    .. attribute:: rib_mo_frr_configured
                    
                    	Is MoFRR RIB configured?
                    	**type**\: bool
                    
                    .. attribute:: rump_enabled
                    
                    	Is RUMP MuRIB enabled?
                    	**type**\: bool
                    
                    .. attribute:: rib_convergence_timeout
                    
                    	RIB convergence timeout in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: rib_convergence_time_left
                    
                    	RIB convergence time left in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: is_multipath_enabled
                    
                    	Is Multipath Enabled ?
                    	**type**\: bool
                    
                    .. attribute:: is_multipath_interface_hash_enabled
                    
                    	Is Multipath Interface Hash Extension Enabled ?
                    	**type**\: bool
                    
                    .. attribute:: is_multipath_source_hash_enabled
                    
                    	Is Multipath Source based Hash Enabled ?
                    	**type**\: bool
                    
                    .. attribute:: is_multipath_source_next_hop_hash_enabled
                    
                    	Is Multipath Source\-Nexthop Hash Enabled ?
                    	**type**\: bool
                    
                    .. attribute:: rpf_registrations
                    
                    	RPF Registration count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_rib_convergence
                    
                    	RIB Convergence status
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.RpfSummary, self).__init__()

                        self.yang_name = "rpf-summary"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('default_safi', (YLeaf(YType.uint32, 'default-safi'), ['int'])),
                            ('default_table_name', (YLeaf(YType.str, 'default-table-name'), ['str'])),
                            ('is_mbgp_configured', (YLeaf(YType.boolean, 'is-mbgp-configured'), ['bool'])),
                            ('is_ospf_te_configured', (YLeaf(YType.boolean, 'is-ospf-te-configured'), ['bool'])),
                            ('is_isis_te_configured', (YLeaf(YType.boolean, 'is-isis-te-configured'), ['bool'])),
                            ('is_isis_mtr_configured', (YLeaf(YType.boolean, 'is-isis-mtr-configured'), ['bool'])),
                            ('mo_frr_configured', (YLeaf(YType.boolean, 'mo-frr-configured'), ['bool'])),
                            ('rib_mo_frr_configured', (YLeaf(YType.boolean, 'rib-mo-frr-configured'), ['bool'])),
                            ('rump_enabled', (YLeaf(YType.boolean, 'rump-enabled'), ['bool'])),
                            ('rib_convergence_timeout', (YLeaf(YType.uint32, 'rib-convergence-timeout'), ['int'])),
                            ('rib_convergence_time_left', (YLeaf(YType.uint32, 'rib-convergence-time-left'), ['int'])),
                            ('is_multipath_enabled', (YLeaf(YType.boolean, 'is-multipath-enabled'), ['bool'])),
                            ('is_multipath_interface_hash_enabled', (YLeaf(YType.boolean, 'is-multipath-interface-hash-enabled'), ['bool'])),
                            ('is_multipath_source_hash_enabled', (YLeaf(YType.boolean, 'is-multipath-source-hash-enabled'), ['bool'])),
                            ('is_multipath_source_next_hop_hash_enabled', (YLeaf(YType.boolean, 'is-multipath-source-next-hop-hash-enabled'), ['bool'])),
                            ('rpf_registrations', (YLeaf(YType.uint32, 'rpf-registrations'), ['int'])),
                            ('is_rib_convergence', (YLeaf(YType.boolean, 'is-rib-convergence'), ['bool'])),
                        ])
                        self.default_safi = None
                        self.default_table_name = None
                        self.is_mbgp_configured = None
                        self.is_ospf_te_configured = None
                        self.is_isis_te_configured = None
                        self.is_isis_mtr_configured = None
                        self.mo_frr_configured = None
                        self.rib_mo_frr_configured = None
                        self.rump_enabled = None
                        self.rib_convergence_timeout = None
                        self.rib_convergence_time_left = None
                        self.is_multipath_enabled = None
                        self.is_multipath_interface_hash_enabled = None
                        self.is_multipath_source_hash_enabled = None
                        self.is_multipath_source_next_hop_hash_enabled = None
                        self.rpf_registrations = None
                        self.is_rib_convergence = None
                        self._segment_path = lambda: "rpf-summary"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.Vrfs.Vrf.RpfSummary, ['default_safi', 'default_table_name', 'is_mbgp_configured', 'is_ospf_te_configured', 'is_isis_te_configured', 'is_isis_mtr_configured', 'mo_frr_configured', 'rib_mo_frr_configured', 'rump_enabled', 'rib_convergence_timeout', 'rib_convergence_time_left', 'is_multipath_enabled', 'is_multipath_interface_hash_enabled', 'is_multipath_source_hash_enabled', 'is_multipath_source_next_hop_hash_enabled', 'rpf_registrations', 'is_rib_convergence'], name, value)


                class Interfaces(Entity):
                    """
                    PIM interfaces
                    
                    .. attribute:: interface
                    
                    	PIM interface name
                    	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Interfaces.Interface>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.Interfaces, self).__init__()

                        self.yang_name = "interfaces"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("interface", ("interface", Pim.Active.Vrfs.Vrf.Interfaces.Interface))])
                        self._leafs = OrderedDict()

                        self.interface = YList(self)
                        self._segment_path = lambda: "interfaces"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.Vrfs.Vrf.Interfaces, [], name, value)


                    class Interface(Entity):
                        """
                        PIM interface name
                        
                        .. attribute:: interface_name  (key)
                        
                        	Interface name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: dr_address
                        
                        	PIM Designated Router
                        	**type**\:  :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Interfaces.Interface.DrAddress>`
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identfier
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: interface_address_mask
                        
                        	Interface IP Address Mask
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: is_enabled
                        
                        	Is PIM enabled on this IF ?
                        	**type**\: bool
                        
                        .. attribute:: neighbor_count
                        
                        	No. of neighbors on this IF
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: external_neighbor_count
                        
                        	No. of external neighbors on this IF
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: hello_interval
                        
                        	Hello Interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: dr_priority
                        
                        	DR Priority
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: hello_expiry
                        
                        	Hello Timer Expiry
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: are_we_dr
                        
                        	Are we the DR on this IF ?
                        	**type**\: bool
                        
                        .. attribute:: bfd_enabled
                        
                        	BFD state
                        	**type**\: bool
                        
                        .. attribute:: bfd_interval
                        
                        	BFD Interval
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bfd_multiplier
                        
                        	BFD Multiplier
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_interface
                        
                        	 is this a Virtual Interfaces ?
                        	**type**\: bool
                        
                        .. attribute:: passive_interface
                        
                        	Passive PIM interface
                        	**type**\: bool
                        
                        .. attribute:: neighbor_filter_name
                        
                        	Neighbor Filter Name
                        	**type**\: str
                        
                        .. attribute:: join_prune_interval
                        
                        	Join\-Prune Interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: prune_delay_enabled
                        
                        	Prune Delay Enabled
                        	**type**\: bool
                        
                        .. attribute:: configured_propagation_delay
                        
                        	Configured Propagation Delay
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: configured_override_interval
                        
                        	Configured Override Interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: generation_id
                        
                        	Generation Identifier
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Bidir Capable
                        	**type**\: bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Proxy Capable
                        	**type**\: bool
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Batch Asserts Capable
                        	**type**\: bool
                        
                        .. attribute:: idb_oor_enabled
                        
                        	Interface oor enabled
                        	**type**\: bool
                        
                        .. attribute:: idb_acl_provided
                        
                        	ACL name provided
                        	**type**\: bool
                        
                        .. attribute:: idb_max_count
                        
                        	Interface ole max count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_threshold_count
                        
                        	Interface ole threshold count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_current_count
                        
                        	Interface ole current count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_acl_name
                        
                        	Interface ole ACL Name
                        	**type**\: str
                        
                        	**length:** 0..64
                        
                        .. attribute:: interface_address
                        
                        	List of Interface IP Addresses
                        	**type**\: list of  		 :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Interfaces.Interface.InterfaceAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.Interfaces.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "interfaces"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['interface_name']
                            self._child_classes = OrderedDict([("dr-address", ("dr_address", Pim.Active.Vrfs.Vrf.Interfaces.Interface.DrAddress)), ("interface-address", ("interface_address", Pim.Active.Vrfs.Vrf.Interfaces.Interface.InterfaceAddress))])
                            self._leafs = OrderedDict([
                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                                ('interface_address_mask', (YLeaf(YType.uint8, 'interface-address-mask'), ['int'])),
                                ('is_enabled', (YLeaf(YType.boolean, 'is-enabled'), ['bool'])),
                                ('neighbor_count', (YLeaf(YType.uint16, 'neighbor-count'), ['int'])),
                                ('external_neighbor_count', (YLeaf(YType.uint16, 'external-neighbor-count'), ['int'])),
                                ('hello_interval', (YLeaf(YType.uint16, 'hello-interval'), ['int'])),
                                ('dr_priority', (YLeaf(YType.uint32, 'dr-priority'), ['int'])),
                                ('hello_expiry', (YLeaf(YType.uint64, 'hello-expiry'), ['int'])),
                                ('are_we_dr', (YLeaf(YType.boolean, 'are-we-dr'), ['bool'])),
                                ('bfd_enabled', (YLeaf(YType.boolean, 'bfd-enabled'), ['bool'])),
                                ('bfd_interval', (YLeaf(YType.uint32, 'bfd-interval'), ['int'])),
                                ('bfd_multiplier', (YLeaf(YType.uint32, 'bfd-multiplier'), ['int'])),
                                ('virtual_interface', (YLeaf(YType.boolean, 'virtual-interface'), ['bool'])),
                                ('passive_interface', (YLeaf(YType.boolean, 'passive-interface'), ['bool'])),
                                ('neighbor_filter_name', (YLeaf(YType.str, 'neighbor-filter-name'), ['str'])),
                                ('join_prune_interval', (YLeaf(YType.uint16, 'join-prune-interval'), ['int'])),
                                ('prune_delay_enabled', (YLeaf(YType.boolean, 'prune-delay-enabled'), ['bool'])),
                                ('configured_propagation_delay', (YLeaf(YType.uint16, 'configured-propagation-delay'), ['int'])),
                                ('propagation_delay', (YLeaf(YType.uint16, 'propagation-delay'), ['int'])),
                                ('configured_override_interval', (YLeaf(YType.uint16, 'configured-override-interval'), ['int'])),
                                ('override_interval', (YLeaf(YType.uint16, 'override-interval'), ['int'])),
                                ('generation_id', (YLeaf(YType.uint32, 'generation-id'), ['int'])),
                                ('is_bidirectional_capable', (YLeaf(YType.boolean, 'is-bidirectional-capable'), ['bool'])),
                                ('is_proxy_capable', (YLeaf(YType.boolean, 'is-proxy-capable'), ['bool'])),
                                ('is_batch_asserts_capable', (YLeaf(YType.boolean, 'is-batch-asserts-capable'), ['bool'])),
                                ('idb_oor_enabled', (YLeaf(YType.boolean, 'idb-oor-enabled'), ['bool'])),
                                ('idb_acl_provided', (YLeaf(YType.boolean, 'idb-acl-provided'), ['bool'])),
                                ('idb_max_count', (YLeaf(YType.uint32, 'idb-max-count'), ['int'])),
                                ('idb_threshold_count', (YLeaf(YType.uint32, 'idb-threshold-count'), ['int'])),
                                ('idb_current_count', (YLeaf(YType.uint32, 'idb-current-count'), ['int'])),
                                ('idb_acl_name', (YLeaf(YType.str, 'idb-acl-name'), ['str'])),
                            ])
                            self.interface_name = None
                            self.interface_name_xr = None
                            self.interface_address_mask = None
                            self.is_enabled = None
                            self.neighbor_count = None
                            self.external_neighbor_count = None
                            self.hello_interval = None
                            self.dr_priority = None
                            self.hello_expiry = None
                            self.are_we_dr = None
                            self.bfd_enabled = None
                            self.bfd_interval = None
                            self.bfd_multiplier = None
                            self.virtual_interface = None
                            self.passive_interface = None
                            self.neighbor_filter_name = None
                            self.join_prune_interval = None
                            self.prune_delay_enabled = None
                            self.configured_propagation_delay = None
                            self.propagation_delay = None
                            self.configured_override_interval = None
                            self.override_interval = None
                            self.generation_id = None
                            self.is_bidirectional_capable = None
                            self.is_proxy_capable = None
                            self.is_batch_asserts_capable = None
                            self.idb_oor_enabled = None
                            self.idb_acl_provided = None
                            self.idb_max_count = None
                            self.idb_threshold_count = None
                            self.idb_current_count = None
                            self.idb_acl_name = None

                            self.dr_address = Pim.Active.Vrfs.Vrf.Interfaces.Interface.DrAddress()
                            self.dr_address.parent = self
                            self._children_name_map["dr_address"] = "dr-address"

                            self.interface_address = YList(self)
                            self._segment_path = lambda: "interface" + "[interface-name='" + str(self.interface_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.Interfaces.Interface, ['interface_name', 'interface_name_xr', 'interface_address_mask', 'is_enabled', 'neighbor_count', 'external_neighbor_count', 'hello_interval', 'dr_priority', 'hello_expiry', 'are_we_dr', 'bfd_enabled', 'bfd_interval', 'bfd_multiplier', 'virtual_interface', 'passive_interface', 'neighbor_filter_name', 'join_prune_interval', 'prune_delay_enabled', 'configured_propagation_delay', 'propagation_delay', 'configured_override_interval', 'override_interval', 'generation_id', 'is_bidirectional_capable', 'is_proxy_capable', 'is_batch_asserts_capable', 'idb_oor_enabled', 'idb_acl_provided', 'idb_max_count', 'idb_threshold_count', 'idb_current_count', 'idb_acl_name'], name, value)


                        class DrAddress(Entity):
                            """
                            PIM Designated Router
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Interfaces.Interface.DrAddress, self).__init__()

                                self.yang_name = "dr-address"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "dr-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.Interfaces.Interface.DrAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class InterfaceAddress(Entity):
                            """
                            List of Interface IP Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Interfaces.Interface.InterfaceAddress, self).__init__()

                                self.yang_name = "interface-address"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "interface-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.Interfaces.Interface.InterfaceAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class NetIoTunnels(Entity):
                    """
                    Tunnel information that NETIO has 
                    
                    .. attribute:: net_io_tunnel
                    
                    	PIM netio tunnel information
                    	**type**\: list of  		 :py:class:`NetIoTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.NetIoTunnels, self).__init__()

                        self.yang_name = "net-io-tunnels"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("net-io-tunnel", ("net_io_tunnel", Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel))])
                        self._leafs = OrderedDict()

                        self.net_io_tunnel = YList(self)
                        self._segment_path = lambda: "net-io-tunnels"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.Vrfs.Vrf.NetIoTunnels, [], name, value)


                    class NetIoTunnel(Entity):
                        """
                        PIM netio tunnel information
                        
                        .. attribute:: tunnel_name  (key)
                        
                        	Tunnel name
                        	**type**\: str
                        
                        	**length:** 1..64
                        
                        .. attribute:: source_address
                        
                        	Source addr known to PIM
                        	**type**\:  :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress>`
                        
                        .. attribute:: rp_address
                        
                        	RP addr known to PIM
                        	**type**\:  :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress>`
                        
                        .. attribute:: source_address_netio
                        
                        	Source addr from netio
                        	**type**\:  :py:class:`SourceAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio>`
                        
                        .. attribute:: group_address_netio
                        
                        	Group addr from netio
                        	**type**\:  :py:class:`GroupAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio>`
                        
                        .. attribute:: vrf_name
                        
                        	VRF Name
                        	**type**\: str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel, self).__init__()

                            self.yang_name = "net-io-tunnel"
                            self.yang_parent_name = "net-io-tunnels"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['tunnel_name']
                            self._child_classes = OrderedDict([("source-address", ("source_address", Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress)), ("rp-address", ("rp_address", Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress)), ("source-address-netio", ("source_address_netio", Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio)), ("group-address-netio", ("group_address_netio", Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio))])
                            self._leafs = OrderedDict([
                                ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                            ])
                            self.tunnel_name = None
                            self.vrf_name = None

                            self.source_address = Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"

                            self.rp_address = Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"

                            self.source_address_netio = Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio()
                            self.source_address_netio.parent = self
                            self._children_name_map["source_address_netio"] = "source-address-netio"

                            self.group_address_netio = Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio()
                            self.group_address_netio.parent = self
                            self._children_name_map["group_address_netio"] = "group-address-netio"
                            self._segment_path = lambda: "net-io-tunnel" + "[tunnel-name='" + str(self.tunnel_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel, ['tunnel_name', 'vrf_name'], name, value)


                        class SourceAddress(Entity):
                            """
                            Source addr known to PIM
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "net-io-tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "source-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class RpAddress(Entity):
                            """
                            RP addr known to PIM
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "net-io-tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "rp-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class SourceAddressNetio(Entity):
                            """
                            Source addr from netio
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio, self).__init__()

                                self.yang_name = "source-address-netio"
                                self.yang_parent_name = "net-io-tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "source-address-netio"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class GroupAddressNetio(Entity):
                            """
                            Group addr from netio
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio, self).__init__()

                                self.yang_name = "group-address-netio"
                                self.yang_parent_name = "net-io-tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "group-address-netio"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class BidirDfStates(Entity):
                    """
                    Bidirectional PIM DF election state table
                    
                    .. attribute:: bidir_df_state
                    
                    	Bidirectional PIM DF Election Table Entry
                    	**type**\: list of  		 :py:class:`BidirDfState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.BidirDfStates, self).__init__()

                        self.yang_name = "bidir-df-states"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("bidir-df-state", ("bidir_df_state", Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState))])
                        self._leafs = OrderedDict()

                        self.bidir_df_state = YList(self)
                        self._segment_path = lambda: "bidir-df-states"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.Vrfs.Vrf.BidirDfStates, [], name, value)


                    class BidirDfState(Entity):
                        """
                        Bidirectional PIM DF Election Table Entry
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: rp_address_xr
                        
                        	RP Address
                        	**type**\:  :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr>`
                        
                        .. attribute:: pim_interface_name
                        
                        	Interface Name
                        	**type**\: str
                        
                        .. attribute:: election_state
                        
                        	DF Election State
                        	**type**\: str
                        
                        .. attribute:: time_seconds
                        
                        	Timer expires (seconds)
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: time_nano_seconds
                        
                        	Timer expires (nseconds)
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: nanosecond
                        
                        .. attribute:: our_metric
                        
                        	Metric
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: our_metric_preference
                        
                        	MetricPreference
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState, self).__init__()

                            self.yang_name = "bidir-df-state"
                            self.yang_parent_name = "bidir-df-states"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rp-address-xr", ("rp_address_xr", Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr))])
                            self._leafs = OrderedDict([
                                ('rp_address', (YLeaf(YType.str, 'rp-address'), ['str','str'])),
                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ('pim_interface_name', (YLeaf(YType.str, 'pim-interface-name'), ['str'])),
                                ('election_state', (YLeaf(YType.str, 'election-state'), ['str'])),
                                ('time_seconds', (YLeaf(YType.uint64, 'time-seconds'), ['int'])),
                                ('time_nano_seconds', (YLeaf(YType.uint64, 'time-nano-seconds'), ['int'])),
                                ('our_metric', (YLeaf(YType.uint32, 'our-metric'), ['int'])),
                                ('our_metric_preference', (YLeaf(YType.uint32, 'our-metric-preference'), ['int'])),
                            ])
                            self.rp_address = None
                            self.interface_name = None
                            self.pim_interface_name = None
                            self.election_state = None
                            self.time_seconds = None
                            self.time_nano_seconds = None
                            self.our_metric = None
                            self.our_metric_preference = None

                            self.rp_address_xr = Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr()
                            self.rp_address_xr.parent = self
                            self._children_name_map["rp_address_xr"] = "rp-address-xr"
                            self._segment_path = lambda: "bidir-df-state"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState, ['rp_address', 'interface_name', 'pim_interface_name', 'election_state', 'time_seconds', 'time_nano_seconds', 'our_metric', 'our_metric_preference'], name, value)


                        class RpAddressXr(Entity):
                            """
                            RP Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr, self).__init__()

                                self.yang_name = "rp-address-xr"
                                self.yang_parent_name = "bidir-df-state"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "rp-address-xr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class Topologies(Entity):
                    """
                    PIM topology table
                    
                    .. attribute:: topology
                    
                    	PIM topology information
                    	**type**\: list of  		 :py:class:`Topology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Topologies.Topology>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.Topologies, self).__init__()

                        self.yang_name = "topologies"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("topology", ("topology", Pim.Active.Vrfs.Vrf.Topologies.Topology))])
                        self._leafs = OrderedDict()

                        self.topology = YList(self)
                        self._segment_path = lambda: "topologies"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.Vrfs.Vrf.Topologies, [], name, value)


                    class Topology(Entity):
                        """
                        PIM topology information
                        
                        .. attribute:: source_address
                        
                        	Source address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: group_address
                        
                        	Group address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: rpt
                        
                        	RPT bit
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:  :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Topologies.Topology.GroupAddressXr>`
                        
                        .. attribute:: source_address_xr
                        
                        	Source Address
                        	**type**\:  :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Topologies.Topology.SourceAddressXr>`
                        
                        .. attribute:: rp_address
                        
                        	RP Address (If rpt)
                        	**type**\:  :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Topologies.Topology.RpAddress>`
                        
                        .. attribute:: rpf_neighbor
                        
                        	RPF Neighbor
                        	**type**\:  :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfNeighbor>`
                        
                        .. attribute:: secondary_rpf_neighbor
                        
                        	Secondary RPF Neighbor
                        	**type**\:  :py:class:`SecondaryRpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor>`
                        
                        .. attribute:: rpf_root
                        
                        	Root of this mcast tree
                        	**type**\:  :py:class:`RpfRoot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfRoot>`
                        
                        .. attribute:: proxy_address
                        
                        	RPF Proxy address
                        	**type**\:  :py:class:`ProxyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Topologies.Topology.ProxyAddress>`
                        
                        .. attribute:: orig_src_address
                        
                        	Orig Src Address
                        	**type**\:  :py:class:`OrigSrcAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress>`
                        
                        .. attribute:: limit_reached
                        
                        	Have we throttled the creation of routes or interfaces ?
                        	**type**\: bool
                        
                        .. attribute:: low_memory
                        
                        	Node is running low on memory
                        	**type**\: bool
                        
                        .. attribute:: protocol
                        
                        	The PIM protocol
                        	**type**\:  :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: wildcard
                        
                        	WC \-Wildcard
                        	**type**\: bool
                        
                        .. attribute:: rpt_xr
                        
                        	Is this on the RPT ?
                        	**type**\: bool
                        
                        .. attribute:: spt
                        
                        	Is this on the SPT ?
                        	**type**\: bool
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: expiry
                        
                        	When this entry expires
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: alive
                        
                        	Alive time in seconds (\-1 if never)
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: register_received_timer
                        
                        	Register Received Timer in seconds (\-1 if never)
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: remote_source
                        
                        	MSDP told us
                        	**type**\: bool
                        
                        .. attribute:: crossed_threshold
                        
                        	Incoming traffic crossed threshold. MT flag set
                        	**type**\: bool
                        
                        .. attribute:: data_mdt_addr_assigned
                        
                        	PIM has assigned a Data MDT Address
                        	**type**\: bool
                        
                        .. attribute:: rpf_interface_name
                        
                        	Interface Identifier
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: rpf_vrf_name
                        
                        	RPF VRF Name
                        	**type**\: str
                        
                        	**length:** 0..33
                        
                        .. attribute:: rpf_safi
                        
                        	Unicast or mcast
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: rpf_table_name
                        
                        	RPF Table name
                        	**type**\: str
                        
                        .. attribute:: rpf_drop
                        
                        	RPF route\-policy drop
                        	**type**\: bool
                        
                        .. attribute:: rpf_extranet
                        
                        	Extranet RPF route\-policy
                        	**type**\: bool
                        
                        .. attribute:: is_via_lsm
                        
                        	Via LSM
                        	**type**\: bool
                        
                        .. attribute:: secondary_rpf_interface_name
                        
                        	Secondary Interface Identifier
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: connected
                        
                        	Is Connected ?
                        	**type**\: bool
                        
                        .. attribute:: proxy
                        
                        	Is the RPF target a proxy?
                        	**type**\: bool
                        
                        .. attribute:: rpf_proxy_enabled
                        
                        	Is rpf if proxy enabled?
                        	**type**\: bool
                        
                        .. attribute:: mofrr_enabled
                        
                        	Is this SG MoFRR enabled?
                        	**type**\: bool
                        
                        .. attribute:: rib_mo_frr_enabled
                        
                        	Is this SG MoFRR enabled?
                        	**type**\: bool
                        
                        .. attribute:: jp_timer
                        
                        	Join\-Prune Timer
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: jp_status
                        
                        	Join\-Prune Status
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: suppress_registers
                        
                        	When the Null register probe expires
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: assume_alive
                        
                        	The Assume Alive Bit
                        	**type**\: bool
                        
                        .. attribute:: probe_alive
                        
                        	The Probe Alive Bit
                        	**type**\: bool
                        
                        .. attribute:: really_alive
                        
                        	The Really Alive Bit
                        	**type**\: bool
                        
                        .. attribute:: inherit_alive
                        
                        	The Inherit Alive Bit
                        	**type**\: bool
                        
                        .. attribute:: inherit_spt
                        
                        	The Inherit SPT Bit
                        	**type**\: bool
                        
                        .. attribute:: signal_sources
                        
                        	Signal Sources on route?
                        	**type**\: bool
                        
                        .. attribute:: dont_check_connected
                        
                        	Do we need to make the connected check on this route ?
                        	**type**\: bool
                        
                        .. attribute:: register_received
                        
                        	Have registers been received for this source ?
                        	**type**\: bool
                        
                        .. attribute:: last_hop
                        
                        	Are we last hop ?
                        	**type**\: bool
                        
                        .. attribute:: sending_registers
                        
                        	Are we sending registers for this route ?
                        	**type**\: bool
                        
                        .. attribute:: sending_null_registers
                        
                        	Are we sending null registers for this route ?
                        	**type**\: bool
                        
                        .. attribute:: sa_sent
                        
                        	BGP SA sent
                        	**type**\: bool
                        
                        .. attribute:: sa_received
                        
                        	BGP SA received
                        	**type**\: bool
                        
                        .. attribute:: sa_joined
                        
                        	BGP SA join
                        	**type**\: bool
                        
                        .. attribute:: anycast_rp_match
                        
                        	Group matches Anycast\-RP policy
                        	**type**\: bool
                        
                        .. attribute:: anycast_rp_route_target
                        
                        	Anycast\-RP RT
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: bgp_join
                        
                        	BGP C JOIN
                        	**type**\: bool
                        
                        .. attribute:: bgp_jp_time
                        
                        	BGP C JP Time
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: customer_routing_type
                        
                        	Type of Customer Routing in the MVPN
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: extranet_route
                        
                        	Is a Extranet route ?
                        	**type**\: bool
                        
                        .. attribute:: mofrr_active
                        
                        	Is MoFRR Active?
                        	**type**\: bool
                        
                        .. attribute:: mofrr_primary
                        
                        	Is this Mofrr Primary?
                        	**type**\: bool
                        
                        .. attribute:: mofrr_backup
                        
                        	Is this Mofrr Backup?
                        	**type**\: bool
                        
                        .. attribute:: vxlan
                        
                        	Is this VXLAN?
                        	**type**\: bool
                        
                        .. attribute:: kat_state
                        
                        	Keep Alive Timer State
                        	**type**\: bool
                        
                        .. attribute:: outgoing_interface
                        
                        	Outgoing interface list
                        	**type**\: list of  		 :py:class:`OutgoingInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.Topologies.Topology, self).__init__()

                            self.yang_name = "topology"
                            self.yang_parent_name = "topologies"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("group-address-xr", ("group_address_xr", Pim.Active.Vrfs.Vrf.Topologies.Topology.GroupAddressXr)), ("source-address-xr", ("source_address_xr", Pim.Active.Vrfs.Vrf.Topologies.Topology.SourceAddressXr)), ("rp-address", ("rp_address", Pim.Active.Vrfs.Vrf.Topologies.Topology.RpAddress)), ("rpf-neighbor", ("rpf_neighbor", Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfNeighbor)), ("secondary-rpf-neighbor", ("secondary_rpf_neighbor", Pim.Active.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor)), ("rpf-root", ("rpf_root", Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfRoot)), ("proxy-address", ("proxy_address", Pim.Active.Vrfs.Vrf.Topologies.Topology.ProxyAddress)), ("orig-src-address", ("orig_src_address", Pim.Active.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress)), ("outgoing-interface", ("outgoing_interface", Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface))])
                            self._leafs = OrderedDict([
                                ('source_address', (YLeaf(YType.str, 'source-address'), ['str','str'])),
                                ('group_address', (YLeaf(YType.str, 'group-address'), ['str','str'])),
                                ('rpt', (YLeaf(YType.uint32, 'rpt'), ['int'])),
                                ('limit_reached', (YLeaf(YType.boolean, 'limit-reached'), ['bool'])),
                                ('low_memory', (YLeaf(YType.boolean, 'low-memory'), ['bool'])),
                                ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowProtocol', '')])),
                                ('wildcard', (YLeaf(YType.boolean, 'wildcard'), ['bool'])),
                                ('rpt_xr', (YLeaf(YType.boolean, 'rpt-xr'), ['bool'])),
                                ('spt', (YLeaf(YType.boolean, 'spt'), ['bool'])),
                                ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                                ('expiry', (YLeaf(YType.uint64, 'expiry'), ['int'])),
                                ('alive', (YLeaf(YType.int32, 'alive'), ['int'])),
                                ('register_received_timer', (YLeaf(YType.int32, 'register-received-timer'), ['int'])),
                                ('remote_source', (YLeaf(YType.boolean, 'remote-source'), ['bool'])),
                                ('crossed_threshold', (YLeaf(YType.boolean, 'crossed-threshold'), ['bool'])),
                                ('data_mdt_addr_assigned', (YLeaf(YType.boolean, 'data-mdt-addr-assigned'), ['bool'])),
                                ('rpf_interface_name', (YLeaf(YType.str, 'rpf-interface-name'), ['str'])),
                                ('rpf_vrf_name', (YLeaf(YType.str, 'rpf-vrf-name'), ['str'])),
                                ('rpf_safi', (YLeaf(YType.uint8, 'rpf-safi'), ['int'])),
                                ('rpf_table_name', (YLeaf(YType.str, 'rpf-table-name'), ['str'])),
                                ('rpf_drop', (YLeaf(YType.boolean, 'rpf-drop'), ['bool'])),
                                ('rpf_extranet', (YLeaf(YType.boolean, 'rpf-extranet'), ['bool'])),
                                ('is_via_lsm', (YLeaf(YType.boolean, 'is-via-lsm'), ['bool'])),
                                ('secondary_rpf_interface_name', (YLeaf(YType.str, 'secondary-rpf-interface-name'), ['str'])),
                                ('connected', (YLeaf(YType.boolean, 'connected'), ['bool'])),
                                ('proxy', (YLeaf(YType.boolean, 'proxy'), ['bool'])),
                                ('rpf_proxy_enabled', (YLeaf(YType.boolean, 'rpf-proxy-enabled'), ['bool'])),
                                ('mofrr_enabled', (YLeaf(YType.boolean, 'mofrr-enabled'), ['bool'])),
                                ('rib_mo_frr_enabled', (YLeaf(YType.boolean, 'rib-mo-frr-enabled'), ['bool'])),
                                ('jp_timer', (YLeaf(YType.int32, 'jp-timer'), ['int'])),
                                ('jp_status', (YLeaf(YType.int32, 'jp-status'), ['int'])),
                                ('suppress_registers', (YLeaf(YType.int32, 'suppress-registers'), ['int'])),
                                ('assume_alive', (YLeaf(YType.boolean, 'assume-alive'), ['bool'])),
                                ('probe_alive', (YLeaf(YType.boolean, 'probe-alive'), ['bool'])),
                                ('really_alive', (YLeaf(YType.boolean, 'really-alive'), ['bool'])),
                                ('inherit_alive', (YLeaf(YType.boolean, 'inherit-alive'), ['bool'])),
                                ('inherit_spt', (YLeaf(YType.boolean, 'inherit-spt'), ['bool'])),
                                ('signal_sources', (YLeaf(YType.boolean, 'signal-sources'), ['bool'])),
                                ('dont_check_connected', (YLeaf(YType.boolean, 'dont-check-connected'), ['bool'])),
                                ('register_received', (YLeaf(YType.boolean, 'register-received'), ['bool'])),
                                ('last_hop', (YLeaf(YType.boolean, 'last-hop'), ['bool'])),
                                ('sending_registers', (YLeaf(YType.boolean, 'sending-registers'), ['bool'])),
                                ('sending_null_registers', (YLeaf(YType.boolean, 'sending-null-registers'), ['bool'])),
                                ('sa_sent', (YLeaf(YType.boolean, 'sa-sent'), ['bool'])),
                                ('sa_received', (YLeaf(YType.boolean, 'sa-received'), ['bool'])),
                                ('sa_joined', (YLeaf(YType.boolean, 'sa-joined'), ['bool'])),
                                ('anycast_rp_match', (YLeaf(YType.boolean, 'anycast-rp-match'), ['bool'])),
                                ('anycast_rp_route_target', (YLeaf(YType.str, 'anycast-rp-route-target'), ['str'])),
                                ('bgp_join', (YLeaf(YType.boolean, 'bgp-join'), ['bool'])),
                                ('bgp_jp_time', (YLeaf(YType.uint64, 'bgp-jp-time'), ['int'])),
                                ('customer_routing_type', (YLeaf(YType.int32, 'customer-routing-type'), ['int'])),
                                ('extranet_route', (YLeaf(YType.boolean, 'extranet-route'), ['bool'])),
                                ('mofrr_active', (YLeaf(YType.boolean, 'mofrr-active'), ['bool'])),
                                ('mofrr_primary', (YLeaf(YType.boolean, 'mofrr-primary'), ['bool'])),
                                ('mofrr_backup', (YLeaf(YType.boolean, 'mofrr-backup'), ['bool'])),
                                ('vxlan', (YLeaf(YType.boolean, 'vxlan'), ['bool'])),
                                ('kat_state', (YLeaf(YType.boolean, 'kat-state'), ['bool'])),
                            ])
                            self.source_address = None
                            self.group_address = None
                            self.rpt = None
                            self.limit_reached = None
                            self.low_memory = None
                            self.protocol = None
                            self.wildcard = None
                            self.rpt_xr = None
                            self.spt = None
                            self.uptime = None
                            self.expiry = None
                            self.alive = None
                            self.register_received_timer = None
                            self.remote_source = None
                            self.crossed_threshold = None
                            self.data_mdt_addr_assigned = None
                            self.rpf_interface_name = None
                            self.rpf_vrf_name = None
                            self.rpf_safi = None
                            self.rpf_table_name = None
                            self.rpf_drop = None
                            self.rpf_extranet = None
                            self.is_via_lsm = None
                            self.secondary_rpf_interface_name = None
                            self.connected = None
                            self.proxy = None
                            self.rpf_proxy_enabled = None
                            self.mofrr_enabled = None
                            self.rib_mo_frr_enabled = None
                            self.jp_timer = None
                            self.jp_status = None
                            self.suppress_registers = None
                            self.assume_alive = None
                            self.probe_alive = None
                            self.really_alive = None
                            self.inherit_alive = None
                            self.inherit_spt = None
                            self.signal_sources = None
                            self.dont_check_connected = None
                            self.register_received = None
                            self.last_hop = None
                            self.sending_registers = None
                            self.sending_null_registers = None
                            self.sa_sent = None
                            self.sa_received = None
                            self.sa_joined = None
                            self.anycast_rp_match = None
                            self.anycast_rp_route_target = None
                            self.bgp_join = None
                            self.bgp_jp_time = None
                            self.customer_routing_type = None
                            self.extranet_route = None
                            self.mofrr_active = None
                            self.mofrr_primary = None
                            self.mofrr_backup = None
                            self.vxlan = None
                            self.kat_state = None

                            self.group_address_xr = Pim.Active.Vrfs.Vrf.Topologies.Topology.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"

                            self.source_address_xr = Pim.Active.Vrfs.Vrf.Topologies.Topology.SourceAddressXr()
                            self.source_address_xr.parent = self
                            self._children_name_map["source_address_xr"] = "source-address-xr"

                            self.rp_address = Pim.Active.Vrfs.Vrf.Topologies.Topology.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"

                            self.rpf_neighbor = Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfNeighbor()
                            self.rpf_neighbor.parent = self
                            self._children_name_map["rpf_neighbor"] = "rpf-neighbor"

                            self.secondary_rpf_neighbor = Pim.Active.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor()
                            self.secondary_rpf_neighbor.parent = self
                            self._children_name_map["secondary_rpf_neighbor"] = "secondary-rpf-neighbor"

                            self.rpf_root = Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfRoot()
                            self.rpf_root.parent = self
                            self._children_name_map["rpf_root"] = "rpf-root"

                            self.proxy_address = Pim.Active.Vrfs.Vrf.Topologies.Topology.ProxyAddress()
                            self.proxy_address.parent = self
                            self._children_name_map["proxy_address"] = "proxy-address"

                            self.orig_src_address = Pim.Active.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress()
                            self.orig_src_address.parent = self
                            self._children_name_map["orig_src_address"] = "orig-src-address"

                            self.outgoing_interface = YList(self)
                            self._segment_path = lambda: "topology"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.Topologies.Topology, ['source_address', 'group_address', 'rpt', 'limit_reached', 'low_memory', 'protocol', 'wildcard', 'rpt_xr', 'spt', 'uptime', 'expiry', 'alive', 'register_received_timer', 'remote_source', 'crossed_threshold', 'data_mdt_addr_assigned', 'rpf_interface_name', 'rpf_vrf_name', 'rpf_safi', 'rpf_table_name', 'rpf_drop', 'rpf_extranet', 'is_via_lsm', 'secondary_rpf_interface_name', 'connected', 'proxy', 'rpf_proxy_enabled', 'mofrr_enabled', 'rib_mo_frr_enabled', 'jp_timer', 'jp_status', 'suppress_registers', 'assume_alive', 'probe_alive', 'really_alive', 'inherit_alive', 'inherit_spt', 'signal_sources', 'dont_check_connected', 'register_received', 'last_hop', 'sending_registers', 'sending_null_registers', 'sa_sent', 'sa_received', 'sa_joined', 'anycast_rp_match', 'anycast_rp_route_target', 'bgp_join', 'bgp_jp_time', 'customer_routing_type', 'extranet_route', 'mofrr_active', 'mofrr_primary', 'mofrr_backup', 'vxlan', 'kat_state'], name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Topologies.Topology.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "group-address-xr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.Topologies.Topology.GroupAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class SourceAddressXr(Entity):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Topologies.Topology.SourceAddressXr, self).__init__()

                                self.yang_name = "source-address-xr"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "source-address-xr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.Topologies.Topology.SourceAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class RpAddress(Entity):
                            """
                            RP Address (If rpt)
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Topologies.Topology.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "rp-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.Topologies.Topology.RpAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class RpfNeighbor(Entity):
                            """
                            RPF Neighbor
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfNeighbor, self).__init__()

                                self.yang_name = "rpf-neighbor"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "rpf-neighbor"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfNeighbor, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class SecondaryRpfNeighbor(Entity):
                            """
                            Secondary RPF Neighbor
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor, self).__init__()

                                self.yang_name = "secondary-rpf-neighbor"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "secondary-rpf-neighbor"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class RpfRoot(Entity):
                            """
                            Root of this mcast tree
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfRoot, self).__init__()

                                self.yang_name = "rpf-root"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "rpf-root"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfRoot, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class ProxyAddress(Entity):
                            """
                            RPF Proxy address.
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Topologies.Topology.ProxyAddress, self).__init__()

                                self.yang_name = "proxy-address"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "proxy-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.Topologies.Topology.ProxyAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class OrigSrcAddress(Entity):
                            """
                            Orig Src Address.
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress, self).__init__()

                                self.yang_name = "orig-src-address"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "orig-src-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class OutgoingInterface(Entity):
                            """
                            Outgoing interface list
                            
                            .. attribute:: assert_winner
                            
                            	Assert Winner
                            	**type**\:  :py:class:`AssertWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner>`
                            
                            .. attribute:: interface_name
                            
                            	Interface Identifier
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: expiry
                            
                            	Expiry in seconds
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: bgp_c_mcast_prune_delay_timer
                            
                            	BGP C\-MCAST Prune Suppression in seconds
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: jp_timer
                            
                            	Join\-Prune Timer (secs)
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: second
                            
                            .. attribute:: jp_state
                            
                            	Join\-Prune State
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: assert_timer
                            
                            	Assert Timer in seconds
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: second
                            
                            .. attribute:: local_members
                            
                            	Local Information. Deprecated \- use 'local\-members\-information' instead
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: internal_interest_info
                            
                            	Internal Interest. Deprecated \- use 'internal\-interest\-information' instead
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: forwarding_state
                            
                            	Forward or Prune
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: immediate_state
                            
                            	Immediate fwding state
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: last_hop
                            
                            	Are we last hop ?
                            	**type**\: bool
                            
                            .. attribute:: mldp_inband_mdt
                            
                            	MLDP Inband MDT interface
                            	**type**\: bool
                            
                            .. attribute:: mldp_stale
                            
                            	OLE is stale
                            	**type**\: bool
                            
                            .. attribute:: sa_prune
                            
                            	BGP SA Prune state
                            	**type**\: bool
                            
                            .. attribute:: admin_boundary
                            
                            	Is this an administrative boundary ?
                            	**type**\: bool
                            
                            .. attribute:: igmp_membership
                            
                            	IGMP membership
                            	**type**\: bool
                            
                            .. attribute:: mdt_safi_join
                            
                            	MDT Safi join
                            	**type**\: bool
                            
                            .. attribute:: mvpn_safi_join
                            
                            	MVPN Safi join
                            	**type**\: bool
                            
                            .. attribute:: local_mdt_join
                            
                            	Default MDT Join
                            	**type**\: bool
                            
                            .. attribute:: data_mdt_join
                            
                            	Data MDT join
                            	**type**\: bool
                            
                            .. attribute:: mvpnv6_safi_join
                            
                            	MVPN IPv6 Safi join
                            	**type**\: bool
                            
                            .. attribute:: bgp_c_mcast_join
                            
                            	BGP C\-Mcast join
                            	**type**\: bool
                            
                            .. attribute:: vrf_name
                            
                            	VRF which physically owns
                            	**type**\: str
                            
                            	**length:** 0..33
                            
                            .. attribute:: extranet_interface
                            
                            	Is this an Extranet Interface ?
                            	**type**\: bool
                            
                            .. attribute:: internal_interest_information
                            
                            	Internal Interest. Replaces internal\-interest\-info
                            	**type**\:  :py:class:`PimInternalInterestInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimInternalInterestInfo>`
                            
                            .. attribute:: local_members_information
                            
                            	Local Information. Replaces local\-members
                            	**type**\:  :py:class:`PimShowLocalInterest <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowLocalInterest>`
                            
                            .. attribute:: assert_state
                            
                            	Assert State
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface, self).__init__()

                                self.yang_name = "outgoing-interface"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("assert-winner", ("assert_winner", Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner))])
                                self._leafs = OrderedDict([
                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                    ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                                    ('expiry', (YLeaf(YType.uint64, 'expiry'), ['int'])),
                                    ('bgp_c_mcast_prune_delay_timer', (YLeaf(YType.uint64, 'bgp-c-mcast-prune-delay-timer'), ['int'])),
                                    ('jp_timer', (YLeaf(YType.int32, 'jp-timer'), ['int'])),
                                    ('jp_state', (YLeaf(YType.int32, 'jp-state'), ['int'])),
                                    ('assert_timer', (YLeaf(YType.int32, 'assert-timer'), ['int'])),
                                    ('local_members', (YLeaf(YType.int32, 'local-members'), ['int'])),
                                    ('internal_interest_info', (YLeaf(YType.int32, 'internal-interest-info'), ['int'])),
                                    ('forwarding_state', (YLeaf(YType.int32, 'forwarding-state'), ['int'])),
                                    ('immediate_state', (YLeaf(YType.int32, 'immediate-state'), ['int'])),
                                    ('last_hop', (YLeaf(YType.boolean, 'last-hop'), ['bool'])),
                                    ('mldp_inband_mdt', (YLeaf(YType.boolean, 'mldp-inband-mdt'), ['bool'])),
                                    ('mldp_stale', (YLeaf(YType.boolean, 'mldp-stale'), ['bool'])),
                                    ('sa_prune', (YLeaf(YType.boolean, 'sa-prune'), ['bool'])),
                                    ('admin_boundary', (YLeaf(YType.boolean, 'admin-boundary'), ['bool'])),
                                    ('igmp_membership', (YLeaf(YType.boolean, 'igmp-membership'), ['bool'])),
                                    ('mdt_safi_join', (YLeaf(YType.boolean, 'mdt-safi-join'), ['bool'])),
                                    ('mvpn_safi_join', (YLeaf(YType.boolean, 'mvpn-safi-join'), ['bool'])),
                                    ('local_mdt_join', (YLeaf(YType.boolean, 'local-mdt-join'), ['bool'])),
                                    ('data_mdt_join', (YLeaf(YType.boolean, 'data-mdt-join'), ['bool'])),
                                    ('mvpnv6_safi_join', (YLeaf(YType.boolean, 'mvpnv6-safi-join'), ['bool'])),
                                    ('bgp_c_mcast_join', (YLeaf(YType.boolean, 'bgp-c-mcast-join'), ['bool'])),
                                    ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                    ('extranet_interface', (YLeaf(YType.boolean, 'extranet-interface'), ['bool'])),
                                    ('internal_interest_information', (YLeaf(YType.enumeration, 'internal-interest-information'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimInternalInterestInfo', '')])),
                                    ('local_members_information', (YLeaf(YType.enumeration, 'local-members-information'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowLocalInterest', '')])),
                                    ('assert_state', (YLeaf(YType.boolean, 'assert-state'), ['bool'])),
                                ])
                                self.interface_name = None
                                self.uptime = None
                                self.expiry = None
                                self.bgp_c_mcast_prune_delay_timer = None
                                self.jp_timer = None
                                self.jp_state = None
                                self.assert_timer = None
                                self.local_members = None
                                self.internal_interest_info = None
                                self.forwarding_state = None
                                self.immediate_state = None
                                self.last_hop = None
                                self.mldp_inband_mdt = None
                                self.mldp_stale = None
                                self.sa_prune = None
                                self.admin_boundary = None
                                self.igmp_membership = None
                                self.mdt_safi_join = None
                                self.mvpn_safi_join = None
                                self.local_mdt_join = None
                                self.data_mdt_join = None
                                self.mvpnv6_safi_join = None
                                self.bgp_c_mcast_join = None
                                self.vrf_name = None
                                self.extranet_interface = None
                                self.internal_interest_information = None
                                self.local_members_information = None
                                self.assert_state = None

                                self.assert_winner = Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner()
                                self.assert_winner.parent = self
                                self._children_name_map["assert_winner"] = "assert-winner"
                                self._segment_path = lambda: "outgoing-interface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface, ['interface_name', 'uptime', 'expiry', 'bgp_c_mcast_prune_delay_timer', 'jp_timer', 'jp_state', 'assert_timer', 'local_members', 'internal_interest_info', 'forwarding_state', 'immediate_state', 'last_hop', 'mldp_inband_mdt', 'mldp_stale', 'sa_prune', 'admin_boundary', 'igmp_membership', 'mdt_safi_join', 'mvpn_safi_join', 'local_mdt_join', 'data_mdt_join', 'mvpnv6_safi_join', 'bgp_c_mcast_join', 'vrf_name', 'extranet_interface', 'internal_interest_information', 'local_members_information', 'assert_state'], name, value)


                            class AssertWinner(Entity):
                                """
                                Assert Winner
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner, self).__init__()

                                    self.yang_name = "assert-winner"
                                    self.yang_parent_name = "outgoing-interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "assert-winner"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class BgpAfs(Entity):
                    """
                    PIM BGP SAFI table
                    
                    .. attribute:: bgp_af
                    
                    	PIM BGP SAFI information
                    	**type**\: list of  		 :py:class:`BgpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.BgpAfs, self).__init__()

                        self.yang_name = "bgp-afs"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("bgp-af", ("bgp_af", Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf))])
                        self._leafs = OrderedDict()

                        self.bgp_af = YList(self)
                        self._segment_path = lambda: "bgp-afs"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.Vrfs.Vrf.BgpAfs, [], name, value)


                    class BgpAf(Entity):
                        """
                        PIM BGP SAFI information
                        
                        .. attribute:: source_address
                        
                        	Source IP address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: group_address
                        
                        	Group IP address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source
                        
                        	Source address
                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Source>`
                        
                        .. attribute:: group
                        
                        	Group address
                        	**type**\:  :py:class:`Group <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Group>`
                        
                        .. attribute:: next_hop
                        
                        	Next hop address
                        	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.NextHop>`
                        
                        .. attribute:: route_distinguisher
                        
                        	Router ID
                        	**type**\: str
                        
                        	**length:** 0..256
                        
                        .. attribute:: extranet_path_count
                        
                        	Count of dependent extranet paths
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_bgp_added
                        
                        	SAFI learnt from BGP
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf, self).__init__()

                            self.yang_name = "bgp-af"
                            self.yang_parent_name = "bgp-afs"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("source", ("source", Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Source)), ("group", ("group", Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Group)), ("next-hop", ("next_hop", Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.NextHop))])
                            self._leafs = OrderedDict([
                                ('source_address', (YLeaf(YType.str, 'source-address'), ['str','str'])),
                                ('group_address', (YLeaf(YType.str, 'group-address'), ['str','str'])),
                                ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                ('extranet_path_count', (YLeaf(YType.uint32, 'extranet-path-count'), ['int'])),
                                ('is_bgp_added', (YLeaf(YType.boolean, 'is-bgp-added'), ['bool'])),
                            ])
                            self.source_address = None
                            self.group_address = None
                            self.route_distinguisher = None
                            self.extranet_path_count = None
                            self.is_bgp_added = None

                            self.source = Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Source()
                            self.source.parent = self
                            self._children_name_map["source"] = "source"

                            self.group = Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Group()
                            self.group.parent = self
                            self._children_name_map["group"] = "group"

                            self.next_hop = Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.NextHop()
                            self.next_hop.parent = self
                            self._children_name_map["next_hop"] = "next-hop"
                            self._segment_path = lambda: "bgp-af"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf, ['source_address', 'group_address', 'route_distinguisher', 'extranet_path_count', 'is_bgp_added'], name, value)


                        class Source(Entity):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "bgp-af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "source"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Source, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class Group(Entity):
                            """
                            Group address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Group, self).__init__()

                                self.yang_name = "group"
                                self.yang_parent_name = "bgp-af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "group"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Group, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class NextHop(Entity):
                            """
                            Next hop address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.NextHop, self).__init__()

                                self.yang_name = "next-hop"
                                self.yang_parent_name = "bgp-af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "next-hop"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.NextHop, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class AutoRp(Entity):
                    """
                    PIM Auto\-RP information
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.AutoRp, self).__init__()

                        self.yang_name = "auto-rp"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "auto-rp"
                        self._is_frozen = True


                class TopologyInterfaceFlagRouteCounts(Entity):
                    """
                    Route count for topology with interface flag set
                    
                    .. attribute:: topology_interface_flag_route_count
                    
                    	Route count for topology with interface flag set
                    	**type**\: list of  		 :py:class:`TopologyInterfaceFlagRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts, self).__init__()

                        self.yang_name = "topology-interface-flag-route-counts"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("topology-interface-flag-route-count", ("topology_interface_flag_route_count", Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount))])
                        self._leafs = OrderedDict()

                        self.topology_interface_flag_route_count = YList(self)
                        self._segment_path = lambda: "topology-interface-flag-route-counts"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts, [], name, value)


                    class TopologyInterfaceFlagRouteCount(Entity):
                        """
                        Route count for topology with interface flag
                        set
                        
                        .. attribute:: interface_flag  (key)
                        
                        	Interface flag
                        	**type**\:  :py:class:`PimTopologyInterfaceFlag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimTopologyInterfaceFlag>`
                        
                        .. attribute:: group_ranges
                        
                        	No. of (\*,G/M) routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: active_group_ranges
                        
                        	No. of (\*,G/M) routes active in mrib
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: groute_count
                        
                        	No. of (\*,G) routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sg_route_count
                        
                        	No. of (S,G) routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sgr_route_count
                        
                        	No. of (S,G)RPT routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_node_low_memory
                        
                        	Is node in low memory condition
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount, self).__init__()

                            self.yang_name = "topology-interface-flag-route-count"
                            self.yang_parent_name = "topology-interface-flag-route-counts"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['interface_flag']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface_flag', (YLeaf(YType.enumeration, 'interface-flag'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimTopologyInterfaceFlag', '')])),
                                ('group_ranges', (YLeaf(YType.uint32, 'group-ranges'), ['int'])),
                                ('active_group_ranges', (YLeaf(YType.uint32, 'active-group-ranges'), ['int'])),
                                ('groute_count', (YLeaf(YType.uint32, 'groute-count'), ['int'])),
                                ('sg_route_count', (YLeaf(YType.uint32, 'sg-route-count'), ['int'])),
                                ('sgr_route_count', (YLeaf(YType.uint32, 'sgr-route-count'), ['int'])),
                                ('is_node_low_memory', (YLeaf(YType.boolean, 'is-node-low-memory'), ['bool'])),
                            ])
                            self.interface_flag = None
                            self.group_ranges = None
                            self.active_group_ranges = None
                            self.groute_count = None
                            self.sg_route_count = None
                            self.sgr_route_count = None
                            self.is_node_low_memory = None
                            self._segment_path = lambda: "topology-interface-flag-route-count" + "[interface-flag='" + str(self.interface_flag) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount, ['interface_flag', 'group_ranges', 'active_group_ranges', 'groute_count', 'sg_route_count', 'sgr_route_count', 'is_node_low_memory'], name, value)


                class GroupMapSources(Entity):
                    """
                    PIM group\-mapping with source information
                    
                    .. attribute:: group_map_source
                    
                    	PIM Group Mapping Entry with source information
                    	**type**\: list of  		 :py:class:`GroupMapSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.GroupMapSources, self).__init__()

                        self.yang_name = "group-map-sources"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("group-map-source", ("group_map_source", Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource))])
                        self._leafs = OrderedDict()

                        self.group_map_source = YList(self)
                        self._segment_path = lambda: "group-map-sources"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.Vrfs.Vrf.GroupMapSources, [], name, value)


                    class GroupMapSource(Entity):
                        """
                        PIM Group Mapping Entry with source information
                        
                        .. attribute:: prefix
                        
                        	Prefix
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: client
                        
                        	Client
                        	**type**\:  :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:  :py:class:`PimProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimProtocol>`
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: priority
                        
                        	RP Priority
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: source_of_information
                        
                        	The source of information
                        	**type**\:  :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation>`
                        
                        .. attribute:: group_map_information
                        
                        	Group Mapping information
                        	**type**\:  :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation>`
                        
                        .. attribute:: holdtime
                        
                        	Holdtime in seconds
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: expires
                        
                        	Mapping expiry time in seconds
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: uptime
                        
                        	Mapping uptime in seconds
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource, self).__init__()

                            self.yang_name = "group-map-source"
                            self.yang_parent_name = "group-map-sources"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("source-of-information", ("source_of_information", Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation)), ("group-map-information", ("group_map_information", Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation))])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                ('client', (YLeaf(YType.enumeration, 'client'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimClient', '')])),
                                ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimProtocol', '')])),
                                ('rp_address', (YLeaf(YType.str, 'rp-address'), ['str','str'])),
                                ('priority', (YLeaf(YType.uint32, 'priority'), ['int'])),
                                ('holdtime', (YLeaf(YType.int32, 'holdtime'), ['int'])),
                                ('expires', (YLeaf(YType.uint64, 'expires'), ['int'])),
                                ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                            ])
                            self.prefix = None
                            self.prefix_length = None
                            self.client = None
                            self.protocol = None
                            self.rp_address = None
                            self.priority = None
                            self.holdtime = None
                            self.expires = None
                            self.uptime = None

                            self.source_of_information = Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation()
                            self.source_of_information.parent = self
                            self._children_name_map["source_of_information"] = "source-of-information"

                            self.group_map_information = Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation()
                            self.group_map_information.parent = self
                            self._children_name_map["group_map_information"] = "group-map-information"
                            self._segment_path = lambda: "group-map-source"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource, ['prefix', 'prefix_length', 'client', 'protocol', 'rp_address', 'priority', 'holdtime', 'expires', 'uptime'], name, value)


                        class SourceOfInformation(Entity):
                            """
                            The source of information
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation, self).__init__()

                                self.yang_name = "source-of-information"
                                self.yang_parent_name = "group-map-source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "source-of-information"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class GroupMapInformation(Entity):
                            """
                            Group Mapping information
                            
                            .. attribute:: prefix
                            
                            	Group range prefix
                            	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix>`
                            
                            .. attribute:: rp_address
                            
                            	Rendezvous Point Address
                            	**type**\:  :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress>`
                            
                            .. attribute:: prefix_length
                            
                            	Group range prefix length
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: client
                            
                            	Client mapping learnt from
                            	**type**\:  :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                            
                            .. attribute:: protocol
                            
                            	Protocol mode of the range
                            	**type**\:  :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                            
                            .. attribute:: group_count
                            
                            	No. of groups in this range
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_used
                            
                            	Is this mapping being used?
                            	**type**\: bool
                            
                            .. attribute:: mrib_active
                            
                            	Is this mapping active in MRIB?
                            	**type**\: bool
                            
                            .. attribute:: is_override
                            
                            	Is this the override range?
                            	**type**\: bool
                            
                            .. attribute:: priority
                            
                            	Bootstrap priority
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation, self).__init__()

                                self.yang_name = "group-map-information"
                                self.yang_parent_name = "group-map-source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("prefix", ("prefix", Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix)), ("rp-address", ("rp_address", Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress))])
                                self._leafs = OrderedDict([
                                    ('prefix_length', (YLeaf(YType.int32, 'prefix-length'), ['int'])),
                                    ('client', (YLeaf(YType.enumeration, 'client'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowRangeClient', '')])),
                                    ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowProtocol', '')])),
                                    ('group_count', (YLeaf(YType.uint32, 'group-count'), ['int'])),
                                    ('is_used', (YLeaf(YType.boolean, 'is-used'), ['bool'])),
                                    ('mrib_active', (YLeaf(YType.boolean, 'mrib-active'), ['bool'])),
                                    ('is_override', (YLeaf(YType.boolean, 'is-override'), ['bool'])),
                                    ('priority', (YLeaf(YType.uint32, 'priority'), ['int'])),
                                ])
                                self.prefix_length = None
                                self.client = None
                                self.protocol = None
                                self.group_count = None
                                self.is_used = None
                                self.mrib_active = None
                                self.is_override = None
                                self.priority = None

                                self.prefix = Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix()
                                self.prefix.parent = self
                                self._children_name_map["prefix"] = "prefix"

                                self.rp_address = Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress()
                                self.rp_address.parent = self
                                self._children_name_map["rp_address"] = "rp-address"
                                self._segment_path = lambda: "group-map-information"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation, ['prefix_length', 'client', 'protocol', 'group_count', 'is_used', 'mrib_active', 'is_override', 'priority'], name, value)


                            class Prefix(Entity):
                                """
                                Group range prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix, self).__init__()

                                    self.yang_name = "prefix"
                                    self.yang_parent_name = "group-map-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "prefix"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                            class RpAddress(Entity):
                                """
                                Rendezvous Point Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress, self).__init__()

                                    self.yang_name = "rp-address"
                                    self.yang_parent_name = "group-map-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "rp-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class TrafficCounters(Entity):
                    """
                    PIM message traffic counters
                    
                    .. attribute:: elapsed_time
                    
                    	Running time for counters in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: inputs
                    
                    	Packets in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: outputs
                    
                    	Packets out
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: format_error
                    
                    	Malformed packets in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pakman_error
                    
                    	Pakman packets dropped
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: standby_packets_error
                    
                    	Packets received in standby state
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: checksum_error
                    
                    	Checksum errors
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: socket_error
                    
                    	Socket errors
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: send_queue_full
                    
                    	Packets dropped since send queue was full
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: boundary_acl_rx_drop
                    
                    	Inc. JP dropped since boundary ACL confg
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: boundary_acl_tx_drop
                    
                    	Out JP dropped since boundary ACL confg
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: no_socket_connection
                    
                    	Packets dropped since no socket connection
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: no_source_address
                    
                    	Packets dropped since no source address
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_hello
                    
                    	Hello packets in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_hello
                    
                    	Hello packets out
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_jp
                    
                    	Join Prune packets in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_jp
                    
                    	Join Prune packets out
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_data_register
                    
                    	Data Register packets in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_null_register
                    
                    	Null Register packets in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_null_register
                    
                    	Null Register packets out
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_register_stop
                    
                    	Register Stop packets in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_register_stop
                    
                    	Register Stop packets out
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_assert
                    
                    	Assert packets in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_assert_batched
                    
                    	Batched Assert packets in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_assert
                    
                    	Assert packets out
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_assert_batched
                    
                    	Batched Assert packets out
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_df_election
                    
                    	DF Election packets in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_df_election
                    
                    	DF Election packets out
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_bsr_message
                    
                    	Input BSR Messages
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_bsr_message
                    
                    	Output BSR Messages
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_candidate_rp_advertisement
                    
                    	Input Candidate\-RP Advertisment
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_candidate_rp_advertisement
                    
                    	Output Candidate\-RP Advertisment
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_ecmp_redirect
                    
                    	Input Ecmp Redirect
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_ecmp_redirect
                    
                    	Output Ecmp Redirect
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_loop_error
                    
                    	Output on loopback error
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_invalid_lsm_identifier
                    
                    	 Invalid LSM ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_idb_error
                    
                    	No IDB for intf error
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_vrf_error
                    
                    	No VRF for idb error
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_pim_error
                    
                    	PIM Disabled on intf error
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_pim_version_error
                    
                    	Invalid PIM version error
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_join_group
                    
                    	Output Join Groups
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_prune_group
                    
                    	Output Prune Groups
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_join_prune_bytes
                    
                    	Output JP Bytes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: byte
                    
                    .. attribute:: output_hello_bytes
                    
                    	Output Hello Bytes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: byte
                    
                    .. attribute:: non_supported_packets
                    
                    	PIM non supported pckets
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_registers
                    
                    	PIM invalid registers received
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_join_prunes
                    
                    	PIM invalid Join/Prunes received
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_packman_error
                    
                    	Packets Dropped due to Pakman Error
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_read_socket_error
                    
                    	Packet Read Socket Error
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_queue_last_clear
                    
                    	Time in seconds since the last clear of all packet queues stats
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: packets_standby
                    
                    	Packets Dropped due to Standby Error
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: no_mdt_socket_connection
                    
                    	Packets dropped since no mdt socket connection
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_send_queue_full
                    
                    	Packets dropped since mdt send queue was full
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_socket_error
                    
                    	MDT Socket errors
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_join_tlv_sent
                    
                    	Data MDT Join Msgs sent
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_join_tlv_received
                    
                    	Data MDT Join Msgs received
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_join_bad_type
                    
                    	Data MDT TLV bad type
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_drop_local_source_address
                    
                    	Data MDT Join msgs dropped due to local source addr
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_drop_null_local_address
                    
                    	Data MDT Join msgs dropped due to null local addr
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_drop_no_idb
                    
                    	Data MDT Join msgs dropped due to idb missing
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_drop_no_vrf
                    
                    	Data MDT Join msgs dropped due to vrf missing
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_destination_packets
                    
                    	Control Packets with Invalid Destination
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_joins_drop_multiple_encapsulation
                    
                    	MDT Join msgs dropped due to multiple Encap limitation
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: truncated_pim_packets
                    
                    	Packets dropped due to truncated Joins or Prunes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_source_encodings
                    
                    	Number of invalid source encodings received
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_hello_options
                    
                    	Number of invalid hello options received
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_queue
                    
                    	Packet queue state and statistics
                    	**type**\: list of  		 :py:class:`PacketQueue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.TrafficCounters, self).__init__()

                        self.yang_name = "traffic-counters"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("packet-queue", ("packet_queue", Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue))])
                        self._leafs = OrderedDict([
                            ('elapsed_time', (YLeaf(YType.uint32, 'elapsed-time'), ['int'])),
                            ('inputs', (YLeaf(YType.uint32, 'inputs'), ['int'])),
                            ('outputs', (YLeaf(YType.uint32, 'outputs'), ['int'])),
                            ('format_error', (YLeaf(YType.uint32, 'format-error'), ['int'])),
                            ('pakman_error', (YLeaf(YType.uint32, 'pakman-error'), ['int'])),
                            ('standby_packets_error', (YLeaf(YType.uint32, 'standby-packets-error'), ['int'])),
                            ('checksum_error', (YLeaf(YType.uint32, 'checksum-error'), ['int'])),
                            ('socket_error', (YLeaf(YType.uint32, 'socket-error'), ['int'])),
                            ('send_queue_full', (YLeaf(YType.uint32, 'send-queue-full'), ['int'])),
                            ('boundary_acl_rx_drop', (YLeaf(YType.uint32, 'boundary-acl-rx-drop'), ['int'])),
                            ('boundary_acl_tx_drop', (YLeaf(YType.uint32, 'boundary-acl-tx-drop'), ['int'])),
                            ('no_socket_connection', (YLeaf(YType.uint32, 'no-socket-connection'), ['int'])),
                            ('no_source_address', (YLeaf(YType.uint32, 'no-source-address'), ['int'])),
                            ('input_hello', (YLeaf(YType.uint32, 'input-hello'), ['int'])),
                            ('output_hello', (YLeaf(YType.uint32, 'output-hello'), ['int'])),
                            ('input_jp', (YLeaf(YType.uint32, 'input-jp'), ['int'])),
                            ('output_jp', (YLeaf(YType.uint32, 'output-jp'), ['int'])),
                            ('input_data_register', (YLeaf(YType.uint32, 'input-data-register'), ['int'])),
                            ('input_null_register', (YLeaf(YType.uint32, 'input-null-register'), ['int'])),
                            ('output_null_register', (YLeaf(YType.uint32, 'output-null-register'), ['int'])),
                            ('input_register_stop', (YLeaf(YType.uint32, 'input-register-stop'), ['int'])),
                            ('output_register_stop', (YLeaf(YType.uint32, 'output-register-stop'), ['int'])),
                            ('input_assert', (YLeaf(YType.uint32, 'input-assert'), ['int'])),
                            ('input_assert_batched', (YLeaf(YType.uint32, 'input-assert-batched'), ['int'])),
                            ('output_assert', (YLeaf(YType.uint32, 'output-assert'), ['int'])),
                            ('output_assert_batched', (YLeaf(YType.uint32, 'output-assert-batched'), ['int'])),
                            ('input_df_election', (YLeaf(YType.uint32, 'input-df-election'), ['int'])),
                            ('output_df_election', (YLeaf(YType.uint32, 'output-df-election'), ['int'])),
                            ('input_bsr_message', (YLeaf(YType.uint32, 'input-bsr-message'), ['int'])),
                            ('output_bsr_message', (YLeaf(YType.uint32, 'output-bsr-message'), ['int'])),
                            ('input_candidate_rp_advertisement', (YLeaf(YType.uint32, 'input-candidate-rp-advertisement'), ['int'])),
                            ('output_candidate_rp_advertisement', (YLeaf(YType.uint32, 'output-candidate-rp-advertisement'), ['int'])),
                            ('input_ecmp_redirect', (YLeaf(YType.uint32, 'input-ecmp-redirect'), ['int'])),
                            ('output_ecmp_redirect', (YLeaf(YType.uint32, 'output-ecmp-redirect'), ['int'])),
                            ('output_loop_error', (YLeaf(YType.uint32, 'output-loop-error'), ['int'])),
                            ('mldp_mdt_invalid_lsm_identifier', (YLeaf(YType.uint32, 'mldp-mdt-invalid-lsm-identifier'), ['int'])),
                            ('input_no_idb_error', (YLeaf(YType.uint32, 'input-no-idb-error'), ['int'])),
                            ('input_no_vrf_error', (YLeaf(YType.uint32, 'input-no-vrf-error'), ['int'])),
                            ('input_no_pim_error', (YLeaf(YType.uint32, 'input-no-pim-error'), ['int'])),
                            ('input_pim_version_error', (YLeaf(YType.uint32, 'input-pim-version-error'), ['int'])),
                            ('output_join_group', (YLeaf(YType.uint32, 'output-join-group'), ['int'])),
                            ('output_prune_group', (YLeaf(YType.uint32, 'output-prune-group'), ['int'])),
                            ('output_join_prune_bytes', (YLeaf(YType.uint32, 'output-join-prune-bytes'), ['int'])),
                            ('output_hello_bytes', (YLeaf(YType.uint32, 'output-hello-bytes'), ['int'])),
                            ('non_supported_packets', (YLeaf(YType.uint32, 'non-supported-packets'), ['int'])),
                            ('invalid_registers', (YLeaf(YType.uint32, 'invalid-registers'), ['int'])),
                            ('invalid_join_prunes', (YLeaf(YType.uint32, 'invalid-join-prunes'), ['int'])),
                            ('packet_packman_error', (YLeaf(YType.uint32, 'packet-packman-error'), ['int'])),
                            ('packet_read_socket_error', (YLeaf(YType.uint32, 'packet-read-socket-error'), ['int'])),
                            ('packet_queue_last_clear', (YLeaf(YType.uint32, 'packet-queue-last-clear'), ['int'])),
                            ('packets_standby', (YLeaf(YType.uint32, 'packets-standby'), ['int'])),
                            ('no_mdt_socket_connection', (YLeaf(YType.uint32, 'no-mdt-socket-connection'), ['int'])),
                            ('mdt_send_queue_full', (YLeaf(YType.uint32, 'mdt-send-queue-full'), ['int'])),
                            ('mdt_socket_error', (YLeaf(YType.uint32, 'mdt-socket-error'), ['int'])),
                            ('mdt_join_tlv_sent', (YLeaf(YType.uint32, 'mdt-join-tlv-sent'), ['int'])),
                            ('mdt_join_tlv_received', (YLeaf(YType.uint32, 'mdt-join-tlv-received'), ['int'])),
                            ('mdt_join_bad_type', (YLeaf(YType.uint32, 'mdt-join-bad-type'), ['int'])),
                            ('mdt_drop_local_source_address', (YLeaf(YType.uint32, 'mdt-drop-local-source-address'), ['int'])),
                            ('mdt_drop_null_local_address', (YLeaf(YType.uint32, 'mdt-drop-null-local-address'), ['int'])),
                            ('mdt_drop_no_idb', (YLeaf(YType.uint32, 'mdt-drop-no-idb'), ['int'])),
                            ('mdt_drop_no_vrf', (YLeaf(YType.uint32, 'mdt-drop-no-vrf'), ['int'])),
                            ('invalid_destination_packets', (YLeaf(YType.uint32, 'invalid-destination-packets'), ['int'])),
                            ('mdt_joins_drop_multiple_encapsulation', (YLeaf(YType.uint32, 'mdt-joins-drop-multiple-encapsulation'), ['int'])),
                            ('truncated_pim_packets', (YLeaf(YType.uint32, 'truncated-pim-packets'), ['int'])),
                            ('invalid_source_encodings', (YLeaf(YType.uint32, 'invalid-source-encodings'), ['int'])),
                            ('invalid_hello_options', (YLeaf(YType.uint32, 'invalid-hello-options'), ['int'])),
                        ])
                        self.elapsed_time = None
                        self.inputs = None
                        self.outputs = None
                        self.format_error = None
                        self.pakman_error = None
                        self.standby_packets_error = None
                        self.checksum_error = None
                        self.socket_error = None
                        self.send_queue_full = None
                        self.boundary_acl_rx_drop = None
                        self.boundary_acl_tx_drop = None
                        self.no_socket_connection = None
                        self.no_source_address = None
                        self.input_hello = None
                        self.output_hello = None
                        self.input_jp = None
                        self.output_jp = None
                        self.input_data_register = None
                        self.input_null_register = None
                        self.output_null_register = None
                        self.input_register_stop = None
                        self.output_register_stop = None
                        self.input_assert = None
                        self.input_assert_batched = None
                        self.output_assert = None
                        self.output_assert_batched = None
                        self.input_df_election = None
                        self.output_df_election = None
                        self.input_bsr_message = None
                        self.output_bsr_message = None
                        self.input_candidate_rp_advertisement = None
                        self.output_candidate_rp_advertisement = None
                        self.input_ecmp_redirect = None
                        self.output_ecmp_redirect = None
                        self.output_loop_error = None
                        self.mldp_mdt_invalid_lsm_identifier = None
                        self.input_no_idb_error = None
                        self.input_no_vrf_error = None
                        self.input_no_pim_error = None
                        self.input_pim_version_error = None
                        self.output_join_group = None
                        self.output_prune_group = None
                        self.output_join_prune_bytes = None
                        self.output_hello_bytes = None
                        self.non_supported_packets = None
                        self.invalid_registers = None
                        self.invalid_join_prunes = None
                        self.packet_packman_error = None
                        self.packet_read_socket_error = None
                        self.packet_queue_last_clear = None
                        self.packets_standby = None
                        self.no_mdt_socket_connection = None
                        self.mdt_send_queue_full = None
                        self.mdt_socket_error = None
                        self.mdt_join_tlv_sent = None
                        self.mdt_join_tlv_received = None
                        self.mdt_join_bad_type = None
                        self.mdt_drop_local_source_address = None
                        self.mdt_drop_null_local_address = None
                        self.mdt_drop_no_idb = None
                        self.mdt_drop_no_vrf = None
                        self.invalid_destination_packets = None
                        self.mdt_joins_drop_multiple_encapsulation = None
                        self.truncated_pim_packets = None
                        self.invalid_source_encodings = None
                        self.invalid_hello_options = None

                        self.packet_queue = YList(self)
                        self._segment_path = lambda: "traffic-counters"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.Vrfs.Vrf.TrafficCounters, ['elapsed_time', 'inputs', 'outputs', 'format_error', 'pakman_error', 'standby_packets_error', 'checksum_error', 'socket_error', 'send_queue_full', 'boundary_acl_rx_drop', 'boundary_acl_tx_drop', 'no_socket_connection', 'no_source_address', 'input_hello', 'output_hello', 'input_jp', 'output_jp', 'input_data_register', 'input_null_register', 'output_null_register', 'input_register_stop', 'output_register_stop', 'input_assert', 'input_assert_batched', 'output_assert', 'output_assert_batched', 'input_df_election', 'output_df_election', 'input_bsr_message', 'output_bsr_message', 'input_candidate_rp_advertisement', 'output_candidate_rp_advertisement', 'input_ecmp_redirect', 'output_ecmp_redirect', 'output_loop_error', 'mldp_mdt_invalid_lsm_identifier', 'input_no_idb_error', 'input_no_vrf_error', 'input_no_pim_error', 'input_pim_version_error', 'output_join_group', 'output_prune_group', 'output_join_prune_bytes', 'output_hello_bytes', 'non_supported_packets', 'invalid_registers', 'invalid_join_prunes', 'packet_packman_error', 'packet_read_socket_error', 'packet_queue_last_clear', 'packets_standby', 'no_mdt_socket_connection', 'mdt_send_queue_full', 'mdt_socket_error', 'mdt_join_tlv_sent', 'mdt_join_tlv_received', 'mdt_join_bad_type', 'mdt_drop_local_source_address', 'mdt_drop_null_local_address', 'mdt_drop_no_idb', 'mdt_drop_no_vrf', 'invalid_destination_packets', 'mdt_joins_drop_multiple_encapsulation', 'truncated_pim_packets', 'invalid_source_encodings', 'invalid_hello_options'], name, value)


                    class PacketQueue(Entity):
                        """
                        Packet queue state and statistics
                        
                        .. attribute:: packet_queue_state
                        
                        	State of the queue
                        	**type**\:  :py:class:`PacketQueueState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState>`
                        
                        .. attribute:: packet_queue_stats
                        
                        	Statistics about the queue
                        	**type**\:  :py:class:`PacketQueueStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats>`
                        
                        .. attribute:: packet_queue_priority
                        
                        	Priority of this packet queue
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue, self).__init__()

                            self.yang_name = "packet-queue"
                            self.yang_parent_name = "traffic-counters"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("packet-queue-state", ("packet_queue_state", Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState)), ("packet-queue-stats", ("packet_queue_stats", Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats))])
                            self._leafs = OrderedDict([
                                ('packet_queue_priority', (YLeaf(YType.uint32, 'packet-queue-priority'), ['int'])),
                            ])
                            self.packet_queue_priority = None

                            self.packet_queue_state = Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState()
                            self.packet_queue_state.parent = self
                            self._children_name_map["packet_queue_state"] = "packet-queue-state"

                            self.packet_queue_stats = Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats()
                            self.packet_queue_stats.parent = self
                            self._children_name_map["packet_queue_stats"] = "packet-queue-stats"
                            self._segment_path = lambda: "packet-queue"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue, ['packet_queue_priority'], name, value)


                        class PacketQueueState(Entity):
                            """
                            State of the queue
                            
                            .. attribute:: max_queue_size
                            
                            	Maximum size of queue in bytes
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: queue_size_bytes
                            
                            	Size of queue in bytes
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: queue_size_packets
                            
                            	Size of queue in number of packets
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState, self).__init__()

                                self.yang_name = "packet-queue-state"
                                self.yang_parent_name = "packet-queue"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('max_queue_size', (YLeaf(YType.uint32, 'max-queue-size'), ['int'])),
                                    ('queue_size_bytes', (YLeaf(YType.uint32, 'queue-size-bytes'), ['int'])),
                                    ('queue_size_packets', (YLeaf(YType.uint32, 'queue-size-packets'), ['int'])),
                                ])
                                self.max_queue_size = None
                                self.queue_size_bytes = None
                                self.queue_size_packets = None
                                self._segment_path = lambda: "packet-queue-state"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState, ['max_queue_size', 'queue_size_bytes', 'queue_size_packets'], name, value)


                        class PacketQueueStats(Entity):
                            """
                            Statistics about the queue
                            
                            .. attribute:: enqueued_packets
                            
                            	Total number of packets enqueued to this queue
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: dequeued_packets
                            
                            	Total number of packets dequeued from this queue
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: high_water_mark_packets
                            
                            	Highest number of packets enqueued in this queue
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: high_water_mark_bytes
                            
                            	Highest number of bytes enqueued in this queue
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: tail_drops
                            
                            	Number packets dropped from this queue due to max size
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats, self).__init__()

                                self.yang_name = "packet-queue-stats"
                                self.yang_parent_name = "packet-queue"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('enqueued_packets', (YLeaf(YType.uint32, 'enqueued-packets'), ['int'])),
                                    ('dequeued_packets', (YLeaf(YType.uint32, 'dequeued-packets'), ['int'])),
                                    ('high_water_mark_packets', (YLeaf(YType.uint32, 'high-water-mark-packets'), ['int'])),
                                    ('high_water_mark_bytes', (YLeaf(YType.uint32, 'high-water-mark-bytes'), ['int'])),
                                    ('tail_drops', (YLeaf(YType.uint32, 'tail-drops'), ['int'])),
                                ])
                                self.enqueued_packets = None
                                self.dequeued_packets = None
                                self.high_water_mark_packets = None
                                self.high_water_mark_bytes = None
                                self.tail_drops = None
                                self._segment_path = lambda: "packet-queue-stats"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats, ['enqueued_packets', 'dequeued_packets', 'high_water_mark_packets', 'high_water_mark_bytes', 'tail_drops'], name, value)


                class GroupMapRpfs(Entity):
                    """
                    PIM group mapping information
                    
                    .. attribute:: group_map_rpf
                    
                    	PIM group mapping entry
                    	**type**\: list of  		 :py:class:`GroupMapRpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.GroupMapRpfs, self).__init__()

                        self.yang_name = "group-map-rpfs"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("group-map-rpf", ("group_map_rpf", Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf))])
                        self._leafs = OrderedDict()

                        self.group_map_rpf = YList(self)
                        self._segment_path = lambda: "group-map-rpfs"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.Vrfs.Vrf.GroupMapRpfs, [], name, value)


                    class GroupMapRpf(Entity):
                        """
                        PIM group mapping entry
                        
                        .. attribute:: prefix
                        
                        	Prefix
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: client
                        
                        	Client
                        	**type**\:  :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:  :py:class:`PimProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimProtocol>`
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: rp_priority
                        
                        	RP priority
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rpf_neighbor
                        
                        	RPF neighbor to the RP
                        	**type**\:  :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor>`
                        
                        .. attribute:: group_map_information
                        
                        	Group Mapping information
                        	**type**\:  :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation>`
                        
                        .. attribute:: are_we_rp
                        
                        	Are we the RP?
                        	**type**\: bool
                        
                        .. attribute:: rpf_interface_name
                        
                        	RPF interface to the RP
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: rpf_vrf_name
                        
                        	RPF VRF Name
                        	**type**\: str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf, self).__init__()

                            self.yang_name = "group-map-rpf"
                            self.yang_parent_name = "group-map-rpfs"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rpf-neighbor", ("rpf_neighbor", Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor)), ("group-map-information", ("group_map_information", Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation))])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                ('client', (YLeaf(YType.enumeration, 'client'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimClient', '')])),
                                ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimProtocol', '')])),
                                ('rp_address', (YLeaf(YType.str, 'rp-address'), ['str','str'])),
                                ('rp_priority', (YLeaf(YType.uint32, 'rp-priority'), ['int'])),
                                ('are_we_rp', (YLeaf(YType.boolean, 'are-we-rp'), ['bool'])),
                                ('rpf_interface_name', (YLeaf(YType.str, 'rpf-interface-name'), ['str'])),
                                ('rpf_vrf_name', (YLeaf(YType.str, 'rpf-vrf-name'), ['str'])),
                            ])
                            self.prefix = None
                            self.prefix_length = None
                            self.client = None
                            self.protocol = None
                            self.rp_address = None
                            self.rp_priority = None
                            self.are_we_rp = None
                            self.rpf_interface_name = None
                            self.rpf_vrf_name = None

                            self.rpf_neighbor = Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor()
                            self.rpf_neighbor.parent = self
                            self._children_name_map["rpf_neighbor"] = "rpf-neighbor"

                            self.group_map_information = Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation()
                            self.group_map_information.parent = self
                            self._children_name_map["group_map_information"] = "group-map-information"
                            self._segment_path = lambda: "group-map-rpf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf, ['prefix', 'prefix_length', 'client', 'protocol', 'rp_address', 'rp_priority', 'are_we_rp', 'rpf_interface_name', 'rpf_vrf_name'], name, value)


                        class RpfNeighbor(Entity):
                            """
                            RPF neighbor to the RP
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor, self).__init__()

                                self.yang_name = "rpf-neighbor"
                                self.yang_parent_name = "group-map-rpf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "rpf-neighbor"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class GroupMapInformation(Entity):
                            """
                            Group Mapping information
                            
                            .. attribute:: prefix
                            
                            	Group range prefix
                            	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix>`
                            
                            .. attribute:: rp_address
                            
                            	Rendezvous Point Address
                            	**type**\:  :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress>`
                            
                            .. attribute:: prefix_length
                            
                            	Group range prefix length
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: client
                            
                            	Client mapping learnt from
                            	**type**\:  :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                            
                            .. attribute:: protocol
                            
                            	Protocol mode of the range
                            	**type**\:  :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                            
                            .. attribute:: group_count
                            
                            	No. of groups in this range
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_used
                            
                            	Is this mapping being used?
                            	**type**\: bool
                            
                            .. attribute:: mrib_active
                            
                            	Is this mapping active in MRIB?
                            	**type**\: bool
                            
                            .. attribute:: is_override
                            
                            	Is this the override range?
                            	**type**\: bool
                            
                            .. attribute:: priority
                            
                            	Bootstrap priority
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation, self).__init__()

                                self.yang_name = "group-map-information"
                                self.yang_parent_name = "group-map-rpf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("prefix", ("prefix", Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix)), ("rp-address", ("rp_address", Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress))])
                                self._leafs = OrderedDict([
                                    ('prefix_length', (YLeaf(YType.int32, 'prefix-length'), ['int'])),
                                    ('client', (YLeaf(YType.enumeration, 'client'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowRangeClient', '')])),
                                    ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowProtocol', '')])),
                                    ('group_count', (YLeaf(YType.uint32, 'group-count'), ['int'])),
                                    ('is_used', (YLeaf(YType.boolean, 'is-used'), ['bool'])),
                                    ('mrib_active', (YLeaf(YType.boolean, 'mrib-active'), ['bool'])),
                                    ('is_override', (YLeaf(YType.boolean, 'is-override'), ['bool'])),
                                    ('priority', (YLeaf(YType.uint32, 'priority'), ['int'])),
                                ])
                                self.prefix_length = None
                                self.client = None
                                self.protocol = None
                                self.group_count = None
                                self.is_used = None
                                self.mrib_active = None
                                self.is_override = None
                                self.priority = None

                                self.prefix = Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix()
                                self.prefix.parent = self
                                self._children_name_map["prefix"] = "prefix"

                                self.rp_address = Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress()
                                self.rp_address.parent = self
                                self._children_name_map["rp_address"] = "rp-address"
                                self._segment_path = lambda: "group-map-information"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation, ['prefix_length', 'client', 'protocol', 'group_count', 'is_used', 'mrib_active', 'is_override', 'priority'], name, value)


                            class Prefix(Entity):
                                """
                                Group range prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix, self).__init__()

                                    self.yang_name = "prefix"
                                    self.yang_parent_name = "group-map-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "prefix"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                            class RpAddress(Entity):
                                """
                                Rendezvous Point Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress, self).__init__()

                                    self.yang_name = "rp-address"
                                    self.yang_parent_name = "group-map-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "rp-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class Summary(Entity):
                    """
                    PIM summary
                    
                    .. attribute:: route_limit
                    
                    	Maximum routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_count
                    
                    	Current routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_low_water_mark
                    
                    	The number of routes below which the throttle on route creation will be lifted
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_route_limit_reached
                    
                    	Is route creation throttled
                    	**type**\: bool
                    
                    .. attribute:: topology_interface_state_limit
                    
                    	Maximum Topology Interface State count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: topology_interface_state_count
                    
                    	Current Topology Interface State count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rxi_low_water_mark
                    
                    	The rxi below which the throttle on interface creation will be lifted
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rxi_limit_reached
                    
                    	Is interface creation throttled
                    	**type**\: bool
                    
                    .. attribute:: register_limit
                    
                    	Maximum registers
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: register_count
                    
                    	Current registers
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: register_limit_reached
                    
                    	Is PIM SM register handling throttled
                    	**type**\: bool
                    
                    .. attribute:: ranges_limit
                    
                    	Maximum group ranges from Autorp
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ranges_count
                    
                    	Current group ranges from Autorp
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ranges_threshold
                    
                    	OOR theshold of grange ranges from AutoRP
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_ranges_limit_reached
                    
                    	Is Auto\-RP group\-to\-RP mapping range creation throttled
                    	**type**\: bool
                    
                    .. attribute:: bsr_ranges_limit
                    
                    	Maximum group ranges from BSR
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_ranges_count
                    
                    	Current group ranges from BSR
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_range_threshold
                    
                    	Threshold group range from BSR
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_bsr_ranges_threshold_reached
                    
                    	Is VRF\-specific BSR group\-to\-RP mapping range creation throttled
                    	**type**\: bool
                    
                    .. attribute:: bsr_candidate_rp_set_limit
                    
                    	Maximum crp\-set from BSR
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_candidate_rp_set_count
                    
                    	Current crp\-set count from BSR
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_candidate_rp_set_threshold
                    
                    	Threshold crp\-set from BSR
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_maximum_enforcement_disabled
                    
                    	Is maximum enforcement disabled
                    	**type**\: bool
                    
                    .. attribute:: is_node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\: bool
                    
                    .. attribute:: route_threshold
                    
                    	Threshold routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_auto_rp_ranges_limit
                    
                    	Global Auto\-RP maximum group ranges
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_global_auto_rp_ranges_limit_reached
                    
                    	Is global AutoRP group\-to\-RP mapping range creation throttled
                    	**type**\: bool
                    
                    .. attribute:: global_bsr_ranges_limit
                    
                    	Global BSR maximum group ranges
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_ranges_count
                    
                    	Global BSR current group ranges
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_ranges_threshold
                    
                    	Global BSR Threshold group ranges
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_global_bsr_ranges_limit_reached
                    
                    	Is global BSR group\-to\-RP mapping range creation throttled
                    	**type**\: bool
                    
                    .. attribute:: global_bsr_candidate_rp_set_limit
                    
                    	Global BSR maximum crp\-set
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_candidate_rp_set_count
                    
                    	Global BSR current crp\-set count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_candidate_rp_set_threshold
                    
                    	Global BSR Threshold crp\-set
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_global_route_limit_reached
                    
                    	Is global route creation throttled
                    	**type**\: bool
                    
                    .. attribute:: topology_interface_state_threshold
                    
                    	Topology Interface State threshold
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_global_rxi_limit_reached
                    
                    	Is global interface creation throttled
                    	**type**\: bool
                    
                    .. attribute:: register_threshold
                    
                    	Threshold registers
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_register_limit
                    
                    	Maximum global registers
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_global_register_limit_reached
                    
                    	Is global PIM SM register handling throttled
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.Summary, self).__init__()

                        self.yang_name = "summary"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_limit', (YLeaf(YType.uint32, 'route-limit'), ['int'])),
                            ('route_count', (YLeaf(YType.uint32, 'route-count'), ['int'])),
                            ('route_low_water_mark', (YLeaf(YType.uint32, 'route-low-water-mark'), ['int'])),
                            ('is_route_limit_reached', (YLeaf(YType.boolean, 'is-route-limit-reached'), ['bool'])),
                            ('topology_interface_state_limit', (YLeaf(YType.uint32, 'topology-interface-state-limit'), ['int'])),
                            ('topology_interface_state_count', (YLeaf(YType.uint32, 'topology-interface-state-count'), ['int'])),
                            ('rxi_low_water_mark', (YLeaf(YType.uint32, 'rxi-low-water-mark'), ['int'])),
                            ('rxi_limit_reached', (YLeaf(YType.boolean, 'rxi-limit-reached'), ['bool'])),
                            ('register_limit', (YLeaf(YType.uint32, 'register-limit'), ['int'])),
                            ('register_count', (YLeaf(YType.uint32, 'register-count'), ['int'])),
                            ('register_limit_reached', (YLeaf(YType.boolean, 'register-limit-reached'), ['bool'])),
                            ('ranges_limit', (YLeaf(YType.uint32, 'ranges-limit'), ['int'])),
                            ('ranges_count', (YLeaf(YType.uint32, 'ranges-count'), ['int'])),
                            ('ranges_threshold', (YLeaf(YType.uint32, 'ranges-threshold'), ['int'])),
                            ('is_ranges_limit_reached', (YLeaf(YType.boolean, 'is-ranges-limit-reached'), ['bool'])),
                            ('bsr_ranges_limit', (YLeaf(YType.uint32, 'bsr-ranges-limit'), ['int'])),
                            ('bsr_ranges_count', (YLeaf(YType.uint32, 'bsr-ranges-count'), ['int'])),
                            ('bsr_range_threshold', (YLeaf(YType.uint32, 'bsr-range-threshold'), ['int'])),
                            ('is_bsr_ranges_threshold_reached', (YLeaf(YType.boolean, 'is-bsr-ranges-threshold-reached'), ['bool'])),
                            ('bsr_candidate_rp_set_limit', (YLeaf(YType.uint32, 'bsr-candidate-rp-set-limit'), ['int'])),
                            ('bsr_candidate_rp_set_count', (YLeaf(YType.uint32, 'bsr-candidate-rp-set-count'), ['int'])),
                            ('bsr_candidate_rp_set_threshold', (YLeaf(YType.uint32, 'bsr-candidate-rp-set-threshold'), ['int'])),
                            ('is_maximum_enforcement_disabled', (YLeaf(YType.boolean, 'is-maximum-enforcement-disabled'), ['bool'])),
                            ('is_node_low_memory', (YLeaf(YType.boolean, 'is-node-low-memory'), ['bool'])),
                            ('route_threshold', (YLeaf(YType.uint32, 'route-threshold'), ['int'])),
                            ('global_auto_rp_ranges_limit', (YLeaf(YType.uint32, 'global-auto-rp-ranges-limit'), ['int'])),
                            ('is_global_auto_rp_ranges_limit_reached', (YLeaf(YType.boolean, 'is-global-auto-rp-ranges-limit-reached'), ['bool'])),
                            ('global_bsr_ranges_limit', (YLeaf(YType.uint32, 'global-bsr-ranges-limit'), ['int'])),
                            ('global_bsr_ranges_count', (YLeaf(YType.uint32, 'global-bsr-ranges-count'), ['int'])),
                            ('global_bsr_ranges_threshold', (YLeaf(YType.uint32, 'global-bsr-ranges-threshold'), ['int'])),
                            ('is_global_bsr_ranges_limit_reached', (YLeaf(YType.boolean, 'is-global-bsr-ranges-limit-reached'), ['bool'])),
                            ('global_bsr_candidate_rp_set_limit', (YLeaf(YType.uint32, 'global-bsr-candidate-rp-set-limit'), ['int'])),
                            ('global_bsr_candidate_rp_set_count', (YLeaf(YType.uint32, 'global-bsr-candidate-rp-set-count'), ['int'])),
                            ('global_bsr_candidate_rp_set_threshold', (YLeaf(YType.uint32, 'global-bsr-candidate-rp-set-threshold'), ['int'])),
                            ('is_global_route_limit_reached', (YLeaf(YType.boolean, 'is-global-route-limit-reached'), ['bool'])),
                            ('topology_interface_state_threshold', (YLeaf(YType.uint32, 'topology-interface-state-threshold'), ['int'])),
                            ('is_global_rxi_limit_reached', (YLeaf(YType.boolean, 'is-global-rxi-limit-reached'), ['bool'])),
                            ('register_threshold', (YLeaf(YType.uint32, 'register-threshold'), ['int'])),
                            ('global_register_limit', (YLeaf(YType.uint32, 'global-register-limit'), ['int'])),
                            ('is_global_register_limit_reached', (YLeaf(YType.boolean, 'is-global-register-limit-reached'), ['bool'])),
                        ])
                        self.route_limit = None
                        self.route_count = None
                        self.route_low_water_mark = None
                        self.is_route_limit_reached = None
                        self.topology_interface_state_limit = None
                        self.topology_interface_state_count = None
                        self.rxi_low_water_mark = None
                        self.rxi_limit_reached = None
                        self.register_limit = None
                        self.register_count = None
                        self.register_limit_reached = None
                        self.ranges_limit = None
                        self.ranges_count = None
                        self.ranges_threshold = None
                        self.is_ranges_limit_reached = None
                        self.bsr_ranges_limit = None
                        self.bsr_ranges_count = None
                        self.bsr_range_threshold = None
                        self.is_bsr_ranges_threshold_reached = None
                        self.bsr_candidate_rp_set_limit = None
                        self.bsr_candidate_rp_set_count = None
                        self.bsr_candidate_rp_set_threshold = None
                        self.is_maximum_enforcement_disabled = None
                        self.is_node_low_memory = None
                        self.route_threshold = None
                        self.global_auto_rp_ranges_limit = None
                        self.is_global_auto_rp_ranges_limit_reached = None
                        self.global_bsr_ranges_limit = None
                        self.global_bsr_ranges_count = None
                        self.global_bsr_ranges_threshold = None
                        self.is_global_bsr_ranges_limit_reached = None
                        self.global_bsr_candidate_rp_set_limit = None
                        self.global_bsr_candidate_rp_set_count = None
                        self.global_bsr_candidate_rp_set_threshold = None
                        self.is_global_route_limit_reached = None
                        self.topology_interface_state_threshold = None
                        self.is_global_rxi_limit_reached = None
                        self.register_threshold = None
                        self.global_register_limit = None
                        self.is_global_register_limit_reached = None
                        self._segment_path = lambda: "summary"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.Vrfs.Vrf.Summary, ['route_limit', 'route_count', 'route_low_water_mark', 'is_route_limit_reached', 'topology_interface_state_limit', 'topology_interface_state_count', 'rxi_low_water_mark', 'rxi_limit_reached', 'register_limit', 'register_count', 'register_limit_reached', 'ranges_limit', 'ranges_count', 'ranges_threshold', 'is_ranges_limit_reached', 'bsr_ranges_limit', 'bsr_ranges_count', 'bsr_range_threshold', 'is_bsr_ranges_threshold_reached', 'bsr_candidate_rp_set_limit', 'bsr_candidate_rp_set_count', 'bsr_candidate_rp_set_threshold', 'is_maximum_enforcement_disabled', 'is_node_low_memory', 'route_threshold', 'global_auto_rp_ranges_limit', 'is_global_auto_rp_ranges_limit_reached', 'global_bsr_ranges_limit', 'global_bsr_ranges_count', 'global_bsr_ranges_threshold', 'is_global_bsr_ranges_limit_reached', 'global_bsr_candidate_rp_set_limit', 'global_bsr_candidate_rp_set_count', 'global_bsr_candidate_rp_set_threshold', 'is_global_route_limit_reached', 'topology_interface_state_threshold', 'is_global_rxi_limit_reached', 'register_threshold', 'global_register_limit', 'is_global_register_limit_reached'], name, value)


                class Gre(Entity):
                    """
                    GRE information
                    
                    .. attribute:: gre_hashes
                    
                    	GRE hash
                    	**type**\:  :py:class:`GreHashes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Gre.GreHashes>`
                    
                    .. attribute:: gre_next_hops
                    
                    	GRE destination neighbor table
                    	**type**\:  :py:class:`GreNextHops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Gre.GreNextHops>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.Gre, self).__init__()

                        self.yang_name = "gre"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("gre-hashes", ("gre_hashes", Pim.Active.Vrfs.Vrf.Gre.GreHashes)), ("gre-next-hops", ("gre_next_hops", Pim.Active.Vrfs.Vrf.Gre.GreNextHops))])
                        self._leafs = OrderedDict()

                        self.gre_hashes = Pim.Active.Vrfs.Vrf.Gre.GreHashes()
                        self.gre_hashes.parent = self
                        self._children_name_map["gre_hashes"] = "gre-hashes"

                        self.gre_next_hops = Pim.Active.Vrfs.Vrf.Gre.GreNextHops()
                        self.gre_next_hops.parent = self
                        self._children_name_map["gre_next_hops"] = "gre-next-hops"
                        self._segment_path = lambda: "gre"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.Vrfs.Vrf.Gre, [], name, value)


                    class GreHashes(Entity):
                        """
                        GRE hash
                        
                        .. attribute:: gre_hash
                        
                        	PIM GRE Hashed Underlying Interface
                        	**type**\: list of  		 :py:class:`GreHash <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Gre.GreHashes.GreHash>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.Gre.GreHashes, self).__init__()

                            self.yang_name = "gre-hashes"
                            self.yang_parent_name = "gre"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("gre-hash", ("gre_hash", Pim.Active.Vrfs.Vrf.Gre.GreHashes.GreHash))])
                            self._leafs = OrderedDict()

                            self.gre_hash = YList(self)
                            self._segment_path = lambda: "gre-hashes"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.Gre.GreHashes, [], name, value)


                        class GreHash(Entity):
                            """
                            PIM GRE Hashed Underlying Interface
                            
                            .. attribute:: source_address  (key)
                            
                            	Source address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: destination_address  (key)
                            
                            	Destination address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ifname  (key)
                            
                            	GRE Tunnel Interface
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: next_hop_interface
                            
                            	Next hop neighbor interface
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Gre.GreHashes.GreHash, self).__init__()

                                self.yang_name = "gre-hash"
                                self.yang_parent_name = "gre-hashes"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['source_address','destination_address','ifname']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('source_address', (YLeaf(YType.str, 'source-address'), ['str','str'])),
                                    ('destination_address', (YLeaf(YType.str, 'destination-address'), ['str','str'])),
                                    ('ifname', (YLeaf(YType.str, 'ifname'), ['str'])),
                                    ('next_hop_interface', (YLeaf(YType.str, 'next-hop-interface'), ['str'])),
                                ])
                                self.source_address = None
                                self.destination_address = None
                                self.ifname = None
                                self.next_hop_interface = None
                                self._segment_path = lambda: "gre-hash" + "[source-address='" + str(self.source_address) + "']" + "[destination-address='" + str(self.destination_address) + "']" + "[ifname='" + str(self.ifname) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.Gre.GreHashes.GreHash, ['source_address', 'destination_address', 'ifname', 'next_hop_interface'], name, value)


                    class GreNextHops(Entity):
                        """
                        GRE destination neighbor table
                        
                        .. attribute:: gre_next_hop
                        
                        	PIM GRE address next\-hop information
                        	**type**\: list of  		 :py:class:`GreNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.Gre.GreNextHops, self).__init__()

                            self.yang_name = "gre-next-hops"
                            self.yang_parent_name = "gre"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("gre-next-hop", ("gre_next_hop", Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop))])
                            self._leafs = OrderedDict()

                            self.gre_next_hop = YList(self)
                            self._segment_path = lambda: "gre-next-hops"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.Gre.GreNextHops, [], name, value)


                        class GreNextHop(Entity):
                            """
                            PIM GRE address next\-hop information
                            
                            .. attribute:: destination_address  (key)
                            
                            	GRE destination address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: registered_address
                            
                            	Address registered
                            	**type**\:  :py:class:`RegisteredAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress>`
                            
                            .. attribute:: metric
                            
                            	Metric
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_preference
                            
                            	Metric preference
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_connected
                            
                            	Are we connected ?
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: gre_path
                            
                            	GRE Paths list
                            	**type**\: list of  		 :py:class:`GrePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop, self).__init__()

                                self.yang_name = "gre-next-hop"
                                self.yang_parent_name = "gre-next-hops"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['destination_address']
                                self._child_classes = OrderedDict([("registered-address", ("registered_address", Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress)), ("gre-path", ("gre_path", Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath))])
                                self._leafs = OrderedDict([
                                    ('destination_address', (YLeaf(YType.str, 'destination-address'), ['str','str'])),
                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                    ('metric_preference', (YLeaf(YType.uint32, 'metric-preference'), ['int'])),
                                    ('is_connected', (YLeaf(YType.uint8, 'is-connected'), ['int'])),
                                ])
                                self.destination_address = None
                                self.metric = None
                                self.metric_preference = None
                                self.is_connected = None

                                self.registered_address = Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress()
                                self.registered_address.parent = self
                                self._children_name_map["registered_address"] = "registered-address"

                                self.gre_path = YList(self)
                                self._segment_path = lambda: "gre-next-hop" + "[destination-address='" + str(self.destination_address) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop, ['destination_address', 'metric', 'metric_preference', 'is_connected'], name, value)


                            class RegisteredAddress(Entity):
                                """
                                Address registered
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress, self).__init__()

                                    self.yang_name = "registered-address"
                                    self.yang_parent_name = "gre-next-hop"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "registered-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                            class GrePath(Entity):
                                """
                                GRE Paths list
                                
                                .. attribute:: gre_neighbor
                                
                                	GRE neighbor
                                	**type**\:  :py:class:`GreNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor>`
                                
                                .. attribute:: gre_next_hop
                                
                                	GRE nexthop
                                	**type**\:  :py:class:`GreNextHop_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop_>`
                                
                                .. attribute:: gre_interface_name
                                
                                	GRE Interface
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                .. attribute:: is_gre_interface_disabled
                                
                                	Is the gre interface disabled ?
                                	**type**\: bool
                                
                                .. attribute:: is_via_lsm
                                
                                	Via LSM
                                	**type**\: bool
                                
                                .. attribute:: is_connector_attribute_present
                                
                                	Connector attribute present
                                	**type**\: bool
                                
                                .. attribute:: extranet_vrf_name
                                
                                	Extranet VRF name
                                	**type**\: str
                                
                                	**length:** 0..33
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath, self).__init__()

                                    self.yang_name = "gre-path"
                                    self.yang_parent_name = "gre-next-hop"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("gre-neighbor", ("gre_neighbor", Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor)), ("gre-next-hop", ("gre_next_hop", Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop_))])
                                    self._leafs = OrderedDict([
                                        ('gre_interface_name', (YLeaf(YType.str, 'gre-interface-name'), ['str'])),
                                        ('is_gre_interface_disabled', (YLeaf(YType.boolean, 'is-gre-interface-disabled'), ['bool'])),
                                        ('is_via_lsm', (YLeaf(YType.boolean, 'is-via-lsm'), ['bool'])),
                                        ('is_connector_attribute_present', (YLeaf(YType.boolean, 'is-connector-attribute-present'), ['bool'])),
                                        ('extranet_vrf_name', (YLeaf(YType.str, 'extranet-vrf-name'), ['str'])),
                                    ])
                                    self.gre_interface_name = None
                                    self.is_gre_interface_disabled = None
                                    self.is_via_lsm = None
                                    self.is_connector_attribute_present = None
                                    self.extranet_vrf_name = None

                                    self.gre_neighbor = Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor()
                                    self.gre_neighbor.parent = self
                                    self._children_name_map["gre_neighbor"] = "gre-neighbor"

                                    self.gre_next_hop = Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop_()
                                    self.gre_next_hop.parent = self
                                    self._children_name_map["gre_next_hop"] = "gre-next-hop"
                                    self._segment_path = lambda: "gre-path"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath, ['gre_interface_name', 'is_gre_interface_disabled', 'is_via_lsm', 'is_connector_attribute_present', 'extranet_vrf_name'], name, value)


                                class GreNeighbor(Entity):
                                    """
                                    GRE neighbor
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor, self).__init__()

                                        self.yang_name = "gre-neighbor"
                                        self.yang_parent_name = "gre-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ])
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None
                                        self._segment_path = lambda: "gre-neighbor"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                                class GreNextHop_(Entity):
                                    """
                                    GRE nexthop
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop_, self).__init__()

                                        self.yang_name = "gre-next-hop"
                                        self.yang_parent_name = "gre-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ])
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None
                                        self._segment_path = lambda: "gre-next-hop"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop_, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class BidirDfWinners(Entity):
                    """
                    Bidirectional PIM DF election winner table
                    
                    .. attribute:: bidir_df_winner
                    
                    	Bidirectional PIM DF election table entry
                    	**type**\: list of  		 :py:class:`BidirDfWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.BidirDfWinners, self).__init__()

                        self.yang_name = "bidir-df-winners"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("bidir-df-winner", ("bidir_df_winner", Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner))])
                        self._leafs = OrderedDict()

                        self.bidir_df_winner = YList(self)
                        self._segment_path = lambda: "bidir-df-winners"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.Vrfs.Vrf.BidirDfWinners, [], name, value)


                    class BidirDfWinner(Entity):
                        """
                        Bidirectional PIM DF election table entry
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: rp_address_xr
                        
                        	RP Address
                        	**type**\:  :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr>`
                        
                        .. attribute:: df_winner
                        
                        	DF Winner
                        	**type**\:  :py:class:`DfWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner>`
                        
                        .. attribute:: pim_interface_name
                        
                        	Interface Name
                        	**type**\: str
                        
                        .. attribute:: are_we_df
                        
                        	Are we DF
                        	**type**\: bool
                        
                        .. attribute:: rp_lan
                        
                        	Is this the RP LAN
                        	**type**\: bool
                        
                        .. attribute:: metric
                        
                        	Metric
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: metric_preference
                        
                        	Metric Preference
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner, self).__init__()

                            self.yang_name = "bidir-df-winner"
                            self.yang_parent_name = "bidir-df-winners"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rp-address-xr", ("rp_address_xr", Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr)), ("df-winner", ("df_winner", Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner))])
                            self._leafs = OrderedDict([
                                ('rp_address', (YLeaf(YType.str, 'rp-address'), ['str','str'])),
                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ('pim_interface_name', (YLeaf(YType.str, 'pim-interface-name'), ['str'])),
                                ('are_we_df', (YLeaf(YType.boolean, 'are-we-df'), ['bool'])),
                                ('rp_lan', (YLeaf(YType.boolean, 'rp-lan'), ['bool'])),
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                ('metric_preference', (YLeaf(YType.uint32, 'metric-preference'), ['int'])),
                                ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                            ])
                            self.rp_address = None
                            self.interface_name = None
                            self.pim_interface_name = None
                            self.are_we_df = None
                            self.rp_lan = None
                            self.metric = None
                            self.metric_preference = None
                            self.uptime = None

                            self.rp_address_xr = Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr()
                            self.rp_address_xr.parent = self
                            self._children_name_map["rp_address_xr"] = "rp-address-xr"

                            self.df_winner = Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner()
                            self.df_winner.parent = self
                            self._children_name_map["df_winner"] = "df-winner"
                            self._segment_path = lambda: "bidir-df-winner"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner, ['rp_address', 'interface_name', 'pim_interface_name', 'are_we_df', 'rp_lan', 'metric', 'metric_preference', 'uptime'], name, value)


                        class RpAddressXr(Entity):
                            """
                            RP Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr, self).__init__()

                                self.yang_name = "rp-address-xr"
                                self.yang_parent_name = "bidir-df-winner"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "rp-address-xr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class DfWinner(Entity):
                            """
                            DF Winner
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner, self).__init__()

                                self.yang_name = "df-winner"
                                self.yang_parent_name = "bidir-df-winner"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "df-winner"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class TableContexts(Entity):
                    """
                    PIM table context list
                    
                    .. attribute:: table_context
                    
                    	PIM table context information
                    	**type**\: list of  		 :py:class:`TableContext <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.TableContexts.TableContext>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.TableContexts, self).__init__()

                        self.yang_name = "table-contexts"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("table-context", ("table_context", Pim.Active.Vrfs.Vrf.TableContexts.TableContext))])
                        self._leafs = OrderedDict()

                        self.table_context = YList(self)
                        self._segment_path = lambda: "table-contexts"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.Vrfs.Vrf.TableContexts, [], name, value)


                    class TableContext(Entity):
                        """
                        PIM table context information
                        
                        .. attribute:: saf_name
                        
                        	SAF name
                        	**type**\:  :py:class:`PimSafi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimSafi>`
                        
                        .. attribute:: topology_name
                        
                        	Topology name
                        	**type**\: str
                        
                        	**length:** 1..32
                        
                        .. attribute:: afi
                        
                        	AFI
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: safi
                        
                        	SAFI
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_name
                        
                        	Table name
                        	**type**\: str
                        
                        .. attribute:: vrf_id
                        
                        	VRF ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_id
                        
                        	Table ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_active
                        
                        	Active status
                        	**type**\: bool
                        
                        .. attribute:: is_ital_registration_done
                        
                        	ITAL reg status
                        	**type**\: bool
                        
                        .. attribute:: is_rib_registration_done
                        
                        	RIB reg status
                        	**type**\: bool
                        
                        .. attribute:: is_rib_convergence_received
                        
                        	RIB Convergence receive status
                        	**type**\: bool
                        
                        .. attribute:: is_rib_convergence
                        
                        	RIB Convergence status
                        	**type**\: bool
                        
                        .. attribute:: rpf_registrations
                        
                        	RPF Registration count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.TableContexts.TableContext, self).__init__()

                            self.yang_name = "table-context"
                            self.yang_parent_name = "table-contexts"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('saf_name', (YLeaf(YType.enumeration, 'saf-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimSafi', '')])),
                                ('topology_name', (YLeaf(YType.str, 'topology-name'), ['str'])),
                                ('afi', (YLeaf(YType.uint32, 'afi'), ['int'])),
                                ('safi', (YLeaf(YType.uint32, 'safi'), ['int'])),
                                ('table_name', (YLeaf(YType.str, 'table-name'), ['str'])),
                                ('vrf_id', (YLeaf(YType.uint32, 'vrf-id'), ['int'])),
                                ('table_id', (YLeaf(YType.uint32, 'table-id'), ['int'])),
                                ('is_active', (YLeaf(YType.boolean, 'is-active'), ['bool'])),
                                ('is_ital_registration_done', (YLeaf(YType.boolean, 'is-ital-registration-done'), ['bool'])),
                                ('is_rib_registration_done', (YLeaf(YType.boolean, 'is-rib-registration-done'), ['bool'])),
                                ('is_rib_convergence_received', (YLeaf(YType.boolean, 'is-rib-convergence-received'), ['bool'])),
                                ('is_rib_convergence', (YLeaf(YType.boolean, 'is-rib-convergence'), ['bool'])),
                                ('rpf_registrations', (YLeaf(YType.uint32, 'rpf-registrations'), ['int'])),
                            ])
                            self.saf_name = None
                            self.topology_name = None
                            self.afi = None
                            self.safi = None
                            self.table_name = None
                            self.vrf_id = None
                            self.table_id = None
                            self.is_active = None
                            self.is_ital_registration_done = None
                            self.is_rib_registration_done = None
                            self.is_rib_convergence_received = None
                            self.is_rib_convergence = None
                            self.rpf_registrations = None
                            self._segment_path = lambda: "table-context"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.TableContexts.TableContext, ['saf_name', 'topology_name', 'afi', 'safi', 'table_name', 'vrf_id', 'table_id', 'is_active', 'is_ital_registration_done', 'is_rib_registration_done', 'is_rib_convergence_received', 'is_rib_convergence', 'rpf_registrations'], name, value)


                class NeighborSummaries(Entity):
                    """
                    PIM neighbor summary table
                    
                    .. attribute:: neighbor_summary
                    
                    	PIM neighbor summary information
                    	**type**\: list of  		 :py:class:`NeighborSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.NeighborSummaries.NeighborSummary>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.NeighborSummaries, self).__init__()

                        self.yang_name = "neighbor-summaries"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("neighbor-summary", ("neighbor_summary", Pim.Active.Vrfs.Vrf.NeighborSummaries.NeighborSummary))])
                        self._leafs = OrderedDict()

                        self.neighbor_summary = YList(self)
                        self._segment_path = lambda: "neighbor-summaries"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.Vrfs.Vrf.NeighborSummaries, [], name, value)


                    class NeighborSummary(Entity):
                        """
                        PIM neighbor summary information
                        
                        .. attribute:: interface_name  (key)
                        
                        	Interface name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: number_of_neighbors
                        
                        	Number of neighbors
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: number_of_external_neighbors
                        
                        	Number of external neighbors
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.NeighborSummaries.NeighborSummary, self).__init__()

                            self.yang_name = "neighbor-summary"
                            self.yang_parent_name = "neighbor-summaries"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['interface_name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ('number_of_neighbors', (YLeaf(YType.int32, 'number-of-neighbors'), ['int'])),
                                ('number_of_external_neighbors', (YLeaf(YType.int32, 'number-of-external-neighbors'), ['int'])),
                            ])
                            self.interface_name = None
                            self.number_of_neighbors = None
                            self.number_of_external_neighbors = None
                            self._segment_path = lambda: "neighbor-summary" + "[interface-name='" + str(self.interface_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.NeighborSummaries.NeighborSummary, ['interface_name', 'number_of_neighbors', 'number_of_external_neighbors'], name, value)


                class Context(Entity):
                    """
                    PIM context information
                    
                    .. attribute:: remote_default_group
                    
                    	Remote Default Group
                    	**type**\:  :py:class:`RemoteDefaultGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Context.RemoteDefaultGroup>`
                    
                    .. attribute:: rpf_default_table
                    
                    	RPF Default Table
                    	**type**\:  :py:class:`RpfDefaultTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Context.RpfDefaultTable>`
                    
                    .. attribute:: vrf_id
                    
                    	VRF ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_id
                    
                    	Table ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: murib_id
                    
                    	MURIB ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rpf_id
                    
                    	RPF ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: remote_table_id
                    
                    	Remote Table ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_default_group
                    
                    	MDT Default group
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: mdt_source
                    
                    	MDT source
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: mdt_source_interface
                    
                    	MDT Source Interface Name
                    	**type**\: str
                    
                    .. attribute:: mdt_interface
                    
                    	MDT handle
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: mdt_gre_rpf_identifier
                    
                    	GRE\-MDT RPF Identifier
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_gre_remote_rpf_identifier
                    
                    	GRE\-MDT Remote RPF Identifier
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_unicast_rib_registration
                    
                    	Ucast RIB Registration
                    	**type**\: bool
                    
                    .. attribute:: is_multicast_rib_registration
                    
                    	Mcast RIB Registration
                    	**type**\: bool
                    
                    .. attribute:: is_active
                    
                    	Active
                    	**type**\: bool
                    
                    .. attribute:: is_active_ital
                    
                    	Active ITAL
                    	**type**\: bool
                    
                    .. attribute:: is_mrib_register
                    
                    	MRIB Register
                    	**type**\: bool
                    
                    .. attribute:: is_mdt_owner
                    
                    	MDT Owner
                    	**type**\: bool
                    
                    .. attribute:: is_routing_enabled
                    
                    	Routing Enabled
                    	**type**\: bool
                    
                    .. attribute:: is_socket_add_required
                    
                    	VRF required on Socket
                    	**type**\: bool
                    
                    .. attribute:: is_socket_added
                    
                    	VRF added on Socket
                    	**type**\: bool
                    
                    .. attribute:: is_lpts_socket_add_required
                    
                    	VRF LPTS filter required on Socket
                    	**type**\: bool
                    
                    .. attribute:: is_lpts_socket_added
                    
                    	VRF LPTS filter added on Socket
                    	**type**\: bool
                    
                    .. attribute:: is_udp_socket_add_required
                    
                    	VRF added on UDP Socket
                    	**type**\: bool
                    
                    .. attribute:: is_udp_socket_added
                    
                    	VRF added on UDP Socket
                    	**type**\: bool
                    
                    .. attribute:: is_udp_socket_bind_required
                    
                    	VRF bind required on UDP Socket
                    	**type**\: bool
                    
                    .. attribute:: is_udp_socket_bind
                    
                    	VRF bound on UDP Socket
                    	**type**\: bool
                    
                    .. attribute:: is_register_injection_socket_add_required
                    
                    	VRF required on Register Injection Socket
                    	**type**\: bool
                    
                    .. attribute:: is_register_injection_socket_added
                    
                    	VRF added on Register Injection Socket
                    	**type**\: bool
                    
                    .. attribute:: is_register_injection_lpts_socket_add_required
                    
                    	VRF LPTS filter required on Register Injection Socket
                    	**type**\: bool
                    
                    .. attribute:: is_register_injection_lpts_socket_added
                    
                    	VRF LPTS filter added on Register Injection Socket
                    	**type**\: bool
                    
                    .. attribute:: is_m_host_publish_pending
                    
                    	Publish pending for MHost Default interface
                    	**type**\: bool
                    
                    .. attribute:: mhost_interface
                    
                    	MHost handle
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: mhost_default_interface_config
                    
                    	Configured Mhost Defint
                    	**type**\: str
                    
                    .. attribute:: mdt_mtu
                    
                    	MDT MTU
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: maximum_mdt_aggregation
                    
                    	MDT max aggregation
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_data_switchover_interval
                    
                    	Data MDT Switchover interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_data_announce_interval
                    
                    	Data MDT Announce interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: non_default_vrf_count_on_socket
                    
                    	Count of non\-default vrfs on raw socket
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\: str
                    
                    .. attribute:: mdt_neighbor_filter_name
                    
                    	MDT Neighbor Filter Name
                    	**type**\: str
                    
                    .. attribute:: allow_rp_configured
                    
                    	Allow RP Configured
                    	**type**\: bool
                    
                    .. attribute:: allow_rp_group_list
                    
                    	Allow RP Group\-List ACL Name
                    	**type**\: str
                    
                    	**length:** 0..64
                    
                    .. attribute:: allow_rp_rp_list
                    
                    	Allow RP RP\-list ACL Name
                    	**type**\: str
                    
                    	**length:** 0..64
                    
                    .. attribute:: sg_expiry_timer_configured
                    
                    	S,G Expiry Timer Configured
                    	**type**\: bool
                    
                    .. attribute:: sg_expiry_time
                    
                    	S,G Expiry Time Configured, in seconds
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    	**units**\: second
                    
                    .. attribute:: sg_expiry_timer_sg_list
                    
                    	S,G expiry timer ACL name
                    	**type**\: str
                    
                    	**length:** 0..64
                    
                    .. attribute:: mldp_mdt_name
                    
                    	MLDP MDT Name
                    	**type**\: str
                    
                    .. attribute:: mldp_mdt_interface
                    
                    	MLDP MDT handle
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: mldp_mdt_mtu
                    
                    	MLDP MDT MTU
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_maximum_mdt_aggregation
                    
                    	MLDP MDT max aggregation
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_data_switchover_interval
                    
                    	MLDP Data MDT Switchover interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_data_announce_interval
                    
                    	MLDP Data MDT Announce interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_rpf_identifier
                    
                    	MLDP RPF\-ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_remote_rpf_identifier
                    
                    	MLDP Remote RPF\-ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_create_mldp_mdt_interface
                    
                    	Create MLDP MDT interface
                    	**type**\: bool
                    
                    .. attribute:: is_mldp_mdt_owner
                    
                    	MLDP MDT Owner
                    	**type**\: bool
                    
                    .. attribute:: mldp_root_count
                    
                    	MLDP Root count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_head_lsm_identifier
                    
                    	MLDP Head LSM\-ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_remote_head_lsm_identifier
                    
                    	MLDP Remote Head LSM\-ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: organization_unique_identifier
                    
                    	OUI for VPN\-ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vpn_index
                    
                    	VPN Index
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_partitioned_mdt_configured
                    
                    	MLDP Partitioned MDT
                    	**type**\: bool
                    
                    .. attribute:: mldp_remote_partitioned_mdt_configured
                    
                    	MLDP Remote Partitioned MDT
                    	**type**\: bool
                    
                    .. attribute:: mldp_partioned_mp2m_ptree
                    
                    	MP2MP Partitioned MDT tree
                    	**type**\: bool
                    
                    .. attribute:: mldp_partitioned_head_lsm_identifier
                    
                    	Partitioned MDT Head LSM\-ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_head_local_label
                    
                    	Partitioned MDT Head local label
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_partitioned_mdt_identifier
                    
                    	MLDP Partitioned MDT Identifier
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bgp_auto_discovery_configured
                    
                    	BGP Auto\-Discovery configured
                    	**type**\: bool
                    
                    .. attribute:: suppress_pim_data_mdt_tlv
                    
                    	Suppress PIM Data\-MDT TLV Announcements
                    	**type**\: bool
                    
                    .. attribute:: inter_autonomous_system_enabled
                    
                    	Inter\-AS Enabled
                    	**type**\: bool
                    
                    .. attribute:: bgp_source_active_announce
                    
                    	Send BGP Source\-Active Announcements
                    	**type**\: bool
                    
                    .. attribute:: bgp_i_pmsi_added
                    
                    	BGP I\-PMSI Added
                    	**type**\: bool
                    
                    .. attribute:: mldp_bsr_control_tree_added
                    
                    	MLDP BSR Control tree added
                    	**type**\: bool
                    
                    .. attribute:: mldp_auto_rp_discovery_tree_added
                    
                    	MLDP Autorp Discovery Control tree added
                    	**type**\: bool
                    
                    .. attribute:: mldp_auto_rp_announce_tree_added
                    
                    	MLDP Autorp Announce Control tree added
                    	**type**\: bool
                    
                    .. attribute:: bgp_auto_discovery_type
                    
                    	BGP Auto Discovery Type
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_partitioned_mdt_control_identifier
                    
                    	Partitioned MDT Control Identifier
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_partitioned_ir_control_identifier
                    
                    	Partitioned IR MDT Control Identifier
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_control_head_lsm_identifier
                    
                    	MLDP MVPN Identifier
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: umh
                    
                    	Join UMH Core\-Tree
                    	**type**\: bool
                    
                    .. attribute:: suppress_shared_tree_join
                    
                    	Suppress Shared\-Tree Joins
                    	**type**\: bool
                    
                    .. attribute:: rsvp_te_mdt_name
                    
                    	RSVP\-TE MDT Name
                    	**type**\: str
                    
                    .. attribute:: rsvp_te_mdt_interface
                    
                    	RSVP\-TEMDT handle
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: rsvp_te_mdt_mtu
                    
                    	RSVP\-TEMDT MTU
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_maximum_mdt_aggregation
                    
                    	RSVP\-TE MDT max aggregation
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_data_switchover_interval
                    
                    	RSVP\-TE Data MDT Switchover interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_data_announce_interval
                    
                    	RSVP\-TE Data MDT Announce interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_rpf_identifier
                    
                    	RSVP\-TE RPF\-ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_create_rsvp_te_mdt_interface
                    
                    	Create RSVP\-TE MDT interface
                    	**type**\: bool
                    
                    .. attribute:: is_rsvp_te_mdt_owner
                    
                    	RSVP\-TE MDT Owner
                    	**type**\: bool
                    
                    .. attribute:: rsvp_te_mdt_static_p2mp_count
                    
                    	Number of Static P2MP\-TE MDT
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: p2mpte_li_drop
                    
                    	Route LI updates dropped for P2MP
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_name
                    
                    	IR MDT Name
                    	**type**\: str
                    
                    .. attribute:: ir_mdt_interface
                    
                    	IRMDT handle
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: ir_mdt_mtu
                    
                    	IRMDT MTU
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_maximum_mdt_aggregation
                    
                    	IR MDT max aggregation
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_data_switchover_interval
                    
                    	IR Data MDT Switchover interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_data_announce_interval
                    
                    	IR Data MDT Announce interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_rpf_identifier
                    
                    	IR RPF\-ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_tail_label
                    
                    	IR Tail Label
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_create_ir_mdt_interface
                    
                    	Create IR MDT interface
                    	**type**\: bool
                    
                    .. attribute:: is_ir_mdt_owner
                    
                    	IR MDT Owner
                    	**type**\: bool
                    
                    .. attribute:: in_b_and_mdt_name
                    
                    	Inband MDT Name
                    	**type**\: str
                    
                    .. attribute:: in_b_and_mdt_interface
                    
                    	Inband MDT handle
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: in_b_and_mdt_mtu
                    
                    	Inband MDT MTU
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_band_maximum_mdt_aggregation
                    
                    	Inband MDT max aggregation
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_b_and_mdt_data_switchover_interval
                    
                    	Inband Data MDT Switchover interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_b_and_mdt_data_announce_interval
                    
                    	Inband Data MDT Announce interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_b_and_mdt_rpf_identifier
                    
                    	Inband RPF\-ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_create_in_b_and_mdt_interface
                    
                    	Create Inband MDT interface
                    	**type**\: bool
                    
                    .. attribute:: is_in_b_and_mdt_owner
                    
                    	Inband MDT Owner
                    	**type**\: bool
                    
                    .. attribute:: in_band_signaling_local_enabled
                    
                    	Inband signaling Local enabled
                    	**type**\: bool
                    
                    .. attribute:: in_band_signaling_remote_enabled
                    
                    	Inband signaling Remote enabled
                    	**type**\: bool
                    
                    .. attribute:: valid_rd_present
                    
                    	RD is valid
                    	**type**\: bool
                    
                    .. attribute:: stale_rd_present
                    
                    	RD is stale
                    	**type**\: bool
                    
                    .. attribute:: route_distinguisher
                    
                    	RD value
                    	**type**\: str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: gin_b_and_mdt_name
                    
                    	Inband MDT Name
                    	**type**\: str
                    
                    .. attribute:: gin_b_and_mdt_interface
                    
                    	Inband MDT handle
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: gin_b_and_mdt_mtu
                    
                    	Inband MDT MTU
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gin_band_maximum_mdt_aggregation
                    
                    	Inband MDT max aggregation
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gin_b_and_mdt_data_switchover_interval
                    
                    	Inband Data MDT Switchover interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gin_b_and_mdt_data_announce_interval
                    
                    	Inband Data MDT Announce interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gin_b_and_mdt_rpf_identifier
                    
                    	Inband RPF\-ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_create_gin_b_and_mdt_interface
                    
                    	Create Inband MDT interface
                    	**type**\: bool
                    
                    .. attribute:: is_gin_b_and_mdt_owner
                    
                    	Inband MDT Owner
                    	**type**\: bool
                    
                    .. attribute:: is_pim_nsf_rib_converged
                    
                    	PIM NSF RIB converged
                    	**type**\: bool
                    
                    .. attribute:: is_pim_nsf_rib_converge_received
                    
                    	PIM NSF RIB converge received
                    	**type**\: bool
                    
                    .. attribute:: is_rib_multipath_enabled
                    
                    	PIM RIB multiplath enabled
                    	**type**\: bool
                    
                    .. attribute:: is_rib_multipath_interface_hash
                    
                    	PIM RIB multipath interface hash
                    	**type**\: bool
                    
                    .. attribute:: is_rib_multipath_source_hash
                    
                    	PIM RIB multipath source based hash
                    	**type**\: bool
                    
                    .. attribute:: is_rib_multipath_source_next_hop_hash
                    
                    	PIM RIB multipath source\-nexthop hash
                    	**type**\: bool
                    
                    .. attribute:: rump_enabled
                    
                    	PIM is using MuRIB
                    	**type**\: bool
                    
                    .. attribute:: is_create_mdt_interface
                    
                    	Create MDT interface
                    	**type**\: bool
                    
                    .. attribute:: is_auto_rp_listen_enabled
                    
                    	Auto RP Listen Enabled
                    	**type**\: bool
                    
                    .. attribute:: is_all_interface_disable_operation
                    
                    	PIM all interface disable operation
                    	**type**\: bool
                    
                    .. attribute:: is_default_granges
                    
                    	Default granges
                    	**type**\: bool
                    
                    .. attribute:: is_auto_rp_listen_sock_add
                    
                    	Auto RP listen sock add
                    	**type**\: bool
                    
                    .. attribute:: is_redistribution_reset
                    
                    	Pending redist reset
                    	**type**\: bool
                    
                    .. attribute:: redistribution_reset_count
                    
                    	Redist reset count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rpf_policy_name
                    
                    	RPF topology selection route\-policy name
                    	**type**\: str
                    
                    .. attribute:: table_count
                    
                    	Number of configured Tables
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: active_table_count
                    
                    	Number of active Tables
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: anycast_rp_policy_name
                    
                    	Anycast\-RP Policy Name
                    	**type**\: str
                    
                    .. attribute:: anycast_rp_configured
                    
                    	Anycast\-RP config
                    	**type**\: bool
                    
                    .. attribute:: bgp_remote_on
                    
                    	BGP remote interface status
                    	**type**\: bool
                    
                    .. attribute:: bgp_remote_interface_name
                    
                    	BGP remote interface name
                    	**type**\: str
                    
                    .. attribute:: bgp_remote_interface
                    
                    	BGP remote interface handle
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: bgp_remote_address
                    
                    	BGP remote interface address
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: bgp_remote_state
                    
                    	BGP remote interface state
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: physical_interface_count
                    
                    	Enabled Physical Interface Count
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: virtual_interface_count
                    
                    	Enabled Virtual Interface Count
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: virtual_mlc_interface_name
                    
                    	Virtual master line card Interface
                    	**type**\: str
                    
                    .. attribute:: mdt_immediate_switch
                    
                    	MDT Immediate Switch
                    	**type**\: bool
                    
                    .. attribute:: mldp_root_address
                    
                    	MLDP Root addresses
                    	**type**\: list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: export_route_target
                    
                    	Export Route Targets
                    	**type**\: list of  		 :py:class:`ExportRouteTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Context.ExportRouteTarget>`
                    
                    .. attribute:: import_route_target
                    
                    	Import Route Targets
                    	**type**\: list of  		 :py:class:`ImportRouteTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Context.ImportRouteTarget>`
                    
                    .. attribute:: anycast_rp_range
                    
                    	Anycast\-RP Ranges
                    	**type**\: list of  		 :py:class:`AnycastRpRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Context.AnycastRpRange>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.Context, self).__init__()

                        self.yang_name = "context"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("remote-default-group", ("remote_default_group", Pim.Active.Vrfs.Vrf.Context.RemoteDefaultGroup)), ("rpf-default-table", ("rpf_default_table", Pim.Active.Vrfs.Vrf.Context.RpfDefaultTable)), ("export-route-target", ("export_route_target", Pim.Active.Vrfs.Vrf.Context.ExportRouteTarget)), ("import-route-target", ("import_route_target", Pim.Active.Vrfs.Vrf.Context.ImportRouteTarget)), ("anycast-rp-range", ("anycast_rp_range", Pim.Active.Vrfs.Vrf.Context.AnycastRpRange))])
                        self._leafs = OrderedDict([
                            ('vrf_id', (YLeaf(YType.uint32, 'vrf-id'), ['int'])),
                            ('table_id', (YLeaf(YType.uint32, 'table-id'), ['int'])),
                            ('murib_id', (YLeaf(YType.uint32, 'murib-id'), ['int'])),
                            ('rpf_id', (YLeaf(YType.uint32, 'rpf-id'), ['int'])),
                            ('remote_table_id', (YLeaf(YType.uint32, 'remote-table-id'), ['int'])),
                            ('mdt_default_group', (YLeaf(YType.str, 'mdt-default-group'), ['str'])),
                            ('mdt_source', (YLeaf(YType.str, 'mdt-source'), ['str'])),
                            ('mdt_source_interface', (YLeaf(YType.str, 'mdt-source-interface'), ['str'])),
                            ('mdt_interface', (YLeaf(YType.str, 'mdt-interface'), ['str'])),
                            ('mdt_gre_rpf_identifier', (YLeaf(YType.uint32, 'mdt-gre-rpf-identifier'), ['int'])),
                            ('mdt_gre_remote_rpf_identifier', (YLeaf(YType.uint32, 'mdt-gre-remote-rpf-identifier'), ['int'])),
                            ('is_unicast_rib_registration', (YLeaf(YType.boolean, 'is-unicast-rib-registration'), ['bool'])),
                            ('is_multicast_rib_registration', (YLeaf(YType.boolean, 'is-multicast-rib-registration'), ['bool'])),
                            ('is_active', (YLeaf(YType.boolean, 'is-active'), ['bool'])),
                            ('is_active_ital', (YLeaf(YType.boolean, 'is-active-ital'), ['bool'])),
                            ('is_mrib_register', (YLeaf(YType.boolean, 'is-mrib-register'), ['bool'])),
                            ('is_mdt_owner', (YLeaf(YType.boolean, 'is-mdt-owner'), ['bool'])),
                            ('is_routing_enabled', (YLeaf(YType.boolean, 'is-routing-enabled'), ['bool'])),
                            ('is_socket_add_required', (YLeaf(YType.boolean, 'is-socket-add-required'), ['bool'])),
                            ('is_socket_added', (YLeaf(YType.boolean, 'is-socket-added'), ['bool'])),
                            ('is_lpts_socket_add_required', (YLeaf(YType.boolean, 'is-lpts-socket-add-required'), ['bool'])),
                            ('is_lpts_socket_added', (YLeaf(YType.boolean, 'is-lpts-socket-added'), ['bool'])),
                            ('is_udp_socket_add_required', (YLeaf(YType.boolean, 'is-udp-socket-add-required'), ['bool'])),
                            ('is_udp_socket_added', (YLeaf(YType.boolean, 'is-udp-socket-added'), ['bool'])),
                            ('is_udp_socket_bind_required', (YLeaf(YType.boolean, 'is-udp-socket-bind-required'), ['bool'])),
                            ('is_udp_socket_bind', (YLeaf(YType.boolean, 'is-udp-socket-bind'), ['bool'])),
                            ('is_register_injection_socket_add_required', (YLeaf(YType.boolean, 'is-register-injection-socket-add-required'), ['bool'])),
                            ('is_register_injection_socket_added', (YLeaf(YType.boolean, 'is-register-injection-socket-added'), ['bool'])),
                            ('is_register_injection_lpts_socket_add_required', (YLeaf(YType.boolean, 'is-register-injection-lpts-socket-add-required'), ['bool'])),
                            ('is_register_injection_lpts_socket_added', (YLeaf(YType.boolean, 'is-register-injection-lpts-socket-added'), ['bool'])),
                            ('is_m_host_publish_pending', (YLeaf(YType.boolean, 'is-m-host-publish-pending'), ['bool'])),
                            ('mhost_interface', (YLeaf(YType.str, 'mhost-interface'), ['str'])),
                            ('mhost_default_interface_config', (YLeaf(YType.str, 'mhost-default-interface-config'), ['str'])),
                            ('mdt_mtu', (YLeaf(YType.uint32, 'mdt-mtu'), ['int'])),
                            ('maximum_mdt_aggregation', (YLeaf(YType.uint32, 'maximum-mdt-aggregation'), ['int'])),
                            ('mdt_data_switchover_interval', (YLeaf(YType.uint32, 'mdt-data-switchover-interval'), ['int'])),
                            ('mdt_data_announce_interval', (YLeaf(YType.uint32, 'mdt-data-announce-interval'), ['int'])),
                            ('non_default_vrf_count_on_socket', (YLeaf(YType.uint32, 'non-default-vrf-count-on-socket'), ['int'])),
                            ('neighbor_filter_name', (YLeaf(YType.str, 'neighbor-filter-name'), ['str'])),
                            ('mdt_neighbor_filter_name', (YLeaf(YType.str, 'mdt-neighbor-filter-name'), ['str'])),
                            ('allow_rp_configured', (YLeaf(YType.boolean, 'allow-rp-configured'), ['bool'])),
                            ('allow_rp_group_list', (YLeaf(YType.str, 'allow-rp-group-list'), ['str'])),
                            ('allow_rp_rp_list', (YLeaf(YType.str, 'allow-rp-rp-list'), ['str'])),
                            ('sg_expiry_timer_configured', (YLeaf(YType.boolean, 'sg-expiry-timer-configured'), ['bool'])),
                            ('sg_expiry_time', (YLeaf(YType.uint16, 'sg-expiry-time'), ['int'])),
                            ('sg_expiry_timer_sg_list', (YLeaf(YType.str, 'sg-expiry-timer-sg-list'), ['str'])),
                            ('mldp_mdt_name', (YLeaf(YType.str, 'mldp-mdt-name'), ['str'])),
                            ('mldp_mdt_interface', (YLeaf(YType.str, 'mldp-mdt-interface'), ['str'])),
                            ('mldp_mdt_mtu', (YLeaf(YType.uint32, 'mldp-mdt-mtu'), ['int'])),
                            ('mldp_maximum_mdt_aggregation', (YLeaf(YType.uint32, 'mldp-maximum-mdt-aggregation'), ['int'])),
                            ('mldp_mdt_data_switchover_interval', (YLeaf(YType.uint32, 'mldp-mdt-data-switchover-interval'), ['int'])),
                            ('mldp_mdt_data_announce_interval', (YLeaf(YType.uint32, 'mldp-mdt-data-announce-interval'), ['int'])),
                            ('mldp_mdt_rpf_identifier', (YLeaf(YType.uint32, 'mldp-mdt-rpf-identifier'), ['int'])),
                            ('mldp_mdt_remote_rpf_identifier', (YLeaf(YType.uint32, 'mldp-mdt-remote-rpf-identifier'), ['int'])),
                            ('is_create_mldp_mdt_interface', (YLeaf(YType.boolean, 'is-create-mldp-mdt-interface'), ['bool'])),
                            ('is_mldp_mdt_owner', (YLeaf(YType.boolean, 'is-mldp-mdt-owner'), ['bool'])),
                            ('mldp_root_count', (YLeaf(YType.uint32, 'mldp-root-count'), ['int'])),
                            ('mldp_head_lsm_identifier', (YLeaf(YType.uint32, 'mldp-head-lsm-identifier'), ['int'])),
                            ('mldp_remote_head_lsm_identifier', (YLeaf(YType.uint32, 'mldp-remote-head-lsm-identifier'), ['int'])),
                            ('organization_unique_identifier', (YLeaf(YType.uint32, 'organization-unique-identifier'), ['int'])),
                            ('vpn_index', (YLeaf(YType.uint32, 'vpn-index'), ['int'])),
                            ('mldp_partitioned_mdt_configured', (YLeaf(YType.boolean, 'mldp-partitioned-mdt-configured'), ['bool'])),
                            ('mldp_remote_partitioned_mdt_configured', (YLeaf(YType.boolean, 'mldp-remote-partitioned-mdt-configured'), ['bool'])),
                            ('mldp_partioned_mp2m_ptree', (YLeaf(YType.boolean, 'mldp-partioned-mp2m-ptree'), ['bool'])),
                            ('mldp_partitioned_head_lsm_identifier', (YLeaf(YType.uint32, 'mldp-partitioned-head-lsm-identifier'), ['int'])),
                            ('mldp_head_local_label', (YLeaf(YType.uint32, 'mldp-head-local-label'), ['int'])),
                            ('mldp_partitioned_mdt_identifier', (YLeaf(YType.uint32, 'mldp-partitioned-mdt-identifier'), ['int'])),
                            ('bgp_auto_discovery_configured', (YLeaf(YType.boolean, 'bgp-auto-discovery-configured'), ['bool'])),
                            ('suppress_pim_data_mdt_tlv', (YLeaf(YType.boolean, 'suppress-pim-data-mdt-tlv'), ['bool'])),
                            ('inter_autonomous_system_enabled', (YLeaf(YType.boolean, 'inter-autonomous-system-enabled'), ['bool'])),
                            ('bgp_source_active_announce', (YLeaf(YType.boolean, 'bgp-source-active-announce'), ['bool'])),
                            ('bgp_i_pmsi_added', (YLeaf(YType.boolean, 'bgp-i-pmsi-added'), ['bool'])),
                            ('mldp_bsr_control_tree_added', (YLeaf(YType.boolean, 'mldp-bsr-control-tree-added'), ['bool'])),
                            ('mldp_auto_rp_discovery_tree_added', (YLeaf(YType.boolean, 'mldp-auto-rp-discovery-tree-added'), ['bool'])),
                            ('mldp_auto_rp_announce_tree_added', (YLeaf(YType.boolean, 'mldp-auto-rp-announce-tree-added'), ['bool'])),
                            ('bgp_auto_discovery_type', (YLeaf(YType.uint32, 'bgp-auto-discovery-type'), ['int'])),
                            ('mdt_partitioned_mdt_control_identifier', (YLeaf(YType.uint32, 'mdt-partitioned-mdt-control-identifier'), ['int'])),
                            ('mdt_partitioned_ir_control_identifier', (YLeaf(YType.uint32, 'mdt-partitioned-ir-control-identifier'), ['int'])),
                            ('mldp_control_head_lsm_identifier', (YLeaf(YType.uint32, 'mldp-control-head-lsm-identifier'), ['int'])),
                            ('umh', (YLeaf(YType.boolean, 'umh'), ['bool'])),
                            ('suppress_shared_tree_join', (YLeaf(YType.boolean, 'suppress-shared-tree-join'), ['bool'])),
                            ('rsvp_te_mdt_name', (YLeaf(YType.str, 'rsvp-te-mdt-name'), ['str'])),
                            ('rsvp_te_mdt_interface', (YLeaf(YType.str, 'rsvp-te-mdt-interface'), ['str'])),
                            ('rsvp_te_mdt_mtu', (YLeaf(YType.uint32, 'rsvp-te-mdt-mtu'), ['int'])),
                            ('rsvp_te_maximum_mdt_aggregation', (YLeaf(YType.uint32, 'rsvp-te-maximum-mdt-aggregation'), ['int'])),
                            ('rsvp_te_mdt_data_switchover_interval', (YLeaf(YType.uint32, 'rsvp-te-mdt-data-switchover-interval'), ['int'])),
                            ('rsvp_te_mdt_data_announce_interval', (YLeaf(YType.uint32, 'rsvp-te-mdt-data-announce-interval'), ['int'])),
                            ('rsvp_te_mdt_rpf_identifier', (YLeaf(YType.uint32, 'rsvp-te-mdt-rpf-identifier'), ['int'])),
                            ('is_create_rsvp_te_mdt_interface', (YLeaf(YType.boolean, 'is-create-rsvp-te-mdt-interface'), ['bool'])),
                            ('is_rsvp_te_mdt_owner', (YLeaf(YType.boolean, 'is-rsvp-te-mdt-owner'), ['bool'])),
                            ('rsvp_te_mdt_static_p2mp_count', (YLeaf(YType.uint32, 'rsvp-te-mdt-static-p2mp-count'), ['int'])),
                            ('p2mpte_li_drop', (YLeaf(YType.uint32, 'p2mpte-li-drop'), ['int'])),
                            ('ir_mdt_name', (YLeaf(YType.str, 'ir-mdt-name'), ['str'])),
                            ('ir_mdt_interface', (YLeaf(YType.str, 'ir-mdt-interface'), ['str'])),
                            ('ir_mdt_mtu', (YLeaf(YType.uint32, 'ir-mdt-mtu'), ['int'])),
                            ('ir_maximum_mdt_aggregation', (YLeaf(YType.uint32, 'ir-maximum-mdt-aggregation'), ['int'])),
                            ('ir_mdt_data_switchover_interval', (YLeaf(YType.uint32, 'ir-mdt-data-switchover-interval'), ['int'])),
                            ('ir_mdt_data_announce_interval', (YLeaf(YType.uint32, 'ir-mdt-data-announce-interval'), ['int'])),
                            ('ir_mdt_rpf_identifier', (YLeaf(YType.uint32, 'ir-mdt-rpf-identifier'), ['int'])),
                            ('ir_mdt_tail_label', (YLeaf(YType.uint32, 'ir-mdt-tail-label'), ['int'])),
                            ('is_create_ir_mdt_interface', (YLeaf(YType.boolean, 'is-create-ir-mdt-interface'), ['bool'])),
                            ('is_ir_mdt_owner', (YLeaf(YType.boolean, 'is-ir-mdt-owner'), ['bool'])),
                            ('in_b_and_mdt_name', (YLeaf(YType.str, 'in-b-and-mdt-name'), ['str'])),
                            ('in_b_and_mdt_interface', (YLeaf(YType.str, 'in-b-and-mdt-interface'), ['str'])),
                            ('in_b_and_mdt_mtu', (YLeaf(YType.uint32, 'in-b-and-mdt-mtu'), ['int'])),
                            ('in_band_maximum_mdt_aggregation', (YLeaf(YType.uint32, 'in-band-maximum-mdt-aggregation'), ['int'])),
                            ('in_b_and_mdt_data_switchover_interval', (YLeaf(YType.uint32, 'in-b-and-mdt-data-switchover-interval'), ['int'])),
                            ('in_b_and_mdt_data_announce_interval', (YLeaf(YType.uint32, 'in-b-and-mdt-data-announce-interval'), ['int'])),
                            ('in_b_and_mdt_rpf_identifier', (YLeaf(YType.uint32, 'in-b-and-mdt-rpf-identifier'), ['int'])),
                            ('is_create_in_b_and_mdt_interface', (YLeaf(YType.boolean, 'is-create-in-b-and-mdt-interface'), ['bool'])),
                            ('is_in_b_and_mdt_owner', (YLeaf(YType.boolean, 'is-in-b-and-mdt-owner'), ['bool'])),
                            ('in_band_signaling_local_enabled', (YLeaf(YType.boolean, 'in-band-signaling-local-enabled'), ['bool'])),
                            ('in_band_signaling_remote_enabled', (YLeaf(YType.boolean, 'in-band-signaling-remote-enabled'), ['bool'])),
                            ('valid_rd_present', (YLeaf(YType.boolean, 'valid-rd-present'), ['bool'])),
                            ('stale_rd_present', (YLeaf(YType.boolean, 'stale-rd-present'), ['bool'])),
                            ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                            ('gin_b_and_mdt_name', (YLeaf(YType.str, 'gin-b-and-mdt-name'), ['str'])),
                            ('gin_b_and_mdt_interface', (YLeaf(YType.str, 'gin-b-and-mdt-interface'), ['str'])),
                            ('gin_b_and_mdt_mtu', (YLeaf(YType.uint32, 'gin-b-and-mdt-mtu'), ['int'])),
                            ('gin_band_maximum_mdt_aggregation', (YLeaf(YType.uint32, 'gin-band-maximum-mdt-aggregation'), ['int'])),
                            ('gin_b_and_mdt_data_switchover_interval', (YLeaf(YType.uint32, 'gin-b-and-mdt-data-switchover-interval'), ['int'])),
                            ('gin_b_and_mdt_data_announce_interval', (YLeaf(YType.uint32, 'gin-b-and-mdt-data-announce-interval'), ['int'])),
                            ('gin_b_and_mdt_rpf_identifier', (YLeaf(YType.uint32, 'gin-b-and-mdt-rpf-identifier'), ['int'])),
                            ('is_create_gin_b_and_mdt_interface', (YLeaf(YType.boolean, 'is-create-gin-b-and-mdt-interface'), ['bool'])),
                            ('is_gin_b_and_mdt_owner', (YLeaf(YType.boolean, 'is-gin-b-and-mdt-owner'), ['bool'])),
                            ('is_pim_nsf_rib_converged', (YLeaf(YType.boolean, 'is-pim-nsf-rib-converged'), ['bool'])),
                            ('is_pim_nsf_rib_converge_received', (YLeaf(YType.boolean, 'is-pim-nsf-rib-converge-received'), ['bool'])),
                            ('is_rib_multipath_enabled', (YLeaf(YType.boolean, 'is-rib-multipath-enabled'), ['bool'])),
                            ('is_rib_multipath_interface_hash', (YLeaf(YType.boolean, 'is-rib-multipath-interface-hash'), ['bool'])),
                            ('is_rib_multipath_source_hash', (YLeaf(YType.boolean, 'is-rib-multipath-source-hash'), ['bool'])),
                            ('is_rib_multipath_source_next_hop_hash', (YLeaf(YType.boolean, 'is-rib-multipath-source-next-hop-hash'), ['bool'])),
                            ('rump_enabled', (YLeaf(YType.boolean, 'rump-enabled'), ['bool'])),
                            ('is_create_mdt_interface', (YLeaf(YType.boolean, 'is-create-mdt-interface'), ['bool'])),
                            ('is_auto_rp_listen_enabled', (YLeaf(YType.boolean, 'is-auto-rp-listen-enabled'), ['bool'])),
                            ('is_all_interface_disable_operation', (YLeaf(YType.boolean, 'is-all-interface-disable-operation'), ['bool'])),
                            ('is_default_granges', (YLeaf(YType.boolean, 'is-default-granges'), ['bool'])),
                            ('is_auto_rp_listen_sock_add', (YLeaf(YType.boolean, 'is-auto-rp-listen-sock-add'), ['bool'])),
                            ('is_redistribution_reset', (YLeaf(YType.boolean, 'is-redistribution-reset'), ['bool'])),
                            ('redistribution_reset_count', (YLeaf(YType.uint32, 'redistribution-reset-count'), ['int'])),
                            ('rpf_policy_name', (YLeaf(YType.str, 'rpf-policy-name'), ['str'])),
                            ('table_count', (YLeaf(YType.uint32, 'table-count'), ['int'])),
                            ('active_table_count', (YLeaf(YType.uint32, 'active-table-count'), ['int'])),
                            ('anycast_rp_policy_name', (YLeaf(YType.str, 'anycast-rp-policy-name'), ['str'])),
                            ('anycast_rp_configured', (YLeaf(YType.boolean, 'anycast-rp-configured'), ['bool'])),
                            ('bgp_remote_on', (YLeaf(YType.boolean, 'bgp-remote-on'), ['bool'])),
                            ('bgp_remote_interface_name', (YLeaf(YType.str, 'bgp-remote-interface-name'), ['str'])),
                            ('bgp_remote_interface', (YLeaf(YType.str, 'bgp-remote-interface'), ['str'])),
                            ('bgp_remote_address', (YLeaf(YType.str, 'bgp-remote-address'), ['str'])),
                            ('bgp_remote_state', (YLeaf(YType.uint32, 'bgp-remote-state'), ['int'])),
                            ('physical_interface_count', (YLeaf(YType.uint64, 'physical-interface-count'), ['int'])),
                            ('virtual_interface_count', (YLeaf(YType.uint64, 'virtual-interface-count'), ['int'])),
                            ('virtual_mlc_interface_name', (YLeaf(YType.str, 'virtual-mlc-interface-name'), ['str'])),
                            ('mdt_immediate_switch', (YLeaf(YType.boolean, 'mdt-immediate-switch'), ['bool'])),
                            ('mldp_root_address', (YLeafList(YType.uint32, 'mldp-root-address'), ['int'])),
                        ])
                        self.vrf_id = None
                        self.table_id = None
                        self.murib_id = None
                        self.rpf_id = None
                        self.remote_table_id = None
                        self.mdt_default_group = None
                        self.mdt_source = None
                        self.mdt_source_interface = None
                        self.mdt_interface = None
                        self.mdt_gre_rpf_identifier = None
                        self.mdt_gre_remote_rpf_identifier = None
                        self.is_unicast_rib_registration = None
                        self.is_multicast_rib_registration = None
                        self.is_active = None
                        self.is_active_ital = None
                        self.is_mrib_register = None
                        self.is_mdt_owner = None
                        self.is_routing_enabled = None
                        self.is_socket_add_required = None
                        self.is_socket_added = None
                        self.is_lpts_socket_add_required = None
                        self.is_lpts_socket_added = None
                        self.is_udp_socket_add_required = None
                        self.is_udp_socket_added = None
                        self.is_udp_socket_bind_required = None
                        self.is_udp_socket_bind = None
                        self.is_register_injection_socket_add_required = None
                        self.is_register_injection_socket_added = None
                        self.is_register_injection_lpts_socket_add_required = None
                        self.is_register_injection_lpts_socket_added = None
                        self.is_m_host_publish_pending = None
                        self.mhost_interface = None
                        self.mhost_default_interface_config = None
                        self.mdt_mtu = None
                        self.maximum_mdt_aggregation = None
                        self.mdt_data_switchover_interval = None
                        self.mdt_data_announce_interval = None
                        self.non_default_vrf_count_on_socket = None
                        self.neighbor_filter_name = None
                        self.mdt_neighbor_filter_name = None
                        self.allow_rp_configured = None
                        self.allow_rp_group_list = None
                        self.allow_rp_rp_list = None
                        self.sg_expiry_timer_configured = None
                        self.sg_expiry_time = None
                        self.sg_expiry_timer_sg_list = None
                        self.mldp_mdt_name = None
                        self.mldp_mdt_interface = None
                        self.mldp_mdt_mtu = None
                        self.mldp_maximum_mdt_aggregation = None
                        self.mldp_mdt_data_switchover_interval = None
                        self.mldp_mdt_data_announce_interval = None
                        self.mldp_mdt_rpf_identifier = None
                        self.mldp_mdt_remote_rpf_identifier = None
                        self.is_create_mldp_mdt_interface = None
                        self.is_mldp_mdt_owner = None
                        self.mldp_root_count = None
                        self.mldp_head_lsm_identifier = None
                        self.mldp_remote_head_lsm_identifier = None
                        self.organization_unique_identifier = None
                        self.vpn_index = None
                        self.mldp_partitioned_mdt_configured = None
                        self.mldp_remote_partitioned_mdt_configured = None
                        self.mldp_partioned_mp2m_ptree = None
                        self.mldp_partitioned_head_lsm_identifier = None
                        self.mldp_head_local_label = None
                        self.mldp_partitioned_mdt_identifier = None
                        self.bgp_auto_discovery_configured = None
                        self.suppress_pim_data_mdt_tlv = None
                        self.inter_autonomous_system_enabled = None
                        self.bgp_source_active_announce = None
                        self.bgp_i_pmsi_added = None
                        self.mldp_bsr_control_tree_added = None
                        self.mldp_auto_rp_discovery_tree_added = None
                        self.mldp_auto_rp_announce_tree_added = None
                        self.bgp_auto_discovery_type = None
                        self.mdt_partitioned_mdt_control_identifier = None
                        self.mdt_partitioned_ir_control_identifier = None
                        self.mldp_control_head_lsm_identifier = None
                        self.umh = None
                        self.suppress_shared_tree_join = None
                        self.rsvp_te_mdt_name = None
                        self.rsvp_te_mdt_interface = None
                        self.rsvp_te_mdt_mtu = None
                        self.rsvp_te_maximum_mdt_aggregation = None
                        self.rsvp_te_mdt_data_switchover_interval = None
                        self.rsvp_te_mdt_data_announce_interval = None
                        self.rsvp_te_mdt_rpf_identifier = None
                        self.is_create_rsvp_te_mdt_interface = None
                        self.is_rsvp_te_mdt_owner = None
                        self.rsvp_te_mdt_static_p2mp_count = None
                        self.p2mpte_li_drop = None
                        self.ir_mdt_name = None
                        self.ir_mdt_interface = None
                        self.ir_mdt_mtu = None
                        self.ir_maximum_mdt_aggregation = None
                        self.ir_mdt_data_switchover_interval = None
                        self.ir_mdt_data_announce_interval = None
                        self.ir_mdt_rpf_identifier = None
                        self.ir_mdt_tail_label = None
                        self.is_create_ir_mdt_interface = None
                        self.is_ir_mdt_owner = None
                        self.in_b_and_mdt_name = None
                        self.in_b_and_mdt_interface = None
                        self.in_b_and_mdt_mtu = None
                        self.in_band_maximum_mdt_aggregation = None
                        self.in_b_and_mdt_data_switchover_interval = None
                        self.in_b_and_mdt_data_announce_interval = None
                        self.in_b_and_mdt_rpf_identifier = None
                        self.is_create_in_b_and_mdt_interface = None
                        self.is_in_b_and_mdt_owner = None
                        self.in_band_signaling_local_enabled = None
                        self.in_band_signaling_remote_enabled = None
                        self.valid_rd_present = None
                        self.stale_rd_present = None
                        self.route_distinguisher = None
                        self.gin_b_and_mdt_name = None
                        self.gin_b_and_mdt_interface = None
                        self.gin_b_and_mdt_mtu = None
                        self.gin_band_maximum_mdt_aggregation = None
                        self.gin_b_and_mdt_data_switchover_interval = None
                        self.gin_b_and_mdt_data_announce_interval = None
                        self.gin_b_and_mdt_rpf_identifier = None
                        self.is_create_gin_b_and_mdt_interface = None
                        self.is_gin_b_and_mdt_owner = None
                        self.is_pim_nsf_rib_converged = None
                        self.is_pim_nsf_rib_converge_received = None
                        self.is_rib_multipath_enabled = None
                        self.is_rib_multipath_interface_hash = None
                        self.is_rib_multipath_source_hash = None
                        self.is_rib_multipath_source_next_hop_hash = None
                        self.rump_enabled = None
                        self.is_create_mdt_interface = None
                        self.is_auto_rp_listen_enabled = None
                        self.is_all_interface_disable_operation = None
                        self.is_default_granges = None
                        self.is_auto_rp_listen_sock_add = None
                        self.is_redistribution_reset = None
                        self.redistribution_reset_count = None
                        self.rpf_policy_name = None
                        self.table_count = None
                        self.active_table_count = None
                        self.anycast_rp_policy_name = None
                        self.anycast_rp_configured = None
                        self.bgp_remote_on = None
                        self.bgp_remote_interface_name = None
                        self.bgp_remote_interface = None
                        self.bgp_remote_address = None
                        self.bgp_remote_state = None
                        self.physical_interface_count = None
                        self.virtual_interface_count = None
                        self.virtual_mlc_interface_name = None
                        self.mdt_immediate_switch = None
                        self.mldp_root_address = []

                        self.remote_default_group = Pim.Active.Vrfs.Vrf.Context.RemoteDefaultGroup()
                        self.remote_default_group.parent = self
                        self._children_name_map["remote_default_group"] = "remote-default-group"

                        self.rpf_default_table = Pim.Active.Vrfs.Vrf.Context.RpfDefaultTable()
                        self.rpf_default_table.parent = self
                        self._children_name_map["rpf_default_table"] = "rpf-default-table"

                        self.export_route_target = YList(self)
                        self.import_route_target = YList(self)
                        self.anycast_rp_range = YList(self)
                        self._segment_path = lambda: "context"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.Vrfs.Vrf.Context, ['vrf_id', 'table_id', 'murib_id', 'rpf_id', 'remote_table_id', 'mdt_default_group', 'mdt_source', 'mdt_source_interface', 'mdt_interface', 'mdt_gre_rpf_identifier', 'mdt_gre_remote_rpf_identifier', 'is_unicast_rib_registration', 'is_multicast_rib_registration', 'is_active', 'is_active_ital', 'is_mrib_register', 'is_mdt_owner', 'is_routing_enabled', 'is_socket_add_required', 'is_socket_added', 'is_lpts_socket_add_required', 'is_lpts_socket_added', 'is_udp_socket_add_required', 'is_udp_socket_added', 'is_udp_socket_bind_required', 'is_udp_socket_bind', 'is_register_injection_socket_add_required', 'is_register_injection_socket_added', 'is_register_injection_lpts_socket_add_required', 'is_register_injection_lpts_socket_added', 'is_m_host_publish_pending', 'mhost_interface', 'mhost_default_interface_config', 'mdt_mtu', 'maximum_mdt_aggregation', 'mdt_data_switchover_interval', 'mdt_data_announce_interval', 'non_default_vrf_count_on_socket', 'neighbor_filter_name', 'mdt_neighbor_filter_name', 'allow_rp_configured', 'allow_rp_group_list', 'allow_rp_rp_list', 'sg_expiry_timer_configured', 'sg_expiry_time', 'sg_expiry_timer_sg_list', 'mldp_mdt_name', 'mldp_mdt_interface', 'mldp_mdt_mtu', 'mldp_maximum_mdt_aggregation', 'mldp_mdt_data_switchover_interval', 'mldp_mdt_data_announce_interval', 'mldp_mdt_rpf_identifier', 'mldp_mdt_remote_rpf_identifier', 'is_create_mldp_mdt_interface', 'is_mldp_mdt_owner', 'mldp_root_count', 'mldp_head_lsm_identifier', 'mldp_remote_head_lsm_identifier', 'organization_unique_identifier', 'vpn_index', 'mldp_partitioned_mdt_configured', 'mldp_remote_partitioned_mdt_configured', 'mldp_partioned_mp2m_ptree', 'mldp_partitioned_head_lsm_identifier', 'mldp_head_local_label', 'mldp_partitioned_mdt_identifier', 'bgp_auto_discovery_configured', 'suppress_pim_data_mdt_tlv', 'inter_autonomous_system_enabled', 'bgp_source_active_announce', 'bgp_i_pmsi_added', 'mldp_bsr_control_tree_added', 'mldp_auto_rp_discovery_tree_added', 'mldp_auto_rp_announce_tree_added', 'bgp_auto_discovery_type', 'mdt_partitioned_mdt_control_identifier', 'mdt_partitioned_ir_control_identifier', 'mldp_control_head_lsm_identifier', 'umh', 'suppress_shared_tree_join', 'rsvp_te_mdt_name', 'rsvp_te_mdt_interface', 'rsvp_te_mdt_mtu', 'rsvp_te_maximum_mdt_aggregation', 'rsvp_te_mdt_data_switchover_interval', 'rsvp_te_mdt_data_announce_interval', 'rsvp_te_mdt_rpf_identifier', 'is_create_rsvp_te_mdt_interface', 'is_rsvp_te_mdt_owner', 'rsvp_te_mdt_static_p2mp_count', 'p2mpte_li_drop', 'ir_mdt_name', 'ir_mdt_interface', 'ir_mdt_mtu', 'ir_maximum_mdt_aggregation', 'ir_mdt_data_switchover_interval', 'ir_mdt_data_announce_interval', 'ir_mdt_rpf_identifier', 'ir_mdt_tail_label', 'is_create_ir_mdt_interface', 'is_ir_mdt_owner', 'in_b_and_mdt_name', 'in_b_and_mdt_interface', 'in_b_and_mdt_mtu', 'in_band_maximum_mdt_aggregation', 'in_b_and_mdt_data_switchover_interval', 'in_b_and_mdt_data_announce_interval', 'in_b_and_mdt_rpf_identifier', 'is_create_in_b_and_mdt_interface', 'is_in_b_and_mdt_owner', 'in_band_signaling_local_enabled', 'in_band_signaling_remote_enabled', 'valid_rd_present', 'stale_rd_present', 'route_distinguisher', 'gin_b_and_mdt_name', 'gin_b_and_mdt_interface', 'gin_b_and_mdt_mtu', 'gin_band_maximum_mdt_aggregation', 'gin_b_and_mdt_data_switchover_interval', 'gin_b_and_mdt_data_announce_interval', 'gin_b_and_mdt_rpf_identifier', 'is_create_gin_b_and_mdt_interface', 'is_gin_b_and_mdt_owner', 'is_pim_nsf_rib_converged', 'is_pim_nsf_rib_converge_received', 'is_rib_multipath_enabled', 'is_rib_multipath_interface_hash', 'is_rib_multipath_source_hash', 'is_rib_multipath_source_next_hop_hash', 'rump_enabled', 'is_create_mdt_interface', 'is_auto_rp_listen_enabled', 'is_all_interface_disable_operation', 'is_default_granges', 'is_auto_rp_listen_sock_add', 'is_redistribution_reset', 'redistribution_reset_count', 'rpf_policy_name', 'table_count', 'active_table_count', 'anycast_rp_policy_name', 'anycast_rp_configured', 'bgp_remote_on', 'bgp_remote_interface_name', 'bgp_remote_interface', 'bgp_remote_address', 'bgp_remote_state', 'physical_interface_count', 'virtual_interface_count', 'virtual_mlc_interface_name', 'mdt_immediate_switch', 'mldp_root_address'], name, value)


                    class RemoteDefaultGroup(Entity):
                        """
                        Remote Default Group
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.Context.RemoteDefaultGroup, self).__init__()

                            self.yang_name = "remote-default-group"
                            self.yang_parent_name = "context"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "remote-default-group"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.Context.RemoteDefaultGroup, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class RpfDefaultTable(Entity):
                        """
                        RPF Default Table
                        
                        .. attribute:: afi
                        
                        	AFI
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: safi
                        
                        	SAFI
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_name
                        
                        	Table name
                        	**type**\: str
                        
                        .. attribute:: vrf_id
                        
                        	VRF ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_id
                        
                        	Table ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_active
                        
                        	Active status
                        	**type**\: bool
                        
                        .. attribute:: is_ital_registration_done
                        
                        	ITAL reg status
                        	**type**\: bool
                        
                        .. attribute:: is_rib_registration_done
                        
                        	RIB reg status
                        	**type**\: bool
                        
                        .. attribute:: is_rib_convergence_received
                        
                        	RIB Convergence receive status
                        	**type**\: bool
                        
                        .. attribute:: is_rib_convergence
                        
                        	RIB Convergence status
                        	**type**\: bool
                        
                        .. attribute:: rpf_registrations
                        
                        	RPF Registration count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.Context.RpfDefaultTable, self).__init__()

                            self.yang_name = "rpf-default-table"
                            self.yang_parent_name = "context"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('afi', (YLeaf(YType.uint32, 'afi'), ['int'])),
                                ('safi', (YLeaf(YType.uint32, 'safi'), ['int'])),
                                ('table_name', (YLeaf(YType.str, 'table-name'), ['str'])),
                                ('vrf_id', (YLeaf(YType.uint32, 'vrf-id'), ['int'])),
                                ('table_id', (YLeaf(YType.uint32, 'table-id'), ['int'])),
                                ('is_active', (YLeaf(YType.boolean, 'is-active'), ['bool'])),
                                ('is_ital_registration_done', (YLeaf(YType.boolean, 'is-ital-registration-done'), ['bool'])),
                                ('is_rib_registration_done', (YLeaf(YType.boolean, 'is-rib-registration-done'), ['bool'])),
                                ('is_rib_convergence_received', (YLeaf(YType.boolean, 'is-rib-convergence-received'), ['bool'])),
                                ('is_rib_convergence', (YLeaf(YType.boolean, 'is-rib-convergence'), ['bool'])),
                                ('rpf_registrations', (YLeaf(YType.uint32, 'rpf-registrations'), ['int'])),
                            ])
                            self.afi = None
                            self.safi = None
                            self.table_name = None
                            self.vrf_id = None
                            self.table_id = None
                            self.is_active = None
                            self.is_ital_registration_done = None
                            self.is_rib_registration_done = None
                            self.is_rib_convergence_received = None
                            self.is_rib_convergence = None
                            self.rpf_registrations = None
                            self._segment_path = lambda: "rpf-default-table"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.Context.RpfDefaultTable, ['afi', 'safi', 'table_name', 'vrf_id', 'table_id', 'is_active', 'is_ital_registration_done', 'is_rib_registration_done', 'is_rib_convergence_received', 'is_rib_convergence', 'rpf_registrations'], name, value)


                    class ExportRouteTarget(Entity):
                        """
                        Export Route Targets
                        
                        .. attribute:: route_target
                        
                        	Route Target Extended community value
                        	**type**\: str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        .. attribute:: configured
                        
                        	Configured Route Target
                        	**type**\: bool
                        
                        .. attribute:: anycast_rp
                        
                        	Anycast\-RP Group
                        	**type**\: bool
                        
                        .. attribute:: anycast_rp_marked
                        
                        	Anycast\-RP Group marked
                        	**type**\: bool
                        
                        .. attribute:: update_pending
                        
                        	Update Pending to BGP
                        	**type**\: bool
                        
                        .. attribute:: bgp_auto_discovery
                        
                        	BGP Auto Discovery
                        	**type**\: bool
                        
                        .. attribute:: segment_border
                        
                        	Segment Border
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.Context.ExportRouteTarget, self).__init__()

                            self.yang_name = "export-route-target"
                            self.yang_parent_name = "context"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('route_target', (YLeaf(YType.str, 'route-target'), ['str'])),
                                ('configured', (YLeaf(YType.boolean, 'configured'), ['bool'])),
                                ('anycast_rp', (YLeaf(YType.boolean, 'anycast-rp'), ['bool'])),
                                ('anycast_rp_marked', (YLeaf(YType.boolean, 'anycast-rp-marked'), ['bool'])),
                                ('update_pending', (YLeaf(YType.boolean, 'update-pending'), ['bool'])),
                                ('bgp_auto_discovery', (YLeaf(YType.boolean, 'bgp-auto-discovery'), ['bool'])),
                                ('segment_border', (YLeaf(YType.boolean, 'segment-border'), ['bool'])),
                            ])
                            self.route_target = None
                            self.configured = None
                            self.anycast_rp = None
                            self.anycast_rp_marked = None
                            self.update_pending = None
                            self.bgp_auto_discovery = None
                            self.segment_border = None
                            self._segment_path = lambda: "export-route-target"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.Context.ExportRouteTarget, ['route_target', 'configured', 'anycast_rp', 'anycast_rp_marked', 'update_pending', 'bgp_auto_discovery', 'segment_border'], name, value)


                    class ImportRouteTarget(Entity):
                        """
                        Import Route Targets
                        
                        .. attribute:: route_target
                        
                        	Route Target Extended community value
                        	**type**\: str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        .. attribute:: configured
                        
                        	Configured Route Target
                        	**type**\: bool
                        
                        .. attribute:: anycast_rp
                        
                        	Anycast\-RP Group
                        	**type**\: bool
                        
                        .. attribute:: anycast_rp_marked
                        
                        	Anycast\-RP Group marked
                        	**type**\: bool
                        
                        .. attribute:: update_pending
                        
                        	Update Pending to BGP
                        	**type**\: bool
                        
                        .. attribute:: bgp_auto_discovery
                        
                        	BGP Auto Discovery
                        	**type**\: bool
                        
                        .. attribute:: segment_border
                        
                        	Segment Border
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.Context.ImportRouteTarget, self).__init__()

                            self.yang_name = "import-route-target"
                            self.yang_parent_name = "context"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('route_target', (YLeaf(YType.str, 'route-target'), ['str'])),
                                ('configured', (YLeaf(YType.boolean, 'configured'), ['bool'])),
                                ('anycast_rp', (YLeaf(YType.boolean, 'anycast-rp'), ['bool'])),
                                ('anycast_rp_marked', (YLeaf(YType.boolean, 'anycast-rp-marked'), ['bool'])),
                                ('update_pending', (YLeaf(YType.boolean, 'update-pending'), ['bool'])),
                                ('bgp_auto_discovery', (YLeaf(YType.boolean, 'bgp-auto-discovery'), ['bool'])),
                                ('segment_border', (YLeaf(YType.boolean, 'segment-border'), ['bool'])),
                            ])
                            self.route_target = None
                            self.configured = None
                            self.anycast_rp = None
                            self.anycast_rp_marked = None
                            self.update_pending = None
                            self.bgp_auto_discovery = None
                            self.segment_border = None
                            self._segment_path = lambda: "import-route-target"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.Context.ImportRouteTarget, ['route_target', 'configured', 'anycast_rp', 'anycast_rp_marked', 'update_pending', 'bgp_auto_discovery', 'segment_border'], name, value)


                    class AnycastRpRange(Entity):
                        """
                        Anycast\-RP Ranges
                        
                        .. attribute:: prefix
                        
                        	Anycast\-RP Range Prefix
                        	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Context.AnycastRpRange.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Anycast\-RP Range Prefix Length
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: ancast_rp_marked
                        
                        	Anycast\-RP Range marked
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.Context.AnycastRpRange, self).__init__()

                            self.yang_name = "anycast-rp-range"
                            self.yang_parent_name = "context"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("prefix", ("prefix", Pim.Active.Vrfs.Vrf.Context.AnycastRpRange.Prefix))])
                            self._leafs = OrderedDict([
                                ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                ('ancast_rp_marked', (YLeaf(YType.boolean, 'ancast-rp-marked'), ['bool'])),
                            ])
                            self.prefix_length = None
                            self.ancast_rp_marked = None

                            self.prefix = Pim.Active.Vrfs.Vrf.Context.AnycastRpRange.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"
                            self._segment_path = lambda: "anycast-rp-range"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.Context.AnycastRpRange, ['prefix_length', 'ancast_rp_marked'], name, value)


                        class Prefix(Entity):
                            """
                            Anycast\-RP Range Prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Context.AnycastRpRange.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "anycast-rp-range"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "prefix"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.Context.AnycastRpRange.Prefix, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class TopologyEntryFlagRouteCounts(Entity):
                    """
                    Route count for topology with entry flag set
                    
                    .. attribute:: topology_entry_flag_route_count
                    
                    	Route count for topology with entry flag set
                    	**type**\: list of  		 :py:class:`TopologyEntryFlagRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts, self).__init__()

                        self.yang_name = "topology-entry-flag-route-counts"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("topology-entry-flag-route-count", ("topology_entry_flag_route_count", Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount))])
                        self._leafs = OrderedDict()

                        self.topology_entry_flag_route_count = YList(self)
                        self._segment_path = lambda: "topology-entry-flag-route-counts"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts, [], name, value)


                    class TopologyEntryFlagRouteCount(Entity):
                        """
                        Route count for topology with entry flag set
                        
                        .. attribute:: entry_flag  (key)
                        
                        	entry flag
                        	**type**\:  :py:class:`PimTopologyEntryFlag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimTopologyEntryFlag>`
                        
                        .. attribute:: group_ranges
                        
                        	No. of (\*,G/M) routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: active_group_ranges
                        
                        	No. of (\*,G/M) routes active in mrib
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: groute_count
                        
                        	No. of (\*,G) routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sg_route_count
                        
                        	No. of (S,G) routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sgr_route_count
                        
                        	No. of (S,G)RPT routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_node_low_memory
                        
                        	Is node in low memory condition
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount, self).__init__()

                            self.yang_name = "topology-entry-flag-route-count"
                            self.yang_parent_name = "topology-entry-flag-route-counts"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['entry_flag']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('entry_flag', (YLeaf(YType.enumeration, 'entry-flag'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimTopologyEntryFlag', '')])),
                                ('group_ranges', (YLeaf(YType.uint32, 'group-ranges'), ['int'])),
                                ('active_group_ranges', (YLeaf(YType.uint32, 'active-group-ranges'), ['int'])),
                                ('groute_count', (YLeaf(YType.uint32, 'groute-count'), ['int'])),
                                ('sg_route_count', (YLeaf(YType.uint32, 'sg-route-count'), ['int'])),
                                ('sgr_route_count', (YLeaf(YType.uint32, 'sgr-route-count'), ['int'])),
                                ('is_node_low_memory', (YLeaf(YType.boolean, 'is-node-low-memory'), ['bool'])),
                            ])
                            self.entry_flag = None
                            self.group_ranges = None
                            self.active_group_ranges = None
                            self.groute_count = None
                            self.sg_route_count = None
                            self.sgr_route_count = None
                            self.is_node_low_memory = None
                            self._segment_path = lambda: "topology-entry-flag-route-count" + "[entry-flag='" + str(self.entry_flag) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount, ['entry_flag', 'group_ranges', 'active_group_ranges', 'groute_count', 'sg_route_count', 'sgr_route_count', 'is_node_low_memory'], name, value)


                class RpfRedirect(Entity):
                    """
                    PIM ECMP RPF\-redirect bundle
                    
                    .. attribute:: redirect_route_databases
                    
                    	PIM ECMP RPF\-redirect route database
                    	**type**\:  :py:class:`RedirectRouteDatabases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases>`
                    
                    .. attribute:: bundle_interfaces
                    
                    	PIM ECMP RPF\-redirect bundle information
                    	**type**\:  :py:class:`BundleInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.RpfRedirect, self).__init__()

                        self.yang_name = "rpf-redirect"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("redirect-route-databases", ("redirect_route_databases", Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases)), ("bundle-interfaces", ("bundle_interfaces", Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces))])
                        self._leafs = OrderedDict()

                        self.redirect_route_databases = Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases()
                        self.redirect_route_databases.parent = self
                        self._children_name_map["redirect_route_databases"] = "redirect-route-databases"

                        self.bundle_interfaces = Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces()
                        self.bundle_interfaces.parent = self
                        self._children_name_map["bundle_interfaces"] = "bundle-interfaces"
                        self._segment_path = lambda: "rpf-redirect"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.Vrfs.Vrf.RpfRedirect, [], name, value)


                    class RedirectRouteDatabases(Entity):
                        """
                        PIM ECMP RPF\-redirect route database
                        
                        .. attribute:: redirect_route_database
                        
                        	PIM ECMP RPF\-redirect route information
                        	**type**\: list of  		 :py:class:`RedirectRouteDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases, self).__init__()

                            self.yang_name = "redirect-route-databases"
                            self.yang_parent_name = "rpf-redirect"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("redirect-route-database", ("redirect_route_database", Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase))])
                            self._leafs = OrderedDict()

                            self.redirect_route_database = YList(self)
                            self._segment_path = lambda: "redirect-route-databases"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases, [], name, value)


                        class RedirectRouteDatabase(Entity):
                            """
                            PIM ECMP RPF\-redirect route information
                            
                            .. attribute:: source_address
                            
                            	Source address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: group_address
                            
                            	Group address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: group_address_xr
                            
                            	Group ddress
                            	**type**\:  :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr>`
                            
                            .. attribute:: source_address_xr
                            
                            	Source address
                            	**type**\:  :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr>`
                            
                            .. attribute:: bandwidth
                            
                            	Bandwidth in Kbps
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: interface
                            
                            	Outgoing interface list
                            	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase, self).__init__()

                                self.yang_name = "redirect-route-database"
                                self.yang_parent_name = "redirect-route-databases"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("group-address-xr", ("group_address_xr", Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr)), ("source-address-xr", ("source_address_xr", Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr)), ("interface", ("interface", Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface))])
                                self._leafs = OrderedDict([
                                    ('source_address', (YLeaf(YType.str, 'source-address'), ['str','str'])),
                                    ('group_address', (YLeaf(YType.str, 'group-address'), ['str','str'])),
                                    ('bandwidth', (YLeaf(YType.uint32, 'bandwidth'), ['int'])),
                                    ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                                ])
                                self.source_address = None
                                self.group_address = None
                                self.bandwidth = None
                                self.uptime = None

                                self.group_address_xr = Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"

                                self.source_address_xr = Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr()
                                self.source_address_xr.parent = self
                                self._children_name_map["source_address_xr"] = "source-address-xr"

                                self.interface = YList(self)
                                self._segment_path = lambda: "redirect-route-database"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase, ['source_address', 'group_address', 'bandwidth', 'uptime'], name, value)


                            class GroupAddressXr(Entity):
                                """
                                Group ddress
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr, self).__init__()

                                    self.yang_name = "group-address-xr"
                                    self.yang_parent_name = "redirect-route-database"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "group-address-xr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                            class SourceAddressXr(Entity):
                                """
                                Source address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr, self).__init__()

                                    self.yang_name = "source-address-xr"
                                    self.yang_parent_name = "redirect-route-database"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "source-address-xr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                            class Interface(Entity):
                                """
                                Outgoing interface list
                                
                                .. attribute:: rpf_address
                                
                                	RPF Address
                                	**type**\:  :py:class:`RpfAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress>`
                                
                                .. attribute:: interface_name
                                
                                	Interface name
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                .. attribute:: uptime
                                
                                	Uptime in seconds
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: second
                                
                                .. attribute:: expiry
                                
                                	Expiry in seconds
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: second
                                
                                .. attribute:: is_rpf_interface
                                
                                	Is RPF Interface
                                	**type**\: bool
                                
                                .. attribute:: is_outgoing_interface
                                
                                	Is outgoing Interface
                                	**type**\: bool
                                
                                .. attribute:: is_snoop_interface
                                
                                	Is snooping Interface
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface, self).__init__()

                                    self.yang_name = "interface"
                                    self.yang_parent_name = "redirect-route-database"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("rpf-address", ("rpf_address", Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress))])
                                    self._leafs = OrderedDict([
                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                        ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                                        ('expiry', (YLeaf(YType.uint64, 'expiry'), ['int'])),
                                        ('is_rpf_interface', (YLeaf(YType.boolean, 'is-rpf-interface'), ['bool'])),
                                        ('is_outgoing_interface', (YLeaf(YType.boolean, 'is-outgoing-interface'), ['bool'])),
                                        ('is_snoop_interface', (YLeaf(YType.boolean, 'is-snoop-interface'), ['bool'])),
                                    ])
                                    self.interface_name = None
                                    self.uptime = None
                                    self.expiry = None
                                    self.is_rpf_interface = None
                                    self.is_outgoing_interface = None
                                    self.is_snoop_interface = None

                                    self.rpf_address = Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress()
                                    self.rpf_address.parent = self
                                    self._children_name_map["rpf_address"] = "rpf-address"
                                    self._segment_path = lambda: "interface"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface, ['interface_name', 'uptime', 'expiry', 'is_rpf_interface', 'is_outgoing_interface', 'is_snoop_interface'], name, value)


                                class RpfAddress(Entity):
                                    """
                                    RPF Address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress, self).__init__()

                                        self.yang_name = "rpf-address"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ])
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None
                                        self._segment_path = lambda: "rpf-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class BundleInterfaces(Entity):
                        """
                        PIM ECMP RPF\-redirect bundle information
                        
                        .. attribute:: bundle_interface
                        
                        	PIM ECMP RPF\-redirect bundle interface information
                        	**type**\: list of  		 :py:class:`BundleInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces.BundleInterface>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces, self).__init__()

                            self.yang_name = "bundle-interfaces"
                            self.yang_parent_name = "rpf-redirect"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("bundle-interface", ("bundle_interface", Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces.BundleInterface))])
                            self._leafs = OrderedDict()

                            self.bundle_interface = YList(self)
                            self._segment_path = lambda: "bundle-interfaces"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces, [], name, value)


                        class BundleInterface(Entity):
                            """
                            PIM ECMP RPF\-redirect bundle interface
                            information
                            
                            .. attribute:: bundle_name
                            
                            	Bundle name
                            	**type**\: str
                            
                            	**length:** 1..32
                            
                            .. attribute:: interface_name
                            
                            	Bundle interface name
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: rpf_redirect_bundle_name
                            
                            	RPF redirect bundle name
                            	**type**\: str
                            
                            	**length:** 0..33
                            
                            .. attribute:: rpf_redirect_interface_name
                            
                            	RPF redirect interface name
                            	**type**\: str
                            
                            	**length:** 0..33
                            
                            .. attribute:: available_bandwidth
                            
                            	Bandwidth available in Kbps
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: allocated_bandwidth
                            
                            	Bandwidth allocated in Kbps
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: total_bandwidth
                            
                            	Total bandwidth used in Kbps
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: topology_bandwidth_used
                            
                            	Bandwidth used by topology in Kbps
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: snooping_bandwidth_used
                            
                            	Bandwidth used by snooped entries in Kbps
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: allocated_threshold_bandwidth
                            
                            	Configured threshold in Kbps
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: available_threshold_bandwidth
                            
                            	Available threshold in Kbps
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces.BundleInterface, self).__init__()

                                self.yang_name = "bundle-interface"
                                self.yang_parent_name = "bundle-interfaces"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('bundle_name', (YLeaf(YType.str, 'bundle-name'), ['str'])),
                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                    ('rpf_redirect_bundle_name', (YLeaf(YType.str, 'rpf-redirect-bundle-name'), ['str'])),
                                    ('rpf_redirect_interface_name', (YLeaf(YType.str, 'rpf-redirect-interface-name'), ['str'])),
                                    ('available_bandwidth', (YLeaf(YType.int32, 'available-bandwidth'), ['int'])),
                                    ('allocated_bandwidth', (YLeaf(YType.int32, 'allocated-bandwidth'), ['int'])),
                                    ('total_bandwidth', (YLeaf(YType.int32, 'total-bandwidth'), ['int'])),
                                    ('topology_bandwidth_used', (YLeaf(YType.int32, 'topology-bandwidth-used'), ['int'])),
                                    ('snooping_bandwidth_used', (YLeaf(YType.int32, 'snooping-bandwidth-used'), ['int'])),
                                    ('allocated_threshold_bandwidth', (YLeaf(YType.int32, 'allocated-threshold-bandwidth'), ['int'])),
                                    ('available_threshold_bandwidth', (YLeaf(YType.int32, 'available-threshold-bandwidth'), ['int'])),
                                ])
                                self.bundle_name = None
                                self.interface_name = None
                                self.rpf_redirect_bundle_name = None
                                self.rpf_redirect_interface_name = None
                                self.available_bandwidth = None
                                self.allocated_bandwidth = None
                                self.total_bandwidth = None
                                self.topology_bandwidth_used = None
                                self.snooping_bandwidth_used = None
                                self.allocated_threshold_bandwidth = None
                                self.available_threshold_bandwidth = None
                                self._segment_path = lambda: "bundle-interface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces.BundleInterface, ['bundle_name', 'interface_name', 'rpf_redirect_bundle_name', 'rpf_redirect_interface_name', 'available_bandwidth', 'allocated_bandwidth', 'total_bandwidth', 'topology_bandwidth_used', 'snooping_bandwidth_used', 'allocated_threshold_bandwidth', 'available_threshold_bandwidth'], name, value)


                class Tunnels(Entity):
                    """
                    Tunnels information that PIM has
                    
                    .. attribute:: tunnel
                    
                    	PIM tunnel information
                    	**type**\: list of  		 :py:class:`Tunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Tunnels.Tunnel>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.Tunnels, self).__init__()

                        self.yang_name = "tunnels"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("tunnel", ("tunnel", Pim.Active.Vrfs.Vrf.Tunnels.Tunnel))])
                        self._leafs = OrderedDict()

                        self.tunnel = YList(self)
                        self._segment_path = lambda: "tunnels"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.Vrfs.Vrf.Tunnels, [], name, value)


                    class Tunnel(Entity):
                        """
                        PIM tunnel information
                        
                        .. attribute:: tunnel_name  (key)
                        
                        	Tunnel name
                        	**type**\: str
                        
                        	**length:** 1..64
                        
                        .. attribute:: source_address
                        
                        	Source addr known to PIM
                        	**type**\:  :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress>`
                        
                        .. attribute:: rp_address
                        
                        	RP addr known to PIM
                        	**type**\:  :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.RpAddress>`
                        
                        .. attribute:: source_address_netio
                        
                        	Source addr from netio
                        	**type**\:  :py:class:`SourceAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio>`
                        
                        .. attribute:: group_address_netio
                        
                        	Group addr from netio
                        	**type**\:  :py:class:`GroupAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio>`
                        
                        .. attribute:: vrf_name
                        
                        	VRF Name
                        	**type**\: str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.Tunnels.Tunnel, self).__init__()

                            self.yang_name = "tunnel"
                            self.yang_parent_name = "tunnels"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['tunnel_name']
                            self._child_classes = OrderedDict([("source-address", ("source_address", Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress)), ("rp-address", ("rp_address", Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.RpAddress)), ("source-address-netio", ("source_address_netio", Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio)), ("group-address-netio", ("group_address_netio", Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio))])
                            self._leafs = OrderedDict([
                                ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                            ])
                            self.tunnel_name = None
                            self.vrf_name = None

                            self.source_address = Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"

                            self.rp_address = Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"

                            self.source_address_netio = Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio()
                            self.source_address_netio.parent = self
                            self._children_name_map["source_address_netio"] = "source-address-netio"

                            self.group_address_netio = Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio()
                            self.group_address_netio.parent = self
                            self._children_name_map["group_address_netio"] = "group-address-netio"
                            self._segment_path = lambda: "tunnel" + "[tunnel-name='" + str(self.tunnel_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.Tunnels.Tunnel, ['tunnel_name', 'vrf_name'], name, value)


                        class SourceAddress(Entity):
                            """
                            Source addr known to PIM
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "source-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class RpAddress(Entity):
                            """
                            RP addr known to PIM
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "rp-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.RpAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class SourceAddressNetio(Entity):
                            """
                            Source addr from netio
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio, self).__init__()

                                self.yang_name = "source-address-netio"
                                self.yang_parent_name = "tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "source-address-netio"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class GroupAddressNetio(Entity):
                            """
                            Group addr from netio
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio, self).__init__()

                                self.yang_name = "group-address-netio"
                                self.yang_parent_name = "tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "group-address-netio"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class MulticastStaticRoutes(Entity):
                    """
                    PIM multicast static route table
                    
                    .. attribute:: multicast_static_route
                    
                    	PIM multicast static route information
                    	**type**\: list of  		 :py:class:`MulticastStaticRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.MulticastStaticRoutes, self).__init__()

                        self.yang_name = "multicast-static-routes"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("multicast-static-route", ("multicast_static_route", Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute))])
                        self._leafs = OrderedDict()

                        self.multicast_static_route = YList(self)
                        self._segment_path = lambda: "multicast-static-routes"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.Vrfs.Vrf.MulticastStaticRoutes, [], name, value)


                    class MulticastStaticRoute(Entity):
                        """
                        PIM multicast static route information
                        
                        .. attribute:: address
                        
                        	Network address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: prefix
                        
                        	Prefix
                        	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix>`
                        
                        .. attribute:: nexthop
                        
                        	Next Hop
                        	**type**\:  :py:class:`Nexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop>`
                        
                        .. attribute:: interface_name
                        
                        	Interface Handle
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: distance
                        
                        	Distance
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: prefix_length_xr
                        
                        	Prefix Length
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: is_via_lsm
                        
                        	LSM flag
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute, self).__init__()

                            self.yang_name = "multicast-static-route"
                            self.yang_parent_name = "multicast-static-routes"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("prefix", ("prefix", Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix)), ("nexthop", ("nexthop", Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop))])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str','str'])),
                                ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ('distance', (YLeaf(YType.uint32, 'distance'), ['int'])),
                                ('prefix_length_xr', (YLeaf(YType.uint8, 'prefix-length-xr'), ['int'])),
                                ('is_via_lsm', (YLeaf(YType.boolean, 'is-via-lsm'), ['bool'])),
                            ])
                            self.address = None
                            self.prefix_length = None
                            self.interface_name = None
                            self.distance = None
                            self.prefix_length_xr = None
                            self.is_via_lsm = None

                            self.prefix = Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"

                            self.nexthop = Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop()
                            self.nexthop.parent = self
                            self._children_name_map["nexthop"] = "nexthop"
                            self._segment_path = lambda: "multicast-static-route"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute, ['address', 'prefix_length', 'interface_name', 'distance', 'prefix_length_xr', 'is_via_lsm'], name, value)


                        class Prefix(Entity):
                            """
                            Prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "multicast-static-route"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "prefix"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class Nexthop(Entity):
                            """
                            Next Hop
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop, self).__init__()

                                self.yang_name = "nexthop"
                                self.yang_parent_name = "multicast-static-route"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "nexthop"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class Neighbors(Entity):
                    """
                    PIM neighbor table
                    
                    .. attribute:: neighbor
                    
                    	PIM neighbor information
                    	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Neighbors.Neighbor>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.Neighbors, self).__init__()

                        self.yang_name = "neighbors"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("neighbor", ("neighbor", Pim.Active.Vrfs.Vrf.Neighbors.Neighbor))])
                        self._leafs = OrderedDict()

                        self.neighbor = YList(self)
                        self._segment_path = lambda: "neighbors"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim.Active.Vrfs.Vrf.Neighbors, [], name, value)


                    class Neighbor(Entity):
                        """
                        PIM neighbor information
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: neighbor_address
                        
                        	Neighbor address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identifier
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: expires
                        
                        	Neighbor expiry in seconds
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: expiry_timer
                        
                        	Expiry timer in seconds
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: is_this_neighbor_us
                        
                        	Is this neighbor us ?
                        	**type**\: bool
                        
                        .. attribute:: is_this_neighbor_dr
                        
                        	Is this neighbor the DR
                        	**type**\: bool
                        
                        .. attribute:: is_dr_priority_capable
                        
                        	Is this neighbor DR priority capable ?
                        	**type**\: bool
                        
                        .. attribute:: dr_priority
                        
                        	DR priority
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Is this neighbor bidir capable ?
                        	**type**\: bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Is this neighbor proxy capable?
                        	**type**\: bool
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Is this neighbor capable of batching asserts?
                        	**type**\: bool
                        
                        .. attribute:: is_ecmp_redirect_capable
                        
                        	Is this neighbor capable of Ecmp Redirect?
                        	**type**\: bool
                        
                        .. attribute:: is_bfd_state
                        
                        	Is the neighbor bfd session created
                        	**type**\: bool
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_address_xr
                        
                        	List of Neighbor Addresses
                        	**type**\: list of  		 :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Neighbors.Neighbor.NeighborAddressXr>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.Neighbors.Neighbor, self).__init__()

                            self.yang_name = "neighbor"
                            self.yang_parent_name = "neighbors"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("neighbor-address-xr", ("neighbor_address_xr", Pim.Active.Vrfs.Vrf.Neighbors.Neighbor.NeighborAddressXr))])
                            self._leafs = OrderedDict([
                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                                ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                                ('expires', (YLeaf(YType.uint64, 'expires'), ['int'])),
                                ('expiry_timer', (YLeaf(YType.uint64, 'expiry-timer'), ['int'])),
                                ('is_this_neighbor_us', (YLeaf(YType.boolean, 'is-this-neighbor-us'), ['bool'])),
                                ('is_this_neighbor_dr', (YLeaf(YType.boolean, 'is-this-neighbor-dr'), ['bool'])),
                                ('is_dr_priority_capable', (YLeaf(YType.boolean, 'is-dr-priority-capable'), ['bool'])),
                                ('dr_priority', (YLeaf(YType.uint32, 'dr-priority'), ['int'])),
                                ('is_bidirectional_capable', (YLeaf(YType.boolean, 'is-bidirectional-capable'), ['bool'])),
                                ('is_proxy_capable', (YLeaf(YType.boolean, 'is-proxy-capable'), ['bool'])),
                                ('is_batch_asserts_capable', (YLeaf(YType.boolean, 'is-batch-asserts-capable'), ['bool'])),
                                ('is_ecmp_redirect_capable', (YLeaf(YType.boolean, 'is-ecmp-redirect-capable'), ['bool'])),
                                ('is_bfd_state', (YLeaf(YType.boolean, 'is-bfd-state'), ['bool'])),
                                ('propagation_delay', (YLeaf(YType.uint16, 'propagation-delay'), ['int'])),
                                ('override_interval', (YLeaf(YType.uint16, 'override-interval'), ['int'])),
                            ])
                            self.interface_name = None
                            self.neighbor_address = None
                            self.interface_name_xr = None
                            self.uptime = None
                            self.expires = None
                            self.expiry_timer = None
                            self.is_this_neighbor_us = None
                            self.is_this_neighbor_dr = None
                            self.is_dr_priority_capable = None
                            self.dr_priority = None
                            self.is_bidirectional_capable = None
                            self.is_proxy_capable = None
                            self.is_batch_asserts_capable = None
                            self.is_ecmp_redirect_capable = None
                            self.is_bfd_state = None
                            self.propagation_delay = None
                            self.override_interval = None

                            self.neighbor_address_xr = YList(self)
                            self._segment_path = lambda: "neighbor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim.Active.Vrfs.Vrf.Neighbors.Neighbor, ['interface_name', 'neighbor_address', 'interface_name_xr', 'uptime', 'expires', 'expiry_timer', 'is_this_neighbor_us', 'is_this_neighbor_dr', 'is_dr_priority_capable', 'dr_priority', 'is_bidirectional_capable', 'is_proxy_capable', 'is_batch_asserts_capable', 'is_ecmp_redirect_capable', 'is_bfd_state', 'propagation_delay', 'override_interval'], name, value)


                        class NeighborAddressXr(Entity):
                            """
                            List of Neighbor Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Neighbors.Neighbor.NeighborAddressXr, self).__init__()

                                self.yang_name = "neighbor-address-xr"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "neighbor-address-xr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Pim.Active.Vrfs.Vrf.Neighbors.Neighbor.NeighborAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)

    def clone_ptr(self):
        self._top_entity = Pim()
        return self._top_entity

class Ipv6Pim(Entity):
    """
    ipv6 pim
    
    .. attribute:: standby
    
    	Standby Process
    	**type**\:  :py:class:`Standby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby>`
    
    .. attribute:: active
    
    	Active Process
    	**type**\:  :py:class:`Active <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active>`
    
    

    """

    _prefix = 'ipv4-pim-oper'
    _revision = '2017-09-07'

    def __init__(self):
        super(Ipv6Pim, self).__init__()
        self._top_entity = None

        self.yang_name = "ipv6-pim"
        self.yang_parent_name = "Cisco-IOS-XR-ipv4-pim-oper"
        self.is_top_level_class = True
        self.has_list_ancestor = False
        self.ylist_key_names = []
        self._child_classes = OrderedDict([("standby", ("standby", Ipv6Pim.Standby)), ("active", ("active", Ipv6Pim.Active))])
        self._leafs = OrderedDict()

        self.standby = Ipv6Pim.Standby()
        self.standby.parent = self
        self._children_name_map["standby"] = "standby"

        self.active = Ipv6Pim.Active()
        self.active.parent = self
        self._children_name_map["active"] = "active"
        self._segment_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim"
        self._is_frozen = True

    def __setattr__(self, name, value):
        self._perform_setattr(Ipv6Pim, [], name, value)


    class Standby(Entity):
        """
        Standby Process
        
        .. attribute:: default_context
        
        	Default Context
        	**type**\:  :py:class:`DefaultContext <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext>`
        
        .. attribute:: process
        
        	Process
        	**type**\:  :py:class:`Process <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Process>`
        
        .. attribute:: vrfs
        
        	VRF Table
        	**type**\:  :py:class:`Vrfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs>`
        
        

        """

        _prefix = 'ipv4-pim-oper'
        _revision = '2017-09-07'

        def __init__(self):
            super(Ipv6Pim.Standby, self).__init__()

            self.yang_name = "standby"
            self.yang_parent_name = "ipv6-pim"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("default-context", ("default_context", Ipv6Pim.Standby.DefaultContext)), ("process", ("process", Ipv6Pim.Standby.Process)), ("vrfs", ("vrfs", Ipv6Pim.Standby.Vrfs))])
            self._leafs = OrderedDict()

            self.default_context = Ipv6Pim.Standby.DefaultContext()
            self.default_context.parent = self
            self._children_name_map["default_context"] = "default-context"

            self.process = Ipv6Pim.Standby.Process()
            self.process.parent = self
            self._children_name_map["process"] = "process"

            self.vrfs = Ipv6Pim.Standby.Vrfs()
            self.vrfs.parent = self
            self._children_name_map["vrfs"] = "vrfs"
            self._segment_path = lambda: "standby"
            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Ipv6Pim.Standby, [], name, value)


        class DefaultContext(Entity):
            """
            Default Context
            
            .. attribute:: global_interfaces
            
            	PIM global interface table
            	**type**\:  :py:class:`GlobalInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GlobalInterfaces>`
            
            .. attribute:: ifrs_interfaces
            
            	PIM interfaces in forward reference store table
            	**type**\:  :py:class:`IfrsInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.IfrsInterfaces>`
            
            .. attribute:: safs
            
            	SAFI table and type
            	**type**\:  :py:class:`Safs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Safs>`
            
            .. attribute:: interface_statistics
            
            	PIM interface statistics
            	**type**\:  :py:class:`InterfaceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.InterfaceStatistics>`
            
            .. attribute:: topology_route_count
            
            	Topology route count information from PIM topology table
            	**type**\:  :py:class:`TopologyRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.TopologyRouteCount>`
            
            .. attribute:: jp_statistics
            
            	PIM join prune statistics table
            	**type**\:  :py:class:`JpStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.JpStatistics>`
            
            .. attribute:: mib_databases
            
            	PIM group database for mroute mibs table
            	**type**\:  :py:class:`MibDatabases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.MibDatabases>`
            
            .. attribute:: neighbor_old_formats
            
            	PIM neighbor table old format
            	**type**\:  :py:class:`NeighborOldFormats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.NeighborOldFormats>`
            
            .. attribute:: ifrs_summary
            
            	PIM interfaces in forward reference store summary
            	**type**\:  :py:class:`IfrsSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.IfrsSummary>`
            
            .. attribute:: ranges
            
            	PIM range list information
            	**type**\:  :py:class:`Ranges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Ranges>`
            
            .. attribute:: interface_old_formats
            
            	PIM interfaces in old format
            	**type**\:  :py:class:`InterfaceOldFormats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats>`
            
            .. attribute:: bsr
            
            	PIM BSR information
            	**type**\:  :py:class:`Bsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Bsr>`
            
            .. attribute:: route_policy
            
            	PIM route policy
            	**type**\:  :py:class:`RoutePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.RoutePolicy>`
            
            .. attribute:: rpf_summary
            
            	PIM RPF registration summary
            	**type**\:  :py:class:`RpfSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.RpfSummary>`
            
            .. attribute:: interfaces
            
            	PIM interfaces
            	**type**\:  :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Interfaces>`
            
            .. attribute:: net_io_tunnels
            
            	Tunnel information that NETIO has 
            	**type**\:  :py:class:`NetIoTunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.NetIoTunnels>`
            
            .. attribute:: bidir_df_states
            
            	Bidirectional PIM DF election state table
            	**type**\:  :py:class:`BidirDfStates <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.BidirDfStates>`
            
            .. attribute:: topologies
            
            	PIM topology table
            	**type**\:  :py:class:`Topologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Topologies>`
            
            .. attribute:: bgp_afs
            
            	PIM BGP SAFI table
            	**type**\:  :py:class:`BgpAfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.BgpAfs>`
            
            .. attribute:: auto_rp
            
            	PIM Auto\-RP information
            	**type**\:  :py:class:`AutoRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.AutoRp>`
            
            .. attribute:: topology_interface_flag_route_counts
            
            	Route count for topology with interface flag set
            	**type**\:  :py:class:`TopologyInterfaceFlagRouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts>`
            
            .. attribute:: group_map_sources
            
            	PIM group\-mapping with source information
            	**type**\:  :py:class:`GroupMapSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapSources>`
            
            .. attribute:: traffic_counters
            
            	PIM message traffic counters
            	**type**\:  :py:class:`TrafficCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.TrafficCounters>`
            
            .. attribute:: group_map_rpfs
            
            	PIM group mapping information
            	**type**\:  :py:class:`GroupMapRpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapRpfs>`
            
            .. attribute:: summary
            
            	PIM summary
            	**type**\:  :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Summary>`
            
            .. attribute:: gre
            
            	GRE information
            	**type**\:  :py:class:`Gre <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Gre>`
            
            .. attribute:: bidir_df_winners
            
            	Bidirectional PIM DF election winner table
            	**type**\:  :py:class:`BidirDfWinners <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.BidirDfWinners>`
            
            .. attribute:: table_contexts
            
            	PIM table context list
            	**type**\:  :py:class:`TableContexts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.TableContexts>`
            
            .. attribute:: neighbor_summaries
            
            	PIM neighbor summary table
            	**type**\:  :py:class:`NeighborSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.NeighborSummaries>`
            
            .. attribute:: context
            
            	PIM context information
            	**type**\:  :py:class:`Context <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Context>`
            
            .. attribute:: topology_entry_flag_route_counts
            
            	Route count for topology with entry flag set
            	**type**\:  :py:class:`TopologyEntryFlagRouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts>`
            
            .. attribute:: rpf_redirect
            
            	PIM ECMP RPF\-redirect bundle
            	**type**\:  :py:class:`RpfRedirect <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.RpfRedirect>`
            
            .. attribute:: tunnels
            
            	Tunnels information that PIM has
            	**type**\:  :py:class:`Tunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Tunnels>`
            
            .. attribute:: multicast_static_routes
            
            	PIM multicast static route table
            	**type**\:  :py:class:`MulticastStaticRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes>`
            
            .. attribute:: neighbors
            
            	PIM neighbor table
            	**type**\:  :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Neighbors>`
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(Ipv6Pim.Standby.DefaultContext, self).__init__()

                self.yang_name = "default-context"
                self.yang_parent_name = "standby"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("global-interfaces", ("global_interfaces", Ipv6Pim.Standby.DefaultContext.GlobalInterfaces)), ("ifrs-interfaces", ("ifrs_interfaces", Ipv6Pim.Standby.DefaultContext.IfrsInterfaces)), ("safs", ("safs", Ipv6Pim.Standby.DefaultContext.Safs)), ("interface-statistics", ("interface_statistics", Ipv6Pim.Standby.DefaultContext.InterfaceStatistics)), ("topology-route-count", ("topology_route_count", Ipv6Pim.Standby.DefaultContext.TopologyRouteCount)), ("jp-statistics", ("jp_statistics", Ipv6Pim.Standby.DefaultContext.JpStatistics)), ("mib-databases", ("mib_databases", Ipv6Pim.Standby.DefaultContext.MibDatabases)), ("neighbor-old-formats", ("neighbor_old_formats", Ipv6Pim.Standby.DefaultContext.NeighborOldFormats)), ("ifrs-summary", ("ifrs_summary", Ipv6Pim.Standby.DefaultContext.IfrsSummary)), ("ranges", ("ranges", Ipv6Pim.Standby.DefaultContext.Ranges)), ("interface-old-formats", ("interface_old_formats", Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats)), ("bsr", ("bsr", Ipv6Pim.Standby.DefaultContext.Bsr)), ("route-policy", ("route_policy", Ipv6Pim.Standby.DefaultContext.RoutePolicy)), ("rpf-summary", ("rpf_summary", Ipv6Pim.Standby.DefaultContext.RpfSummary)), ("interfaces", ("interfaces", Ipv6Pim.Standby.DefaultContext.Interfaces)), ("net-io-tunnels", ("net_io_tunnels", Ipv6Pim.Standby.DefaultContext.NetIoTunnels)), ("bidir-df-states", ("bidir_df_states", Ipv6Pim.Standby.DefaultContext.BidirDfStates)), ("topologies", ("topologies", Ipv6Pim.Standby.DefaultContext.Topologies)), ("bgp-afs", ("bgp_afs", Ipv6Pim.Standby.DefaultContext.BgpAfs)), ("auto-rp", ("auto_rp", Ipv6Pim.Standby.DefaultContext.AutoRp)), ("topology-interface-flag-route-counts", ("topology_interface_flag_route_counts", Ipv6Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts)), ("group-map-sources", ("group_map_sources", Ipv6Pim.Standby.DefaultContext.GroupMapSources)), ("traffic-counters", ("traffic_counters", Ipv6Pim.Standby.DefaultContext.TrafficCounters)), ("group-map-rpfs", ("group_map_rpfs", Ipv6Pim.Standby.DefaultContext.GroupMapRpfs)), ("summary", ("summary", Ipv6Pim.Standby.DefaultContext.Summary)), ("gre", ("gre", Ipv6Pim.Standby.DefaultContext.Gre)), ("bidir-df-winners", ("bidir_df_winners", Ipv6Pim.Standby.DefaultContext.BidirDfWinners)), ("table-contexts", ("table_contexts", Ipv6Pim.Standby.DefaultContext.TableContexts)), ("neighbor-summaries", ("neighbor_summaries", Ipv6Pim.Standby.DefaultContext.NeighborSummaries)), ("context", ("context", Ipv6Pim.Standby.DefaultContext.Context)), ("topology-entry-flag-route-counts", ("topology_entry_flag_route_counts", Ipv6Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts)), ("rpf-redirect", ("rpf_redirect", Ipv6Pim.Standby.DefaultContext.RpfRedirect)), ("tunnels", ("tunnels", Ipv6Pim.Standby.DefaultContext.Tunnels)), ("multicast-static-routes", ("multicast_static_routes", Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes)), ("neighbors", ("neighbors", Ipv6Pim.Standby.DefaultContext.Neighbors))])
                self._leafs = OrderedDict()

                self.global_interfaces = Ipv6Pim.Standby.DefaultContext.GlobalInterfaces()
                self.global_interfaces.parent = self
                self._children_name_map["global_interfaces"] = "global-interfaces"

                self.ifrs_interfaces = Ipv6Pim.Standby.DefaultContext.IfrsInterfaces()
                self.ifrs_interfaces.parent = self
                self._children_name_map["ifrs_interfaces"] = "ifrs-interfaces"

                self.safs = Ipv6Pim.Standby.DefaultContext.Safs()
                self.safs.parent = self
                self._children_name_map["safs"] = "safs"

                self.interface_statistics = Ipv6Pim.Standby.DefaultContext.InterfaceStatistics()
                self.interface_statistics.parent = self
                self._children_name_map["interface_statistics"] = "interface-statistics"

                self.topology_route_count = Ipv6Pim.Standby.DefaultContext.TopologyRouteCount()
                self.topology_route_count.parent = self
                self._children_name_map["topology_route_count"] = "topology-route-count"

                self.jp_statistics = Ipv6Pim.Standby.DefaultContext.JpStatistics()
                self.jp_statistics.parent = self
                self._children_name_map["jp_statistics"] = "jp-statistics"

                self.mib_databases = Ipv6Pim.Standby.DefaultContext.MibDatabases()
                self.mib_databases.parent = self
                self._children_name_map["mib_databases"] = "mib-databases"

                self.neighbor_old_formats = Ipv6Pim.Standby.DefaultContext.NeighborOldFormats()
                self.neighbor_old_formats.parent = self
                self._children_name_map["neighbor_old_formats"] = "neighbor-old-formats"

                self.ifrs_summary = Ipv6Pim.Standby.DefaultContext.IfrsSummary()
                self.ifrs_summary.parent = self
                self._children_name_map["ifrs_summary"] = "ifrs-summary"

                self.ranges = Ipv6Pim.Standby.DefaultContext.Ranges()
                self.ranges.parent = self
                self._children_name_map["ranges"] = "ranges"

                self.interface_old_formats = Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats()
                self.interface_old_formats.parent = self
                self._children_name_map["interface_old_formats"] = "interface-old-formats"

                self.bsr = Ipv6Pim.Standby.DefaultContext.Bsr()
                self.bsr.parent = self
                self._children_name_map["bsr"] = "bsr"

                self.route_policy = Ipv6Pim.Standby.DefaultContext.RoutePolicy()
                self.route_policy.parent = self
                self._children_name_map["route_policy"] = "route-policy"

                self.rpf_summary = Ipv6Pim.Standby.DefaultContext.RpfSummary()
                self.rpf_summary.parent = self
                self._children_name_map["rpf_summary"] = "rpf-summary"

                self.interfaces = Ipv6Pim.Standby.DefaultContext.Interfaces()
                self.interfaces.parent = self
                self._children_name_map["interfaces"] = "interfaces"

                self.net_io_tunnels = Ipv6Pim.Standby.DefaultContext.NetIoTunnels()
                self.net_io_tunnels.parent = self
                self._children_name_map["net_io_tunnels"] = "net-io-tunnels"

                self.bidir_df_states = Ipv6Pim.Standby.DefaultContext.BidirDfStates()
                self.bidir_df_states.parent = self
                self._children_name_map["bidir_df_states"] = "bidir-df-states"

                self.topologies = Ipv6Pim.Standby.DefaultContext.Topologies()
                self.topologies.parent = self
                self._children_name_map["topologies"] = "topologies"

                self.bgp_afs = Ipv6Pim.Standby.DefaultContext.BgpAfs()
                self.bgp_afs.parent = self
                self._children_name_map["bgp_afs"] = "bgp-afs"

                self.auto_rp = Ipv6Pim.Standby.DefaultContext.AutoRp()
                self.auto_rp.parent = self
                self._children_name_map["auto_rp"] = "auto-rp"

                self.topology_interface_flag_route_counts = Ipv6Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts()
                self.topology_interface_flag_route_counts.parent = self
                self._children_name_map["topology_interface_flag_route_counts"] = "topology-interface-flag-route-counts"

                self.group_map_sources = Ipv6Pim.Standby.DefaultContext.GroupMapSources()
                self.group_map_sources.parent = self
                self._children_name_map["group_map_sources"] = "group-map-sources"

                self.traffic_counters = Ipv6Pim.Standby.DefaultContext.TrafficCounters()
                self.traffic_counters.parent = self
                self._children_name_map["traffic_counters"] = "traffic-counters"

                self.group_map_rpfs = Ipv6Pim.Standby.DefaultContext.GroupMapRpfs()
                self.group_map_rpfs.parent = self
                self._children_name_map["group_map_rpfs"] = "group-map-rpfs"

                self.summary = Ipv6Pim.Standby.DefaultContext.Summary()
                self.summary.parent = self
                self._children_name_map["summary"] = "summary"

                self.gre = Ipv6Pim.Standby.DefaultContext.Gre()
                self.gre.parent = self
                self._children_name_map["gre"] = "gre"

                self.bidir_df_winners = Ipv6Pim.Standby.DefaultContext.BidirDfWinners()
                self.bidir_df_winners.parent = self
                self._children_name_map["bidir_df_winners"] = "bidir-df-winners"

                self.table_contexts = Ipv6Pim.Standby.DefaultContext.TableContexts()
                self.table_contexts.parent = self
                self._children_name_map["table_contexts"] = "table-contexts"

                self.neighbor_summaries = Ipv6Pim.Standby.DefaultContext.NeighborSummaries()
                self.neighbor_summaries.parent = self
                self._children_name_map["neighbor_summaries"] = "neighbor-summaries"

                self.context = Ipv6Pim.Standby.DefaultContext.Context()
                self.context.parent = self
                self._children_name_map["context"] = "context"

                self.topology_entry_flag_route_counts = Ipv6Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts()
                self.topology_entry_flag_route_counts.parent = self
                self._children_name_map["topology_entry_flag_route_counts"] = "topology-entry-flag-route-counts"

                self.rpf_redirect = Ipv6Pim.Standby.DefaultContext.RpfRedirect()
                self.rpf_redirect.parent = self
                self._children_name_map["rpf_redirect"] = "rpf-redirect"

                self.tunnels = Ipv6Pim.Standby.DefaultContext.Tunnels()
                self.tunnels.parent = self
                self._children_name_map["tunnels"] = "tunnels"

                self.multicast_static_routes = Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes()
                self.multicast_static_routes.parent = self
                self._children_name_map["multicast_static_routes"] = "multicast-static-routes"

                self.neighbors = Ipv6Pim.Standby.DefaultContext.Neighbors()
                self.neighbors.parent = self
                self._children_name_map["neighbors"] = "neighbors"
                self._segment_path = lambda: "default-context"
                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Ipv6Pim.Standby.DefaultContext, [], name, value)


            class GlobalInterfaces(Entity):
                """
                PIM global interface table
                
                .. attribute:: global_interface
                
                	PIM interface name
                	**type**\: list of  		 :py:class:`GlobalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.GlobalInterfaces, self).__init__()

                    self.yang_name = "global-interfaces"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("global-interface", ("global_interface", Ipv6Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface))])
                    self._leafs = OrderedDict()

                    self.global_interface = YList(self)
                    self._segment_path = lambda: "global-interfaces"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.GlobalInterfaces, [], name, value)


                class GlobalInterface(Entity):
                    """
                    PIM interface name
                    
                    .. attribute:: interface_name  (key)
                    
                    	Interface name
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: dr_address
                    
                    	PIM Designated Router
                    	**type**\:  :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress>`
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identfier
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: interface_address_mask
                    
                    	Interface IP Address Mask
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: is_enabled
                    
                    	Is PIM enabled on this IF ?
                    	**type**\: bool
                    
                    .. attribute:: neighbor_count
                    
                    	No. of neighbors on this IF
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: external_neighbor_count
                    
                    	No. of external neighbors on this IF
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: hello_interval
                    
                    	Hello Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dr_priority
                    
                    	DR Priority
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_expiry
                    
                    	Hello Timer Expiry
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: are_we_dr
                    
                    	Are we the DR on this IF ?
                    	**type**\: bool
                    
                    .. attribute:: bfd_enabled
                    
                    	BFD state
                    	**type**\: bool
                    
                    .. attribute:: bfd_interval
                    
                    	BFD Interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bfd_multiplier
                    
                    	BFD Multiplier
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_interface
                    
                    	 is this a Virtual Interfaces ?
                    	**type**\: bool
                    
                    .. attribute:: passive_interface
                    
                    	Passive PIM interface
                    	**type**\: bool
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\: str
                    
                    .. attribute:: join_prune_interval
                    
                    	Join\-Prune Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: prune_delay_enabled
                    
                    	Prune Delay Enabled
                    	**type**\: bool
                    
                    .. attribute:: configured_propagation_delay
                    
                    	Configured Propagation Delay
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_override_interval
                    
                    	Configured Override Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: generation_id
                    
                    	Generation Identifier
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Bidir Capable
                    	**type**\: bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Proxy Capable
                    	**type**\: bool
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Batch Asserts Capable
                    	**type**\: bool
                    
                    .. attribute:: idb_oor_enabled
                    
                    	Interface oor enabled
                    	**type**\: bool
                    
                    .. attribute:: idb_acl_provided
                    
                    	ACL name provided
                    	**type**\: bool
                    
                    .. attribute:: idb_max_count
                    
                    	Interface ole max count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_threshold_count
                    
                    	Interface ole threshold count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_current_count
                    
                    	Interface ole current count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_acl_name
                    
                    	Interface ole ACL Name
                    	**type**\: str
                    
                    	**length:** 0..64
                    
                    .. attribute:: interface_address
                    
                    	List of Interface IP Addresses
                    	**type**\: list of  		 :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.InterfaceAddress>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface, self).__init__()

                        self.yang_name = "global-interface"
                        self.yang_parent_name = "global-interfaces"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['interface_name']
                        self._child_classes = OrderedDict([("dr-address", ("dr_address", Ipv6Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress)), ("interface-address", ("interface_address", Ipv6Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.InterfaceAddress))])
                        self._leafs = OrderedDict([
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                            ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                            ('interface_address_mask', (YLeaf(YType.uint8, 'interface-address-mask'), ['int'])),
                            ('is_enabled', (YLeaf(YType.boolean, 'is-enabled'), ['bool'])),
                            ('neighbor_count', (YLeaf(YType.uint16, 'neighbor-count'), ['int'])),
                            ('external_neighbor_count', (YLeaf(YType.uint16, 'external-neighbor-count'), ['int'])),
                            ('hello_interval', (YLeaf(YType.uint16, 'hello-interval'), ['int'])),
                            ('dr_priority', (YLeaf(YType.uint32, 'dr-priority'), ['int'])),
                            ('hello_expiry', (YLeaf(YType.uint64, 'hello-expiry'), ['int'])),
                            ('are_we_dr', (YLeaf(YType.boolean, 'are-we-dr'), ['bool'])),
                            ('bfd_enabled', (YLeaf(YType.boolean, 'bfd-enabled'), ['bool'])),
                            ('bfd_interval', (YLeaf(YType.uint32, 'bfd-interval'), ['int'])),
                            ('bfd_multiplier', (YLeaf(YType.uint32, 'bfd-multiplier'), ['int'])),
                            ('virtual_interface', (YLeaf(YType.boolean, 'virtual-interface'), ['bool'])),
                            ('passive_interface', (YLeaf(YType.boolean, 'passive-interface'), ['bool'])),
                            ('neighbor_filter_name', (YLeaf(YType.str, 'neighbor-filter-name'), ['str'])),
                            ('join_prune_interval', (YLeaf(YType.uint16, 'join-prune-interval'), ['int'])),
                            ('prune_delay_enabled', (YLeaf(YType.boolean, 'prune-delay-enabled'), ['bool'])),
                            ('configured_propagation_delay', (YLeaf(YType.uint16, 'configured-propagation-delay'), ['int'])),
                            ('propagation_delay', (YLeaf(YType.uint16, 'propagation-delay'), ['int'])),
                            ('configured_override_interval', (YLeaf(YType.uint16, 'configured-override-interval'), ['int'])),
                            ('override_interval', (YLeaf(YType.uint16, 'override-interval'), ['int'])),
                            ('generation_id', (YLeaf(YType.uint32, 'generation-id'), ['int'])),
                            ('is_bidirectional_capable', (YLeaf(YType.boolean, 'is-bidirectional-capable'), ['bool'])),
                            ('is_proxy_capable', (YLeaf(YType.boolean, 'is-proxy-capable'), ['bool'])),
                            ('is_batch_asserts_capable', (YLeaf(YType.boolean, 'is-batch-asserts-capable'), ['bool'])),
                            ('idb_oor_enabled', (YLeaf(YType.boolean, 'idb-oor-enabled'), ['bool'])),
                            ('idb_acl_provided', (YLeaf(YType.boolean, 'idb-acl-provided'), ['bool'])),
                            ('idb_max_count', (YLeaf(YType.uint32, 'idb-max-count'), ['int'])),
                            ('idb_threshold_count', (YLeaf(YType.uint32, 'idb-threshold-count'), ['int'])),
                            ('idb_current_count', (YLeaf(YType.uint32, 'idb-current-count'), ['int'])),
                            ('idb_acl_name', (YLeaf(YType.str, 'idb-acl-name'), ['str'])),
                        ])
                        self.interface_name = None
                        self.interface_name_xr = None
                        self.interface_address_mask = None
                        self.is_enabled = None
                        self.neighbor_count = None
                        self.external_neighbor_count = None
                        self.hello_interval = None
                        self.dr_priority = None
                        self.hello_expiry = None
                        self.are_we_dr = None
                        self.bfd_enabled = None
                        self.bfd_interval = None
                        self.bfd_multiplier = None
                        self.virtual_interface = None
                        self.passive_interface = None
                        self.neighbor_filter_name = None
                        self.join_prune_interval = None
                        self.prune_delay_enabled = None
                        self.configured_propagation_delay = None
                        self.propagation_delay = None
                        self.configured_override_interval = None
                        self.override_interval = None
                        self.generation_id = None
                        self.is_bidirectional_capable = None
                        self.is_proxy_capable = None
                        self.is_batch_asserts_capable = None
                        self.idb_oor_enabled = None
                        self.idb_acl_provided = None
                        self.idb_max_count = None
                        self.idb_threshold_count = None
                        self.idb_current_count = None
                        self.idb_acl_name = None

                        self.dr_address = Ipv6Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress()
                        self.dr_address.parent = self
                        self._children_name_map["dr_address"] = "dr-address"

                        self.interface_address = YList(self)
                        self._segment_path = lambda: "global-interface" + "[interface-name='" + str(self.interface_name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/global-interfaces/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface, ['interface_name', 'interface_name_xr', 'interface_address_mask', 'is_enabled', 'neighbor_count', 'external_neighbor_count', 'hello_interval', 'dr_priority', 'hello_expiry', 'are_we_dr', 'bfd_enabled', 'bfd_interval', 'bfd_multiplier', 'virtual_interface', 'passive_interface', 'neighbor_filter_name', 'join_prune_interval', 'prune_delay_enabled', 'configured_propagation_delay', 'propagation_delay', 'configured_override_interval', 'override_interval', 'generation_id', 'is_bidirectional_capable', 'is_proxy_capable', 'is_batch_asserts_capable', 'idb_oor_enabled', 'idb_acl_provided', 'idb_max_count', 'idb_threshold_count', 'idb_current_count', 'idb_acl_name'], name, value)


                    class DrAddress(Entity):
                        """
                        PIM Designated Router
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress, self).__init__()

                            self.yang_name = "dr-address"
                            self.yang_parent_name = "global-interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "dr-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class InterfaceAddress(Entity):
                        """
                        List of Interface IP Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.InterfaceAddress, self).__init__()

                            self.yang_name = "interface-address"
                            self.yang_parent_name = "global-interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "interface-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.InterfaceAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class IfrsInterfaces(Entity):
                """
                PIM interfaces in forward reference store table
                
                .. attribute:: ifrs_interface
                
                	PIM IFRS interface information
                	**type**\: list of  		 :py:class:`IfrsInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.IfrsInterfaces, self).__init__()

                    self.yang_name = "ifrs-interfaces"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ifrs-interface", ("ifrs_interface", Ipv6Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface))])
                    self._leafs = OrderedDict()

                    self.ifrs_interface = YList(self)
                    self._segment_path = lambda: "ifrs-interfaces"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.IfrsInterfaces, [], name, value)


                class IfrsInterface(Entity):
                    """
                    PIM IFRS interface information
                    
                    .. attribute:: interface_name  (key)
                    
                    	Interface name
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: dr_address
                    
                    	PIM Designated Router
                    	**type**\:  :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress>`
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identfier
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: interface_address_mask
                    
                    	Interface IP Address Mask
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: is_enabled
                    
                    	Is PIM enabled on this IF ?
                    	**type**\: bool
                    
                    .. attribute:: neighbor_count
                    
                    	No. of neighbors on this IF
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: external_neighbor_count
                    
                    	No. of external neighbors on this IF
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: hello_interval
                    
                    	Hello Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dr_priority
                    
                    	DR Priority
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_expiry
                    
                    	Hello Timer Expiry
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: are_we_dr
                    
                    	Are we the DR on this IF ?
                    	**type**\: bool
                    
                    .. attribute:: bfd_enabled
                    
                    	BFD state
                    	**type**\: bool
                    
                    .. attribute:: bfd_interval
                    
                    	BFD Interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bfd_multiplier
                    
                    	BFD Multiplier
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_interface
                    
                    	 is this a Virtual Interfaces ?
                    	**type**\: bool
                    
                    .. attribute:: passive_interface
                    
                    	Passive PIM interface
                    	**type**\: bool
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\: str
                    
                    .. attribute:: join_prune_interval
                    
                    	Join\-Prune Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: prune_delay_enabled
                    
                    	Prune Delay Enabled
                    	**type**\: bool
                    
                    .. attribute:: configured_propagation_delay
                    
                    	Configured Propagation Delay
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_override_interval
                    
                    	Configured Override Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: generation_id
                    
                    	Generation Identifier
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Bidir Capable
                    	**type**\: bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Proxy Capable
                    	**type**\: bool
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Batch Asserts Capable
                    	**type**\: bool
                    
                    .. attribute:: idb_oor_enabled
                    
                    	Interface oor enabled
                    	**type**\: bool
                    
                    .. attribute:: idb_acl_provided
                    
                    	ACL name provided
                    	**type**\: bool
                    
                    .. attribute:: idb_max_count
                    
                    	Interface ole max count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_threshold_count
                    
                    	Interface ole threshold count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_current_count
                    
                    	Interface ole current count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_acl_name
                    
                    	Interface ole ACL Name
                    	**type**\: str
                    
                    	**length:** 0..64
                    
                    .. attribute:: interface_address
                    
                    	List of Interface IP Addresses
                    	**type**\: list of  		 :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.InterfaceAddress>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface, self).__init__()

                        self.yang_name = "ifrs-interface"
                        self.yang_parent_name = "ifrs-interfaces"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['interface_name']
                        self._child_classes = OrderedDict([("dr-address", ("dr_address", Ipv6Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress)), ("interface-address", ("interface_address", Ipv6Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.InterfaceAddress))])
                        self._leafs = OrderedDict([
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                            ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                            ('interface_address_mask', (YLeaf(YType.uint8, 'interface-address-mask'), ['int'])),
                            ('is_enabled', (YLeaf(YType.boolean, 'is-enabled'), ['bool'])),
                            ('neighbor_count', (YLeaf(YType.uint16, 'neighbor-count'), ['int'])),
                            ('external_neighbor_count', (YLeaf(YType.uint16, 'external-neighbor-count'), ['int'])),
                            ('hello_interval', (YLeaf(YType.uint16, 'hello-interval'), ['int'])),
                            ('dr_priority', (YLeaf(YType.uint32, 'dr-priority'), ['int'])),
                            ('hello_expiry', (YLeaf(YType.uint64, 'hello-expiry'), ['int'])),
                            ('are_we_dr', (YLeaf(YType.boolean, 'are-we-dr'), ['bool'])),
                            ('bfd_enabled', (YLeaf(YType.boolean, 'bfd-enabled'), ['bool'])),
                            ('bfd_interval', (YLeaf(YType.uint32, 'bfd-interval'), ['int'])),
                            ('bfd_multiplier', (YLeaf(YType.uint32, 'bfd-multiplier'), ['int'])),
                            ('virtual_interface', (YLeaf(YType.boolean, 'virtual-interface'), ['bool'])),
                            ('passive_interface', (YLeaf(YType.boolean, 'passive-interface'), ['bool'])),
                            ('neighbor_filter_name', (YLeaf(YType.str, 'neighbor-filter-name'), ['str'])),
                            ('join_prune_interval', (YLeaf(YType.uint16, 'join-prune-interval'), ['int'])),
                            ('prune_delay_enabled', (YLeaf(YType.boolean, 'prune-delay-enabled'), ['bool'])),
                            ('configured_propagation_delay', (YLeaf(YType.uint16, 'configured-propagation-delay'), ['int'])),
                            ('propagation_delay', (YLeaf(YType.uint16, 'propagation-delay'), ['int'])),
                            ('configured_override_interval', (YLeaf(YType.uint16, 'configured-override-interval'), ['int'])),
                            ('override_interval', (YLeaf(YType.uint16, 'override-interval'), ['int'])),
                            ('generation_id', (YLeaf(YType.uint32, 'generation-id'), ['int'])),
                            ('is_bidirectional_capable', (YLeaf(YType.boolean, 'is-bidirectional-capable'), ['bool'])),
                            ('is_proxy_capable', (YLeaf(YType.boolean, 'is-proxy-capable'), ['bool'])),
                            ('is_batch_asserts_capable', (YLeaf(YType.boolean, 'is-batch-asserts-capable'), ['bool'])),
                            ('idb_oor_enabled', (YLeaf(YType.boolean, 'idb-oor-enabled'), ['bool'])),
                            ('idb_acl_provided', (YLeaf(YType.boolean, 'idb-acl-provided'), ['bool'])),
                            ('idb_max_count', (YLeaf(YType.uint32, 'idb-max-count'), ['int'])),
                            ('idb_threshold_count', (YLeaf(YType.uint32, 'idb-threshold-count'), ['int'])),
                            ('idb_current_count', (YLeaf(YType.uint32, 'idb-current-count'), ['int'])),
                            ('idb_acl_name', (YLeaf(YType.str, 'idb-acl-name'), ['str'])),
                        ])
                        self.interface_name = None
                        self.interface_name_xr = None
                        self.interface_address_mask = None
                        self.is_enabled = None
                        self.neighbor_count = None
                        self.external_neighbor_count = None
                        self.hello_interval = None
                        self.dr_priority = None
                        self.hello_expiry = None
                        self.are_we_dr = None
                        self.bfd_enabled = None
                        self.bfd_interval = None
                        self.bfd_multiplier = None
                        self.virtual_interface = None
                        self.passive_interface = None
                        self.neighbor_filter_name = None
                        self.join_prune_interval = None
                        self.prune_delay_enabled = None
                        self.configured_propagation_delay = None
                        self.propagation_delay = None
                        self.configured_override_interval = None
                        self.override_interval = None
                        self.generation_id = None
                        self.is_bidirectional_capable = None
                        self.is_proxy_capable = None
                        self.is_batch_asserts_capable = None
                        self.idb_oor_enabled = None
                        self.idb_acl_provided = None
                        self.idb_max_count = None
                        self.idb_threshold_count = None
                        self.idb_current_count = None
                        self.idb_acl_name = None

                        self.dr_address = Ipv6Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress()
                        self.dr_address.parent = self
                        self._children_name_map["dr_address"] = "dr-address"

                        self.interface_address = YList(self)
                        self._segment_path = lambda: "ifrs-interface" + "[interface-name='" + str(self.interface_name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/ifrs-interfaces/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface, ['interface_name', 'interface_name_xr', 'interface_address_mask', 'is_enabled', 'neighbor_count', 'external_neighbor_count', 'hello_interval', 'dr_priority', 'hello_expiry', 'are_we_dr', 'bfd_enabled', 'bfd_interval', 'bfd_multiplier', 'virtual_interface', 'passive_interface', 'neighbor_filter_name', 'join_prune_interval', 'prune_delay_enabled', 'configured_propagation_delay', 'propagation_delay', 'configured_override_interval', 'override_interval', 'generation_id', 'is_bidirectional_capable', 'is_proxy_capable', 'is_batch_asserts_capable', 'idb_oor_enabled', 'idb_acl_provided', 'idb_max_count', 'idb_threshold_count', 'idb_current_count', 'idb_acl_name'], name, value)


                    class DrAddress(Entity):
                        """
                        PIM Designated Router
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress, self).__init__()

                            self.yang_name = "dr-address"
                            self.yang_parent_name = "ifrs-interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "dr-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class InterfaceAddress(Entity):
                        """
                        List of Interface IP Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.InterfaceAddress, self).__init__()

                            self.yang_name = "interface-address"
                            self.yang_parent_name = "ifrs-interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "interface-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.InterfaceAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class Safs(Entity):
                """
                SAFI table and type
                
                .. attribute:: saf
                
                	SAF name 
                	**type**\: list of  		 :py:class:`Saf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Safs.Saf>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.Safs, self).__init__()

                    self.yang_name = "safs"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("saf", ("saf", Ipv6Pim.Standby.DefaultContext.Safs.Saf))])
                    self._leafs = OrderedDict()

                    self.saf = YList(self)
                    self._segment_path = lambda: "safs"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Safs, [], name, value)


                class Saf(Entity):
                    """
                    SAF name 
                    
                    .. attribute:: rpf_hash_source_groups
                    
                    	PIM RPF multipath hash outcome
                    	**type**\:  :py:class:`RpfHashSourceGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups>`
                    
                    .. attribute:: rpf_hash_sources
                    
                    	PIM RPF multipath hash outcome
                    	**type**\:  :py:class:`RpfHashSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources>`
                    
                    .. attribute:: rpfs
                    
                    	PIM RPF information table
                    	**type**\:  :py:class:`Rpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs>`
                    
                    .. attribute:: saf_name
                    
                    	SAF name 
                    	**type**\:  :py:class:`PimSafi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimSafi>`
                    
                    .. attribute:: topology_name
                    
                    	Topology name 
                    	**type**\: str
                    
                    	**length:** 1..32
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.Safs.Saf, self).__init__()

                        self.yang_name = "saf"
                        self.yang_parent_name = "safs"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("rpf-hash-source-groups", ("rpf_hash_source_groups", Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups)), ("rpf-hash-sources", ("rpf_hash_sources", Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources)), ("rpfs", ("rpfs", Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs))])
                        self._leafs = OrderedDict([
                            ('saf_name', (YLeaf(YType.enumeration, 'saf-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimSafi', '')])),
                            ('topology_name', (YLeaf(YType.str, 'topology-name'), ['str'])),
                        ])
                        self.saf_name = None
                        self.topology_name = None

                        self.rpf_hash_source_groups = Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups()
                        self.rpf_hash_source_groups.parent = self
                        self._children_name_map["rpf_hash_source_groups"] = "rpf-hash-source-groups"

                        self.rpf_hash_sources = Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources()
                        self.rpf_hash_sources.parent = self
                        self._children_name_map["rpf_hash_sources"] = "rpf-hash-sources"

                        self.rpfs = Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs()
                        self.rpfs.parent = self
                        self._children_name_map["rpfs"] = "rpfs"
                        self._segment_path = lambda: "saf"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/safs/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Safs.Saf, ['saf_name', 'topology_name'], name, value)


                    class RpfHashSourceGroups(Entity):
                        """
                        PIM RPF multipath hash outcome
                        
                        .. attribute:: rpf_hash_source_group
                        
                        	PIM RPF hash outcome for S,G
                        	**type**\: list of  		 :py:class:`RpfHashSourceGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups, self).__init__()

                            self.yang_name = "rpf-hash-source-groups"
                            self.yang_parent_name = "saf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rpf-hash-source-group", ("rpf_hash_source_group", Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup))])
                            self._leafs = OrderedDict()

                            self.rpf_hash_source_group = YList(self)
                            self._segment_path = lambda: "rpf-hash-source-groups"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/safs/saf/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups, [], name, value)


                        class RpfHashSourceGroup(Entity):
                            """
                            PIM RPF hash outcome for S,G
                            
                            .. attribute:: source_address
                            
                            	Source address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: group_address
                            
                            	Group address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: mask_length
                            
                            	Hash mask length
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mofrr
                            
                            	MOFRR
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: next_hop_address
                            
                            	Next hop neighbor address
                            	**type**\:  :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress>`
                            
                            .. attribute:: secondary_next_hop_address
                            
                            	Secondary Next hop neighbor address
                            	**type**\:  :py:class:`SecondaryNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress>`
                            
                            .. attribute:: next_hop_multipath_enabled
                            
                            	Next hop multipath enabled?
                            	**type**\: bool
                            
                            .. attribute:: next_hop_interface
                            
                            	Next hop neighbor interface
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: secondary_next_hop_interface
                            
                            	Secondary Next hop neighbor interface
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup, self).__init__()

                                self.yang_name = "rpf-hash-source-group"
                                self.yang_parent_name = "rpf-hash-source-groups"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("next-hop-address", ("next_hop_address", Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress)), ("secondary-next-hop-address", ("secondary_next_hop_address", Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress))])
                                self._leafs = OrderedDict([
                                    ('source_address', (YLeaf(YType.str, 'source-address'), ['str','str'])),
                                    ('group_address', (YLeaf(YType.str, 'group-address'), ['str','str'])),
                                    ('mask_length', (YLeaf(YType.uint32, 'mask-length'), ['int'])),
                                    ('mofrr', (YLeaf(YType.uint32, 'mofrr'), ['int'])),
                                    ('next_hop_multipath_enabled', (YLeaf(YType.boolean, 'next-hop-multipath-enabled'), ['bool'])),
                                    ('next_hop_interface', (YLeaf(YType.str, 'next-hop-interface'), ['str'])),
                                    ('secondary_next_hop_interface', (YLeaf(YType.str, 'secondary-next-hop-interface'), ['str'])),
                                ])
                                self.source_address = None
                                self.group_address = None
                                self.mask_length = None
                                self.mofrr = None
                                self.next_hop_multipath_enabled = None
                                self.next_hop_interface = None
                                self.secondary_next_hop_interface = None

                                self.next_hop_address = Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress()
                                self.next_hop_address.parent = self
                                self._children_name_map["next_hop_address"] = "next-hop-address"

                                self.secondary_next_hop_address = Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress()
                                self.secondary_next_hop_address.parent = self
                                self._children_name_map["secondary_next_hop_address"] = "secondary-next-hop-address"
                                self._segment_path = lambda: "rpf-hash-source-group"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/safs/saf/rpf-hash-source-groups/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup, ['source_address', 'group_address', 'mask_length', 'mofrr', 'next_hop_multipath_enabled', 'next_hop_interface', 'secondary_next_hop_interface'], name, value)


                            class NextHopAddress(Entity):
                                """
                                Next hop neighbor address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress, self).__init__()

                                    self.yang_name = "next-hop-address"
                                    self.yang_parent_name = "rpf-hash-source-group"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "next-hop-address"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/safs/saf/rpf-hash-source-groups/rpf-hash-source-group/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                            class SecondaryNextHopAddress(Entity):
                                """
                                Secondary Next hop neighbor address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress, self).__init__()

                                    self.yang_name = "secondary-next-hop-address"
                                    self.yang_parent_name = "rpf-hash-source-group"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "secondary-next-hop-address"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/safs/saf/rpf-hash-source-groups/rpf-hash-source-group/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class RpfHashSources(Entity):
                        """
                        PIM RPF multipath hash outcome
                        
                        .. attribute:: rpf_hash_source
                        
                        	PIM RPF hash outcome for S,G
                        	**type**\: list of  		 :py:class:`RpfHashSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources, self).__init__()

                            self.yang_name = "rpf-hash-sources"
                            self.yang_parent_name = "saf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rpf-hash-source", ("rpf_hash_source", Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource))])
                            self._leafs = OrderedDict()

                            self.rpf_hash_source = YList(self)
                            self._segment_path = lambda: "rpf-hash-sources"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/safs/saf/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources, [], name, value)


                        class RpfHashSource(Entity):
                            """
                            PIM RPF hash outcome for S,G
                            
                            .. attribute:: source_address
                            
                            	Source address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: mofrr
                            
                            	MOFRR
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: next_hop_address
                            
                            	Next hop neighbor address
                            	**type**\:  :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress>`
                            
                            .. attribute:: secondary_next_hop_address
                            
                            	Secondary Next hop neighbor address
                            	**type**\:  :py:class:`SecondaryNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress>`
                            
                            .. attribute:: next_hop_multipath_enabled
                            
                            	Next hop multipath enabled?
                            	**type**\: bool
                            
                            .. attribute:: next_hop_interface
                            
                            	Next hop neighbor interface
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: secondary_next_hop_interface
                            
                            	Secondary Next hop neighbor interface
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource, self).__init__()

                                self.yang_name = "rpf-hash-source"
                                self.yang_parent_name = "rpf-hash-sources"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("next-hop-address", ("next_hop_address", Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress)), ("secondary-next-hop-address", ("secondary_next_hop_address", Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress))])
                                self._leafs = OrderedDict([
                                    ('source_address', (YLeaf(YType.str, 'source-address'), ['str','str'])),
                                    ('mofrr', (YLeaf(YType.uint32, 'mofrr'), ['int'])),
                                    ('next_hop_multipath_enabled', (YLeaf(YType.boolean, 'next-hop-multipath-enabled'), ['bool'])),
                                    ('next_hop_interface', (YLeaf(YType.str, 'next-hop-interface'), ['str'])),
                                    ('secondary_next_hop_interface', (YLeaf(YType.str, 'secondary-next-hop-interface'), ['str'])),
                                ])
                                self.source_address = None
                                self.mofrr = None
                                self.next_hop_multipath_enabled = None
                                self.next_hop_interface = None
                                self.secondary_next_hop_interface = None

                                self.next_hop_address = Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress()
                                self.next_hop_address.parent = self
                                self._children_name_map["next_hop_address"] = "next-hop-address"

                                self.secondary_next_hop_address = Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress()
                                self.secondary_next_hop_address.parent = self
                                self._children_name_map["secondary_next_hop_address"] = "secondary-next-hop-address"
                                self._segment_path = lambda: "rpf-hash-source"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/safs/saf/rpf-hash-sources/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource, ['source_address', 'mofrr', 'next_hop_multipath_enabled', 'next_hop_interface', 'secondary_next_hop_interface'], name, value)


                            class NextHopAddress(Entity):
                                """
                                Next hop neighbor address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress, self).__init__()

                                    self.yang_name = "next-hop-address"
                                    self.yang_parent_name = "rpf-hash-source"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "next-hop-address"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/safs/saf/rpf-hash-sources/rpf-hash-source/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                            class SecondaryNextHopAddress(Entity):
                                """
                                Secondary Next hop neighbor address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress, self).__init__()

                                    self.yang_name = "secondary-next-hop-address"
                                    self.yang_parent_name = "rpf-hash-source"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "secondary-next-hop-address"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/safs/saf/rpf-hash-sources/rpf-hash-source/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class Rpfs(Entity):
                        """
                        PIM RPF information table
                        
                        .. attribute:: rpf
                        
                        	PIM RPF information
                        	**type**\: list of  		 :py:class:`Rpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs, self).__init__()

                            self.yang_name = "rpfs"
                            self.yang_parent_name = "saf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rpf", ("rpf", Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf))])
                            self._leafs = OrderedDict()

                            self.rpf = YList(self)
                            self._segment_path = lambda: "rpfs"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/safs/saf/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs, [], name, value)


                        class Rpf(Entity):
                            """
                            PIM RPF information
                            
                            .. attribute:: registered_address  (key)
                            
                            	Address for which RPF lookup
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: registered_address_xr
                            
                            	Address registered
                            	**type**\:  :py:class:`RegisteredAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr>`
                            
                            .. attribute:: metric
                            
                            	Metric
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_preference
                            
                            	Metric preference
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_connected
                            
                            	Are we connected ?
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: is_rpf_bgp_route
                            
                            	Is RPF through BGP route
                            	**type**\: bool
                            
                            .. attribute:: rpf_path
                            
                            	RPF Paths list
                            	**type**\: list of  		 :py:class:`RpfPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf, self).__init__()

                                self.yang_name = "rpf"
                                self.yang_parent_name = "rpfs"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['registered_address']
                                self._child_classes = OrderedDict([("registered-address-xr", ("registered_address_xr", Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr)), ("rpf-path", ("rpf_path", Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath))])
                                self._leafs = OrderedDict([
                                    ('registered_address', (YLeaf(YType.str, 'registered-address'), ['str','str'])),
                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                    ('metric_preference', (YLeaf(YType.uint32, 'metric-preference'), ['int'])),
                                    ('is_connected', (YLeaf(YType.uint8, 'is-connected'), ['int'])),
                                    ('is_rpf_bgp_route', (YLeaf(YType.boolean, 'is-rpf-bgp-route'), ['bool'])),
                                ])
                                self.registered_address = None
                                self.metric = None
                                self.metric_preference = None
                                self.is_connected = None
                                self.is_rpf_bgp_route = None

                                self.registered_address_xr = Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr()
                                self.registered_address_xr.parent = self
                                self._children_name_map["registered_address_xr"] = "registered-address-xr"

                                self.rpf_path = YList(self)
                                self._segment_path = lambda: "rpf" + "[registered-address='" + str(self.registered_address) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/safs/saf/rpfs/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf, ['registered_address', 'metric', 'metric_preference', 'is_connected', 'is_rpf_bgp_route'], name, value)


                            class RegisteredAddressXr(Entity):
                                """
                                Address registered
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr, self).__init__()

                                    self.yang_name = "registered-address-xr"
                                    self.yang_parent_name = "rpf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "registered-address-xr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                            class RpfPath(Entity):
                                """
                                RPF Paths list
                                
                                .. attribute:: rpf_neighbor
                                
                                	RPF neighbor
                                	**type**\:  :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor>`
                                
                                .. attribute:: rpf_nexthop
                                
                                	RPF nexthop
                                	**type**\:  :py:class:`RpfNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop>`
                                
                                .. attribute:: rpf_interface_name
                                
                                	RPF Interface
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                .. attribute:: is_rpf_interface_disabled
                                
                                	Is the rpf interface disabled ?
                                	**type**\: bool
                                
                                .. attribute:: is_via_lsm
                                
                                	Via LSM
                                	**type**\: bool
                                
                                .. attribute:: is_via_mlsm
                                
                                	Via Mstatic LSM
                                	**type**\: bool
                                
                                .. attribute:: is_connector_attribute_present
                                
                                	Connector attribute present
                                	**type**\: bool
                                
                                .. attribute:: connector
                                
                                	Connector Attribute
                                	**type**\: str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                .. attribute:: extranet_vrf_name
                                
                                	Extranet VRF name
                                	**type**\: str
                                
                                	**length:** 0..33
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath, self).__init__()

                                    self.yang_name = "rpf-path"
                                    self.yang_parent_name = "rpf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("rpf-neighbor", ("rpf_neighbor", Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor)), ("rpf-nexthop", ("rpf_nexthop", Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop))])
                                    self._leafs = OrderedDict([
                                        ('rpf_interface_name', (YLeaf(YType.str, 'rpf-interface-name'), ['str'])),
                                        ('is_rpf_interface_disabled', (YLeaf(YType.boolean, 'is-rpf-interface-disabled'), ['bool'])),
                                        ('is_via_lsm', (YLeaf(YType.boolean, 'is-via-lsm'), ['bool'])),
                                        ('is_via_mlsm', (YLeaf(YType.boolean, 'is-via-mlsm'), ['bool'])),
                                        ('is_connector_attribute_present', (YLeaf(YType.boolean, 'is-connector-attribute-present'), ['bool'])),
                                        ('connector', (YLeaf(YType.str, 'connector'), ['str'])),
                                        ('extranet_vrf_name', (YLeaf(YType.str, 'extranet-vrf-name'), ['str'])),
                                    ])
                                    self.rpf_interface_name = None
                                    self.is_rpf_interface_disabled = None
                                    self.is_via_lsm = None
                                    self.is_via_mlsm = None
                                    self.is_connector_attribute_present = None
                                    self.connector = None
                                    self.extranet_vrf_name = None

                                    self.rpf_neighbor = Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor()
                                    self.rpf_neighbor.parent = self
                                    self._children_name_map["rpf_neighbor"] = "rpf-neighbor"

                                    self.rpf_nexthop = Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop()
                                    self.rpf_nexthop.parent = self
                                    self._children_name_map["rpf_nexthop"] = "rpf-nexthop"
                                    self._segment_path = lambda: "rpf-path"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath, ['rpf_interface_name', 'is_rpf_interface_disabled', 'is_via_lsm', 'is_via_mlsm', 'is_connector_attribute_present', 'connector', 'extranet_vrf_name'], name, value)


                                class RpfNeighbor(Entity):
                                    """
                                    RPF neighbor
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor, self).__init__()

                                        self.yang_name = "rpf-neighbor"
                                        self.yang_parent_name = "rpf-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ])
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None
                                        self._segment_path = lambda: "rpf-neighbor"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                                class RpfNexthop(Entity):
                                    """
                                    RPF nexthop
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop, self).__init__()

                                        self.yang_name = "rpf-nexthop"
                                        self.yang_parent_name = "rpf-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ])
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None
                                        self._segment_path = lambda: "rpf-nexthop"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class InterfaceStatistics(Entity):
                """
                PIM interface statistics
                
                .. attribute:: interface_statistic
                
                	PIM interface statistics
                	**type**\: list of  		 :py:class:`InterfaceStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.InterfaceStatistics.InterfaceStatistic>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.InterfaceStatistics, self).__init__()

                    self.yang_name = "interface-statistics"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("interface-statistic", ("interface_statistic", Ipv6Pim.Standby.DefaultContext.InterfaceStatistics.InterfaceStatistic))])
                    self._leafs = OrderedDict()

                    self.interface_statistic = YList(self)
                    self._segment_path = lambda: "interface-statistics"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.InterfaceStatistics, [], name, value)


                class InterfaceStatistic(Entity):
                    """
                    PIM interface statistics
                    
                    .. attribute:: interface_name  (key)
                    
                    	Interface name
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: input_hello
                    
                    	Hello packets in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_hello
                    
                    	Hello packets out
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_register
                    
                    	Register packets in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_register
                    
                    	Register packets out
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_register_stop
                    
                    	Register Stop packets in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_register_stop
                    
                    	Register Stop packets out
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_jp
                    
                    	Join Prune packets in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_jp
                    
                    	Join Prune packets out
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_bsr_message
                    
                    	Input BSR Messages
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_bsr_message
                    
                    	Output BSR Messages
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_assert
                    
                    	Assert packets in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_assert
                    
                    	Assert packets out
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_graft_message
                    
                    	Input Graft Messages
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_graft_message
                    
                    	Output Graft Messages
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_graft_ack_message
                    
                    	Input Graft Ack Messages
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_graft_ack_message
                    
                    	Output Graft Ack Messages
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_candidate_rp_advertisement
                    
                    	Input Candidate\-RP Advertisment
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_candidate_rp_advertisement
                    
                    	Output Candidate\-RP Advertisment
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_df_election
                    
                    	DF Election packets in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_df_election
                    
                    	DF Election packets out
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_miscellaneous
                    
                    	Miscellaneous packet in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.InterfaceStatistics.InterfaceStatistic, self).__init__()

                        self.yang_name = "interface-statistic"
                        self.yang_parent_name = "interface-statistics"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['interface_name']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                            ('input_hello', (YLeaf(YType.uint32, 'input-hello'), ['int'])),
                            ('output_hello', (YLeaf(YType.uint32, 'output-hello'), ['int'])),
                            ('input_register', (YLeaf(YType.uint32, 'input-register'), ['int'])),
                            ('output_register', (YLeaf(YType.uint32, 'output-register'), ['int'])),
                            ('input_register_stop', (YLeaf(YType.uint32, 'input-register-stop'), ['int'])),
                            ('output_register_stop', (YLeaf(YType.uint32, 'output-register-stop'), ['int'])),
                            ('input_jp', (YLeaf(YType.uint32, 'input-jp'), ['int'])),
                            ('output_jp', (YLeaf(YType.uint32, 'output-jp'), ['int'])),
                            ('input_bsr_message', (YLeaf(YType.uint32, 'input-bsr-message'), ['int'])),
                            ('output_bsr_message', (YLeaf(YType.uint32, 'output-bsr-message'), ['int'])),
                            ('input_assert', (YLeaf(YType.uint32, 'input-assert'), ['int'])),
                            ('output_assert', (YLeaf(YType.uint32, 'output-assert'), ['int'])),
                            ('input_graft_message', (YLeaf(YType.uint32, 'input-graft-message'), ['int'])),
                            ('output_graft_message', (YLeaf(YType.uint32, 'output-graft-message'), ['int'])),
                            ('input_graft_ack_message', (YLeaf(YType.uint32, 'input-graft-ack-message'), ['int'])),
                            ('output_graft_ack_message', (YLeaf(YType.uint32, 'output-graft-ack-message'), ['int'])),
                            ('input_candidate_rp_advertisement', (YLeaf(YType.uint32, 'input-candidate-rp-advertisement'), ['int'])),
                            ('output_candidate_rp_advertisement', (YLeaf(YType.uint32, 'output-candidate-rp-advertisement'), ['int'])),
                            ('input_df_election', (YLeaf(YType.uint32, 'input-df-election'), ['int'])),
                            ('output_df_election', (YLeaf(YType.uint32, 'output-df-election'), ['int'])),
                            ('input_miscellaneous', (YLeaf(YType.uint32, 'input-miscellaneous'), ['int'])),
                        ])
                        self.interface_name = None
                        self.input_hello = None
                        self.output_hello = None
                        self.input_register = None
                        self.output_register = None
                        self.input_register_stop = None
                        self.output_register_stop = None
                        self.input_jp = None
                        self.output_jp = None
                        self.input_bsr_message = None
                        self.output_bsr_message = None
                        self.input_assert = None
                        self.output_assert = None
                        self.input_graft_message = None
                        self.output_graft_message = None
                        self.input_graft_ack_message = None
                        self.output_graft_ack_message = None
                        self.input_candidate_rp_advertisement = None
                        self.output_candidate_rp_advertisement = None
                        self.input_df_election = None
                        self.output_df_election = None
                        self.input_miscellaneous = None
                        self._segment_path = lambda: "interface-statistic" + "[interface-name='" + str(self.interface_name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/interface-statistics/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.InterfaceStatistics.InterfaceStatistic, ['interface_name', 'input_hello', 'output_hello', 'input_register', 'output_register', 'input_register_stop', 'output_register_stop', 'input_jp', 'output_jp', 'input_bsr_message', 'output_bsr_message', 'input_assert', 'output_assert', 'input_graft_message', 'output_graft_message', 'input_graft_ack_message', 'output_graft_ack_message', 'input_candidate_rp_advertisement', 'output_candidate_rp_advertisement', 'input_df_election', 'output_df_election', 'input_miscellaneous'], name, value)


            class TopologyRouteCount(Entity):
                """
                Topology route count information from PIM
                topology table
                
                .. attribute:: group_ranges
                
                	No. of (\*,G/M) routes
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: active_group_ranges
                
                	No. of (\*,G/M) routes active in mrib
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: groute_count
                
                	No. of (\*,G) routes
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: sg_route_count
                
                	No. of (S,G) routes
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: sgr_route_count
                
                	No. of (S,G)RPT routes
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_node_low_memory
                
                	Is node in low memory condition
                	**type**\: bool
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.TopologyRouteCount, self).__init__()

                    self.yang_name = "topology-route-count"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('group_ranges', (YLeaf(YType.uint32, 'group-ranges'), ['int'])),
                        ('active_group_ranges', (YLeaf(YType.uint32, 'active-group-ranges'), ['int'])),
                        ('groute_count', (YLeaf(YType.uint32, 'groute-count'), ['int'])),
                        ('sg_route_count', (YLeaf(YType.uint32, 'sg-route-count'), ['int'])),
                        ('sgr_route_count', (YLeaf(YType.uint32, 'sgr-route-count'), ['int'])),
                        ('is_node_low_memory', (YLeaf(YType.boolean, 'is-node-low-memory'), ['bool'])),
                    ])
                    self.group_ranges = None
                    self.active_group_ranges = None
                    self.groute_count = None
                    self.sg_route_count = None
                    self.sgr_route_count = None
                    self.is_node_low_memory = None
                    self._segment_path = lambda: "topology-route-count"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.TopologyRouteCount, ['group_ranges', 'active_group_ranges', 'groute_count', 'sg_route_count', 'sgr_route_count', 'is_node_low_memory'], name, value)


            class JpStatistics(Entity):
                """
                PIM join prune statistics table
                
                .. attribute:: jp_statistic
                
                	PIM Join Prune Statistics
                	**type**\: list of  		 :py:class:`JpStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.JpStatistics.JpStatistic>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.JpStatistics, self).__init__()

                    self.yang_name = "jp-statistics"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("jp-statistic", ("jp_statistic", Ipv6Pim.Standby.DefaultContext.JpStatistics.JpStatistic))])
                    self._leafs = OrderedDict()

                    self.jp_statistic = YList(self)
                    self._segment_path = lambda: "jp-statistics"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.JpStatistics, [], name, value)


                class JpStatistic(Entity):
                    """
                    PIM Join Prune Statistics
                    
                    .. attribute:: interface_name  (key)
                    
                    	Interface name
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identifier
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: mtu
                    
                    	Interface MTU
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: transmitted
                    
                    	Transmitted
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: transmitted100
                    
                    	Transmitted 100 average
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: transmitted_1k
                    
                    	Transmitted 1K average
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: transmitted_10k
                    
                    	Transmitted 10K average
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: transmitted_50k
                    
                    	Deprecated by Transmitted100
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: received
                    
                    	Received
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: received100
                    
                    	Received 100 average
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: received_1k
                    
                    	Received 1K average
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: received_10k
                    
                    	Received 10K average
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: received_50k
                    
                    	Deprecated by Received100
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.JpStatistics.JpStatistic, self).__init__()

                        self.yang_name = "jp-statistic"
                        self.yang_parent_name = "jp-statistics"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['interface_name']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                            ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                            ('mtu', (YLeaf(YType.uint32, 'mtu'), ['int'])),
                            ('transmitted', (YLeaf(YType.uint32, 'transmitted'), ['int'])),
                            ('transmitted100', (YLeaf(YType.uint16, 'transmitted100'), ['int'])),
                            ('transmitted_1k', (YLeaf(YType.uint16, 'transmitted-1k'), ['int'])),
                            ('transmitted_10k', (YLeaf(YType.uint16, 'transmitted-10k'), ['int'])),
                            ('transmitted_50k', (YLeaf(YType.uint16, 'transmitted-50k'), ['int'])),
                            ('received', (YLeaf(YType.uint32, 'received'), ['int'])),
                            ('received100', (YLeaf(YType.uint16, 'received100'), ['int'])),
                            ('received_1k', (YLeaf(YType.uint16, 'received-1k'), ['int'])),
                            ('received_10k', (YLeaf(YType.uint16, 'received-10k'), ['int'])),
                            ('received_50k', (YLeaf(YType.uint16, 'received-50k'), ['int'])),
                        ])
                        self.interface_name = None
                        self.interface_name_xr = None
                        self.mtu = None
                        self.transmitted = None
                        self.transmitted100 = None
                        self.transmitted_1k = None
                        self.transmitted_10k = None
                        self.transmitted_50k = None
                        self.received = None
                        self.received100 = None
                        self.received_1k = None
                        self.received_10k = None
                        self.received_50k = None
                        self._segment_path = lambda: "jp-statistic" + "[interface-name='" + str(self.interface_name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/jp-statistics/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.JpStatistics.JpStatistic, ['interface_name', 'interface_name_xr', 'mtu', 'transmitted', 'transmitted100', 'transmitted_1k', 'transmitted_10k', 'transmitted_50k', 'received', 'received100', 'received_1k', 'received_10k', 'received_50k'], name, value)


            class MibDatabases(Entity):
                """
                PIM group database for mroute mibs table
                
                .. attribute:: mib_database
                
                	PIM multicast static route information
                	**type**\: list of  		 :py:class:`MibDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.MibDatabases, self).__init__()

                    self.yang_name = "mib-databases"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("mib-database", ("mib_database", Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase))])
                    self._leafs = OrderedDict()

                    self.mib_database = YList(self)
                    self._segment_path = lambda: "mib-databases"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.MibDatabases, [], name, value)


                class MibDatabase(Entity):
                    """
                    PIM multicast static route information
                    
                    .. attribute:: source_address
                    
                    	Multicast static route source address
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: group_address
                    
                    	Multicast satic route group address
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: source_netmask
                    
                    	Source mask
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: source_address_xr
                    
                    	Source Address
                    	**type**\:  :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr>`
                    
                    .. attribute:: group_address_xr
                    
                    	Group Address
                    	**type**\:  :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr>`
                    
                    .. attribute:: rpf_neighbor
                    
                    	The RPF Neighbor
                    	**type**\:  :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor>`
                    
                    .. attribute:: rpf_root
                    
                    	Root of this mcast tree
                    	**type**\:  :py:class:`RpfRoot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfRoot>`
                    
                    .. attribute:: upstream_assert_timer
                    
                    	Upstream Assert Timer
                    	**type**\: int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: assert_metric
                    
                    	Assert Metric
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: assert_metric_preference
                    
                    	Assert Metric Preference
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: assert_rpt_bit
                    
                    	Assert RPT Bit
                    	**type**\: bool
                    
                    .. attribute:: spt_bit
                    
                    	Is SPT bit set ?
                    	**type**\: bool
                    
                    .. attribute:: rpf_mask
                    
                    	Mask of the multicast root
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rpf_safi
                    
                    	Unicast or mcast
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: rpf_table_name
                    
                    	RPF Table name
                    	**type**\: str
                    
                    .. attribute:: rpf_drop
                    
                    	RPF route\-policy drop
                    	**type**\: bool
                    
                    .. attribute:: rpf_extranet
                    
                    	Extranet RPF route\-policy
                    	**type**\: bool
                    
                    .. attribute:: rpf_interface_name
                    
                    	RPF interface name 
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: rpf_vrf_name
                    
                    	RPF VRF Name
                    	**type**\: str
                    
                    	**length:** 0..33
                    
                    .. attribute:: bidirectional_route
                    
                    	Is this Bidir ?
                    	**type**\: bool
                    
                    .. attribute:: uptime
                    
                    	Uptime of route
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: protocol
                    
                    	The PIM protocol
                    	**type**\:  :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase, self).__init__()

                        self.yang_name = "mib-database"
                        self.yang_parent_name = "mib-databases"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("source-address-xr", ("source_address_xr", Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr)), ("group-address-xr", ("group_address_xr", Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr)), ("rpf-neighbor", ("rpf_neighbor", Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor)), ("rpf-root", ("rpf_root", Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfRoot))])
                        self._leafs = OrderedDict([
                            ('source_address', (YLeaf(YType.str, 'source-address'), ['str','str'])),
                            ('group_address', (YLeaf(YType.str, 'group-address'), ['str','str'])),
                            ('source_netmask', (YLeaf(YType.uint32, 'source-netmask'), ['int'])),
                            ('upstream_assert_timer', (YLeaf(YType.int32, 'upstream-assert-timer'), ['int'])),
                            ('assert_metric', (YLeaf(YType.uint32, 'assert-metric'), ['int'])),
                            ('assert_metric_preference', (YLeaf(YType.uint32, 'assert-metric-preference'), ['int'])),
                            ('assert_rpt_bit', (YLeaf(YType.boolean, 'assert-rpt-bit'), ['bool'])),
                            ('spt_bit', (YLeaf(YType.boolean, 'spt-bit'), ['bool'])),
                            ('rpf_mask', (YLeaf(YType.uint32, 'rpf-mask'), ['int'])),
                            ('rpf_safi', (YLeaf(YType.uint8, 'rpf-safi'), ['int'])),
                            ('rpf_table_name', (YLeaf(YType.str, 'rpf-table-name'), ['str'])),
                            ('rpf_drop', (YLeaf(YType.boolean, 'rpf-drop'), ['bool'])),
                            ('rpf_extranet', (YLeaf(YType.boolean, 'rpf-extranet'), ['bool'])),
                            ('rpf_interface_name', (YLeaf(YType.str, 'rpf-interface-name'), ['str'])),
                            ('rpf_vrf_name', (YLeaf(YType.str, 'rpf-vrf-name'), ['str'])),
                            ('bidirectional_route', (YLeaf(YType.boolean, 'bidirectional-route'), ['bool'])),
                            ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                            ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowProtocol', '')])),
                        ])
                        self.source_address = None
                        self.group_address = None
                        self.source_netmask = None
                        self.upstream_assert_timer = None
                        self.assert_metric = None
                        self.assert_metric_preference = None
                        self.assert_rpt_bit = None
                        self.spt_bit = None
                        self.rpf_mask = None
                        self.rpf_safi = None
                        self.rpf_table_name = None
                        self.rpf_drop = None
                        self.rpf_extranet = None
                        self.rpf_interface_name = None
                        self.rpf_vrf_name = None
                        self.bidirectional_route = None
                        self.uptime = None
                        self.protocol = None

                        self.source_address_xr = Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr()
                        self.source_address_xr.parent = self
                        self._children_name_map["source_address_xr"] = "source-address-xr"

                        self.group_address_xr = Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr()
                        self.group_address_xr.parent = self
                        self._children_name_map["group_address_xr"] = "group-address-xr"

                        self.rpf_neighbor = Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor()
                        self.rpf_neighbor.parent = self
                        self._children_name_map["rpf_neighbor"] = "rpf-neighbor"

                        self.rpf_root = Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfRoot()
                        self.rpf_root.parent = self
                        self._children_name_map["rpf_root"] = "rpf-root"
                        self._segment_path = lambda: "mib-database"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/mib-databases/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase, ['source_address', 'group_address', 'source_netmask', 'upstream_assert_timer', 'assert_metric', 'assert_metric_preference', 'assert_rpt_bit', 'spt_bit', 'rpf_mask', 'rpf_safi', 'rpf_table_name', 'rpf_drop', 'rpf_extranet', 'rpf_interface_name', 'rpf_vrf_name', 'bidirectional_route', 'uptime', 'protocol'], name, value)


                    class SourceAddressXr(Entity):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr, self).__init__()

                            self.yang_name = "source-address-xr"
                            self.yang_parent_name = "mib-database"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "source-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/mib-databases/mib-database/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class GroupAddressXr(Entity):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr, self).__init__()

                            self.yang_name = "group-address-xr"
                            self.yang_parent_name = "mib-database"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "group-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/mib-databases/mib-database/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class RpfNeighbor(Entity):
                        """
                        The RPF Neighbor
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor, self).__init__()

                            self.yang_name = "rpf-neighbor"
                            self.yang_parent_name = "mib-database"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "rpf-neighbor"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/mib-databases/mib-database/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class RpfRoot(Entity):
                        """
                        Root of this mcast tree
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfRoot, self).__init__()

                            self.yang_name = "rpf-root"
                            self.yang_parent_name = "mib-database"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "rpf-root"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/mib-databases/mib-database/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfRoot, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class NeighborOldFormats(Entity):
                """
                PIM neighbor table old format
                
                .. attribute:: neighbor_old_format
                
                	PIM neighbor information
                	**type**\: list of  		 :py:class:`NeighborOldFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.NeighborOldFormats.NeighborOldFormat>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.NeighborOldFormats, self).__init__()

                    self.yang_name = "neighbor-old-formats"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("neighbor-old-format", ("neighbor_old_format", Ipv6Pim.Standby.DefaultContext.NeighborOldFormats.NeighborOldFormat))])
                    self._leafs = OrderedDict()

                    self.neighbor_old_format = YList(self)
                    self._segment_path = lambda: "neighbor-old-formats"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.NeighborOldFormats, [], name, value)


                class NeighborOldFormat(Entity):
                    """
                    PIM neighbor information
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: neighbor_address
                    
                    	Neighbor address
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identifier
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: expires
                    
                    	Neighbor expiry in seconds
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: expiry_timer
                    
                    	Expiry timer in seconds
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: is_this_neighbor_us
                    
                    	Is this neighbor us ?
                    	**type**\: bool
                    
                    .. attribute:: is_this_neighbor_dr
                    
                    	Is this neighbor the DR
                    	**type**\: bool
                    
                    .. attribute:: is_dr_priority_capable
                    
                    	Is this neighbor DR priority capable ?
                    	**type**\: bool
                    
                    .. attribute:: dr_priority
                    
                    	DR priority
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Is this neighbor bidir capable ?
                    	**type**\: bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Is this neighbor proxy capable?
                    	**type**\: bool
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Is this neighbor capable of batching asserts?
                    	**type**\: bool
                    
                    .. attribute:: is_ecmp_redirect_capable
                    
                    	Is this neighbor capable of Ecmp Redirect?
                    	**type**\: bool
                    
                    .. attribute:: is_bfd_state
                    
                    	Is the neighbor bfd session created
                    	**type**\: bool
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_address_xr
                    
                    	List of Neighbor Addresses
                    	**type**\: list of  		 :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.NeighborOldFormats.NeighborOldFormat, self).__init__()

                        self.yang_name = "neighbor-old-format"
                        self.yang_parent_name = "neighbor-old-formats"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("neighbor-address-xr", ("neighbor_address_xr", Ipv6Pim.Standby.DefaultContext.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr))])
                        self._leafs = OrderedDict([
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                            ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                            ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                            ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                            ('expires', (YLeaf(YType.uint64, 'expires'), ['int'])),
                            ('expiry_timer', (YLeaf(YType.uint64, 'expiry-timer'), ['int'])),
                            ('is_this_neighbor_us', (YLeaf(YType.boolean, 'is-this-neighbor-us'), ['bool'])),
                            ('is_this_neighbor_dr', (YLeaf(YType.boolean, 'is-this-neighbor-dr'), ['bool'])),
                            ('is_dr_priority_capable', (YLeaf(YType.boolean, 'is-dr-priority-capable'), ['bool'])),
                            ('dr_priority', (YLeaf(YType.uint32, 'dr-priority'), ['int'])),
                            ('is_bidirectional_capable', (YLeaf(YType.boolean, 'is-bidirectional-capable'), ['bool'])),
                            ('is_proxy_capable', (YLeaf(YType.boolean, 'is-proxy-capable'), ['bool'])),
                            ('is_batch_asserts_capable', (YLeaf(YType.boolean, 'is-batch-asserts-capable'), ['bool'])),
                            ('is_ecmp_redirect_capable', (YLeaf(YType.boolean, 'is-ecmp-redirect-capable'), ['bool'])),
                            ('is_bfd_state', (YLeaf(YType.boolean, 'is-bfd-state'), ['bool'])),
                            ('propagation_delay', (YLeaf(YType.uint16, 'propagation-delay'), ['int'])),
                            ('override_interval', (YLeaf(YType.uint16, 'override-interval'), ['int'])),
                        ])
                        self.interface_name = None
                        self.neighbor_address = None
                        self.interface_name_xr = None
                        self.uptime = None
                        self.expires = None
                        self.expiry_timer = None
                        self.is_this_neighbor_us = None
                        self.is_this_neighbor_dr = None
                        self.is_dr_priority_capable = None
                        self.dr_priority = None
                        self.is_bidirectional_capable = None
                        self.is_proxy_capable = None
                        self.is_batch_asserts_capable = None
                        self.is_ecmp_redirect_capable = None
                        self.is_bfd_state = None
                        self.propagation_delay = None
                        self.override_interval = None

                        self.neighbor_address_xr = YList(self)
                        self._segment_path = lambda: "neighbor-old-format"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/neighbor-old-formats/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.NeighborOldFormats.NeighborOldFormat, ['interface_name', 'neighbor_address', 'interface_name_xr', 'uptime', 'expires', 'expiry_timer', 'is_this_neighbor_us', 'is_this_neighbor_dr', 'is_dr_priority_capable', 'dr_priority', 'is_bidirectional_capable', 'is_proxy_capable', 'is_batch_asserts_capable', 'is_ecmp_redirect_capable', 'is_bfd_state', 'propagation_delay', 'override_interval'], name, value)


                    class NeighborAddressXr(Entity):
                        """
                        List of Neighbor Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr, self).__init__()

                            self.yang_name = "neighbor-address-xr"
                            self.yang_parent_name = "neighbor-old-format"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "neighbor-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/neighbor-old-formats/neighbor-old-format/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class IfrsSummary(Entity):
                """
                PIM interfaces in forward reference store
                summary
                
                .. attribute:: interface_count
                
                	Number of interfaces
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: configuration_count
                
                	Configuration counts
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.IfrsSummary, self).__init__()

                    self.yang_name = "ifrs-summary"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('interface_count', (YLeaf(YType.uint32, 'interface-count'), ['int'])),
                        ('configuration_count', (YLeaf(YType.uint32, 'configuration-count'), ['int'])),
                    ])
                    self.interface_count = None
                    self.configuration_count = None
                    self._segment_path = lambda: "ifrs-summary"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.IfrsSummary, ['interface_count', 'configuration_count'], name, value)


            class Ranges(Entity):
                """
                PIM range list information
                
                .. attribute:: range
                
                	PIM range list information
                	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Ranges.Range>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.Ranges, self).__init__()

                    self.yang_name = "ranges"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("range", ("range", Ipv6Pim.Standby.DefaultContext.Ranges.Range))])
                    self._leafs = OrderedDict()

                    self.range = YList(self)
                    self._segment_path = lambda: "ranges"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Ranges, [], name, value)


                class Range(Entity):
                    """
                    PIM range list information
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: client
                    
                    	Client
                    	**type**\:  :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                    
                    .. attribute:: rp_address_xr
                    
                    	Rendezvous point address
                    	**type**\:  :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Ranges.Range.RpAddressXr>`
                    
                    .. attribute:: source_of_information
                    
                    	Source of information
                    	**type**\:  :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Ranges.Range.SourceOfInformation>`
                    
                    .. attribute:: protocol
                    
                    	PIM protocol
                    	**type**\:  :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                    
                    .. attribute:: client_xr
                    
                    	Client mapping learnt via
                    	**type**\:  :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                    
                    .. attribute:: expires
                    
                    	When mapping expires
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: group_range
                    
                    	List of group ranges
                    	**type**\: list of  		 :py:class:`GroupRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Ranges.Range.GroupRange>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.Ranges.Range, self).__init__()

                        self.yang_name = "range"
                        self.yang_parent_name = "ranges"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("rp-address-xr", ("rp_address_xr", Ipv6Pim.Standby.DefaultContext.Ranges.Range.RpAddressXr)), ("source-of-information", ("source_of_information", Ipv6Pim.Standby.DefaultContext.Ranges.Range.SourceOfInformation)), ("group-range", ("group_range", Ipv6Pim.Standby.DefaultContext.Ranges.Range.GroupRange))])
                        self._leafs = OrderedDict([
                            ('rp_address', (YLeaf(YType.str, 'rp-address'), ['str','str'])),
                            ('client', (YLeaf(YType.enumeration, 'client'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimClient', '')])),
                            ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowProtocol', '')])),
                            ('client_xr', (YLeaf(YType.enumeration, 'client-xr'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowRangeClient', '')])),
                            ('expires', (YLeaf(YType.uint64, 'expires'), ['int'])),
                        ])
                        self.rp_address = None
                        self.client = None
                        self.protocol = None
                        self.client_xr = None
                        self.expires = None

                        self.rp_address_xr = Ipv6Pim.Standby.DefaultContext.Ranges.Range.RpAddressXr()
                        self.rp_address_xr.parent = self
                        self._children_name_map["rp_address_xr"] = "rp-address-xr"

                        self.source_of_information = Ipv6Pim.Standby.DefaultContext.Ranges.Range.SourceOfInformation()
                        self.source_of_information.parent = self
                        self._children_name_map["source_of_information"] = "source-of-information"

                        self.group_range = YList(self)
                        self._segment_path = lambda: "range"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/ranges/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Ranges.Range, ['rp_address', 'client', 'protocol', 'client_xr', 'expires'], name, value)


                    class RpAddressXr(Entity):
                        """
                        Rendezvous point address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Ranges.Range.RpAddressXr, self).__init__()

                            self.yang_name = "rp-address-xr"
                            self.yang_parent_name = "range"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "rp-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/ranges/range/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Ranges.Range.RpAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class SourceOfInformation(Entity):
                        """
                        Source of information
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Ranges.Range.SourceOfInformation, self).__init__()

                            self.yang_name = "source-of-information"
                            self.yang_parent_name = "range"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "source-of-information"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/ranges/range/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Ranges.Range.SourceOfInformation, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class GroupRange(Entity):
                        """
                        List of group ranges
                        
                        .. attribute:: prefix
                        
                        	Group range prefix
                        	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Ranges.Range.GroupRange.Prefix>`
                        
                        .. attribute:: source_of_information
                        
                        	Source of information
                        	**type**\:  :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation>`
                        
                        .. attribute:: prefix_length
                        
                        	Group range prefix length
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: expires
                        
                        	When mapping expires
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Ranges.Range.GroupRange, self).__init__()

                            self.yang_name = "group-range"
                            self.yang_parent_name = "range"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("prefix", ("prefix", Ipv6Pim.Standby.DefaultContext.Ranges.Range.GroupRange.Prefix)), ("source-of-information", ("source_of_information", Ipv6Pim.Standby.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation))])
                            self._leafs = OrderedDict([
                                ('prefix_length', (YLeaf(YType.int32, 'prefix-length'), ['int'])),
                                ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                                ('expires', (YLeaf(YType.uint64, 'expires'), ['int'])),
                            ])
                            self.prefix_length = None
                            self.uptime = None
                            self.expires = None

                            self.prefix = Ipv6Pim.Standby.DefaultContext.Ranges.Range.GroupRange.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"

                            self.source_of_information = Ipv6Pim.Standby.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation()
                            self.source_of_information.parent = self
                            self._children_name_map["source_of_information"] = "source-of-information"
                            self._segment_path = lambda: "group-range"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/ranges/range/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Ranges.Range.GroupRange, ['prefix_length', 'uptime', 'expires'], name, value)


                        class Prefix(Entity):
                            """
                            Group range prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.Ranges.Range.GroupRange.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "group-range"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "prefix"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/ranges/range/group-range/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Ranges.Range.GroupRange.Prefix, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class SourceOfInformation(Entity):
                            """
                            Source of information
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation, self).__init__()

                                self.yang_name = "source-of-information"
                                self.yang_parent_name = "group-range"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "source-of-information"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/ranges/range/group-range/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class InterfaceOldFormats(Entity):
                """
                PIM interfaces in old format
                
                .. attribute:: interface_old_format
                
                	PIM interface name
                	**type**\: list of  		 :py:class:`InterfaceOldFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats, self).__init__()

                    self.yang_name = "interface-old-formats"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("interface-old-format", ("interface_old_format", Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat))])
                    self._leafs = OrderedDict()

                    self.interface_old_format = YList(self)
                    self._segment_path = lambda: "interface-old-formats"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats, [], name, value)


                class InterfaceOldFormat(Entity):
                    """
                    PIM interface name
                    
                    .. attribute:: interface_name  (key)
                    
                    	Interface name
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: dr_address
                    
                    	PIM Designated Router
                    	**type**\:  :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress>`
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identfier
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: interface_address_mask
                    
                    	Interface IP Address Mask
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: is_enabled
                    
                    	Is PIM enabled on this IF ?
                    	**type**\: bool
                    
                    .. attribute:: neighbor_count
                    
                    	No. of neighbors on this IF
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: external_neighbor_count
                    
                    	No. of external neighbors on this IF
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: hello_interval
                    
                    	Hello Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dr_priority
                    
                    	DR Priority
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_expiry
                    
                    	Hello Timer Expiry
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: are_we_dr
                    
                    	Are we the DR on this IF ?
                    	**type**\: bool
                    
                    .. attribute:: bfd_enabled
                    
                    	BFD state
                    	**type**\: bool
                    
                    .. attribute:: bfd_interval
                    
                    	BFD Interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bfd_multiplier
                    
                    	BFD Multiplier
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_interface
                    
                    	 is this a Virtual Interfaces ?
                    	**type**\: bool
                    
                    .. attribute:: passive_interface
                    
                    	Passive PIM interface
                    	**type**\: bool
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\: str
                    
                    .. attribute:: join_prune_interval
                    
                    	Join\-Prune Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: prune_delay_enabled
                    
                    	Prune Delay Enabled
                    	**type**\: bool
                    
                    .. attribute:: configured_propagation_delay
                    
                    	Configured Propagation Delay
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_override_interval
                    
                    	Configured Override Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: generation_id
                    
                    	Generation Identifier
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Bidir Capable
                    	**type**\: bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Proxy Capable
                    	**type**\: bool
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Batch Asserts Capable
                    	**type**\: bool
                    
                    .. attribute:: idb_oor_enabled
                    
                    	Interface oor enabled
                    	**type**\: bool
                    
                    .. attribute:: idb_acl_provided
                    
                    	ACL name provided
                    	**type**\: bool
                    
                    .. attribute:: idb_max_count
                    
                    	Interface ole max count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_threshold_count
                    
                    	Interface ole threshold count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_current_count
                    
                    	Interface ole current count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_acl_name
                    
                    	Interface ole ACL Name
                    	**type**\: str
                    
                    	**length:** 0..64
                    
                    .. attribute:: interface_address
                    
                    	List of Interface IP Addresses
                    	**type**\: list of  		 :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat, self).__init__()

                        self.yang_name = "interface-old-format"
                        self.yang_parent_name = "interface-old-formats"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['interface_name']
                        self._child_classes = OrderedDict([("dr-address", ("dr_address", Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress)), ("interface-address", ("interface_address", Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress))])
                        self._leafs = OrderedDict([
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                            ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                            ('interface_address_mask', (YLeaf(YType.uint8, 'interface-address-mask'), ['int'])),
                            ('is_enabled', (YLeaf(YType.boolean, 'is-enabled'), ['bool'])),
                            ('neighbor_count', (YLeaf(YType.uint16, 'neighbor-count'), ['int'])),
                            ('external_neighbor_count', (YLeaf(YType.uint16, 'external-neighbor-count'), ['int'])),
                            ('hello_interval', (YLeaf(YType.uint16, 'hello-interval'), ['int'])),
                            ('dr_priority', (YLeaf(YType.uint32, 'dr-priority'), ['int'])),
                            ('hello_expiry', (YLeaf(YType.uint64, 'hello-expiry'), ['int'])),
                            ('are_we_dr', (YLeaf(YType.boolean, 'are-we-dr'), ['bool'])),
                            ('bfd_enabled', (YLeaf(YType.boolean, 'bfd-enabled'), ['bool'])),
                            ('bfd_interval', (YLeaf(YType.uint32, 'bfd-interval'), ['int'])),
                            ('bfd_multiplier', (YLeaf(YType.uint32, 'bfd-multiplier'), ['int'])),
                            ('virtual_interface', (YLeaf(YType.boolean, 'virtual-interface'), ['bool'])),
                            ('passive_interface', (YLeaf(YType.boolean, 'passive-interface'), ['bool'])),
                            ('neighbor_filter_name', (YLeaf(YType.str, 'neighbor-filter-name'), ['str'])),
                            ('join_prune_interval', (YLeaf(YType.uint16, 'join-prune-interval'), ['int'])),
                            ('prune_delay_enabled', (YLeaf(YType.boolean, 'prune-delay-enabled'), ['bool'])),
                            ('configured_propagation_delay', (YLeaf(YType.uint16, 'configured-propagation-delay'), ['int'])),
                            ('propagation_delay', (YLeaf(YType.uint16, 'propagation-delay'), ['int'])),
                            ('configured_override_interval', (YLeaf(YType.uint16, 'configured-override-interval'), ['int'])),
                            ('override_interval', (YLeaf(YType.uint16, 'override-interval'), ['int'])),
                            ('generation_id', (YLeaf(YType.uint32, 'generation-id'), ['int'])),
                            ('is_bidirectional_capable', (YLeaf(YType.boolean, 'is-bidirectional-capable'), ['bool'])),
                            ('is_proxy_capable', (YLeaf(YType.boolean, 'is-proxy-capable'), ['bool'])),
                            ('is_batch_asserts_capable', (YLeaf(YType.boolean, 'is-batch-asserts-capable'), ['bool'])),
                            ('idb_oor_enabled', (YLeaf(YType.boolean, 'idb-oor-enabled'), ['bool'])),
                            ('idb_acl_provided', (YLeaf(YType.boolean, 'idb-acl-provided'), ['bool'])),
                            ('idb_max_count', (YLeaf(YType.uint32, 'idb-max-count'), ['int'])),
                            ('idb_threshold_count', (YLeaf(YType.uint32, 'idb-threshold-count'), ['int'])),
                            ('idb_current_count', (YLeaf(YType.uint32, 'idb-current-count'), ['int'])),
                            ('idb_acl_name', (YLeaf(YType.str, 'idb-acl-name'), ['str'])),
                        ])
                        self.interface_name = None
                        self.interface_name_xr = None
                        self.interface_address_mask = None
                        self.is_enabled = None
                        self.neighbor_count = None
                        self.external_neighbor_count = None
                        self.hello_interval = None
                        self.dr_priority = None
                        self.hello_expiry = None
                        self.are_we_dr = None
                        self.bfd_enabled = None
                        self.bfd_interval = None
                        self.bfd_multiplier = None
                        self.virtual_interface = None
                        self.passive_interface = None
                        self.neighbor_filter_name = None
                        self.join_prune_interval = None
                        self.prune_delay_enabled = None
                        self.configured_propagation_delay = None
                        self.propagation_delay = None
                        self.configured_override_interval = None
                        self.override_interval = None
                        self.generation_id = None
                        self.is_bidirectional_capable = None
                        self.is_proxy_capable = None
                        self.is_batch_asserts_capable = None
                        self.idb_oor_enabled = None
                        self.idb_acl_provided = None
                        self.idb_max_count = None
                        self.idb_threshold_count = None
                        self.idb_current_count = None
                        self.idb_acl_name = None

                        self.dr_address = Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress()
                        self.dr_address.parent = self
                        self._children_name_map["dr_address"] = "dr-address"

                        self.interface_address = YList(self)
                        self._segment_path = lambda: "interface-old-format" + "[interface-name='" + str(self.interface_name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/interface-old-formats/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat, ['interface_name', 'interface_name_xr', 'interface_address_mask', 'is_enabled', 'neighbor_count', 'external_neighbor_count', 'hello_interval', 'dr_priority', 'hello_expiry', 'are_we_dr', 'bfd_enabled', 'bfd_interval', 'bfd_multiplier', 'virtual_interface', 'passive_interface', 'neighbor_filter_name', 'join_prune_interval', 'prune_delay_enabled', 'configured_propagation_delay', 'propagation_delay', 'configured_override_interval', 'override_interval', 'generation_id', 'is_bidirectional_capable', 'is_proxy_capable', 'is_batch_asserts_capable', 'idb_oor_enabled', 'idb_acl_provided', 'idb_max_count', 'idb_threshold_count', 'idb_current_count', 'idb_acl_name'], name, value)


                    class DrAddress(Entity):
                        """
                        PIM Designated Router
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress, self).__init__()

                            self.yang_name = "dr-address"
                            self.yang_parent_name = "interface-old-format"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "dr-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class InterfaceAddress(Entity):
                        """
                        List of Interface IP Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress, self).__init__()

                            self.yang_name = "interface-address"
                            self.yang_parent_name = "interface-old-format"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "interface-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class Bsr(Entity):
                """
                PIM BSR information
                
                .. attribute:: rp_caches
                
                	PIM BSR RP cache table
                	**type**\:  :py:class:`RpCaches <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches>`
                
                .. attribute:: candidate_rps
                
                	PIM candidate\-RP
                	**type**\:  :py:class:`CandidateRps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps>`
                
                .. attribute:: bsr_elections
                
                	PIM BSR election state
                	**type**\:  :py:class:`BsrElections <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.Bsr, self).__init__()

                    self.yang_name = "bsr"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("rp-caches", ("rp_caches", Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches)), ("candidate-rps", ("candidate_rps", Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps)), ("bsr-elections", ("bsr_elections", Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections))])
                    self._leafs = OrderedDict()

                    self.rp_caches = Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches()
                    self.rp_caches.parent = self
                    self._children_name_map["rp_caches"] = "rp-caches"

                    self.candidate_rps = Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps()
                    self.candidate_rps.parent = self
                    self._children_name_map["candidate_rps"] = "candidate-rps"

                    self.bsr_elections = Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections()
                    self.bsr_elections.parent = self
                    self._children_name_map["bsr_elections"] = "bsr-elections"
                    self._segment_path = lambda: "bsr"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Bsr, [], name, value)


                class RpCaches(Entity):
                    """
                    PIM BSR RP cache table
                    
                    .. attribute:: rp_cache
                    
                    	PIM BSR RP cache
                    	**type**\: list of  		 :py:class:`RpCache <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches, self).__init__()

                        self.yang_name = "rp-caches"
                        self.yang_parent_name = "bsr"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("rp-cache", ("rp_cache", Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache))])
                        self._leafs = OrderedDict()

                        self.rp_cache = YList(self)
                        self._segment_path = lambda: "rp-caches"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/bsr/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches, [], name, value)


                    class RpCache(Entity):
                        """
                        PIM BSR RP cache
                        
                        .. attribute:: group_prefix  (key)
                        
                        	Group prefix
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: group_prefix_xr
                        
                        	Group Prefix
                        	**type**\:  :py:class:`GroupPrefixXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr>`
                        
                        .. attribute:: candidate_rp_list
                        
                        	C\-RP list for this prefix
                        	**type**\:  :py:class:`CandidateRpList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList>`
                        
                        .. attribute:: group_prefix_length
                        
                        	Group Prefix Length
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: candidate_rp_group_count
                        
                        	C\-RP count for this Prefix
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache, self).__init__()

                            self.yang_name = "rp-cache"
                            self.yang_parent_name = "rp-caches"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['group_prefix']
                            self._child_classes = OrderedDict([("group-prefix-xr", ("group_prefix_xr", Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr)), ("candidate-rp-list", ("candidate_rp_list", Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList))])
                            self._leafs = OrderedDict([
                                ('group_prefix', (YLeaf(YType.str, 'group-prefix'), ['str','str'])),
                                ('group_prefix_length', (YLeaf(YType.uint32, 'group-prefix-length'), ['int'])),
                                ('candidate_rp_group_count', (YLeaf(YType.uint32, 'candidate-rp-group-count'), ['int'])),
                            ])
                            self.group_prefix = None
                            self.group_prefix_length = None
                            self.candidate_rp_group_count = None

                            self.group_prefix_xr = Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr()
                            self.group_prefix_xr.parent = self
                            self._children_name_map["group_prefix_xr"] = "group-prefix-xr"

                            self.candidate_rp_list = Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList()
                            self.candidate_rp_list.parent = self
                            self._children_name_map["candidate_rp_list"] = "candidate-rp-list"
                            self._segment_path = lambda: "rp-cache" + "[group-prefix='" + str(self.group_prefix) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/bsr/rp-caches/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache, ['group_prefix', 'group_prefix_length', 'candidate_rp_group_count'], name, value)


                        class GroupPrefixXr(Entity):
                            """
                            Group Prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr, self).__init__()

                                self.yang_name = "group-prefix-xr"
                                self.yang_parent_name = "rp-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "group-prefix-xr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class CandidateRpList(Entity):
                            """
                            C\-RP list for this prefix
                            
                            .. attribute:: pim_bsr_crp_bag
                            
                            	pim bsr crp bag
                            	**type**\: list of  		 :py:class:`PimBsrCrpBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList, self).__init__()

                                self.yang_name = "candidate-rp-list"
                                self.yang_parent_name = "rp-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("pim-bsr-crp-bag", ("pim_bsr_crp_bag", Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag))])
                                self._leafs = OrderedDict()

                                self.pim_bsr_crp_bag = YList(self)
                                self._segment_path = lambda: "candidate-rp-list"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList, [], name, value)


                            class PimBsrCrpBag(Entity):
                                """
                                pim bsr crp bag
                                
                                .. attribute:: candidate_rp_address
                                
                                	C\-RP address
                                	**type**\:  :py:class:`CandidateRpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress>`
                                
                                .. attribute:: candidate_rp_holdtime
                                
                                	C\-RP Holdtime
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: candidate_rp_priority
                                
                                	C\-RP Priority
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: candidate_rp_up_time
                                
                                	C\-RP Uptime
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: candidate_rp_expires
                                
                                	C\-RP Expires
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: protocol
                                
                                	PIM Protocol
                                	**type**\:  :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag, self).__init__()

                                    self.yang_name = "pim-bsr-crp-bag"
                                    self.yang_parent_name = "candidate-rp-list"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("candidate-rp-address", ("candidate_rp_address", Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress))])
                                    self._leafs = OrderedDict([
                                        ('candidate_rp_holdtime', (YLeaf(YType.uint16, 'candidate-rp-holdtime'), ['int'])),
                                        ('candidate_rp_priority', (YLeaf(YType.uint8, 'candidate-rp-priority'), ['int'])),
                                        ('candidate_rp_up_time', (YLeaf(YType.uint16, 'candidate-rp-up-time'), ['int'])),
                                        ('candidate_rp_expires', (YLeaf(YType.uint16, 'candidate-rp-expires'), ['int'])),
                                        ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowProtocol', '')])),
                                    ])
                                    self.candidate_rp_holdtime = None
                                    self.candidate_rp_priority = None
                                    self.candidate_rp_up_time = None
                                    self.candidate_rp_expires = None
                                    self.protocol = None

                                    self.candidate_rp_address = Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress()
                                    self.candidate_rp_address.parent = self
                                    self._children_name_map["candidate_rp_address"] = "candidate-rp-address"
                                    self._segment_path = lambda: "pim-bsr-crp-bag"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag, ['candidate_rp_holdtime', 'candidate_rp_priority', 'candidate_rp_up_time', 'candidate_rp_expires', 'protocol'], name, value)


                                class CandidateRpAddress(Entity):
                                    """
                                    C\-RP address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress, self).__init__()

                                        self.yang_name = "candidate-rp-address"
                                        self.yang_parent_name = "pim-bsr-crp-bag"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ])
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None
                                        self._segment_path = lambda: "candidate-rp-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class CandidateRps(Entity):
                    """
                    PIM candidate\-RP
                    
                    .. attribute:: candidate_rp
                    
                    	PIM BSR candidate RP information
                    	**type**\: list of  		 :py:class:`CandidateRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps, self).__init__()

                        self.yang_name = "candidate-rps"
                        self.yang_parent_name = "bsr"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("candidate-rp", ("candidate_rp", Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp))])
                        self._leafs = OrderedDict()

                        self.candidate_rp = YList(self)
                        self._segment_path = lambda: "candidate-rps"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/bsr/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps, [], name, value)


                    class CandidateRp(Entity):
                        """
                        PIM BSR candidate RP information
                        
                        .. attribute:: rp_address  (key)
                        
                        	Candidate\-RP address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: candidate_rp
                        
                        	Cand\-RP Address
                        	**type**\:  :py:class:`CandidateRp_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp_>`
                        
                        .. attribute:: candidate_rp_mode
                        
                        	Cand\-RP Mode
                        	**type**\:  :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: candidate_rp_scope
                        
                        	Cand\-RP Scope
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: crp_priority
                        
                        	Cand\-RP Priority
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: crp_holdtime
                        
                        	Cand\-RP Holdtime
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: candidate_rp_advance_interval
                        
                        	Cand\-RP Adv Interval in seconds
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        	**units**\: second
                        
                        .. attribute:: candidate_rp_uptime
                        
                        	Cand\-RP uptime
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: acl_name
                        
                        	Group Access\-List Name
                        	**type**\: str
                        
                        	**length:** 0..33
                        
                        .. attribute:: crp_access
                        
                        	Group Ranges Using this Cand\-RP
                        	**type**\: list of  		 :py:class:`CrpAccess <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CrpAccess>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp, self).__init__()

                            self.yang_name = "candidate-rp"
                            self.yang_parent_name = "candidate-rps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['rp_address']
                            self._child_classes = OrderedDict([("candidate-rp", ("candidate_rp", Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp_)), ("crp-access", ("crp_access", Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CrpAccess))])
                            self._leafs = OrderedDict([
                                ('rp_address', (YLeaf(YType.str, 'rp-address'), ['str','str'])),
                                ('candidate_rp_mode', (YLeaf(YType.enumeration, 'candidate-rp-mode'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowProtocol', '')])),
                                ('candidate_rp_scope', (YLeaf(YType.int32, 'candidate-rp-scope'), ['int'])),
                                ('crp_priority', (YLeaf(YType.uint8, 'crp-priority'), ['int'])),
                                ('crp_holdtime', (YLeaf(YType.uint16, 'crp-holdtime'), ['int'])),
                                ('candidate_rp_advance_interval', (YLeaf(YType.uint16, 'candidate-rp-advance-interval'), ['int'])),
                                ('candidate_rp_uptime', (YLeaf(YType.uint16, 'candidate-rp-uptime'), ['int'])),
                                ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                            ])
                            self.rp_address = None
                            self.candidate_rp_mode = None
                            self.candidate_rp_scope = None
                            self.crp_priority = None
                            self.crp_holdtime = None
                            self.candidate_rp_advance_interval = None
                            self.candidate_rp_uptime = None
                            self.acl_name = None

                            self.candidate_rp = Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp_()
                            self.candidate_rp.parent = self
                            self._children_name_map["candidate_rp"] = "candidate-rp"

                            self.crp_access = YList(self)
                            self._segment_path = lambda: "candidate-rp" + "[rp-address='" + str(self.rp_address) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/bsr/candidate-rps/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp, ['rp_address', 'candidate_rp_mode', 'candidate_rp_scope', 'crp_priority', 'crp_holdtime', 'candidate_rp_advance_interval', 'candidate_rp_uptime', 'acl_name'], name, value)


                        class CandidateRp_(Entity):
                            """
                            Cand\-RP Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp_, self).__init__()

                                self.yang_name = "candidate-rp"
                                self.yang_parent_name = "candidate-rp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "candidate-rp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp_, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class CrpAccess(Entity):
                            """
                            Group Ranges Using this Cand\-RP
                            
                            .. attribute:: candidate_rp_mode
                            
                            	Cand\-RP Mode
                            	**type**\:  :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                            
                            .. attribute:: acl_name
                            
                            	Group Access\-List Name
                            	**type**\: str
                            
                            	**length:** 0..33
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CrpAccess, self).__init__()

                                self.yang_name = "crp-access"
                                self.yang_parent_name = "candidate-rp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('candidate_rp_mode', (YLeaf(YType.enumeration, 'candidate-rp-mode'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowProtocol', '')])),
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                                ])
                                self.candidate_rp_mode = None
                                self.acl_name = None
                                self._segment_path = lambda: "crp-access"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CrpAccess, ['candidate_rp_mode', 'acl_name'], name, value)


                class BsrElections(Entity):
                    """
                    PIM BSR election state
                    
                    .. attribute:: bsr_election
                    
                    	PIM BSR information
                    	**type**\: list of  		 :py:class:`BsrElection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections, self).__init__()

                        self.yang_name = "bsr-elections"
                        self.yang_parent_name = "bsr"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("bsr-election", ("bsr_election", Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection))])
                        self._leafs = OrderedDict()

                        self.bsr_election = YList(self)
                        self._segment_path = lambda: "bsr-elections"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/bsr/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections, [], name, value)


                    class BsrElection(Entity):
                        """
                        PIM BSR information
                        
                        .. attribute:: pim_scope  (key)
                        
                        	BSR information
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bsr_address
                        
                        	BSR address
                        	**type**\:  :py:class:`BsrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress>`
                        
                        .. attribute:: candidate_bsr_address
                        
                        	C\-BSR address
                        	**type**\:  :py:class:`CandidateBsrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress>`
                        
                        .. attribute:: bsr_priority
                        
                        	BSR Priority
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: bsr_mask_length
                        
                        	Hash Function Mask Length
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: bsr_up_time
                        
                        	BSR Uptime
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: bootstrap_timeout
                        
                        	Bootstrap Timeout
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: candidate_bsr_state
                        
                        	BSR Candidate State
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bsr_election_state
                        
                        	BSR Election State
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bsr_scope
                        
                        	BSR Scope
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: candidate_bsr_flag
                        
                        	BSR Candidate Config Flag
                        	**type**\: bool
                        
                        .. attribute:: candidate_bsr_priority
                        
                        	C\-BSR Priority
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: candidate_bsr_mask_length
                        
                        	C\-BSR Hash Func. Mask Len
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection, self).__init__()

                            self.yang_name = "bsr-election"
                            self.yang_parent_name = "bsr-elections"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['pim_scope']
                            self._child_classes = OrderedDict([("bsr-address", ("bsr_address", Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress)), ("candidate-bsr-address", ("candidate_bsr_address", Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress))])
                            self._leafs = OrderedDict([
                                ('pim_scope', (YLeaf(YType.uint32, 'pim-scope'), ['int'])),
                                ('bsr_priority', (YLeaf(YType.uint8, 'bsr-priority'), ['int'])),
                                ('bsr_mask_length', (YLeaf(YType.uint8, 'bsr-mask-length'), ['int'])),
                                ('bsr_up_time', (YLeaf(YType.uint16, 'bsr-up-time'), ['int'])),
                                ('bootstrap_timeout', (YLeaf(YType.uint16, 'bootstrap-timeout'), ['int'])),
                                ('candidate_bsr_state', (YLeaf(YType.uint32, 'candidate-bsr-state'), ['int'])),
                                ('bsr_election_state', (YLeaf(YType.uint32, 'bsr-election-state'), ['int'])),
                                ('bsr_scope', (YLeaf(YType.uint16, 'bsr-scope'), ['int'])),
                                ('candidate_bsr_flag', (YLeaf(YType.boolean, 'candidate-bsr-flag'), ['bool'])),
                                ('candidate_bsr_priority', (YLeaf(YType.uint8, 'candidate-bsr-priority'), ['int'])),
                                ('candidate_bsr_mask_length', (YLeaf(YType.uint8, 'candidate-bsr-mask-length'), ['int'])),
                            ])
                            self.pim_scope = None
                            self.bsr_priority = None
                            self.bsr_mask_length = None
                            self.bsr_up_time = None
                            self.bootstrap_timeout = None
                            self.candidate_bsr_state = None
                            self.bsr_election_state = None
                            self.bsr_scope = None
                            self.candidate_bsr_flag = None
                            self.candidate_bsr_priority = None
                            self.candidate_bsr_mask_length = None

                            self.bsr_address = Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress()
                            self.bsr_address.parent = self
                            self._children_name_map["bsr_address"] = "bsr-address"

                            self.candidate_bsr_address = Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress()
                            self.candidate_bsr_address.parent = self
                            self._children_name_map["candidate_bsr_address"] = "candidate-bsr-address"
                            self._segment_path = lambda: "bsr-election" + "[pim-scope='" + str(self.pim_scope) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/bsr/bsr-elections/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection, ['pim_scope', 'bsr_priority', 'bsr_mask_length', 'bsr_up_time', 'bootstrap_timeout', 'candidate_bsr_state', 'bsr_election_state', 'bsr_scope', 'candidate_bsr_flag', 'candidate_bsr_priority', 'candidate_bsr_mask_length'], name, value)


                        class BsrAddress(Entity):
                            """
                            BSR address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress, self).__init__()

                                self.yang_name = "bsr-address"
                                self.yang_parent_name = "bsr-election"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "bsr-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class CandidateBsrAddress(Entity):
                            """
                            C\-BSR address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress, self).__init__()

                                self.yang_name = "candidate-bsr-address"
                                self.yang_parent_name = "bsr-election"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "candidate-bsr-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class RoutePolicy(Entity):
                """
                PIM route policy
                
                .. attribute:: route_policy_statistics
                
                	PIM route policy statistics
                	**type**\:  :py:class:`RoutePolicyStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyStatistics>`
                
                .. attribute:: route_policy_tests
                
                	PIM route policy test run table
                	**type**\:  :py:class:`RoutePolicyTests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.RoutePolicy, self).__init__()

                    self.yang_name = "route-policy"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("route-policy-statistics", ("route_policy_statistics", Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyStatistics)), ("route-policy-tests", ("route_policy_tests", Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests))])
                    self._leafs = OrderedDict()

                    self.route_policy_statistics = Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyStatistics()
                    self.route_policy_statistics.parent = self
                    self._children_name_map["route_policy_statistics"] = "route-policy-statistics"

                    self.route_policy_tests = Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests()
                    self.route_policy_tests.parent = self
                    self._children_name_map["route_policy_tests"] = "route-policy-tests"
                    self._segment_path = lambda: "route-policy"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.RoutePolicy, [], name, value)


                class RoutePolicyStatistics(Entity):
                    """
                    PIM route policy statistics
                    
                    .. attribute:: policy_name
                    
                    	RPF policy name
                    	**type**\: str
                    
                    .. attribute:: requests
                    
                    	Number of RPF lookup requests
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pass_
                    
                    	Number of RPF pass
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: drop
                    
                    	Number of RPF drops
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: default_table
                    
                    	Number of RPF lookup in default\-only Table
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: any_table
                    
                    	Number of RPF lookup in any Table
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyStatistics, self).__init__()

                        self.yang_name = "route-policy-statistics"
                        self.yang_parent_name = "route-policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('policy_name', (YLeaf(YType.str, 'policy-name'), ['str'])),
                            ('requests', (YLeaf(YType.uint32, 'requests'), ['int'])),
                            ('pass_', (YLeaf(YType.uint32, 'pass'), ['int'])),
                            ('drop', (YLeaf(YType.uint32, 'drop'), ['int'])),
                            ('default_table', (YLeaf(YType.uint32, 'default-table'), ['int'])),
                            ('any_table', (YLeaf(YType.uint32, 'any-table'), ['int'])),
                        ])
                        self.policy_name = None
                        self.requests = None
                        self.pass_ = None
                        self.drop = None
                        self.default_table = None
                        self.any_table = None
                        self._segment_path = lambda: "route-policy-statistics"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/route-policy/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyStatistics, ['policy_name', 'requests', 'pass_', 'drop', 'default_table', 'any_table'], name, value)


                class RoutePolicyTests(Entity):
                    """
                    PIM route policy test run table
                    
                    .. attribute:: route_policy_test
                    
                    	PIM route policy test run
                    	**type**\: list of  		 :py:class:`RoutePolicyTest <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests, self).__init__()

                        self.yang_name = "route-policy-tests"
                        self.yang_parent_name = "route-policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("route-policy-test", ("route_policy_test", Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest))])
                        self._leafs = OrderedDict()

                        self.route_policy_test = YList(self)
                        self._segment_path = lambda: "route-policy-tests"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/route-policy/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests, [], name, value)


                    class RoutePolicyTest(Entity):
                        """
                        PIM route policy test run
                        
                        .. attribute:: source_address
                        
                        	Source IP address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: group_address
                        
                        	Group IP address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ext_comm
                        
                        	Extended Community
                        	**type**\: str
                        
                        	**length:** 1..8
                        
                        .. attribute:: source_address_xr
                        
                        	Source address
                        	**type**\:  :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr>`
                        
                        .. attribute:: group_address_xr
                        
                        	Source address
                        	**type**\:  :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr>`
                        
                        .. attribute:: policy_name
                        
                        	RPF policy name
                        	**type**\: str
                        
                        .. attribute:: extended_community_rt
                        
                        	Route Target
                        	**type**\: str
                        
                        	**length:** 0..33
                        
                        .. attribute:: pass_
                        
                        	Pass
                        	**type**\: bool
                        
                        .. attribute:: default_table
                        
                        	Default table selected
                        	**type**\: bool
                        
                        .. attribute:: vrf_name
                        
                        	VRF name
                        	**type**\: str
                        
                        	**length:** 0..33
                        
                        .. attribute:: afi
                        
                        	AFI
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: safi
                        
                        	SAFI
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_name
                        
                        	Table name
                        	**type**\: str
                        
                        .. attribute:: table_exists
                        
                        	Table exists
                        	**type**\: bool
                        
                        .. attribute:: table_active
                        
                        	Table active
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest, self).__init__()

                            self.yang_name = "route-policy-test"
                            self.yang_parent_name = "route-policy-tests"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("source-address-xr", ("source_address_xr", Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr)), ("group-address-xr", ("group_address_xr", Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr))])
                            self._leafs = OrderedDict([
                                ('source_address', (YLeaf(YType.str, 'source-address'), ['str','str'])),
                                ('group_address', (YLeaf(YType.str, 'group-address'), ['str','str'])),
                                ('ext_comm', (YLeaf(YType.str, 'ext-comm'), ['str'])),
                                ('policy_name', (YLeaf(YType.str, 'policy-name'), ['str'])),
                                ('extended_community_rt', (YLeaf(YType.str, 'extended-community-rt'), ['str'])),
                                ('pass_', (YLeaf(YType.boolean, 'pass'), ['bool'])),
                                ('default_table', (YLeaf(YType.boolean, 'default-table'), ['bool'])),
                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                ('afi', (YLeaf(YType.uint32, 'afi'), ['int'])),
                                ('safi', (YLeaf(YType.uint32, 'safi'), ['int'])),
                                ('table_name', (YLeaf(YType.str, 'table-name'), ['str'])),
                                ('table_exists', (YLeaf(YType.boolean, 'table-exists'), ['bool'])),
                                ('table_active', (YLeaf(YType.boolean, 'table-active'), ['bool'])),
                            ])
                            self.source_address = None
                            self.group_address = None
                            self.ext_comm = None
                            self.policy_name = None
                            self.extended_community_rt = None
                            self.pass_ = None
                            self.default_table = None
                            self.vrf_name = None
                            self.afi = None
                            self.safi = None
                            self.table_name = None
                            self.table_exists = None
                            self.table_active = None

                            self.source_address_xr = Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr()
                            self.source_address_xr.parent = self
                            self._children_name_map["source_address_xr"] = "source-address-xr"

                            self.group_address_xr = Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._segment_path = lambda: "route-policy-test"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/route-policy/route-policy-tests/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest, ['source_address', 'group_address', 'ext_comm', 'policy_name', 'extended_community_rt', 'pass_', 'default_table', 'vrf_name', 'afi', 'safi', 'table_name', 'table_exists', 'table_active'], name, value)


                        class SourceAddressXr(Entity):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr, self).__init__()

                                self.yang_name = "source-address-xr"
                                self.yang_parent_name = "route-policy-test"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "source-address-xr"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/route-policy/route-policy-tests/route-policy-test/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class GroupAddressXr(Entity):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "route-policy-test"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "group-address-xr"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/route-policy/route-policy-tests/route-policy-test/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class RpfSummary(Entity):
                """
                PIM RPF registration summary
                
                .. attribute:: default_safi
                
                	Default RPF Table SAFI
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: default_table_name
                
                	Default RPF Table Name
                	**type**\: str
                
                .. attribute:: is_mbgp_configured
                
                	Is MBGP configured?
                	**type**\: bool
                
                .. attribute:: is_ospf_te_configured
                
                	Is OSPF TE configured?
                	**type**\: bool
                
                .. attribute:: is_isis_te_configured
                
                	Is ISIS TE configured?
                	**type**\: bool
                
                .. attribute:: is_isis_mtr_configured
                
                	Is ISIS MTR configured?
                	**type**\: bool
                
                .. attribute:: mo_frr_configured
                
                	Is MoFRR configured?
                	**type**\: bool
                
                .. attribute:: rib_mo_frr_configured
                
                	Is MoFRR RIB configured?
                	**type**\: bool
                
                .. attribute:: rump_enabled
                
                	Is RUMP MuRIB enabled?
                	**type**\: bool
                
                .. attribute:: rib_convergence_timeout
                
                	RIB convergence timeout in seconds
                	**type**\: int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: rib_convergence_time_left
                
                	RIB convergence time left in seconds
                	**type**\: int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: is_multipath_enabled
                
                	Is Multipath Enabled ?
                	**type**\: bool
                
                .. attribute:: is_multipath_interface_hash_enabled
                
                	Is Multipath Interface Hash Extension Enabled ?
                	**type**\: bool
                
                .. attribute:: is_multipath_source_hash_enabled
                
                	Is Multipath Source based Hash Enabled ?
                	**type**\: bool
                
                .. attribute:: is_multipath_source_next_hop_hash_enabled
                
                	Is Multipath Source\-Nexthop Hash Enabled ?
                	**type**\: bool
                
                .. attribute:: rpf_registrations
                
                	RPF Registration count
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_rib_convergence
                
                	RIB Convergence status
                	**type**\: bool
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.RpfSummary, self).__init__()

                    self.yang_name = "rpf-summary"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('default_safi', (YLeaf(YType.uint32, 'default-safi'), ['int'])),
                        ('default_table_name', (YLeaf(YType.str, 'default-table-name'), ['str'])),
                        ('is_mbgp_configured', (YLeaf(YType.boolean, 'is-mbgp-configured'), ['bool'])),
                        ('is_ospf_te_configured', (YLeaf(YType.boolean, 'is-ospf-te-configured'), ['bool'])),
                        ('is_isis_te_configured', (YLeaf(YType.boolean, 'is-isis-te-configured'), ['bool'])),
                        ('is_isis_mtr_configured', (YLeaf(YType.boolean, 'is-isis-mtr-configured'), ['bool'])),
                        ('mo_frr_configured', (YLeaf(YType.boolean, 'mo-frr-configured'), ['bool'])),
                        ('rib_mo_frr_configured', (YLeaf(YType.boolean, 'rib-mo-frr-configured'), ['bool'])),
                        ('rump_enabled', (YLeaf(YType.boolean, 'rump-enabled'), ['bool'])),
                        ('rib_convergence_timeout', (YLeaf(YType.uint32, 'rib-convergence-timeout'), ['int'])),
                        ('rib_convergence_time_left', (YLeaf(YType.uint32, 'rib-convergence-time-left'), ['int'])),
                        ('is_multipath_enabled', (YLeaf(YType.boolean, 'is-multipath-enabled'), ['bool'])),
                        ('is_multipath_interface_hash_enabled', (YLeaf(YType.boolean, 'is-multipath-interface-hash-enabled'), ['bool'])),
                        ('is_multipath_source_hash_enabled', (YLeaf(YType.boolean, 'is-multipath-source-hash-enabled'), ['bool'])),
                        ('is_multipath_source_next_hop_hash_enabled', (YLeaf(YType.boolean, 'is-multipath-source-next-hop-hash-enabled'), ['bool'])),
                        ('rpf_registrations', (YLeaf(YType.uint32, 'rpf-registrations'), ['int'])),
                        ('is_rib_convergence', (YLeaf(YType.boolean, 'is-rib-convergence'), ['bool'])),
                    ])
                    self.default_safi = None
                    self.default_table_name = None
                    self.is_mbgp_configured = None
                    self.is_ospf_te_configured = None
                    self.is_isis_te_configured = None
                    self.is_isis_mtr_configured = None
                    self.mo_frr_configured = None
                    self.rib_mo_frr_configured = None
                    self.rump_enabled = None
                    self.rib_convergence_timeout = None
                    self.rib_convergence_time_left = None
                    self.is_multipath_enabled = None
                    self.is_multipath_interface_hash_enabled = None
                    self.is_multipath_source_hash_enabled = None
                    self.is_multipath_source_next_hop_hash_enabled = None
                    self.rpf_registrations = None
                    self.is_rib_convergence = None
                    self._segment_path = lambda: "rpf-summary"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.RpfSummary, ['default_safi', 'default_table_name', 'is_mbgp_configured', 'is_ospf_te_configured', 'is_isis_te_configured', 'is_isis_mtr_configured', 'mo_frr_configured', 'rib_mo_frr_configured', 'rump_enabled', 'rib_convergence_timeout', 'rib_convergence_time_left', 'is_multipath_enabled', 'is_multipath_interface_hash_enabled', 'is_multipath_source_hash_enabled', 'is_multipath_source_next_hop_hash_enabled', 'rpf_registrations', 'is_rib_convergence'], name, value)


            class Interfaces(Entity):
                """
                PIM interfaces
                
                .. attribute:: interface
                
                	PIM interface name
                	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Interfaces.Interface>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.Interfaces, self).__init__()

                    self.yang_name = "interfaces"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("interface", ("interface", Ipv6Pim.Standby.DefaultContext.Interfaces.Interface))])
                    self._leafs = OrderedDict()

                    self.interface = YList(self)
                    self._segment_path = lambda: "interfaces"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Interfaces, [], name, value)


                class Interface(Entity):
                    """
                    PIM interface name
                    
                    .. attribute:: interface_name  (key)
                    
                    	Interface name
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: dr_address
                    
                    	PIM Designated Router
                    	**type**\:  :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Interfaces.Interface.DrAddress>`
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identfier
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: interface_address_mask
                    
                    	Interface IP Address Mask
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: is_enabled
                    
                    	Is PIM enabled on this IF ?
                    	**type**\: bool
                    
                    .. attribute:: neighbor_count
                    
                    	No. of neighbors on this IF
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: external_neighbor_count
                    
                    	No. of external neighbors on this IF
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: hello_interval
                    
                    	Hello Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dr_priority
                    
                    	DR Priority
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_expiry
                    
                    	Hello Timer Expiry
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: are_we_dr
                    
                    	Are we the DR on this IF ?
                    	**type**\: bool
                    
                    .. attribute:: bfd_enabled
                    
                    	BFD state
                    	**type**\: bool
                    
                    .. attribute:: bfd_interval
                    
                    	BFD Interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bfd_multiplier
                    
                    	BFD Multiplier
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_interface
                    
                    	 is this a Virtual Interfaces ?
                    	**type**\: bool
                    
                    .. attribute:: passive_interface
                    
                    	Passive PIM interface
                    	**type**\: bool
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\: str
                    
                    .. attribute:: join_prune_interval
                    
                    	Join\-Prune Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: prune_delay_enabled
                    
                    	Prune Delay Enabled
                    	**type**\: bool
                    
                    .. attribute:: configured_propagation_delay
                    
                    	Configured Propagation Delay
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_override_interval
                    
                    	Configured Override Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: generation_id
                    
                    	Generation Identifier
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Bidir Capable
                    	**type**\: bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Proxy Capable
                    	**type**\: bool
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Batch Asserts Capable
                    	**type**\: bool
                    
                    .. attribute:: idb_oor_enabled
                    
                    	Interface oor enabled
                    	**type**\: bool
                    
                    .. attribute:: idb_acl_provided
                    
                    	ACL name provided
                    	**type**\: bool
                    
                    .. attribute:: idb_max_count
                    
                    	Interface ole max count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_threshold_count
                    
                    	Interface ole threshold count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_current_count
                    
                    	Interface ole current count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_acl_name
                    
                    	Interface ole ACL Name
                    	**type**\: str
                    
                    	**length:** 0..64
                    
                    .. attribute:: interface_address
                    
                    	List of Interface IP Addresses
                    	**type**\: list of  		 :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Interfaces.Interface.InterfaceAddress>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.Interfaces.Interface, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "interfaces"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['interface_name']
                        self._child_classes = OrderedDict([("dr-address", ("dr_address", Ipv6Pim.Standby.DefaultContext.Interfaces.Interface.DrAddress)), ("interface-address", ("interface_address", Ipv6Pim.Standby.DefaultContext.Interfaces.Interface.InterfaceAddress))])
                        self._leafs = OrderedDict([
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                            ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                            ('interface_address_mask', (YLeaf(YType.uint8, 'interface-address-mask'), ['int'])),
                            ('is_enabled', (YLeaf(YType.boolean, 'is-enabled'), ['bool'])),
                            ('neighbor_count', (YLeaf(YType.uint16, 'neighbor-count'), ['int'])),
                            ('external_neighbor_count', (YLeaf(YType.uint16, 'external-neighbor-count'), ['int'])),
                            ('hello_interval', (YLeaf(YType.uint16, 'hello-interval'), ['int'])),
                            ('dr_priority', (YLeaf(YType.uint32, 'dr-priority'), ['int'])),
                            ('hello_expiry', (YLeaf(YType.uint64, 'hello-expiry'), ['int'])),
                            ('are_we_dr', (YLeaf(YType.boolean, 'are-we-dr'), ['bool'])),
                            ('bfd_enabled', (YLeaf(YType.boolean, 'bfd-enabled'), ['bool'])),
                            ('bfd_interval', (YLeaf(YType.uint32, 'bfd-interval'), ['int'])),
                            ('bfd_multiplier', (YLeaf(YType.uint32, 'bfd-multiplier'), ['int'])),
                            ('virtual_interface', (YLeaf(YType.boolean, 'virtual-interface'), ['bool'])),
                            ('passive_interface', (YLeaf(YType.boolean, 'passive-interface'), ['bool'])),
                            ('neighbor_filter_name', (YLeaf(YType.str, 'neighbor-filter-name'), ['str'])),
                            ('join_prune_interval', (YLeaf(YType.uint16, 'join-prune-interval'), ['int'])),
                            ('prune_delay_enabled', (YLeaf(YType.boolean, 'prune-delay-enabled'), ['bool'])),
                            ('configured_propagation_delay', (YLeaf(YType.uint16, 'configured-propagation-delay'), ['int'])),
                            ('propagation_delay', (YLeaf(YType.uint16, 'propagation-delay'), ['int'])),
                            ('configured_override_interval', (YLeaf(YType.uint16, 'configured-override-interval'), ['int'])),
                            ('override_interval', (YLeaf(YType.uint16, 'override-interval'), ['int'])),
                            ('generation_id', (YLeaf(YType.uint32, 'generation-id'), ['int'])),
                            ('is_bidirectional_capable', (YLeaf(YType.boolean, 'is-bidirectional-capable'), ['bool'])),
                            ('is_proxy_capable', (YLeaf(YType.boolean, 'is-proxy-capable'), ['bool'])),
                            ('is_batch_asserts_capable', (YLeaf(YType.boolean, 'is-batch-asserts-capable'), ['bool'])),
                            ('idb_oor_enabled', (YLeaf(YType.boolean, 'idb-oor-enabled'), ['bool'])),
                            ('idb_acl_provided', (YLeaf(YType.boolean, 'idb-acl-provided'), ['bool'])),
                            ('idb_max_count', (YLeaf(YType.uint32, 'idb-max-count'), ['int'])),
                            ('idb_threshold_count', (YLeaf(YType.uint32, 'idb-threshold-count'), ['int'])),
                            ('idb_current_count', (YLeaf(YType.uint32, 'idb-current-count'), ['int'])),
                            ('idb_acl_name', (YLeaf(YType.str, 'idb-acl-name'), ['str'])),
                        ])
                        self.interface_name = None
                        self.interface_name_xr = None
                        self.interface_address_mask = None
                        self.is_enabled = None
                        self.neighbor_count = None
                        self.external_neighbor_count = None
                        self.hello_interval = None
                        self.dr_priority = None
                        self.hello_expiry = None
                        self.are_we_dr = None
                        self.bfd_enabled = None
                        self.bfd_interval = None
                        self.bfd_multiplier = None
                        self.virtual_interface = None
                        self.passive_interface = None
                        self.neighbor_filter_name = None
                        self.join_prune_interval = None
                        self.prune_delay_enabled = None
                        self.configured_propagation_delay = None
                        self.propagation_delay = None
                        self.configured_override_interval = None
                        self.override_interval = None
                        self.generation_id = None
                        self.is_bidirectional_capable = None
                        self.is_proxy_capable = None
                        self.is_batch_asserts_capable = None
                        self.idb_oor_enabled = None
                        self.idb_acl_provided = None
                        self.idb_max_count = None
                        self.idb_threshold_count = None
                        self.idb_current_count = None
                        self.idb_acl_name = None

                        self.dr_address = Ipv6Pim.Standby.DefaultContext.Interfaces.Interface.DrAddress()
                        self.dr_address.parent = self
                        self._children_name_map["dr_address"] = "dr-address"

                        self.interface_address = YList(self)
                        self._segment_path = lambda: "interface" + "[interface-name='" + str(self.interface_name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/interfaces/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Interfaces.Interface, ['interface_name', 'interface_name_xr', 'interface_address_mask', 'is_enabled', 'neighbor_count', 'external_neighbor_count', 'hello_interval', 'dr_priority', 'hello_expiry', 'are_we_dr', 'bfd_enabled', 'bfd_interval', 'bfd_multiplier', 'virtual_interface', 'passive_interface', 'neighbor_filter_name', 'join_prune_interval', 'prune_delay_enabled', 'configured_propagation_delay', 'propagation_delay', 'configured_override_interval', 'override_interval', 'generation_id', 'is_bidirectional_capable', 'is_proxy_capable', 'is_batch_asserts_capable', 'idb_oor_enabled', 'idb_acl_provided', 'idb_max_count', 'idb_threshold_count', 'idb_current_count', 'idb_acl_name'], name, value)


                    class DrAddress(Entity):
                        """
                        PIM Designated Router
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Interfaces.Interface.DrAddress, self).__init__()

                            self.yang_name = "dr-address"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "dr-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Interfaces.Interface.DrAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class InterfaceAddress(Entity):
                        """
                        List of Interface IP Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Interfaces.Interface.InterfaceAddress, self).__init__()

                            self.yang_name = "interface-address"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "interface-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Interfaces.Interface.InterfaceAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class NetIoTunnels(Entity):
                """
                Tunnel information that NETIO has 
                
                .. attribute:: net_io_tunnel
                
                	PIM netio tunnel information
                	**type**\: list of  		 :py:class:`NetIoTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.NetIoTunnels, self).__init__()

                    self.yang_name = "net-io-tunnels"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("net-io-tunnel", ("net_io_tunnel", Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel))])
                    self._leafs = OrderedDict()

                    self.net_io_tunnel = YList(self)
                    self._segment_path = lambda: "net-io-tunnels"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.NetIoTunnels, [], name, value)


                class NetIoTunnel(Entity):
                    """
                    PIM netio tunnel information
                    
                    .. attribute:: tunnel_name  (key)
                    
                    	Tunnel name
                    	**type**\: str
                    
                    	**length:** 1..64
                    
                    .. attribute:: source_address
                    
                    	Source addr known to PIM
                    	**type**\:  :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress>`
                    
                    .. attribute:: rp_address
                    
                    	RP addr known to PIM
                    	**type**\:  :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress>`
                    
                    .. attribute:: source_address_netio
                    
                    	Source addr from netio
                    	**type**\:  :py:class:`SourceAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio>`
                    
                    .. attribute:: group_address_netio
                    
                    	Group addr from netio
                    	**type**\:  :py:class:`GroupAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio>`
                    
                    .. attribute:: vrf_name
                    
                    	VRF Name
                    	**type**\: str
                    
                    	**length:** 0..33
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel, self).__init__()

                        self.yang_name = "net-io-tunnel"
                        self.yang_parent_name = "net-io-tunnels"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['tunnel_name']
                        self._child_classes = OrderedDict([("source-address", ("source_address", Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress)), ("rp-address", ("rp_address", Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress)), ("source-address-netio", ("source_address_netio", Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio)), ("group-address-netio", ("group_address_netio", Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio))])
                        self._leafs = OrderedDict([
                            ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                        ])
                        self.tunnel_name = None
                        self.vrf_name = None

                        self.source_address = Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress()
                        self.source_address.parent = self
                        self._children_name_map["source_address"] = "source-address"

                        self.rp_address = Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress()
                        self.rp_address.parent = self
                        self._children_name_map["rp_address"] = "rp-address"

                        self.source_address_netio = Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio()
                        self.source_address_netio.parent = self
                        self._children_name_map["source_address_netio"] = "source-address-netio"

                        self.group_address_netio = Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio()
                        self.group_address_netio.parent = self
                        self._children_name_map["group_address_netio"] = "group-address-netio"
                        self._segment_path = lambda: "net-io-tunnel" + "[tunnel-name='" + str(self.tunnel_name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/net-io-tunnels/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel, ['tunnel_name', 'vrf_name'], name, value)


                    class SourceAddress(Entity):
                        """
                        Source addr known to PIM
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress, self).__init__()

                            self.yang_name = "source-address"
                            self.yang_parent_name = "net-io-tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "source-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class RpAddress(Entity):
                        """
                        RP addr known to PIM
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress, self).__init__()

                            self.yang_name = "rp-address"
                            self.yang_parent_name = "net-io-tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "rp-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class SourceAddressNetio(Entity):
                        """
                        Source addr from netio
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio, self).__init__()

                            self.yang_name = "source-address-netio"
                            self.yang_parent_name = "net-io-tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "source-address-netio"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class GroupAddressNetio(Entity):
                        """
                        Group addr from netio
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio, self).__init__()

                            self.yang_name = "group-address-netio"
                            self.yang_parent_name = "net-io-tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "group-address-netio"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class BidirDfStates(Entity):
                """
                Bidirectional PIM DF election state table
                
                .. attribute:: bidir_df_state
                
                	Bidirectional PIM DF Election Table Entry
                	**type**\: list of  		 :py:class:`BidirDfState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.BidirDfStates.BidirDfState>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.BidirDfStates, self).__init__()

                    self.yang_name = "bidir-df-states"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("bidir-df-state", ("bidir_df_state", Ipv6Pim.Standby.DefaultContext.BidirDfStates.BidirDfState))])
                    self._leafs = OrderedDict()

                    self.bidir_df_state = YList(self)
                    self._segment_path = lambda: "bidir-df-states"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.BidirDfStates, [], name, value)


                class BidirDfState(Entity):
                    """
                    Bidirectional PIM DF Election Table Entry
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: rp_address_xr
                    
                    	RP Address
                    	**type**\:  :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr>`
                    
                    .. attribute:: pim_interface_name
                    
                    	Interface Name
                    	**type**\: str
                    
                    .. attribute:: election_state
                    
                    	DF Election State
                    	**type**\: str
                    
                    .. attribute:: time_seconds
                    
                    	Timer expires (seconds)
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: time_nano_seconds
                    
                    	Timer expires (nseconds)
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: nanosecond
                    
                    .. attribute:: our_metric
                    
                    	Metric
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: our_metric_preference
                    
                    	MetricPreference
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.BidirDfStates.BidirDfState, self).__init__()

                        self.yang_name = "bidir-df-state"
                        self.yang_parent_name = "bidir-df-states"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("rp-address-xr", ("rp_address_xr", Ipv6Pim.Standby.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr))])
                        self._leafs = OrderedDict([
                            ('rp_address', (YLeaf(YType.str, 'rp-address'), ['str','str'])),
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                            ('pim_interface_name', (YLeaf(YType.str, 'pim-interface-name'), ['str'])),
                            ('election_state', (YLeaf(YType.str, 'election-state'), ['str'])),
                            ('time_seconds', (YLeaf(YType.uint64, 'time-seconds'), ['int'])),
                            ('time_nano_seconds', (YLeaf(YType.uint64, 'time-nano-seconds'), ['int'])),
                            ('our_metric', (YLeaf(YType.uint32, 'our-metric'), ['int'])),
                            ('our_metric_preference', (YLeaf(YType.uint32, 'our-metric-preference'), ['int'])),
                        ])
                        self.rp_address = None
                        self.interface_name = None
                        self.pim_interface_name = None
                        self.election_state = None
                        self.time_seconds = None
                        self.time_nano_seconds = None
                        self.our_metric = None
                        self.our_metric_preference = None

                        self.rp_address_xr = Ipv6Pim.Standby.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr()
                        self.rp_address_xr.parent = self
                        self._children_name_map["rp_address_xr"] = "rp-address-xr"
                        self._segment_path = lambda: "bidir-df-state"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/bidir-df-states/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.BidirDfStates.BidirDfState, ['rp_address', 'interface_name', 'pim_interface_name', 'election_state', 'time_seconds', 'time_nano_seconds', 'our_metric', 'our_metric_preference'], name, value)


                    class RpAddressXr(Entity):
                        """
                        RP Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr, self).__init__()

                            self.yang_name = "rp-address-xr"
                            self.yang_parent_name = "bidir-df-state"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "rp-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/bidir-df-states/bidir-df-state/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class Topologies(Entity):
                """
                PIM topology table
                
                .. attribute:: topology
                
                	PIM topology information
                	**type**\: list of  		 :py:class:`Topology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Topologies.Topology>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.Topologies, self).__init__()

                    self.yang_name = "topologies"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("topology", ("topology", Ipv6Pim.Standby.DefaultContext.Topologies.Topology))])
                    self._leafs = OrderedDict()

                    self.topology = YList(self)
                    self._segment_path = lambda: "topologies"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Topologies, [], name, value)


                class Topology(Entity):
                    """
                    PIM topology information
                    
                    .. attribute:: source_address
                    
                    	Source address
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: group_address
                    
                    	Group address
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: rpt
                    
                    	RPT bit
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_address_xr
                    
                    	Group Address
                    	**type**\:  :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Topologies.Topology.GroupAddressXr>`
                    
                    .. attribute:: source_address_xr
                    
                    	Source Address
                    	**type**\:  :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Topologies.Topology.SourceAddressXr>`
                    
                    .. attribute:: rp_address
                    
                    	RP Address (If rpt)
                    	**type**\:  :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Topologies.Topology.RpAddress>`
                    
                    .. attribute:: rpf_neighbor
                    
                    	RPF Neighbor
                    	**type**\:  :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Topologies.Topology.RpfNeighbor>`
                    
                    .. attribute:: secondary_rpf_neighbor
                    
                    	Secondary RPF Neighbor
                    	**type**\:  :py:class:`SecondaryRpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor>`
                    
                    .. attribute:: rpf_root
                    
                    	Root of this mcast tree
                    	**type**\:  :py:class:`RpfRoot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Topologies.Topology.RpfRoot>`
                    
                    .. attribute:: proxy_address
                    
                    	RPF Proxy address
                    	**type**\:  :py:class:`ProxyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Topologies.Topology.ProxyAddress>`
                    
                    .. attribute:: orig_src_address
                    
                    	Orig Src Address
                    	**type**\:  :py:class:`OrigSrcAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Topologies.Topology.OrigSrcAddress>`
                    
                    .. attribute:: limit_reached
                    
                    	Have we throttled the creation of routes or interfaces ?
                    	**type**\: bool
                    
                    .. attribute:: low_memory
                    
                    	Node is running low on memory
                    	**type**\: bool
                    
                    .. attribute:: protocol
                    
                    	The PIM protocol
                    	**type**\:  :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                    
                    .. attribute:: wildcard
                    
                    	WC \-Wildcard
                    	**type**\: bool
                    
                    .. attribute:: rpt_xr
                    
                    	Is this on the RPT ?
                    	**type**\: bool
                    
                    .. attribute:: spt
                    
                    	Is this on the SPT ?
                    	**type**\: bool
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: expiry
                    
                    	When this entry expires
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: alive
                    
                    	Alive time in seconds (\-1 if never)
                    	**type**\: int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    .. attribute:: register_received_timer
                    
                    	Register Received Timer in seconds (\-1 if never)
                    	**type**\: int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    .. attribute:: remote_source
                    
                    	MSDP told us
                    	**type**\: bool
                    
                    .. attribute:: crossed_threshold
                    
                    	Incoming traffic crossed threshold. MT flag set
                    	**type**\: bool
                    
                    .. attribute:: data_mdt_addr_assigned
                    
                    	PIM has assigned a Data MDT Address
                    	**type**\: bool
                    
                    .. attribute:: rpf_interface_name
                    
                    	Interface Identifier
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: rpf_vrf_name
                    
                    	RPF VRF Name
                    	**type**\: str
                    
                    	**length:** 0..33
                    
                    .. attribute:: rpf_safi
                    
                    	Unicast or mcast
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: rpf_table_name
                    
                    	RPF Table name
                    	**type**\: str
                    
                    .. attribute:: rpf_drop
                    
                    	RPF route\-policy drop
                    	**type**\: bool
                    
                    .. attribute:: rpf_extranet
                    
                    	Extranet RPF route\-policy
                    	**type**\: bool
                    
                    .. attribute:: is_via_lsm
                    
                    	Via LSM
                    	**type**\: bool
                    
                    .. attribute:: secondary_rpf_interface_name
                    
                    	Secondary Interface Identifier
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: connected
                    
                    	Is Connected ?
                    	**type**\: bool
                    
                    .. attribute:: proxy
                    
                    	Is the RPF target a proxy?
                    	**type**\: bool
                    
                    .. attribute:: rpf_proxy_enabled
                    
                    	Is rpf if proxy enabled?
                    	**type**\: bool
                    
                    .. attribute:: mofrr_enabled
                    
                    	Is this SG MoFRR enabled?
                    	**type**\: bool
                    
                    .. attribute:: rib_mo_frr_enabled
                    
                    	Is this SG MoFRR enabled?
                    	**type**\: bool
                    
                    .. attribute:: jp_timer
                    
                    	Join\-Prune Timer
                    	**type**\: int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: jp_status
                    
                    	Join\-Prune Status
                    	**type**\: int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: suppress_registers
                    
                    	When the Null register probe expires
                    	**type**\: int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: assume_alive
                    
                    	The Assume Alive Bit
                    	**type**\: bool
                    
                    .. attribute:: probe_alive
                    
                    	The Probe Alive Bit
                    	**type**\: bool
                    
                    .. attribute:: really_alive
                    
                    	The Really Alive Bit
                    	**type**\: bool
                    
                    .. attribute:: inherit_alive
                    
                    	The Inherit Alive Bit
                    	**type**\: bool
                    
                    .. attribute:: inherit_spt
                    
                    	The Inherit SPT Bit
                    	**type**\: bool
                    
                    .. attribute:: signal_sources
                    
                    	Signal Sources on route?
                    	**type**\: bool
                    
                    .. attribute:: dont_check_connected
                    
                    	Do we need to make the connected check on this route ?
                    	**type**\: bool
                    
                    .. attribute:: register_received
                    
                    	Have registers been received for this source ?
                    	**type**\: bool
                    
                    .. attribute:: last_hop
                    
                    	Are we last hop ?
                    	**type**\: bool
                    
                    .. attribute:: sending_registers
                    
                    	Are we sending registers for this route ?
                    	**type**\: bool
                    
                    .. attribute:: sending_null_registers
                    
                    	Are we sending null registers for this route ?
                    	**type**\: bool
                    
                    .. attribute:: sa_sent
                    
                    	BGP SA sent
                    	**type**\: bool
                    
                    .. attribute:: sa_received
                    
                    	BGP SA received
                    	**type**\: bool
                    
                    .. attribute:: sa_joined
                    
                    	BGP SA join
                    	**type**\: bool
                    
                    .. attribute:: anycast_rp_match
                    
                    	Group matches Anycast\-RP policy
                    	**type**\: bool
                    
                    .. attribute:: anycast_rp_route_target
                    
                    	Anycast\-RP RT
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: bgp_join
                    
                    	BGP C JOIN
                    	**type**\: bool
                    
                    .. attribute:: bgp_jp_time
                    
                    	BGP C JP Time
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: customer_routing_type
                    
                    	Type of Customer Routing in the MVPN
                    	**type**\: int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: extranet_route
                    
                    	Is a Extranet route ?
                    	**type**\: bool
                    
                    .. attribute:: mofrr_active
                    
                    	Is MoFRR Active?
                    	**type**\: bool
                    
                    .. attribute:: mofrr_primary
                    
                    	Is this Mofrr Primary?
                    	**type**\: bool
                    
                    .. attribute:: mofrr_backup
                    
                    	Is this Mofrr Backup?
                    	**type**\: bool
                    
                    .. attribute:: vxlan
                    
                    	Is this VXLAN?
                    	**type**\: bool
                    
                    .. attribute:: kat_state
                    
                    	Keep Alive Timer State
                    	**type**\: bool
                    
                    .. attribute:: outgoing_interface
                    
                    	Outgoing interface list
                    	**type**\: list of  		 :py:class:`OutgoingInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.Topologies.Topology, self).__init__()

                        self.yang_name = "topology"
                        self.yang_parent_name = "topologies"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("group-address-xr", ("group_address_xr", Ipv6Pim.Standby.DefaultContext.Topologies.Topology.GroupAddressXr)), ("source-address-xr", ("source_address_xr", Ipv6Pim.Standby.DefaultContext.Topologies.Topology.SourceAddressXr)), ("rp-address", ("rp_address", Ipv6Pim.Standby.DefaultContext.Topologies.Topology.RpAddress)), ("rpf-neighbor", ("rpf_neighbor", Ipv6Pim.Standby.DefaultContext.Topologies.Topology.RpfNeighbor)), ("secondary-rpf-neighbor", ("secondary_rpf_neighbor", Ipv6Pim.Standby.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor)), ("rpf-root", ("rpf_root", Ipv6Pim.Standby.DefaultContext.Topologies.Topology.RpfRoot)), ("proxy-address", ("proxy_address", Ipv6Pim.Standby.DefaultContext.Topologies.Topology.ProxyAddress)), ("orig-src-address", ("orig_src_address", Ipv6Pim.Standby.DefaultContext.Topologies.Topology.OrigSrcAddress)), ("outgoing-interface", ("outgoing_interface", Ipv6Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface))])
                        self._leafs = OrderedDict([
                            ('source_address', (YLeaf(YType.str, 'source-address'), ['str','str'])),
                            ('group_address', (YLeaf(YType.str, 'group-address'), ['str','str'])),
                            ('rpt', (YLeaf(YType.uint32, 'rpt'), ['int'])),
                            ('limit_reached', (YLeaf(YType.boolean, 'limit-reached'), ['bool'])),
                            ('low_memory', (YLeaf(YType.boolean, 'low-memory'), ['bool'])),
                            ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowProtocol', '')])),
                            ('wildcard', (YLeaf(YType.boolean, 'wildcard'), ['bool'])),
                            ('rpt_xr', (YLeaf(YType.boolean, 'rpt-xr'), ['bool'])),
                            ('spt', (YLeaf(YType.boolean, 'spt'), ['bool'])),
                            ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                            ('expiry', (YLeaf(YType.uint64, 'expiry'), ['int'])),
                            ('alive', (YLeaf(YType.int32, 'alive'), ['int'])),
                            ('register_received_timer', (YLeaf(YType.int32, 'register-received-timer'), ['int'])),
                            ('remote_source', (YLeaf(YType.boolean, 'remote-source'), ['bool'])),
                            ('crossed_threshold', (YLeaf(YType.boolean, 'crossed-threshold'), ['bool'])),
                            ('data_mdt_addr_assigned', (YLeaf(YType.boolean, 'data-mdt-addr-assigned'), ['bool'])),
                            ('rpf_interface_name', (YLeaf(YType.str, 'rpf-interface-name'), ['str'])),
                            ('rpf_vrf_name', (YLeaf(YType.str, 'rpf-vrf-name'), ['str'])),
                            ('rpf_safi', (YLeaf(YType.uint8, 'rpf-safi'), ['int'])),
                            ('rpf_table_name', (YLeaf(YType.str, 'rpf-table-name'), ['str'])),
                            ('rpf_drop', (YLeaf(YType.boolean, 'rpf-drop'), ['bool'])),
                            ('rpf_extranet', (YLeaf(YType.boolean, 'rpf-extranet'), ['bool'])),
                            ('is_via_lsm', (YLeaf(YType.boolean, 'is-via-lsm'), ['bool'])),
                            ('secondary_rpf_interface_name', (YLeaf(YType.str, 'secondary-rpf-interface-name'), ['str'])),
                            ('connected', (YLeaf(YType.boolean, 'connected'), ['bool'])),
                            ('proxy', (YLeaf(YType.boolean, 'proxy'), ['bool'])),
                            ('rpf_proxy_enabled', (YLeaf(YType.boolean, 'rpf-proxy-enabled'), ['bool'])),
                            ('mofrr_enabled', (YLeaf(YType.boolean, 'mofrr-enabled'), ['bool'])),
                            ('rib_mo_frr_enabled', (YLeaf(YType.boolean, 'rib-mo-frr-enabled'), ['bool'])),
                            ('jp_timer', (YLeaf(YType.int32, 'jp-timer'), ['int'])),
                            ('jp_status', (YLeaf(YType.int32, 'jp-status'), ['int'])),
                            ('suppress_registers', (YLeaf(YType.int32, 'suppress-registers'), ['int'])),
                            ('assume_alive', (YLeaf(YType.boolean, 'assume-alive'), ['bool'])),
                            ('probe_alive', (YLeaf(YType.boolean, 'probe-alive'), ['bool'])),
                            ('really_alive', (YLeaf(YType.boolean, 'really-alive'), ['bool'])),
                            ('inherit_alive', (YLeaf(YType.boolean, 'inherit-alive'), ['bool'])),
                            ('inherit_spt', (YLeaf(YType.boolean, 'inherit-spt'), ['bool'])),
                            ('signal_sources', (YLeaf(YType.boolean, 'signal-sources'), ['bool'])),
                            ('dont_check_connected', (YLeaf(YType.boolean, 'dont-check-connected'), ['bool'])),
                            ('register_received', (YLeaf(YType.boolean, 'register-received'), ['bool'])),
                            ('last_hop', (YLeaf(YType.boolean, 'last-hop'), ['bool'])),
                            ('sending_registers', (YLeaf(YType.boolean, 'sending-registers'), ['bool'])),
                            ('sending_null_registers', (YLeaf(YType.boolean, 'sending-null-registers'), ['bool'])),
                            ('sa_sent', (YLeaf(YType.boolean, 'sa-sent'), ['bool'])),
                            ('sa_received', (YLeaf(YType.boolean, 'sa-received'), ['bool'])),
                            ('sa_joined', (YLeaf(YType.boolean, 'sa-joined'), ['bool'])),
                            ('anycast_rp_match', (YLeaf(YType.boolean, 'anycast-rp-match'), ['bool'])),
                            ('anycast_rp_route_target', (YLeaf(YType.str, 'anycast-rp-route-target'), ['str'])),
                            ('bgp_join', (YLeaf(YType.boolean, 'bgp-join'), ['bool'])),
                            ('bgp_jp_time', (YLeaf(YType.uint64, 'bgp-jp-time'), ['int'])),
                            ('customer_routing_type', (YLeaf(YType.int32, 'customer-routing-type'), ['int'])),
                            ('extranet_route', (YLeaf(YType.boolean, 'extranet-route'), ['bool'])),
                            ('mofrr_active', (YLeaf(YType.boolean, 'mofrr-active'), ['bool'])),
                            ('mofrr_primary', (YLeaf(YType.boolean, 'mofrr-primary'), ['bool'])),
                            ('mofrr_backup', (YLeaf(YType.boolean, 'mofrr-backup'), ['bool'])),
                            ('vxlan', (YLeaf(YType.boolean, 'vxlan'), ['bool'])),
                            ('kat_state', (YLeaf(YType.boolean, 'kat-state'), ['bool'])),
                        ])
                        self.source_address = None
                        self.group_address = None
                        self.rpt = None
                        self.limit_reached = None
                        self.low_memory = None
                        self.protocol = None
                        self.wildcard = None
                        self.rpt_xr = None
                        self.spt = None
                        self.uptime = None
                        self.expiry = None
                        self.alive = None
                        self.register_received_timer = None
                        self.remote_source = None
                        self.crossed_threshold = None
                        self.data_mdt_addr_assigned = None
                        self.rpf_interface_name = None
                        self.rpf_vrf_name = None
                        self.rpf_safi = None
                        self.rpf_table_name = None
                        self.rpf_drop = None
                        self.rpf_extranet = None
                        self.is_via_lsm = None
                        self.secondary_rpf_interface_name = None
                        self.connected = None
                        self.proxy = None
                        self.rpf_proxy_enabled = None
                        self.mofrr_enabled = None
                        self.rib_mo_frr_enabled = None
                        self.jp_timer = None
                        self.jp_status = None
                        self.suppress_registers = None
                        self.assume_alive = None
                        self.probe_alive = None
                        self.really_alive = None
                        self.inherit_alive = None
                        self.inherit_spt = None
                        self.signal_sources = None
                        self.dont_check_connected = None
                        self.register_received = None
                        self.last_hop = None
                        self.sending_registers = None
                        self.sending_null_registers = None
                        self.sa_sent = None
                        self.sa_received = None
                        self.sa_joined = None
                        self.anycast_rp_match = None
                        self.anycast_rp_route_target = None
                        self.bgp_join = None
                        self.bgp_jp_time = None
                        self.customer_routing_type = None
                        self.extranet_route = None
                        self.mofrr_active = None
                        self.mofrr_primary = None
                        self.mofrr_backup = None
                        self.vxlan = None
                        self.kat_state = None

                        self.group_address_xr = Ipv6Pim.Standby.DefaultContext.Topologies.Topology.GroupAddressXr()
                        self.group_address_xr.parent = self
                        self._children_name_map["group_address_xr"] = "group-address-xr"

                        self.source_address_xr = Ipv6Pim.Standby.DefaultContext.Topologies.Topology.SourceAddressXr()
                        self.source_address_xr.parent = self
                        self._children_name_map["source_address_xr"] = "source-address-xr"

                        self.rp_address = Ipv6Pim.Standby.DefaultContext.Topologies.Topology.RpAddress()
                        self.rp_address.parent = self
                        self._children_name_map["rp_address"] = "rp-address"

                        self.rpf_neighbor = Ipv6Pim.Standby.DefaultContext.Topologies.Topology.RpfNeighbor()
                        self.rpf_neighbor.parent = self
                        self._children_name_map["rpf_neighbor"] = "rpf-neighbor"

                        self.secondary_rpf_neighbor = Ipv6Pim.Standby.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor()
                        self.secondary_rpf_neighbor.parent = self
                        self._children_name_map["secondary_rpf_neighbor"] = "secondary-rpf-neighbor"

                        self.rpf_root = Ipv6Pim.Standby.DefaultContext.Topologies.Topology.RpfRoot()
                        self.rpf_root.parent = self
                        self._children_name_map["rpf_root"] = "rpf-root"

                        self.proxy_address = Ipv6Pim.Standby.DefaultContext.Topologies.Topology.ProxyAddress()
                        self.proxy_address.parent = self
                        self._children_name_map["proxy_address"] = "proxy-address"

                        self.orig_src_address = Ipv6Pim.Standby.DefaultContext.Topologies.Topology.OrigSrcAddress()
                        self.orig_src_address.parent = self
                        self._children_name_map["orig_src_address"] = "orig-src-address"

                        self.outgoing_interface = YList(self)
                        self._segment_path = lambda: "topology"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/topologies/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Topologies.Topology, ['source_address', 'group_address', 'rpt', 'limit_reached', 'low_memory', 'protocol', 'wildcard', 'rpt_xr', 'spt', 'uptime', 'expiry', 'alive', 'register_received_timer', 'remote_source', 'crossed_threshold', 'data_mdt_addr_assigned', 'rpf_interface_name', 'rpf_vrf_name', 'rpf_safi', 'rpf_table_name', 'rpf_drop', 'rpf_extranet', 'is_via_lsm', 'secondary_rpf_interface_name', 'connected', 'proxy', 'rpf_proxy_enabled', 'mofrr_enabled', 'rib_mo_frr_enabled', 'jp_timer', 'jp_status', 'suppress_registers', 'assume_alive', 'probe_alive', 'really_alive', 'inherit_alive', 'inherit_spt', 'signal_sources', 'dont_check_connected', 'register_received', 'last_hop', 'sending_registers', 'sending_null_registers', 'sa_sent', 'sa_received', 'sa_joined', 'anycast_rp_match', 'anycast_rp_route_target', 'bgp_join', 'bgp_jp_time', 'customer_routing_type', 'extranet_route', 'mofrr_active', 'mofrr_primary', 'mofrr_backup', 'vxlan', 'kat_state'], name, value)


                    class GroupAddressXr(Entity):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.GroupAddressXr, self).__init__()

                            self.yang_name = "group-address-xr"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "group-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/topologies/topology/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.GroupAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class SourceAddressXr(Entity):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.SourceAddressXr, self).__init__()

                            self.yang_name = "source-address-xr"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "source-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/topologies/topology/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.SourceAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class RpAddress(Entity):
                        """
                        RP Address (If rpt)
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.RpAddress, self).__init__()

                            self.yang_name = "rp-address"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "rp-address"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/topologies/topology/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.RpAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class RpfNeighbor(Entity):
                        """
                        RPF Neighbor
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.RpfNeighbor, self).__init__()

                            self.yang_name = "rpf-neighbor"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "rpf-neighbor"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/topologies/topology/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.RpfNeighbor, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class SecondaryRpfNeighbor(Entity):
                        """
                        Secondary RPF Neighbor
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor, self).__init__()

                            self.yang_name = "secondary-rpf-neighbor"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "secondary-rpf-neighbor"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/topologies/topology/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class RpfRoot(Entity):
                        """
                        Root of this mcast tree
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.RpfRoot, self).__init__()

                            self.yang_name = "rpf-root"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "rpf-root"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/topologies/topology/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.RpfRoot, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class ProxyAddress(Entity):
                        """
                        RPF Proxy address.
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.ProxyAddress, self).__init__()

                            self.yang_name = "proxy-address"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "proxy-address"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/topologies/topology/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.ProxyAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class OrigSrcAddress(Entity):
                        """
                        Orig Src Address.
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.OrigSrcAddress, self).__init__()

                            self.yang_name = "orig-src-address"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "orig-src-address"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/topologies/topology/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.OrigSrcAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class OutgoingInterface(Entity):
                        """
                        Outgoing interface list
                        
                        .. attribute:: assert_winner
                        
                        	Assert Winner
                        	**type**\:  :py:class:`AssertWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner>`
                        
                        .. attribute:: interface_name
                        
                        	Interface Identifier
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: expiry
                        
                        	Expiry in seconds
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: bgp_c_mcast_prune_delay_timer
                        
                        	BGP C\-MCAST Prune Suppression in seconds
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: jp_timer
                        
                        	Join\-Prune Timer (secs)
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: jp_state
                        
                        	Join\-Prune State
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: assert_timer
                        
                        	Assert Timer in seconds
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: local_members
                        
                        	Local Information. Deprecated \- use 'local\-members\-information' instead
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: internal_interest_info
                        
                        	Internal Interest. Deprecated \- use 'internal\-interest\-information' instead
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: forwarding_state
                        
                        	Forward or Prune
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: immediate_state
                        
                        	Immediate fwding state
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: last_hop
                        
                        	Are we last hop ?
                        	**type**\: bool
                        
                        .. attribute:: mldp_inband_mdt
                        
                        	MLDP Inband MDT interface
                        	**type**\: bool
                        
                        .. attribute:: mldp_stale
                        
                        	OLE is stale
                        	**type**\: bool
                        
                        .. attribute:: sa_prune
                        
                        	BGP SA Prune state
                        	**type**\: bool
                        
                        .. attribute:: admin_boundary
                        
                        	Is this an administrative boundary ?
                        	**type**\: bool
                        
                        .. attribute:: igmp_membership
                        
                        	IGMP membership
                        	**type**\: bool
                        
                        .. attribute:: mdt_safi_join
                        
                        	MDT Safi join
                        	**type**\: bool
                        
                        .. attribute:: mvpn_safi_join
                        
                        	MVPN Safi join
                        	**type**\: bool
                        
                        .. attribute:: local_mdt_join
                        
                        	Default MDT Join
                        	**type**\: bool
                        
                        .. attribute:: data_mdt_join
                        
                        	Data MDT join
                        	**type**\: bool
                        
                        .. attribute:: mvpnv6_safi_join
                        
                        	MVPN IPv6 Safi join
                        	**type**\: bool
                        
                        .. attribute:: bgp_c_mcast_join
                        
                        	BGP C\-Mcast join
                        	**type**\: bool
                        
                        .. attribute:: vrf_name
                        
                        	VRF which physically owns
                        	**type**\: str
                        
                        	**length:** 0..33
                        
                        .. attribute:: extranet_interface
                        
                        	Is this an Extranet Interface ?
                        	**type**\: bool
                        
                        .. attribute:: internal_interest_information
                        
                        	Internal Interest. Replaces internal\-interest\-info
                        	**type**\:  :py:class:`PimInternalInterestInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimInternalInterestInfo>`
                        
                        .. attribute:: local_members_information
                        
                        	Local Information. Replaces local\-members
                        	**type**\:  :py:class:`PimShowLocalInterest <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowLocalInterest>`
                        
                        .. attribute:: assert_state
                        
                        	Assert State
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface, self).__init__()

                            self.yang_name = "outgoing-interface"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("assert-winner", ("assert_winner", Ipv6Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner))])
                            self._leafs = OrderedDict([
                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                                ('expiry', (YLeaf(YType.uint64, 'expiry'), ['int'])),
                                ('bgp_c_mcast_prune_delay_timer', (YLeaf(YType.uint64, 'bgp-c-mcast-prune-delay-timer'), ['int'])),
                                ('jp_timer', (YLeaf(YType.int32, 'jp-timer'), ['int'])),
                                ('jp_state', (YLeaf(YType.int32, 'jp-state'), ['int'])),
                                ('assert_timer', (YLeaf(YType.int32, 'assert-timer'), ['int'])),
                                ('local_members', (YLeaf(YType.int32, 'local-members'), ['int'])),
                                ('internal_interest_info', (YLeaf(YType.int32, 'internal-interest-info'), ['int'])),
                                ('forwarding_state', (YLeaf(YType.int32, 'forwarding-state'), ['int'])),
                                ('immediate_state', (YLeaf(YType.int32, 'immediate-state'), ['int'])),
                                ('last_hop', (YLeaf(YType.boolean, 'last-hop'), ['bool'])),
                                ('mldp_inband_mdt', (YLeaf(YType.boolean, 'mldp-inband-mdt'), ['bool'])),
                                ('mldp_stale', (YLeaf(YType.boolean, 'mldp-stale'), ['bool'])),
                                ('sa_prune', (YLeaf(YType.boolean, 'sa-prune'), ['bool'])),
                                ('admin_boundary', (YLeaf(YType.boolean, 'admin-boundary'), ['bool'])),
                                ('igmp_membership', (YLeaf(YType.boolean, 'igmp-membership'), ['bool'])),
                                ('mdt_safi_join', (YLeaf(YType.boolean, 'mdt-safi-join'), ['bool'])),
                                ('mvpn_safi_join', (YLeaf(YType.boolean, 'mvpn-safi-join'), ['bool'])),
                                ('local_mdt_join', (YLeaf(YType.boolean, 'local-mdt-join'), ['bool'])),
                                ('data_mdt_join', (YLeaf(YType.boolean, 'data-mdt-join'), ['bool'])),
                                ('mvpnv6_safi_join', (YLeaf(YType.boolean, 'mvpnv6-safi-join'), ['bool'])),
                                ('bgp_c_mcast_join', (YLeaf(YType.boolean, 'bgp-c-mcast-join'), ['bool'])),
                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                ('extranet_interface', (YLeaf(YType.boolean, 'extranet-interface'), ['bool'])),
                                ('internal_interest_information', (YLeaf(YType.enumeration, 'internal-interest-information'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimInternalInterestInfo', '')])),
                                ('local_members_information', (YLeaf(YType.enumeration, 'local-members-information'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowLocalInterest', '')])),
                                ('assert_state', (YLeaf(YType.boolean, 'assert-state'), ['bool'])),
                            ])
                            self.interface_name = None
                            self.uptime = None
                            self.expiry = None
                            self.bgp_c_mcast_prune_delay_timer = None
                            self.jp_timer = None
                            self.jp_state = None
                            self.assert_timer = None
                            self.local_members = None
                            self.internal_interest_info = None
                            self.forwarding_state = None
                            self.immediate_state = None
                            self.last_hop = None
                            self.mldp_inband_mdt = None
                            self.mldp_stale = None
                            self.sa_prune = None
                            self.admin_boundary = None
                            self.igmp_membership = None
                            self.mdt_safi_join = None
                            self.mvpn_safi_join = None
                            self.local_mdt_join = None
                            self.data_mdt_join = None
                            self.mvpnv6_safi_join = None
                            self.bgp_c_mcast_join = None
                            self.vrf_name = None
                            self.extranet_interface = None
                            self.internal_interest_information = None
                            self.local_members_information = None
                            self.assert_state = None

                            self.assert_winner = Ipv6Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner()
                            self.assert_winner.parent = self
                            self._children_name_map["assert_winner"] = "assert-winner"
                            self._segment_path = lambda: "outgoing-interface"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/topologies/topology/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface, ['interface_name', 'uptime', 'expiry', 'bgp_c_mcast_prune_delay_timer', 'jp_timer', 'jp_state', 'assert_timer', 'local_members', 'internal_interest_info', 'forwarding_state', 'immediate_state', 'last_hop', 'mldp_inband_mdt', 'mldp_stale', 'sa_prune', 'admin_boundary', 'igmp_membership', 'mdt_safi_join', 'mvpn_safi_join', 'local_mdt_join', 'data_mdt_join', 'mvpnv6_safi_join', 'bgp_c_mcast_join', 'vrf_name', 'extranet_interface', 'internal_interest_information', 'local_members_information', 'assert_state'], name, value)


                        class AssertWinner(Entity):
                            """
                            Assert Winner
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner, self).__init__()

                                self.yang_name = "assert-winner"
                                self.yang_parent_name = "outgoing-interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "assert-winner"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/topologies/topology/outgoing-interface/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class BgpAfs(Entity):
                """
                PIM BGP SAFI table
                
                .. attribute:: bgp_af
                
                	PIM BGP SAFI information
                	**type**\: list of  		 :py:class:`BgpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.BgpAfs, self).__init__()

                    self.yang_name = "bgp-afs"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("bgp-af", ("bgp_af", Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf))])
                    self._leafs = OrderedDict()

                    self.bgp_af = YList(self)
                    self._segment_path = lambda: "bgp-afs"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.BgpAfs, [], name, value)


                class BgpAf(Entity):
                    """
                    PIM BGP SAFI information
                    
                    .. attribute:: source_address
                    
                    	Source IP address
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: group_address
                    
                    	Group IP address
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: source
                    
                    	Source address
                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf.Source>`
                    
                    .. attribute:: group
                    
                    	Group address
                    	**type**\:  :py:class:`Group <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf.Group>`
                    
                    .. attribute:: next_hop
                    
                    	Next hop address
                    	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf.NextHop>`
                    
                    .. attribute:: route_distinguisher
                    
                    	Router ID
                    	**type**\: str
                    
                    	**length:** 0..256
                    
                    .. attribute:: extranet_path_count
                    
                    	Count of dependent extranet paths
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_bgp_added
                    
                    	SAFI learnt from BGP
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf, self).__init__()

                        self.yang_name = "bgp-af"
                        self.yang_parent_name = "bgp-afs"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("source", ("source", Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf.Source)), ("group", ("group", Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf.Group)), ("next-hop", ("next_hop", Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf.NextHop))])
                        self._leafs = OrderedDict([
                            ('source_address', (YLeaf(YType.str, 'source-address'), ['str','str'])),
                            ('group_address', (YLeaf(YType.str, 'group-address'), ['str','str'])),
                            ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                            ('extranet_path_count', (YLeaf(YType.uint32, 'extranet-path-count'), ['int'])),
                            ('is_bgp_added', (YLeaf(YType.boolean, 'is-bgp-added'), ['bool'])),
                        ])
                        self.source_address = None
                        self.group_address = None
                        self.route_distinguisher = None
                        self.extranet_path_count = None
                        self.is_bgp_added = None

                        self.source = Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf.Source()
                        self.source.parent = self
                        self._children_name_map["source"] = "source"

                        self.group = Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf.Group()
                        self.group.parent = self
                        self._children_name_map["group"] = "group"

                        self.next_hop = Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf.NextHop()
                        self.next_hop.parent = self
                        self._children_name_map["next_hop"] = "next-hop"
                        self._segment_path = lambda: "bgp-af"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/bgp-afs/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf, ['source_address', 'group_address', 'route_distinguisher', 'extranet_path_count', 'is_bgp_added'], name, value)


                    class Source(Entity):
                        """
                        Source address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf.Source, self).__init__()

                            self.yang_name = "source"
                            self.yang_parent_name = "bgp-af"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "source"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/bgp-afs/bgp-af/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf.Source, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class Group(Entity):
                        """
                        Group address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf.Group, self).__init__()

                            self.yang_name = "group"
                            self.yang_parent_name = "bgp-af"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "group"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/bgp-afs/bgp-af/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf.Group, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class NextHop(Entity):
                        """
                        Next hop address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf.NextHop, self).__init__()

                            self.yang_name = "next-hop"
                            self.yang_parent_name = "bgp-af"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "next-hop"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/bgp-afs/bgp-af/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf.NextHop, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class AutoRp(Entity):
                """
                PIM Auto\-RP information
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.AutoRp, self).__init__()

                    self.yang_name = "auto-rp"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "auto-rp"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True


            class TopologyInterfaceFlagRouteCounts(Entity):
                """
                Route count for topology with interface flag set
                
                .. attribute:: topology_interface_flag_route_count
                
                	Route count for topology with interface flag set
                	**type**\: list of  		 :py:class:`TopologyInterfaceFlagRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts, self).__init__()

                    self.yang_name = "topology-interface-flag-route-counts"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("topology-interface-flag-route-count", ("topology_interface_flag_route_count", Ipv6Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount))])
                    self._leafs = OrderedDict()

                    self.topology_interface_flag_route_count = YList(self)
                    self._segment_path = lambda: "topology-interface-flag-route-counts"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts, [], name, value)


                class TopologyInterfaceFlagRouteCount(Entity):
                    """
                    Route count for topology with interface flag
                    set
                    
                    .. attribute:: interface_flag  (key)
                    
                    	Interface flag
                    	**type**\:  :py:class:`PimTopologyInterfaceFlag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimTopologyInterfaceFlag>`
                    
                    .. attribute:: group_ranges
                    
                    	No. of (\*,G/M) routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: active_group_ranges
                    
                    	No. of (\*,G/M) routes active in mrib
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: groute_count
                    
                    	No. of (\*,G) routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sg_route_count
                    
                    	No. of (S,G) routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sgr_route_count
                    
                    	No. of (S,G)RPT routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount, self).__init__()

                        self.yang_name = "topology-interface-flag-route-count"
                        self.yang_parent_name = "topology-interface-flag-route-counts"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['interface_flag']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('interface_flag', (YLeaf(YType.enumeration, 'interface-flag'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimTopologyInterfaceFlag', '')])),
                            ('group_ranges', (YLeaf(YType.uint32, 'group-ranges'), ['int'])),
                            ('active_group_ranges', (YLeaf(YType.uint32, 'active-group-ranges'), ['int'])),
                            ('groute_count', (YLeaf(YType.uint32, 'groute-count'), ['int'])),
                            ('sg_route_count', (YLeaf(YType.uint32, 'sg-route-count'), ['int'])),
                            ('sgr_route_count', (YLeaf(YType.uint32, 'sgr-route-count'), ['int'])),
                            ('is_node_low_memory', (YLeaf(YType.boolean, 'is-node-low-memory'), ['bool'])),
                        ])
                        self.interface_flag = None
                        self.group_ranges = None
                        self.active_group_ranges = None
                        self.groute_count = None
                        self.sg_route_count = None
                        self.sgr_route_count = None
                        self.is_node_low_memory = None
                        self._segment_path = lambda: "topology-interface-flag-route-count" + "[interface-flag='" + str(self.interface_flag) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/topology-interface-flag-route-counts/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount, ['interface_flag', 'group_ranges', 'active_group_ranges', 'groute_count', 'sg_route_count', 'sgr_route_count', 'is_node_low_memory'], name, value)


            class GroupMapSources(Entity):
                """
                PIM group\-mapping with source information
                
                .. attribute:: group_map_source
                
                	PIM Group Mapping Entry with source information
                	**type**\: list of  		 :py:class:`GroupMapSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.GroupMapSources, self).__init__()

                    self.yang_name = "group-map-sources"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("group-map-source", ("group_map_source", Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource))])
                    self._leafs = OrderedDict()

                    self.group_map_source = YList(self)
                    self._segment_path = lambda: "group-map-sources"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.GroupMapSources, [], name, value)


                class GroupMapSource(Entity):
                    """
                    PIM Group Mapping Entry with source information
                    
                    .. attribute:: prefix
                    
                    	Prefix
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: client
                    
                    	Client
                    	**type**\:  :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                    
                    .. attribute:: protocol
                    
                    	Protocol
                    	**type**\:  :py:class:`PimProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimProtocol>`
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: priority
                    
                    	RP Priority
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: source_of_information
                    
                    	The source of information
                    	**type**\:  :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation>`
                    
                    .. attribute:: group_map_information
                    
                    	Group Mapping information
                    	**type**\:  :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation>`
                    
                    .. attribute:: holdtime
                    
                    	Holdtime in seconds
                    	**type**\: int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    .. attribute:: expires
                    
                    	Mapping expiry time in seconds
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: uptime
                    
                    	Mapping uptime in seconds
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource, self).__init__()

                        self.yang_name = "group-map-source"
                        self.yang_parent_name = "group-map-sources"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("source-of-information", ("source_of_information", Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation)), ("group-map-information", ("group_map_information", Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation))])
                        self._leafs = OrderedDict([
                            ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                            ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                            ('client', (YLeaf(YType.enumeration, 'client'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimClient', '')])),
                            ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimProtocol', '')])),
                            ('rp_address', (YLeaf(YType.str, 'rp-address'), ['str','str'])),
                            ('priority', (YLeaf(YType.uint32, 'priority'), ['int'])),
                            ('holdtime', (YLeaf(YType.int32, 'holdtime'), ['int'])),
                            ('expires', (YLeaf(YType.uint64, 'expires'), ['int'])),
                            ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                        ])
                        self.prefix = None
                        self.prefix_length = None
                        self.client = None
                        self.protocol = None
                        self.rp_address = None
                        self.priority = None
                        self.holdtime = None
                        self.expires = None
                        self.uptime = None

                        self.source_of_information = Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation()
                        self.source_of_information.parent = self
                        self._children_name_map["source_of_information"] = "source-of-information"

                        self.group_map_information = Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation()
                        self.group_map_information.parent = self
                        self._children_name_map["group_map_information"] = "group-map-information"
                        self._segment_path = lambda: "group-map-source"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/group-map-sources/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource, ['prefix', 'prefix_length', 'client', 'protocol', 'rp_address', 'priority', 'holdtime', 'expires', 'uptime'], name, value)


                    class SourceOfInformation(Entity):
                        """
                        The source of information
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation, self).__init__()

                            self.yang_name = "source-of-information"
                            self.yang_parent_name = "group-map-source"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "source-of-information"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/group-map-sources/group-map-source/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class GroupMapInformation(Entity):
                        """
                        Group Mapping information
                        
                        .. attribute:: prefix
                        
                        	Group range prefix
                        	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix>`
                        
                        .. attribute:: rp_address
                        
                        	Rendezvous Point Address
                        	**type**\:  :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress>`
                        
                        .. attribute:: prefix_length
                        
                        	Group range prefix length
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: client
                        
                        	Client mapping learnt from
                        	**type**\:  :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                        
                        .. attribute:: protocol
                        
                        	Protocol mode of the range
                        	**type**\:  :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: group_count
                        
                        	No. of groups in this range
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_used
                        
                        	Is this mapping being used?
                        	**type**\: bool
                        
                        .. attribute:: mrib_active
                        
                        	Is this mapping active in MRIB?
                        	**type**\: bool
                        
                        .. attribute:: is_override
                        
                        	Is this the override range?
                        	**type**\: bool
                        
                        .. attribute:: priority
                        
                        	Bootstrap priority
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation, self).__init__()

                            self.yang_name = "group-map-information"
                            self.yang_parent_name = "group-map-source"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("prefix", ("prefix", Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix)), ("rp-address", ("rp_address", Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress))])
                            self._leafs = OrderedDict([
                                ('prefix_length', (YLeaf(YType.int32, 'prefix-length'), ['int'])),
                                ('client', (YLeaf(YType.enumeration, 'client'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowRangeClient', '')])),
                                ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowProtocol', '')])),
                                ('group_count', (YLeaf(YType.uint32, 'group-count'), ['int'])),
                                ('is_used', (YLeaf(YType.boolean, 'is-used'), ['bool'])),
                                ('mrib_active', (YLeaf(YType.boolean, 'mrib-active'), ['bool'])),
                                ('is_override', (YLeaf(YType.boolean, 'is-override'), ['bool'])),
                                ('priority', (YLeaf(YType.uint32, 'priority'), ['int'])),
                            ])
                            self.prefix_length = None
                            self.client = None
                            self.protocol = None
                            self.group_count = None
                            self.is_used = None
                            self.mrib_active = None
                            self.is_override = None
                            self.priority = None

                            self.prefix = Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"

                            self.rp_address = Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"
                            self._segment_path = lambda: "group-map-information"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/group-map-sources/group-map-source/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation, ['prefix_length', 'client', 'protocol', 'group_count', 'is_used', 'mrib_active', 'is_override', 'priority'], name, value)


                        class Prefix(Entity):
                            """
                            Group range prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "group-map-information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "prefix"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/group-map-sources/group-map-source/group-map-information/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class RpAddress(Entity):
                            """
                            Rendezvous Point Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "group-map-information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "rp-address"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/group-map-sources/group-map-source/group-map-information/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class TrafficCounters(Entity):
                """
                PIM message traffic counters
                
                .. attribute:: elapsed_time
                
                	Running time for counters in seconds
                	**type**\: int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: inputs
                
                	Packets in
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: outputs
                
                	Packets out
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: format_error
                
                	Malformed packets in
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: pakman_error
                
                	Pakman packets dropped
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: standby_packets_error
                
                	Packets received in standby state
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: checksum_error
                
                	Checksum errors
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: socket_error
                
                	Socket errors
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: send_queue_full
                
                	Packets dropped since send queue was full
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: boundary_acl_rx_drop
                
                	Inc. JP dropped since boundary ACL confg
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: boundary_acl_tx_drop
                
                	Out JP dropped since boundary ACL confg
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: no_socket_connection
                
                	Packets dropped since no socket connection
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: no_source_address
                
                	Packets dropped since no source address
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_hello
                
                	Hello packets in
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_hello
                
                	Hello packets out
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_jp
                
                	Join Prune packets in
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_jp
                
                	Join Prune packets out
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_data_register
                
                	Data Register packets in
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_null_register
                
                	Null Register packets in
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_null_register
                
                	Null Register packets out
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_register_stop
                
                	Register Stop packets in
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_register_stop
                
                	Register Stop packets out
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_assert
                
                	Assert packets in
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_assert_batched
                
                	Batched Assert packets in
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_assert
                
                	Assert packets out
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_assert_batched
                
                	Batched Assert packets out
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_df_election
                
                	DF Election packets in
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_df_election
                
                	DF Election packets out
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_bsr_message
                
                	Input BSR Messages
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_bsr_message
                
                	Output BSR Messages
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_candidate_rp_advertisement
                
                	Input Candidate\-RP Advertisment
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_candidate_rp_advertisement
                
                	Output Candidate\-RP Advertisment
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_ecmp_redirect
                
                	Input Ecmp Redirect
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_ecmp_redirect
                
                	Output Ecmp Redirect
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_loop_error
                
                	Output on loopback error
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_invalid_lsm_identifier
                
                	 Invalid LSM ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_idb_error
                
                	No IDB for intf error
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_vrf_error
                
                	No VRF for idb error
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_pim_error
                
                	PIM Disabled on intf error
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_pim_version_error
                
                	Invalid PIM version error
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_join_group
                
                	Output Join Groups
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_prune_group
                
                	Output Prune Groups
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_join_prune_bytes
                
                	Output JP Bytes
                	**type**\: int
                
                	**range:** 0..4294967295
                
                	**units**\: byte
                
                .. attribute:: output_hello_bytes
                
                	Output Hello Bytes
                	**type**\: int
                
                	**range:** 0..4294967295
                
                	**units**\: byte
                
                .. attribute:: non_supported_packets
                
                	PIM non supported pckets
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: invalid_registers
                
                	PIM invalid registers received
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: invalid_join_prunes
                
                	PIM invalid Join/Prunes received
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_packman_error
                
                	Packets Dropped due to Pakman Error
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_read_socket_error
                
                	Packet Read Socket Error
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_queue_last_clear
                
                	Time in seconds since the last clear of all packet queues stats
                	**type**\: int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: packets_standby
                
                	Packets Dropped due to Standby Error
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: no_mdt_socket_connection
                
                	Packets dropped since no mdt socket connection
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_send_queue_full
                
                	Packets dropped since mdt send queue was full
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_socket_error
                
                	MDT Socket errors
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_join_tlv_sent
                
                	Data MDT Join Msgs sent
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_join_tlv_received
                
                	Data MDT Join Msgs received
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_join_bad_type
                
                	Data MDT TLV bad type
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_drop_local_source_address
                
                	Data MDT Join msgs dropped due to local source addr
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_drop_null_local_address
                
                	Data MDT Join msgs dropped due to null local addr
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_drop_no_idb
                
                	Data MDT Join msgs dropped due to idb missing
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_drop_no_vrf
                
                	Data MDT Join msgs dropped due to vrf missing
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: invalid_destination_packets
                
                	Control Packets with Invalid Destination
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_joins_drop_multiple_encapsulation
                
                	MDT Join msgs dropped due to multiple Encap limitation
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: truncated_pim_packets
                
                	Packets dropped due to truncated Joins or Prunes
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: invalid_source_encodings
                
                	Number of invalid source encodings received
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: invalid_hello_options
                
                	Number of invalid hello options received
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_queue
                
                	Packet queue state and statistics
                	**type**\: list of  		 :py:class:`PacketQueue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.TrafficCounters.PacketQueue>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.TrafficCounters, self).__init__()

                    self.yang_name = "traffic-counters"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("packet-queue", ("packet_queue", Ipv6Pim.Standby.DefaultContext.TrafficCounters.PacketQueue))])
                    self._leafs = OrderedDict([
                        ('elapsed_time', (YLeaf(YType.uint32, 'elapsed-time'), ['int'])),
                        ('inputs', (YLeaf(YType.uint32, 'inputs'), ['int'])),
                        ('outputs', (YLeaf(YType.uint32, 'outputs'), ['int'])),
                        ('format_error', (YLeaf(YType.uint32, 'format-error'), ['int'])),
                        ('pakman_error', (YLeaf(YType.uint32, 'pakman-error'), ['int'])),
                        ('standby_packets_error', (YLeaf(YType.uint32, 'standby-packets-error'), ['int'])),
                        ('checksum_error', (YLeaf(YType.uint32, 'checksum-error'), ['int'])),
                        ('socket_error', (YLeaf(YType.uint32, 'socket-error'), ['int'])),
                        ('send_queue_full', (YLeaf(YType.uint32, 'send-queue-full'), ['int'])),
                        ('boundary_acl_rx_drop', (YLeaf(YType.uint32, 'boundary-acl-rx-drop'), ['int'])),
                        ('boundary_acl_tx_drop', (YLeaf(YType.uint32, 'boundary-acl-tx-drop'), ['int'])),
                        ('no_socket_connection', (YLeaf(YType.uint32, 'no-socket-connection'), ['int'])),
                        ('no_source_address', (YLeaf(YType.uint32, 'no-source-address'), ['int'])),
                        ('input_hello', (YLeaf(YType.uint32, 'input-hello'), ['int'])),
                        ('output_hello', (YLeaf(YType.uint32, 'output-hello'), ['int'])),
                        ('input_jp', (YLeaf(YType.uint32, 'input-jp'), ['int'])),
                        ('output_jp', (YLeaf(YType.uint32, 'output-jp'), ['int'])),
                        ('input_data_register', (YLeaf(YType.uint32, 'input-data-register'), ['int'])),
                        ('input_null_register', (YLeaf(YType.uint32, 'input-null-register'), ['int'])),
                        ('output_null_register', (YLeaf(YType.uint32, 'output-null-register'), ['int'])),
                        ('input_register_stop', (YLeaf(YType.uint32, 'input-register-stop'), ['int'])),
                        ('output_register_stop', (YLeaf(YType.uint32, 'output-register-stop'), ['int'])),
                        ('input_assert', (YLeaf(YType.uint32, 'input-assert'), ['int'])),
                        ('input_assert_batched', (YLeaf(YType.uint32, 'input-assert-batched'), ['int'])),
                        ('output_assert', (YLeaf(YType.uint32, 'output-assert'), ['int'])),
                        ('output_assert_batched', (YLeaf(YType.uint32, 'output-assert-batched'), ['int'])),
                        ('input_df_election', (YLeaf(YType.uint32, 'input-df-election'), ['int'])),
                        ('output_df_election', (YLeaf(YType.uint32, 'output-df-election'), ['int'])),
                        ('input_bsr_message', (YLeaf(YType.uint32, 'input-bsr-message'), ['int'])),
                        ('output_bsr_message', (YLeaf(YType.uint32, 'output-bsr-message'), ['int'])),
                        ('input_candidate_rp_advertisement', (YLeaf(YType.uint32, 'input-candidate-rp-advertisement'), ['int'])),
                        ('output_candidate_rp_advertisement', (YLeaf(YType.uint32, 'output-candidate-rp-advertisement'), ['int'])),
                        ('input_ecmp_redirect', (YLeaf(YType.uint32, 'input-ecmp-redirect'), ['int'])),
                        ('output_ecmp_redirect', (YLeaf(YType.uint32, 'output-ecmp-redirect'), ['int'])),
                        ('output_loop_error', (YLeaf(YType.uint32, 'output-loop-error'), ['int'])),
                        ('mldp_mdt_invalid_lsm_identifier', (YLeaf(YType.uint32, 'mldp-mdt-invalid-lsm-identifier'), ['int'])),
                        ('input_no_idb_error', (YLeaf(YType.uint32, 'input-no-idb-error'), ['int'])),
                        ('input_no_vrf_error', (YLeaf(YType.uint32, 'input-no-vrf-error'), ['int'])),
                        ('input_no_pim_error', (YLeaf(YType.uint32, 'input-no-pim-error'), ['int'])),
                        ('input_pim_version_error', (YLeaf(YType.uint32, 'input-pim-version-error'), ['int'])),
                        ('output_join_group', (YLeaf(YType.uint32, 'output-join-group'), ['int'])),
                        ('output_prune_group', (YLeaf(YType.uint32, 'output-prune-group'), ['int'])),
                        ('output_join_prune_bytes', (YLeaf(YType.uint32, 'output-join-prune-bytes'), ['int'])),
                        ('output_hello_bytes', (YLeaf(YType.uint32, 'output-hello-bytes'), ['int'])),
                        ('non_supported_packets', (YLeaf(YType.uint32, 'non-supported-packets'), ['int'])),
                        ('invalid_registers', (YLeaf(YType.uint32, 'invalid-registers'), ['int'])),
                        ('invalid_join_prunes', (YLeaf(YType.uint32, 'invalid-join-prunes'), ['int'])),
                        ('packet_packman_error', (YLeaf(YType.uint32, 'packet-packman-error'), ['int'])),
                        ('packet_read_socket_error', (YLeaf(YType.uint32, 'packet-read-socket-error'), ['int'])),
                        ('packet_queue_last_clear', (YLeaf(YType.uint32, 'packet-queue-last-clear'), ['int'])),
                        ('packets_standby', (YLeaf(YType.uint32, 'packets-standby'), ['int'])),
                        ('no_mdt_socket_connection', (YLeaf(YType.uint32, 'no-mdt-socket-connection'), ['int'])),
                        ('mdt_send_queue_full', (YLeaf(YType.uint32, 'mdt-send-queue-full'), ['int'])),
                        ('mdt_socket_error', (YLeaf(YType.uint32, 'mdt-socket-error'), ['int'])),
                        ('mdt_join_tlv_sent', (YLeaf(YType.uint32, 'mdt-join-tlv-sent'), ['int'])),
                        ('mdt_join_tlv_received', (YLeaf(YType.uint32, 'mdt-join-tlv-received'), ['int'])),
                        ('mdt_join_bad_type', (YLeaf(YType.uint32, 'mdt-join-bad-type'), ['int'])),
                        ('mdt_drop_local_source_address', (YLeaf(YType.uint32, 'mdt-drop-local-source-address'), ['int'])),
                        ('mdt_drop_null_local_address', (YLeaf(YType.uint32, 'mdt-drop-null-local-address'), ['int'])),
                        ('mdt_drop_no_idb', (YLeaf(YType.uint32, 'mdt-drop-no-idb'), ['int'])),
                        ('mdt_drop_no_vrf', (YLeaf(YType.uint32, 'mdt-drop-no-vrf'), ['int'])),
                        ('invalid_destination_packets', (YLeaf(YType.uint32, 'invalid-destination-packets'), ['int'])),
                        ('mdt_joins_drop_multiple_encapsulation', (YLeaf(YType.uint32, 'mdt-joins-drop-multiple-encapsulation'), ['int'])),
                        ('truncated_pim_packets', (YLeaf(YType.uint32, 'truncated-pim-packets'), ['int'])),
                        ('invalid_source_encodings', (YLeaf(YType.uint32, 'invalid-source-encodings'), ['int'])),
                        ('invalid_hello_options', (YLeaf(YType.uint32, 'invalid-hello-options'), ['int'])),
                    ])
                    self.elapsed_time = None
                    self.inputs = None
                    self.outputs = None
                    self.format_error = None
                    self.pakman_error = None
                    self.standby_packets_error = None
                    self.checksum_error = None
                    self.socket_error = None
                    self.send_queue_full = None
                    self.boundary_acl_rx_drop = None
                    self.boundary_acl_tx_drop = None
                    self.no_socket_connection = None
                    self.no_source_address = None
                    self.input_hello = None
                    self.output_hello = None
                    self.input_jp = None
                    self.output_jp = None
                    self.input_data_register = None
                    self.input_null_register = None
                    self.output_null_register = None
                    self.input_register_stop = None
                    self.output_register_stop = None
                    self.input_assert = None
                    self.input_assert_batched = None
                    self.output_assert = None
                    self.output_assert_batched = None
                    self.input_df_election = None
                    self.output_df_election = None
                    self.input_bsr_message = None
                    self.output_bsr_message = None
                    self.input_candidate_rp_advertisement = None
                    self.output_candidate_rp_advertisement = None
                    self.input_ecmp_redirect = None
                    self.output_ecmp_redirect = None
                    self.output_loop_error = None
                    self.mldp_mdt_invalid_lsm_identifier = None
                    self.input_no_idb_error = None
                    self.input_no_vrf_error = None
                    self.input_no_pim_error = None
                    self.input_pim_version_error = None
                    self.output_join_group = None
                    self.output_prune_group = None
                    self.output_join_prune_bytes = None
                    self.output_hello_bytes = None
                    self.non_supported_packets = None
                    self.invalid_registers = None
                    self.invalid_join_prunes = None
                    self.packet_packman_error = None
                    self.packet_read_socket_error = None
                    self.packet_queue_last_clear = None
                    self.packets_standby = None
                    self.no_mdt_socket_connection = None
                    self.mdt_send_queue_full = None
                    self.mdt_socket_error = None
                    self.mdt_join_tlv_sent = None
                    self.mdt_join_tlv_received = None
                    self.mdt_join_bad_type = None
                    self.mdt_drop_local_source_address = None
                    self.mdt_drop_null_local_address = None
                    self.mdt_drop_no_idb = None
                    self.mdt_drop_no_vrf = None
                    self.invalid_destination_packets = None
                    self.mdt_joins_drop_multiple_encapsulation = None
                    self.truncated_pim_packets = None
                    self.invalid_source_encodings = None
                    self.invalid_hello_options = None

                    self.packet_queue = YList(self)
                    self._segment_path = lambda: "traffic-counters"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.TrafficCounters, ['elapsed_time', 'inputs', 'outputs', 'format_error', 'pakman_error', 'standby_packets_error', 'checksum_error', 'socket_error', 'send_queue_full', 'boundary_acl_rx_drop', 'boundary_acl_tx_drop', 'no_socket_connection', 'no_source_address', 'input_hello', 'output_hello', 'input_jp', 'output_jp', 'input_data_register', 'input_null_register', 'output_null_register', 'input_register_stop', 'output_register_stop', 'input_assert', 'input_assert_batched', 'output_assert', 'output_assert_batched', 'input_df_election', 'output_df_election', 'input_bsr_message', 'output_bsr_message', 'input_candidate_rp_advertisement', 'output_candidate_rp_advertisement', 'input_ecmp_redirect', 'output_ecmp_redirect', 'output_loop_error', 'mldp_mdt_invalid_lsm_identifier', 'input_no_idb_error', 'input_no_vrf_error', 'input_no_pim_error', 'input_pim_version_error', 'output_join_group', 'output_prune_group', 'output_join_prune_bytes', 'output_hello_bytes', 'non_supported_packets', 'invalid_registers', 'invalid_join_prunes', 'packet_packman_error', 'packet_read_socket_error', 'packet_queue_last_clear', 'packets_standby', 'no_mdt_socket_connection', 'mdt_send_queue_full', 'mdt_socket_error', 'mdt_join_tlv_sent', 'mdt_join_tlv_received', 'mdt_join_bad_type', 'mdt_drop_local_source_address', 'mdt_drop_null_local_address', 'mdt_drop_no_idb', 'mdt_drop_no_vrf', 'invalid_destination_packets', 'mdt_joins_drop_multiple_encapsulation', 'truncated_pim_packets', 'invalid_source_encodings', 'invalid_hello_options'], name, value)


                class PacketQueue(Entity):
                    """
                    Packet queue state and statistics
                    
                    .. attribute:: packet_queue_state
                    
                    	State of the queue
                    	**type**\:  :py:class:`PacketQueueState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState>`
                    
                    .. attribute:: packet_queue_stats
                    
                    	Statistics about the queue
                    	**type**\:  :py:class:`PacketQueueStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats>`
                    
                    .. attribute:: packet_queue_priority
                    
                    	Priority of this packet queue
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.TrafficCounters.PacketQueue, self).__init__()

                        self.yang_name = "packet-queue"
                        self.yang_parent_name = "traffic-counters"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("packet-queue-state", ("packet_queue_state", Ipv6Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState)), ("packet-queue-stats", ("packet_queue_stats", Ipv6Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats))])
                        self._leafs = OrderedDict([
                            ('packet_queue_priority', (YLeaf(YType.uint32, 'packet-queue-priority'), ['int'])),
                        ])
                        self.packet_queue_priority = None

                        self.packet_queue_state = Ipv6Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState()
                        self.packet_queue_state.parent = self
                        self._children_name_map["packet_queue_state"] = "packet-queue-state"

                        self.packet_queue_stats = Ipv6Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats()
                        self.packet_queue_stats.parent = self
                        self._children_name_map["packet_queue_stats"] = "packet-queue-stats"
                        self._segment_path = lambda: "packet-queue"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/traffic-counters/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.TrafficCounters.PacketQueue, ['packet_queue_priority'], name, value)


                    class PacketQueueState(Entity):
                        """
                        State of the queue
                        
                        .. attribute:: max_queue_size
                        
                        	Maximum size of queue in bytes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: byte
                        
                        .. attribute:: queue_size_bytes
                        
                        	Size of queue in bytes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: byte
                        
                        .. attribute:: queue_size_packets
                        
                        	Size of queue in number of packets
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState, self).__init__()

                            self.yang_name = "packet-queue-state"
                            self.yang_parent_name = "packet-queue"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('max_queue_size', (YLeaf(YType.uint32, 'max-queue-size'), ['int'])),
                                ('queue_size_bytes', (YLeaf(YType.uint32, 'queue-size-bytes'), ['int'])),
                                ('queue_size_packets', (YLeaf(YType.uint32, 'queue-size-packets'), ['int'])),
                            ])
                            self.max_queue_size = None
                            self.queue_size_bytes = None
                            self.queue_size_packets = None
                            self._segment_path = lambda: "packet-queue-state"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/traffic-counters/packet-queue/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState, ['max_queue_size', 'queue_size_bytes', 'queue_size_packets'], name, value)


                    class PacketQueueStats(Entity):
                        """
                        Statistics about the queue
                        
                        .. attribute:: enqueued_packets
                        
                        	Total number of packets enqueued to this queue
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: dequeued_packets
                        
                        	Total number of packets dequeued from this queue
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: high_water_mark_packets
                        
                        	Highest number of packets enqueued in this queue
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: high_water_mark_bytes
                        
                        	Highest number of bytes enqueued in this queue
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: byte
                        
                        .. attribute:: tail_drops
                        
                        	Number packets dropped from this queue due to max size
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats, self).__init__()

                            self.yang_name = "packet-queue-stats"
                            self.yang_parent_name = "packet-queue"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('enqueued_packets', (YLeaf(YType.uint32, 'enqueued-packets'), ['int'])),
                                ('dequeued_packets', (YLeaf(YType.uint32, 'dequeued-packets'), ['int'])),
                                ('high_water_mark_packets', (YLeaf(YType.uint32, 'high-water-mark-packets'), ['int'])),
                                ('high_water_mark_bytes', (YLeaf(YType.uint32, 'high-water-mark-bytes'), ['int'])),
                                ('tail_drops', (YLeaf(YType.uint32, 'tail-drops'), ['int'])),
                            ])
                            self.enqueued_packets = None
                            self.dequeued_packets = None
                            self.high_water_mark_packets = None
                            self.high_water_mark_bytes = None
                            self.tail_drops = None
                            self._segment_path = lambda: "packet-queue-stats"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/traffic-counters/packet-queue/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats, ['enqueued_packets', 'dequeued_packets', 'high_water_mark_packets', 'high_water_mark_bytes', 'tail_drops'], name, value)


            class GroupMapRpfs(Entity):
                """
                PIM group mapping information
                
                .. attribute:: group_map_rpf
                
                	PIM group mapping entry
                	**type**\: list of  		 :py:class:`GroupMapRpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.GroupMapRpfs, self).__init__()

                    self.yang_name = "group-map-rpfs"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("group-map-rpf", ("group_map_rpf", Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf))])
                    self._leafs = OrderedDict()

                    self.group_map_rpf = YList(self)
                    self._segment_path = lambda: "group-map-rpfs"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.GroupMapRpfs, [], name, value)


                class GroupMapRpf(Entity):
                    """
                    PIM group mapping entry
                    
                    .. attribute:: prefix
                    
                    	Prefix
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: client
                    
                    	Client
                    	**type**\:  :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                    
                    .. attribute:: protocol
                    
                    	Protocol
                    	**type**\:  :py:class:`PimProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimProtocol>`
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: rp_priority
                    
                    	RP priority
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rpf_neighbor
                    
                    	RPF neighbor to the RP
                    	**type**\:  :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor>`
                    
                    .. attribute:: group_map_information
                    
                    	Group Mapping information
                    	**type**\:  :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation>`
                    
                    .. attribute:: are_we_rp
                    
                    	Are we the RP?
                    	**type**\: bool
                    
                    .. attribute:: rpf_interface_name
                    
                    	RPF interface to the RP
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: rpf_vrf_name
                    
                    	RPF VRF Name
                    	**type**\: str
                    
                    	**length:** 0..33
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf, self).__init__()

                        self.yang_name = "group-map-rpf"
                        self.yang_parent_name = "group-map-rpfs"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("rpf-neighbor", ("rpf_neighbor", Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor)), ("group-map-information", ("group_map_information", Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation))])
                        self._leafs = OrderedDict([
                            ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                            ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                            ('client', (YLeaf(YType.enumeration, 'client'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimClient', '')])),
                            ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimProtocol', '')])),
                            ('rp_address', (YLeaf(YType.str, 'rp-address'), ['str','str'])),
                            ('rp_priority', (YLeaf(YType.uint32, 'rp-priority'), ['int'])),
                            ('are_we_rp', (YLeaf(YType.boolean, 'are-we-rp'), ['bool'])),
                            ('rpf_interface_name', (YLeaf(YType.str, 'rpf-interface-name'), ['str'])),
                            ('rpf_vrf_name', (YLeaf(YType.str, 'rpf-vrf-name'), ['str'])),
                        ])
                        self.prefix = None
                        self.prefix_length = None
                        self.client = None
                        self.protocol = None
                        self.rp_address = None
                        self.rp_priority = None
                        self.are_we_rp = None
                        self.rpf_interface_name = None
                        self.rpf_vrf_name = None

                        self.rpf_neighbor = Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor()
                        self.rpf_neighbor.parent = self
                        self._children_name_map["rpf_neighbor"] = "rpf-neighbor"

                        self.group_map_information = Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation()
                        self.group_map_information.parent = self
                        self._children_name_map["group_map_information"] = "group-map-information"
                        self._segment_path = lambda: "group-map-rpf"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/group-map-rpfs/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf, ['prefix', 'prefix_length', 'client', 'protocol', 'rp_address', 'rp_priority', 'are_we_rp', 'rpf_interface_name', 'rpf_vrf_name'], name, value)


                    class RpfNeighbor(Entity):
                        """
                        RPF neighbor to the RP
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor, self).__init__()

                            self.yang_name = "rpf-neighbor"
                            self.yang_parent_name = "group-map-rpf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "rpf-neighbor"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/group-map-rpfs/group-map-rpf/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class GroupMapInformation(Entity):
                        """
                        Group Mapping information
                        
                        .. attribute:: prefix
                        
                        	Group range prefix
                        	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix>`
                        
                        .. attribute:: rp_address
                        
                        	Rendezvous Point Address
                        	**type**\:  :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress>`
                        
                        .. attribute:: prefix_length
                        
                        	Group range prefix length
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: client
                        
                        	Client mapping learnt from
                        	**type**\:  :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                        
                        .. attribute:: protocol
                        
                        	Protocol mode of the range
                        	**type**\:  :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: group_count
                        
                        	No. of groups in this range
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_used
                        
                        	Is this mapping being used?
                        	**type**\: bool
                        
                        .. attribute:: mrib_active
                        
                        	Is this mapping active in MRIB?
                        	**type**\: bool
                        
                        .. attribute:: is_override
                        
                        	Is this the override range?
                        	**type**\: bool
                        
                        .. attribute:: priority
                        
                        	Bootstrap priority
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation, self).__init__()

                            self.yang_name = "group-map-information"
                            self.yang_parent_name = "group-map-rpf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("prefix", ("prefix", Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix)), ("rp-address", ("rp_address", Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress))])
                            self._leafs = OrderedDict([
                                ('prefix_length', (YLeaf(YType.int32, 'prefix-length'), ['int'])),
                                ('client', (YLeaf(YType.enumeration, 'client'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowRangeClient', '')])),
                                ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowProtocol', '')])),
                                ('group_count', (YLeaf(YType.uint32, 'group-count'), ['int'])),
                                ('is_used', (YLeaf(YType.boolean, 'is-used'), ['bool'])),
                                ('mrib_active', (YLeaf(YType.boolean, 'mrib-active'), ['bool'])),
                                ('is_override', (YLeaf(YType.boolean, 'is-override'), ['bool'])),
                                ('priority', (YLeaf(YType.uint32, 'priority'), ['int'])),
                            ])
                            self.prefix_length = None
                            self.client = None
                            self.protocol = None
                            self.group_count = None
                            self.is_used = None
                            self.mrib_active = None
                            self.is_override = None
                            self.priority = None

                            self.prefix = Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"

                            self.rp_address = Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"
                            self._segment_path = lambda: "group-map-information"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/group-map-rpfs/group-map-rpf/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation, ['prefix_length', 'client', 'protocol', 'group_count', 'is_used', 'mrib_active', 'is_override', 'priority'], name, value)


                        class Prefix(Entity):
                            """
                            Group range prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "group-map-information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "prefix"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/group-map-rpfs/group-map-rpf/group-map-information/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class RpAddress(Entity):
                            """
                            Rendezvous Point Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "group-map-information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "rp-address"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/group-map-rpfs/group-map-rpf/group-map-information/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class Summary(Entity):
                """
                PIM summary
                
                .. attribute:: route_limit
                
                	Maximum routes
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_count
                
                	Current routes
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_low_water_mark
                
                	The number of routes below which the throttle on route creation will be lifted
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_route_limit_reached
                
                	Is route creation throttled
                	**type**\: bool
                
                .. attribute:: topology_interface_state_limit
                
                	Maximum Topology Interface State count
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_count
                
                	Current Topology Interface State count
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: rxi_low_water_mark
                
                	The rxi below which the throttle on interface creation will be lifted
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: rxi_limit_reached
                
                	Is interface creation throttled
                	**type**\: bool
                
                .. attribute:: register_limit
                
                	Maximum registers
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_count
                
                	Current registers
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_limit_reached
                
                	Is PIM SM register handling throttled
                	**type**\: bool
                
                .. attribute:: ranges_limit
                
                	Maximum group ranges from Autorp
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: ranges_count
                
                	Current group ranges from Autorp
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: ranges_threshold
                
                	OOR theshold of grange ranges from AutoRP
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_ranges_limit_reached
                
                	Is Auto\-RP group\-to\-RP mapping range creation throttled
                	**type**\: bool
                
                .. attribute:: bsr_ranges_limit
                
                	Maximum group ranges from BSR
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_ranges_count
                
                	Current group ranges from BSR
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_range_threshold
                
                	Threshold group range from BSR
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_bsr_ranges_threshold_reached
                
                	Is VRF\-specific BSR group\-to\-RP mapping range creation throttled
                	**type**\: bool
                
                .. attribute:: bsr_candidate_rp_set_limit
                
                	Maximum crp\-set from BSR
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_candidate_rp_set_count
                
                	Current crp\-set count from BSR
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_candidate_rp_set_threshold
                
                	Threshold crp\-set from BSR
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_maximum_enforcement_disabled
                
                	Is maximum enforcement disabled
                	**type**\: bool
                
                .. attribute:: is_node_low_memory
                
                	Is node in low memory condition
                	**type**\: bool
                
                .. attribute:: route_threshold
                
                	Threshold routes
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_auto_rp_ranges_limit
                
                	Global Auto\-RP maximum group ranges
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_global_auto_rp_ranges_limit_reached
                
                	Is global AutoRP group\-to\-RP mapping range creation throttled
                	**type**\: bool
                
                .. attribute:: global_bsr_ranges_limit
                
                	Global BSR maximum group ranges
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_count
                
                	Global BSR current group ranges
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_threshold
                
                	Global BSR Threshold group ranges
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_global_bsr_ranges_limit_reached
                
                	Is global BSR group\-to\-RP mapping range creation throttled
                	**type**\: bool
                
                .. attribute:: global_bsr_candidate_rp_set_limit
                
                	Global BSR maximum crp\-set
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_count
                
                	Global BSR current crp\-set count
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_threshold
                
                	Global BSR Threshold crp\-set
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_global_route_limit_reached
                
                	Is global route creation throttled
                	**type**\: bool
                
                .. attribute:: topology_interface_state_threshold
                
                	Topology Interface State threshold
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_global_rxi_limit_reached
                
                	Is global interface creation throttled
                	**type**\: bool
                
                .. attribute:: register_threshold
                
                	Threshold registers
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_register_limit
                
                	Maximum global registers
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_global_register_limit_reached
                
                	Is global PIM SM register handling throttled
                	**type**\: bool
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.Summary, self).__init__()

                    self.yang_name = "summary"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('route_limit', (YLeaf(YType.uint32, 'route-limit'), ['int'])),
                        ('route_count', (YLeaf(YType.uint32, 'route-count'), ['int'])),
                        ('route_low_water_mark', (YLeaf(YType.uint32, 'route-low-water-mark'), ['int'])),
                        ('is_route_limit_reached', (YLeaf(YType.boolean, 'is-route-limit-reached'), ['bool'])),
                        ('topology_interface_state_limit', (YLeaf(YType.uint32, 'topology-interface-state-limit'), ['int'])),
                        ('topology_interface_state_count', (YLeaf(YType.uint32, 'topology-interface-state-count'), ['int'])),
                        ('rxi_low_water_mark', (YLeaf(YType.uint32, 'rxi-low-water-mark'), ['int'])),
                        ('rxi_limit_reached', (YLeaf(YType.boolean, 'rxi-limit-reached'), ['bool'])),
                        ('register_limit', (YLeaf(YType.uint32, 'register-limit'), ['int'])),
                        ('register_count', (YLeaf(YType.uint32, 'register-count'), ['int'])),
                        ('register_limit_reached', (YLeaf(YType.boolean, 'register-limit-reached'), ['bool'])),
                        ('ranges_limit', (YLeaf(YType.uint32, 'ranges-limit'), ['int'])),
                        ('ranges_count', (YLeaf(YType.uint32, 'ranges-count'), ['int'])),
                        ('ranges_threshold', (YLeaf(YType.uint32, 'ranges-threshold'), ['int'])),
                        ('is_ranges_limit_reached', (YLeaf(YType.boolean, 'is-ranges-limit-reached'), ['bool'])),
                        ('bsr_ranges_limit', (YLeaf(YType.uint32, 'bsr-ranges-limit'), ['int'])),
                        ('bsr_ranges_count', (YLeaf(YType.uint32, 'bsr-ranges-count'), ['int'])),
                        ('bsr_range_threshold', (YLeaf(YType.uint32, 'bsr-range-threshold'), ['int'])),
                        ('is_bsr_ranges_threshold_reached', (YLeaf(YType.boolean, 'is-bsr-ranges-threshold-reached'), ['bool'])),
                        ('bsr_candidate_rp_set_limit', (YLeaf(YType.uint32, 'bsr-candidate-rp-set-limit'), ['int'])),
                        ('bsr_candidate_rp_set_count', (YLeaf(YType.uint32, 'bsr-candidate-rp-set-count'), ['int'])),
                        ('bsr_candidate_rp_set_threshold', (YLeaf(YType.uint32, 'bsr-candidate-rp-set-threshold'), ['int'])),
                        ('is_maximum_enforcement_disabled', (YLeaf(YType.boolean, 'is-maximum-enforcement-disabled'), ['bool'])),
                        ('is_node_low_memory', (YLeaf(YType.boolean, 'is-node-low-memory'), ['bool'])),
                        ('route_threshold', (YLeaf(YType.uint32, 'route-threshold'), ['int'])),
                        ('global_auto_rp_ranges_limit', (YLeaf(YType.uint32, 'global-auto-rp-ranges-limit'), ['int'])),
                        ('is_global_auto_rp_ranges_limit_reached', (YLeaf(YType.boolean, 'is-global-auto-rp-ranges-limit-reached'), ['bool'])),
                        ('global_bsr_ranges_limit', (YLeaf(YType.uint32, 'global-bsr-ranges-limit'), ['int'])),
                        ('global_bsr_ranges_count', (YLeaf(YType.uint32, 'global-bsr-ranges-count'), ['int'])),
                        ('global_bsr_ranges_threshold', (YLeaf(YType.uint32, 'global-bsr-ranges-threshold'), ['int'])),
                        ('is_global_bsr_ranges_limit_reached', (YLeaf(YType.boolean, 'is-global-bsr-ranges-limit-reached'), ['bool'])),
                        ('global_bsr_candidate_rp_set_limit', (YLeaf(YType.uint32, 'global-bsr-candidate-rp-set-limit'), ['int'])),
                        ('global_bsr_candidate_rp_set_count', (YLeaf(YType.uint32, 'global-bsr-candidate-rp-set-count'), ['int'])),
                        ('global_bsr_candidate_rp_set_threshold', (YLeaf(YType.uint32, 'global-bsr-candidate-rp-set-threshold'), ['int'])),
                        ('is_global_route_limit_reached', (YLeaf(YType.boolean, 'is-global-route-limit-reached'), ['bool'])),
                        ('topology_interface_state_threshold', (YLeaf(YType.uint32, 'topology-interface-state-threshold'), ['int'])),
                        ('is_global_rxi_limit_reached', (YLeaf(YType.boolean, 'is-global-rxi-limit-reached'), ['bool'])),
                        ('register_threshold', (YLeaf(YType.uint32, 'register-threshold'), ['int'])),
                        ('global_register_limit', (YLeaf(YType.uint32, 'global-register-limit'), ['int'])),
                        ('is_global_register_limit_reached', (YLeaf(YType.boolean, 'is-global-register-limit-reached'), ['bool'])),
                    ])
                    self.route_limit = None
                    self.route_count = None
                    self.route_low_water_mark = None
                    self.is_route_limit_reached = None
                    self.topology_interface_state_limit = None
                    self.topology_interface_state_count = None
                    self.rxi_low_water_mark = None
                    self.rxi_limit_reached = None
                    self.register_limit = None
                    self.register_count = None
                    self.register_limit_reached = None
                    self.ranges_limit = None
                    self.ranges_count = None
                    self.ranges_threshold = None
                    self.is_ranges_limit_reached = None
                    self.bsr_ranges_limit = None
                    self.bsr_ranges_count = None
                    self.bsr_range_threshold = None
                    self.is_bsr_ranges_threshold_reached = None
                    self.bsr_candidate_rp_set_limit = None
                    self.bsr_candidate_rp_set_count = None
                    self.bsr_candidate_rp_set_threshold = None
                    self.is_maximum_enforcement_disabled = None
                    self.is_node_low_memory = None
                    self.route_threshold = None
                    self.global_auto_rp_ranges_limit = None
                    self.is_global_auto_rp_ranges_limit_reached = None
                    self.global_bsr_ranges_limit = None
                    self.global_bsr_ranges_count = None
                    self.global_bsr_ranges_threshold = None
                    self.is_global_bsr_ranges_limit_reached = None
                    self.global_bsr_candidate_rp_set_limit = None
                    self.global_bsr_candidate_rp_set_count = None
                    self.global_bsr_candidate_rp_set_threshold = None
                    self.is_global_route_limit_reached = None
                    self.topology_interface_state_threshold = None
                    self.is_global_rxi_limit_reached = None
                    self.register_threshold = None
                    self.global_register_limit = None
                    self.is_global_register_limit_reached = None
                    self._segment_path = lambda: "summary"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Summary, ['route_limit', 'route_count', 'route_low_water_mark', 'is_route_limit_reached', 'topology_interface_state_limit', 'topology_interface_state_count', 'rxi_low_water_mark', 'rxi_limit_reached', 'register_limit', 'register_count', 'register_limit_reached', 'ranges_limit', 'ranges_count', 'ranges_threshold', 'is_ranges_limit_reached', 'bsr_ranges_limit', 'bsr_ranges_count', 'bsr_range_threshold', 'is_bsr_ranges_threshold_reached', 'bsr_candidate_rp_set_limit', 'bsr_candidate_rp_set_count', 'bsr_candidate_rp_set_threshold', 'is_maximum_enforcement_disabled', 'is_node_low_memory', 'route_threshold', 'global_auto_rp_ranges_limit', 'is_global_auto_rp_ranges_limit_reached', 'global_bsr_ranges_limit', 'global_bsr_ranges_count', 'global_bsr_ranges_threshold', 'is_global_bsr_ranges_limit_reached', 'global_bsr_candidate_rp_set_limit', 'global_bsr_candidate_rp_set_count', 'global_bsr_candidate_rp_set_threshold', 'is_global_route_limit_reached', 'topology_interface_state_threshold', 'is_global_rxi_limit_reached', 'register_threshold', 'global_register_limit', 'is_global_register_limit_reached'], name, value)


            class Gre(Entity):
                """
                GRE information
                
                .. attribute:: gre_hashes
                
                	GRE hash
                	**type**\:  :py:class:`GreHashes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Gre.GreHashes>`
                
                .. attribute:: gre_next_hops
                
                	GRE destination neighbor table
                	**type**\:  :py:class:`GreNextHops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.Gre, self).__init__()

                    self.yang_name = "gre"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("gre-hashes", ("gre_hashes", Ipv6Pim.Standby.DefaultContext.Gre.GreHashes)), ("gre-next-hops", ("gre_next_hops", Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops))])
                    self._leafs = OrderedDict()

                    self.gre_hashes = Ipv6Pim.Standby.DefaultContext.Gre.GreHashes()
                    self.gre_hashes.parent = self
                    self._children_name_map["gre_hashes"] = "gre-hashes"

                    self.gre_next_hops = Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops()
                    self.gre_next_hops.parent = self
                    self._children_name_map["gre_next_hops"] = "gre-next-hops"
                    self._segment_path = lambda: "gre"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Gre, [], name, value)


                class GreHashes(Entity):
                    """
                    GRE hash
                    
                    .. attribute:: gre_hash
                    
                    	PIM GRE Hashed Underlying Interface
                    	**type**\: list of  		 :py:class:`GreHash <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Gre.GreHashes.GreHash>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.Gre.GreHashes, self).__init__()

                        self.yang_name = "gre-hashes"
                        self.yang_parent_name = "gre"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("gre-hash", ("gre_hash", Ipv6Pim.Standby.DefaultContext.Gre.GreHashes.GreHash))])
                        self._leafs = OrderedDict()

                        self.gre_hash = YList(self)
                        self._segment_path = lambda: "gre-hashes"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/gre/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Gre.GreHashes, [], name, value)


                    class GreHash(Entity):
                        """
                        PIM GRE Hashed Underlying Interface
                        
                        .. attribute:: source_address  (key)
                        
                        	Source address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: destination_address  (key)
                        
                        	Destination address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ifname  (key)
                        
                        	GRE Tunnel Interface
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: next_hop_interface
                        
                        	Next hop neighbor interface
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Gre.GreHashes.GreHash, self).__init__()

                            self.yang_name = "gre-hash"
                            self.yang_parent_name = "gre-hashes"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['source_address','destination_address','ifname']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('source_address', (YLeaf(YType.str, 'source-address'), ['str','str'])),
                                ('destination_address', (YLeaf(YType.str, 'destination-address'), ['str','str'])),
                                ('ifname', (YLeaf(YType.str, 'ifname'), ['str'])),
                                ('next_hop_interface', (YLeaf(YType.str, 'next-hop-interface'), ['str'])),
                            ])
                            self.source_address = None
                            self.destination_address = None
                            self.ifname = None
                            self.next_hop_interface = None
                            self._segment_path = lambda: "gre-hash" + "[source-address='" + str(self.source_address) + "']" + "[destination-address='" + str(self.destination_address) + "']" + "[ifname='" + str(self.ifname) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/gre/gre-hashes/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Gre.GreHashes.GreHash, ['source_address', 'destination_address', 'ifname', 'next_hop_interface'], name, value)


                class GreNextHops(Entity):
                    """
                    GRE destination neighbor table
                    
                    .. attribute:: gre_next_hop
                    
                    	PIM GRE address next\-hop information
                    	**type**\: list of  		 :py:class:`GreNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops, self).__init__()

                        self.yang_name = "gre-next-hops"
                        self.yang_parent_name = "gre"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("gre-next-hop", ("gre_next_hop", Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop))])
                        self._leafs = OrderedDict()

                        self.gre_next_hop = YList(self)
                        self._segment_path = lambda: "gre-next-hops"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/gre/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops, [], name, value)


                    class GreNextHop(Entity):
                        """
                        PIM GRE address next\-hop information
                        
                        .. attribute:: destination_address  (key)
                        
                        	GRE destination address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: registered_address
                        
                        	Address registered
                        	**type**\:  :py:class:`RegisteredAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress>`
                        
                        .. attribute:: metric
                        
                        	Metric
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: metric_preference
                        
                        	Metric preference
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_connected
                        
                        	Are we connected ?
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: gre_path
                        
                        	GRE Paths list
                        	**type**\: list of  		 :py:class:`GrePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop, self).__init__()

                            self.yang_name = "gre-next-hop"
                            self.yang_parent_name = "gre-next-hops"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['destination_address']
                            self._child_classes = OrderedDict([("registered-address", ("registered_address", Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress)), ("gre-path", ("gre_path", Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath))])
                            self._leafs = OrderedDict([
                                ('destination_address', (YLeaf(YType.str, 'destination-address'), ['str','str'])),
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                ('metric_preference', (YLeaf(YType.uint32, 'metric-preference'), ['int'])),
                                ('is_connected', (YLeaf(YType.uint8, 'is-connected'), ['int'])),
                            ])
                            self.destination_address = None
                            self.metric = None
                            self.metric_preference = None
                            self.is_connected = None

                            self.registered_address = Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress()
                            self.registered_address.parent = self
                            self._children_name_map["registered_address"] = "registered-address"

                            self.gre_path = YList(self)
                            self._segment_path = lambda: "gre-next-hop" + "[destination-address='" + str(self.destination_address) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/gre/gre-next-hops/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop, ['destination_address', 'metric', 'metric_preference', 'is_connected'], name, value)


                        class RegisteredAddress(Entity):
                            """
                            Address registered
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress, self).__init__()

                                self.yang_name = "registered-address"
                                self.yang_parent_name = "gre-next-hop"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "registered-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class GrePath(Entity):
                            """
                            GRE Paths list
                            
                            .. attribute:: gre_neighbor
                            
                            	GRE neighbor
                            	**type**\:  :py:class:`GreNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor>`
                            
                            .. attribute:: gre_next_hop
                            
                            	GRE nexthop
                            	**type**\:  :py:class:`GreNextHop_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop_>`
                            
                            .. attribute:: gre_interface_name
                            
                            	GRE Interface
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: is_gre_interface_disabled
                            
                            	Is the gre interface disabled ?
                            	**type**\: bool
                            
                            .. attribute:: is_via_lsm
                            
                            	Via LSM
                            	**type**\: bool
                            
                            .. attribute:: is_connector_attribute_present
                            
                            	Connector attribute present
                            	**type**\: bool
                            
                            .. attribute:: extranet_vrf_name
                            
                            	Extranet VRF name
                            	**type**\: str
                            
                            	**length:** 0..33
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath, self).__init__()

                                self.yang_name = "gre-path"
                                self.yang_parent_name = "gre-next-hop"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("gre-neighbor", ("gre_neighbor", Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor)), ("gre-next-hop", ("gre_next_hop", Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop_))])
                                self._leafs = OrderedDict([
                                    ('gre_interface_name', (YLeaf(YType.str, 'gre-interface-name'), ['str'])),
                                    ('is_gre_interface_disabled', (YLeaf(YType.boolean, 'is-gre-interface-disabled'), ['bool'])),
                                    ('is_via_lsm', (YLeaf(YType.boolean, 'is-via-lsm'), ['bool'])),
                                    ('is_connector_attribute_present', (YLeaf(YType.boolean, 'is-connector-attribute-present'), ['bool'])),
                                    ('extranet_vrf_name', (YLeaf(YType.str, 'extranet-vrf-name'), ['str'])),
                                ])
                                self.gre_interface_name = None
                                self.is_gre_interface_disabled = None
                                self.is_via_lsm = None
                                self.is_connector_attribute_present = None
                                self.extranet_vrf_name = None

                                self.gre_neighbor = Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor()
                                self.gre_neighbor.parent = self
                                self._children_name_map["gre_neighbor"] = "gre-neighbor"

                                self.gre_next_hop = Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop_()
                                self.gre_next_hop.parent = self
                                self._children_name_map["gre_next_hop"] = "gre-next-hop"
                                self._segment_path = lambda: "gre-path"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath, ['gre_interface_name', 'is_gre_interface_disabled', 'is_via_lsm', 'is_connector_attribute_present', 'extranet_vrf_name'], name, value)


                            class GreNeighbor(Entity):
                                """
                                GRE neighbor
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor, self).__init__()

                                    self.yang_name = "gre-neighbor"
                                    self.yang_parent_name = "gre-path"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "gre-neighbor"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                            class GreNextHop_(Entity):
                                """
                                GRE nexthop
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop_, self).__init__()

                                    self.yang_name = "gre-next-hop"
                                    self.yang_parent_name = "gre-path"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "gre-next-hop"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop_, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class BidirDfWinners(Entity):
                """
                Bidirectional PIM DF election winner table
                
                .. attribute:: bidir_df_winner
                
                	Bidirectional PIM DF election table entry
                	**type**\: list of  		 :py:class:`BidirDfWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.BidirDfWinners, self).__init__()

                    self.yang_name = "bidir-df-winners"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("bidir-df-winner", ("bidir_df_winner", Ipv6Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner))])
                    self._leafs = OrderedDict()

                    self.bidir_df_winner = YList(self)
                    self._segment_path = lambda: "bidir-df-winners"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.BidirDfWinners, [], name, value)


                class BidirDfWinner(Entity):
                    """
                    Bidirectional PIM DF election table entry
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: rp_address_xr
                    
                    	RP Address
                    	**type**\:  :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr>`
                    
                    .. attribute:: df_winner
                    
                    	DF Winner
                    	**type**\:  :py:class:`DfWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner>`
                    
                    .. attribute:: pim_interface_name
                    
                    	Interface Name
                    	**type**\: str
                    
                    .. attribute:: are_we_df
                    
                    	Are we DF
                    	**type**\: bool
                    
                    .. attribute:: rp_lan
                    
                    	Is this the RP LAN
                    	**type**\: bool
                    
                    .. attribute:: metric
                    
                    	Metric
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: metric_preference
                    
                    	Metric Preference
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner, self).__init__()

                        self.yang_name = "bidir-df-winner"
                        self.yang_parent_name = "bidir-df-winners"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("rp-address-xr", ("rp_address_xr", Ipv6Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr)), ("df-winner", ("df_winner", Ipv6Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner))])
                        self._leafs = OrderedDict([
                            ('rp_address', (YLeaf(YType.str, 'rp-address'), ['str','str'])),
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                            ('pim_interface_name', (YLeaf(YType.str, 'pim-interface-name'), ['str'])),
                            ('are_we_df', (YLeaf(YType.boolean, 'are-we-df'), ['bool'])),
                            ('rp_lan', (YLeaf(YType.boolean, 'rp-lan'), ['bool'])),
                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                            ('metric_preference', (YLeaf(YType.uint32, 'metric-preference'), ['int'])),
                            ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                        ])
                        self.rp_address = None
                        self.interface_name = None
                        self.pim_interface_name = None
                        self.are_we_df = None
                        self.rp_lan = None
                        self.metric = None
                        self.metric_preference = None
                        self.uptime = None

                        self.rp_address_xr = Ipv6Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr()
                        self.rp_address_xr.parent = self
                        self._children_name_map["rp_address_xr"] = "rp-address-xr"

                        self.df_winner = Ipv6Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner()
                        self.df_winner.parent = self
                        self._children_name_map["df_winner"] = "df-winner"
                        self._segment_path = lambda: "bidir-df-winner"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/bidir-df-winners/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner, ['rp_address', 'interface_name', 'pim_interface_name', 'are_we_df', 'rp_lan', 'metric', 'metric_preference', 'uptime'], name, value)


                    class RpAddressXr(Entity):
                        """
                        RP Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr, self).__init__()

                            self.yang_name = "rp-address-xr"
                            self.yang_parent_name = "bidir-df-winner"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "rp-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/bidir-df-winners/bidir-df-winner/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class DfWinner(Entity):
                        """
                        DF Winner
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner, self).__init__()

                            self.yang_name = "df-winner"
                            self.yang_parent_name = "bidir-df-winner"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "df-winner"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/bidir-df-winners/bidir-df-winner/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class TableContexts(Entity):
                """
                PIM table context list
                
                .. attribute:: table_context
                
                	PIM table context information
                	**type**\: list of  		 :py:class:`TableContext <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.TableContexts.TableContext>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.TableContexts, self).__init__()

                    self.yang_name = "table-contexts"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("table-context", ("table_context", Ipv6Pim.Standby.DefaultContext.TableContexts.TableContext))])
                    self._leafs = OrderedDict()

                    self.table_context = YList(self)
                    self._segment_path = lambda: "table-contexts"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.TableContexts, [], name, value)


                class TableContext(Entity):
                    """
                    PIM table context information
                    
                    .. attribute:: saf_name
                    
                    	SAF name
                    	**type**\:  :py:class:`PimSafi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimSafi>`
                    
                    .. attribute:: topology_name
                    
                    	Topology name
                    	**type**\: str
                    
                    	**length:** 1..32
                    
                    .. attribute:: afi
                    
                    	AFI
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: safi
                    
                    	SAFI
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_name
                    
                    	Table name
                    	**type**\: str
                    
                    .. attribute:: vrf_id
                    
                    	VRF ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_id
                    
                    	Table ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_active
                    
                    	Active status
                    	**type**\: bool
                    
                    .. attribute:: is_ital_registration_done
                    
                    	ITAL reg status
                    	**type**\: bool
                    
                    .. attribute:: is_rib_registration_done
                    
                    	RIB reg status
                    	**type**\: bool
                    
                    .. attribute:: is_rib_convergence_received
                    
                    	RIB Convergence receive status
                    	**type**\: bool
                    
                    .. attribute:: is_rib_convergence
                    
                    	RIB Convergence status
                    	**type**\: bool
                    
                    .. attribute:: rpf_registrations
                    
                    	RPF Registration count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.TableContexts.TableContext, self).__init__()

                        self.yang_name = "table-context"
                        self.yang_parent_name = "table-contexts"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('saf_name', (YLeaf(YType.enumeration, 'saf-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimSafi', '')])),
                            ('topology_name', (YLeaf(YType.str, 'topology-name'), ['str'])),
                            ('afi', (YLeaf(YType.uint32, 'afi'), ['int'])),
                            ('safi', (YLeaf(YType.uint32, 'safi'), ['int'])),
                            ('table_name', (YLeaf(YType.str, 'table-name'), ['str'])),
                            ('vrf_id', (YLeaf(YType.uint32, 'vrf-id'), ['int'])),
                            ('table_id', (YLeaf(YType.uint32, 'table-id'), ['int'])),
                            ('is_active', (YLeaf(YType.boolean, 'is-active'), ['bool'])),
                            ('is_ital_registration_done', (YLeaf(YType.boolean, 'is-ital-registration-done'), ['bool'])),
                            ('is_rib_registration_done', (YLeaf(YType.boolean, 'is-rib-registration-done'), ['bool'])),
                            ('is_rib_convergence_received', (YLeaf(YType.boolean, 'is-rib-convergence-received'), ['bool'])),
                            ('is_rib_convergence', (YLeaf(YType.boolean, 'is-rib-convergence'), ['bool'])),
                            ('rpf_registrations', (YLeaf(YType.uint32, 'rpf-registrations'), ['int'])),
                        ])
                        self.saf_name = None
                        self.topology_name = None
                        self.afi = None
                        self.safi = None
                        self.table_name = None
                        self.vrf_id = None
                        self.table_id = None
                        self.is_active = None
                        self.is_ital_registration_done = None
                        self.is_rib_registration_done = None
                        self.is_rib_convergence_received = None
                        self.is_rib_convergence = None
                        self.rpf_registrations = None
                        self._segment_path = lambda: "table-context"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/table-contexts/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.TableContexts.TableContext, ['saf_name', 'topology_name', 'afi', 'safi', 'table_name', 'vrf_id', 'table_id', 'is_active', 'is_ital_registration_done', 'is_rib_registration_done', 'is_rib_convergence_received', 'is_rib_convergence', 'rpf_registrations'], name, value)


            class NeighborSummaries(Entity):
                """
                PIM neighbor summary table
                
                .. attribute:: neighbor_summary
                
                	PIM neighbor summary information
                	**type**\: list of  		 :py:class:`NeighborSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.NeighborSummaries.NeighborSummary>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.NeighborSummaries, self).__init__()

                    self.yang_name = "neighbor-summaries"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("neighbor-summary", ("neighbor_summary", Ipv6Pim.Standby.DefaultContext.NeighborSummaries.NeighborSummary))])
                    self._leafs = OrderedDict()

                    self.neighbor_summary = YList(self)
                    self._segment_path = lambda: "neighbor-summaries"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.NeighborSummaries, [], name, value)


                class NeighborSummary(Entity):
                    """
                    PIM neighbor summary information
                    
                    .. attribute:: interface_name  (key)
                    
                    	Interface name
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: number_of_neighbors
                    
                    	Number of neighbors
                    	**type**\: int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: number_of_external_neighbors
                    
                    	Number of external neighbors
                    	**type**\: int
                    
                    	**range:** \-2147483648..2147483647
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.NeighborSummaries.NeighborSummary, self).__init__()

                        self.yang_name = "neighbor-summary"
                        self.yang_parent_name = "neighbor-summaries"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['interface_name']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                            ('number_of_neighbors', (YLeaf(YType.int32, 'number-of-neighbors'), ['int'])),
                            ('number_of_external_neighbors', (YLeaf(YType.int32, 'number-of-external-neighbors'), ['int'])),
                        ])
                        self.interface_name = None
                        self.number_of_neighbors = None
                        self.number_of_external_neighbors = None
                        self._segment_path = lambda: "neighbor-summary" + "[interface-name='" + str(self.interface_name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/neighbor-summaries/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.NeighborSummaries.NeighborSummary, ['interface_name', 'number_of_neighbors', 'number_of_external_neighbors'], name, value)


            class Context(Entity):
                """
                PIM context information
                
                .. attribute:: remote_default_group
                
                	Remote Default Group
                	**type**\:  :py:class:`RemoteDefaultGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Context.RemoteDefaultGroup>`
                
                .. attribute:: rpf_default_table
                
                	RPF Default Table
                	**type**\:  :py:class:`RpfDefaultTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Context.RpfDefaultTable>`
                
                .. attribute:: vrf_id
                
                	VRF ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: table_id
                
                	Table ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: murib_id
                
                	MURIB ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: rpf_id
                
                	RPF ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: remote_table_id
                
                	Remote Table ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_default_group
                
                	MDT Default group
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: mdt_source
                
                	MDT source
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: mdt_source_interface
                
                	MDT Source Interface Name
                	**type**\: str
                
                .. attribute:: mdt_interface
                
                	MDT handle
                	**type**\: str
                
                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                
                .. attribute:: mdt_gre_rpf_identifier
                
                	GRE\-MDT RPF Identifier
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_gre_remote_rpf_identifier
                
                	GRE\-MDT Remote RPF Identifier
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_unicast_rib_registration
                
                	Ucast RIB Registration
                	**type**\: bool
                
                .. attribute:: is_multicast_rib_registration
                
                	Mcast RIB Registration
                	**type**\: bool
                
                .. attribute:: is_active
                
                	Active
                	**type**\: bool
                
                .. attribute:: is_active_ital
                
                	Active ITAL
                	**type**\: bool
                
                .. attribute:: is_mrib_register
                
                	MRIB Register
                	**type**\: bool
                
                .. attribute:: is_mdt_owner
                
                	MDT Owner
                	**type**\: bool
                
                .. attribute:: is_routing_enabled
                
                	Routing Enabled
                	**type**\: bool
                
                .. attribute:: is_socket_add_required
                
                	VRF required on Socket
                	**type**\: bool
                
                .. attribute:: is_socket_added
                
                	VRF added on Socket
                	**type**\: bool
                
                .. attribute:: is_lpts_socket_add_required
                
                	VRF LPTS filter required on Socket
                	**type**\: bool
                
                .. attribute:: is_lpts_socket_added
                
                	VRF LPTS filter added on Socket
                	**type**\: bool
                
                .. attribute:: is_udp_socket_add_required
                
                	VRF added on UDP Socket
                	**type**\: bool
                
                .. attribute:: is_udp_socket_added
                
                	VRF added on UDP Socket
                	**type**\: bool
                
                .. attribute:: is_udp_socket_bind_required
                
                	VRF bind required on UDP Socket
                	**type**\: bool
                
                .. attribute:: is_udp_socket_bind
                
                	VRF bound on UDP Socket
                	**type**\: bool
                
                .. attribute:: is_register_injection_socket_add_required
                
                	VRF required on Register Injection Socket
                	**type**\: bool
                
                .. attribute:: is_register_injection_socket_added
                
                	VRF added on Register Injection Socket
                	**type**\: bool
                
                .. attribute:: is_register_injection_lpts_socket_add_required
                
                	VRF LPTS filter required on Register Injection Socket
                	**type**\: bool
                
                .. attribute:: is_register_injection_lpts_socket_added
                
                	VRF LPTS filter added on Register Injection Socket
                	**type**\: bool
                
                .. attribute:: is_m_host_publish_pending
                
                	Publish pending for MHost Default interface
                	**type**\: bool
                
                .. attribute:: mhost_interface
                
                	MHost handle
                	**type**\: str
                
                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                
                .. attribute:: mhost_default_interface_config
                
                	Configured Mhost Defint
                	**type**\: str
                
                .. attribute:: mdt_mtu
                
                	MDT MTU
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: maximum_mdt_aggregation
                
                	MDT max aggregation
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_data_switchover_interval
                
                	Data MDT Switchover interval
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_data_announce_interval
                
                	Data MDT Announce interval
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: non_default_vrf_count_on_socket
                
                	Count of non\-default vrfs on raw socket
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: neighbor_filter_name
                
                	Neighbor Filter Name
                	**type**\: str
                
                .. attribute:: mdt_neighbor_filter_name
                
                	MDT Neighbor Filter Name
                	**type**\: str
                
                .. attribute:: allow_rp_configured
                
                	Allow RP Configured
                	**type**\: bool
                
                .. attribute:: allow_rp_group_list
                
                	Allow RP Group\-List ACL Name
                	**type**\: str
                
                	**length:** 0..64
                
                .. attribute:: allow_rp_rp_list
                
                	Allow RP RP\-list ACL Name
                	**type**\: str
                
                	**length:** 0..64
                
                .. attribute:: sg_expiry_timer_configured
                
                	S,G Expiry Timer Configured
                	**type**\: bool
                
                .. attribute:: sg_expiry_time
                
                	S,G Expiry Time Configured, in seconds
                	**type**\: int
                
                	**range:** 0..65535
                
                	**units**\: second
                
                .. attribute:: sg_expiry_timer_sg_list
                
                	S,G expiry timer ACL name
                	**type**\: str
                
                	**length:** 0..64
                
                .. attribute:: mldp_mdt_name
                
                	MLDP MDT Name
                	**type**\: str
                
                .. attribute:: mldp_mdt_interface
                
                	MLDP MDT handle
                	**type**\: str
                
                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                
                .. attribute:: mldp_mdt_mtu
                
                	MLDP MDT MTU
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_maximum_mdt_aggregation
                
                	MLDP MDT max aggregation
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_data_switchover_interval
                
                	MLDP Data MDT Switchover interval
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_data_announce_interval
                
                	MLDP Data MDT Announce interval
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_rpf_identifier
                
                	MLDP RPF\-ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_remote_rpf_identifier
                
                	MLDP Remote RPF\-ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_create_mldp_mdt_interface
                
                	Create MLDP MDT interface
                	**type**\: bool
                
                .. attribute:: is_mldp_mdt_owner
                
                	MLDP MDT Owner
                	**type**\: bool
                
                .. attribute:: mldp_root_count
                
                	MLDP Root count
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_head_lsm_identifier
                
                	MLDP Head LSM\-ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_remote_head_lsm_identifier
                
                	MLDP Remote Head LSM\-ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: organization_unique_identifier
                
                	OUI for VPN\-ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: vpn_index
                
                	VPN Index
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_partitioned_mdt_configured
                
                	MLDP Partitioned MDT
                	**type**\: bool
                
                .. attribute:: mldp_remote_partitioned_mdt_configured
                
                	MLDP Remote Partitioned MDT
                	**type**\: bool
                
                .. attribute:: mldp_partioned_mp2m_ptree
                
                	MP2MP Partitioned MDT tree
                	**type**\: bool
                
                .. attribute:: mldp_partitioned_head_lsm_identifier
                
                	Partitioned MDT Head LSM\-ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_head_local_label
                
                	Partitioned MDT Head local label
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_partitioned_mdt_identifier
                
                	MLDP Partitioned MDT Identifier
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: bgp_auto_discovery_configured
                
                	BGP Auto\-Discovery configured
                	**type**\: bool
                
                .. attribute:: suppress_pim_data_mdt_tlv
                
                	Suppress PIM Data\-MDT TLV Announcements
                	**type**\: bool
                
                .. attribute:: inter_autonomous_system_enabled
                
                	Inter\-AS Enabled
                	**type**\: bool
                
                .. attribute:: bgp_source_active_announce
                
                	Send BGP Source\-Active Announcements
                	**type**\: bool
                
                .. attribute:: bgp_i_pmsi_added
                
                	BGP I\-PMSI Added
                	**type**\: bool
                
                .. attribute:: mldp_bsr_control_tree_added
                
                	MLDP BSR Control tree added
                	**type**\: bool
                
                .. attribute:: mldp_auto_rp_discovery_tree_added
                
                	MLDP Autorp Discovery Control tree added
                	**type**\: bool
                
                .. attribute:: mldp_auto_rp_announce_tree_added
                
                	MLDP Autorp Announce Control tree added
                	**type**\: bool
                
                .. attribute:: bgp_auto_discovery_type
                
                	BGP Auto Discovery Type
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_partitioned_mdt_control_identifier
                
                	Partitioned MDT Control Identifier
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_partitioned_ir_control_identifier
                
                	Partitioned IR MDT Control Identifier
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_control_head_lsm_identifier
                
                	MLDP MVPN Identifier
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: umh
                
                	Join UMH Core\-Tree
                	**type**\: bool
                
                .. attribute:: suppress_shared_tree_join
                
                	Suppress Shared\-Tree Joins
                	**type**\: bool
                
                .. attribute:: rsvp_te_mdt_name
                
                	RSVP\-TE MDT Name
                	**type**\: str
                
                .. attribute:: rsvp_te_mdt_interface
                
                	RSVP\-TEMDT handle
                	**type**\: str
                
                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                
                .. attribute:: rsvp_te_mdt_mtu
                
                	RSVP\-TEMDT MTU
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_maximum_mdt_aggregation
                
                	RSVP\-TE MDT max aggregation
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_data_switchover_interval
                
                	RSVP\-TE Data MDT Switchover interval
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_data_announce_interval
                
                	RSVP\-TE Data MDT Announce interval
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_rpf_identifier
                
                	RSVP\-TE RPF\-ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_create_rsvp_te_mdt_interface
                
                	Create RSVP\-TE MDT interface
                	**type**\: bool
                
                .. attribute:: is_rsvp_te_mdt_owner
                
                	RSVP\-TE MDT Owner
                	**type**\: bool
                
                .. attribute:: rsvp_te_mdt_static_p2mp_count
                
                	Number of Static P2MP\-TE MDT
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: p2mpte_li_drop
                
                	Route LI updates dropped for P2MP
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_name
                
                	IR MDT Name
                	**type**\: str
                
                .. attribute:: ir_mdt_interface
                
                	IRMDT handle
                	**type**\: str
                
                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                
                .. attribute:: ir_mdt_mtu
                
                	IRMDT MTU
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_maximum_mdt_aggregation
                
                	IR MDT max aggregation
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_data_switchover_interval
                
                	IR Data MDT Switchover interval
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_data_announce_interval
                
                	IR Data MDT Announce interval
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_rpf_identifier
                
                	IR RPF\-ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_tail_label
                
                	IR Tail Label
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_create_ir_mdt_interface
                
                	Create IR MDT interface
                	**type**\: bool
                
                .. attribute:: is_ir_mdt_owner
                
                	IR MDT Owner
                	**type**\: bool
                
                .. attribute:: in_b_and_mdt_name
                
                	Inband MDT Name
                	**type**\: str
                
                .. attribute:: in_b_and_mdt_interface
                
                	Inband MDT handle
                	**type**\: str
                
                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                
                .. attribute:: in_b_and_mdt_mtu
                
                	Inband MDT MTU
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_band_maximum_mdt_aggregation
                
                	Inband MDT max aggregation
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_b_and_mdt_data_switchover_interval
                
                	Inband Data MDT Switchover interval
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_b_and_mdt_data_announce_interval
                
                	Inband Data MDT Announce interval
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_b_and_mdt_rpf_identifier
                
                	Inband RPF\-ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_create_in_b_and_mdt_interface
                
                	Create Inband MDT interface
                	**type**\: bool
                
                .. attribute:: is_in_b_and_mdt_owner
                
                	Inband MDT Owner
                	**type**\: bool
                
                .. attribute:: in_band_signaling_local_enabled
                
                	Inband signaling Local enabled
                	**type**\: bool
                
                .. attribute:: in_band_signaling_remote_enabled
                
                	Inband signaling Remote enabled
                	**type**\: bool
                
                .. attribute:: valid_rd_present
                
                	RD is valid
                	**type**\: bool
                
                .. attribute:: stale_rd_present
                
                	RD is stale
                	**type**\: bool
                
                .. attribute:: route_distinguisher
                
                	RD value
                	**type**\: str
                
                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                
                .. attribute:: gin_b_and_mdt_name
                
                	Inband MDT Name
                	**type**\: str
                
                .. attribute:: gin_b_and_mdt_interface
                
                	Inband MDT handle
                	**type**\: str
                
                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                
                .. attribute:: gin_b_and_mdt_mtu
                
                	Inband MDT MTU
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: gin_band_maximum_mdt_aggregation
                
                	Inband MDT max aggregation
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: gin_b_and_mdt_data_switchover_interval
                
                	Inband Data MDT Switchover interval
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: gin_b_and_mdt_data_announce_interval
                
                	Inband Data MDT Announce interval
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: gin_b_and_mdt_rpf_identifier
                
                	Inband RPF\-ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_create_gin_b_and_mdt_interface
                
                	Create Inband MDT interface
                	**type**\: bool
                
                .. attribute:: is_gin_b_and_mdt_owner
                
                	Inband MDT Owner
                	**type**\: bool
                
                .. attribute:: is_pim_nsf_rib_converged
                
                	PIM NSF RIB converged
                	**type**\: bool
                
                .. attribute:: is_pim_nsf_rib_converge_received
                
                	PIM NSF RIB converge received
                	**type**\: bool
                
                .. attribute:: is_rib_multipath_enabled
                
                	PIM RIB multiplath enabled
                	**type**\: bool
                
                .. attribute:: is_rib_multipath_interface_hash
                
                	PIM RIB multipath interface hash
                	**type**\: bool
                
                .. attribute:: is_rib_multipath_source_hash
                
                	PIM RIB multipath source based hash
                	**type**\: bool
                
                .. attribute:: is_rib_multipath_source_next_hop_hash
                
                	PIM RIB multipath source\-nexthop hash
                	**type**\: bool
                
                .. attribute:: rump_enabled
                
                	PIM is using MuRIB
                	**type**\: bool
                
                .. attribute:: is_create_mdt_interface
                
                	Create MDT interface
                	**type**\: bool
                
                .. attribute:: is_auto_rp_listen_enabled
                
                	Auto RP Listen Enabled
                	**type**\: bool
                
                .. attribute:: is_all_interface_disable_operation
                
                	PIM all interface disable operation
                	**type**\: bool
                
                .. attribute:: is_default_granges
                
                	Default granges
                	**type**\: bool
                
                .. attribute:: is_auto_rp_listen_sock_add
                
                	Auto RP listen sock add
                	**type**\: bool
                
                .. attribute:: is_redistribution_reset
                
                	Pending redist reset
                	**type**\: bool
                
                .. attribute:: redistribution_reset_count
                
                	Redist reset count
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: rpf_policy_name
                
                	RPF topology selection route\-policy name
                	**type**\: str
                
                .. attribute:: table_count
                
                	Number of configured Tables
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: active_table_count
                
                	Number of active Tables
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: anycast_rp_policy_name
                
                	Anycast\-RP Policy Name
                	**type**\: str
                
                .. attribute:: anycast_rp_configured
                
                	Anycast\-RP config
                	**type**\: bool
                
                .. attribute:: bgp_remote_on
                
                	BGP remote interface status
                	**type**\: bool
                
                .. attribute:: bgp_remote_interface_name
                
                	BGP remote interface name
                	**type**\: str
                
                .. attribute:: bgp_remote_interface
                
                	BGP remote interface handle
                	**type**\: str
                
                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                
                .. attribute:: bgp_remote_address
                
                	BGP remote interface address
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: bgp_remote_state
                
                	BGP remote interface state
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: physical_interface_count
                
                	Enabled Physical Interface Count
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: virtual_interface_count
                
                	Enabled Virtual Interface Count
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: virtual_mlc_interface_name
                
                	Virtual master line card Interface
                	**type**\: str
                
                .. attribute:: mdt_immediate_switch
                
                	MDT Immediate Switch
                	**type**\: bool
                
                .. attribute:: mldp_root_address
                
                	MLDP Root addresses
                	**type**\: list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: export_route_target
                
                	Export Route Targets
                	**type**\: list of  		 :py:class:`ExportRouteTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Context.ExportRouteTarget>`
                
                .. attribute:: import_route_target
                
                	Import Route Targets
                	**type**\: list of  		 :py:class:`ImportRouteTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Context.ImportRouteTarget>`
                
                .. attribute:: anycast_rp_range
                
                	Anycast\-RP Ranges
                	**type**\: list of  		 :py:class:`AnycastRpRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Context.AnycastRpRange>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.Context, self).__init__()

                    self.yang_name = "context"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("remote-default-group", ("remote_default_group", Ipv6Pim.Standby.DefaultContext.Context.RemoteDefaultGroup)), ("rpf-default-table", ("rpf_default_table", Ipv6Pim.Standby.DefaultContext.Context.RpfDefaultTable)), ("export-route-target", ("export_route_target", Ipv6Pim.Standby.DefaultContext.Context.ExportRouteTarget)), ("import-route-target", ("import_route_target", Ipv6Pim.Standby.DefaultContext.Context.ImportRouteTarget)), ("anycast-rp-range", ("anycast_rp_range", Ipv6Pim.Standby.DefaultContext.Context.AnycastRpRange))])
                    self._leafs = OrderedDict([
                        ('vrf_id', (YLeaf(YType.uint32, 'vrf-id'), ['int'])),
                        ('table_id', (YLeaf(YType.uint32, 'table-id'), ['int'])),
                        ('murib_id', (YLeaf(YType.uint32, 'murib-id'), ['int'])),
                        ('rpf_id', (YLeaf(YType.uint32, 'rpf-id'), ['int'])),
                        ('remote_table_id', (YLeaf(YType.uint32, 'remote-table-id'), ['int'])),
                        ('mdt_default_group', (YLeaf(YType.str, 'mdt-default-group'), ['str'])),
                        ('mdt_source', (YLeaf(YType.str, 'mdt-source'), ['str'])),
                        ('mdt_source_interface', (YLeaf(YType.str, 'mdt-source-interface'), ['str'])),
                        ('mdt_interface', (YLeaf(YType.str, 'mdt-interface'), ['str'])),
                        ('mdt_gre_rpf_identifier', (YLeaf(YType.uint32, 'mdt-gre-rpf-identifier'), ['int'])),
                        ('mdt_gre_remote_rpf_identifier', (YLeaf(YType.uint32, 'mdt-gre-remote-rpf-identifier'), ['int'])),
                        ('is_unicast_rib_registration', (YLeaf(YType.boolean, 'is-unicast-rib-registration'), ['bool'])),
                        ('is_multicast_rib_registration', (YLeaf(YType.boolean, 'is-multicast-rib-registration'), ['bool'])),
                        ('is_active', (YLeaf(YType.boolean, 'is-active'), ['bool'])),
                        ('is_active_ital', (YLeaf(YType.boolean, 'is-active-ital'), ['bool'])),
                        ('is_mrib_register', (YLeaf(YType.boolean, 'is-mrib-register'), ['bool'])),
                        ('is_mdt_owner', (YLeaf(YType.boolean, 'is-mdt-owner'), ['bool'])),
                        ('is_routing_enabled', (YLeaf(YType.boolean, 'is-routing-enabled'), ['bool'])),
                        ('is_socket_add_required', (YLeaf(YType.boolean, 'is-socket-add-required'), ['bool'])),
                        ('is_socket_added', (YLeaf(YType.boolean, 'is-socket-added'), ['bool'])),
                        ('is_lpts_socket_add_required', (YLeaf(YType.boolean, 'is-lpts-socket-add-required'), ['bool'])),
                        ('is_lpts_socket_added', (YLeaf(YType.boolean, 'is-lpts-socket-added'), ['bool'])),
                        ('is_udp_socket_add_required', (YLeaf(YType.boolean, 'is-udp-socket-add-required'), ['bool'])),
                        ('is_udp_socket_added', (YLeaf(YType.boolean, 'is-udp-socket-added'), ['bool'])),
                        ('is_udp_socket_bind_required', (YLeaf(YType.boolean, 'is-udp-socket-bind-required'), ['bool'])),
                        ('is_udp_socket_bind', (YLeaf(YType.boolean, 'is-udp-socket-bind'), ['bool'])),
                        ('is_register_injection_socket_add_required', (YLeaf(YType.boolean, 'is-register-injection-socket-add-required'), ['bool'])),
                        ('is_register_injection_socket_added', (YLeaf(YType.boolean, 'is-register-injection-socket-added'), ['bool'])),
                        ('is_register_injection_lpts_socket_add_required', (YLeaf(YType.boolean, 'is-register-injection-lpts-socket-add-required'), ['bool'])),
                        ('is_register_injection_lpts_socket_added', (YLeaf(YType.boolean, 'is-register-injection-lpts-socket-added'), ['bool'])),
                        ('is_m_host_publish_pending', (YLeaf(YType.boolean, 'is-m-host-publish-pending'), ['bool'])),
                        ('mhost_interface', (YLeaf(YType.str, 'mhost-interface'), ['str'])),
                        ('mhost_default_interface_config', (YLeaf(YType.str, 'mhost-default-interface-config'), ['str'])),
                        ('mdt_mtu', (YLeaf(YType.uint32, 'mdt-mtu'), ['int'])),
                        ('maximum_mdt_aggregation', (YLeaf(YType.uint32, 'maximum-mdt-aggregation'), ['int'])),
                        ('mdt_data_switchover_interval', (YLeaf(YType.uint32, 'mdt-data-switchover-interval'), ['int'])),
                        ('mdt_data_announce_interval', (YLeaf(YType.uint32, 'mdt-data-announce-interval'), ['int'])),
                        ('non_default_vrf_count_on_socket', (YLeaf(YType.uint32, 'non-default-vrf-count-on-socket'), ['int'])),
                        ('neighbor_filter_name', (YLeaf(YType.str, 'neighbor-filter-name'), ['str'])),
                        ('mdt_neighbor_filter_name', (YLeaf(YType.str, 'mdt-neighbor-filter-name'), ['str'])),
                        ('allow_rp_configured', (YLeaf(YType.boolean, 'allow-rp-configured'), ['bool'])),
                        ('allow_rp_group_list', (YLeaf(YType.str, 'allow-rp-group-list'), ['str'])),
                        ('allow_rp_rp_list', (YLeaf(YType.str, 'allow-rp-rp-list'), ['str'])),
                        ('sg_expiry_timer_configured', (YLeaf(YType.boolean, 'sg-expiry-timer-configured'), ['bool'])),
                        ('sg_expiry_time', (YLeaf(YType.uint16, 'sg-expiry-time'), ['int'])),
                        ('sg_expiry_timer_sg_list', (YLeaf(YType.str, 'sg-expiry-timer-sg-list'), ['str'])),
                        ('mldp_mdt_name', (YLeaf(YType.str, 'mldp-mdt-name'), ['str'])),
                        ('mldp_mdt_interface', (YLeaf(YType.str, 'mldp-mdt-interface'), ['str'])),
                        ('mldp_mdt_mtu', (YLeaf(YType.uint32, 'mldp-mdt-mtu'), ['int'])),
                        ('mldp_maximum_mdt_aggregation', (YLeaf(YType.uint32, 'mldp-maximum-mdt-aggregation'), ['int'])),
                        ('mldp_mdt_data_switchover_interval', (YLeaf(YType.uint32, 'mldp-mdt-data-switchover-interval'), ['int'])),
                        ('mldp_mdt_data_announce_interval', (YLeaf(YType.uint32, 'mldp-mdt-data-announce-interval'), ['int'])),
                        ('mldp_mdt_rpf_identifier', (YLeaf(YType.uint32, 'mldp-mdt-rpf-identifier'), ['int'])),
                        ('mldp_mdt_remote_rpf_identifier', (YLeaf(YType.uint32, 'mldp-mdt-remote-rpf-identifier'), ['int'])),
                        ('is_create_mldp_mdt_interface', (YLeaf(YType.boolean, 'is-create-mldp-mdt-interface'), ['bool'])),
                        ('is_mldp_mdt_owner', (YLeaf(YType.boolean, 'is-mldp-mdt-owner'), ['bool'])),
                        ('mldp_root_count', (YLeaf(YType.uint32, 'mldp-root-count'), ['int'])),
                        ('mldp_head_lsm_identifier', (YLeaf(YType.uint32, 'mldp-head-lsm-identifier'), ['int'])),
                        ('mldp_remote_head_lsm_identifier', (YLeaf(YType.uint32, 'mldp-remote-head-lsm-identifier'), ['int'])),
                        ('organization_unique_identifier', (YLeaf(YType.uint32, 'organization-unique-identifier'), ['int'])),
                        ('vpn_index', (YLeaf(YType.uint32, 'vpn-index'), ['int'])),
                        ('mldp_partitioned_mdt_configured', (YLeaf(YType.boolean, 'mldp-partitioned-mdt-configured'), ['bool'])),
                        ('mldp_remote_partitioned_mdt_configured', (YLeaf(YType.boolean, 'mldp-remote-partitioned-mdt-configured'), ['bool'])),
                        ('mldp_partioned_mp2m_ptree', (YLeaf(YType.boolean, 'mldp-partioned-mp2m-ptree'), ['bool'])),
                        ('mldp_partitioned_head_lsm_identifier', (YLeaf(YType.uint32, 'mldp-partitioned-head-lsm-identifier'), ['int'])),
                        ('mldp_head_local_label', (YLeaf(YType.uint32, 'mldp-head-local-label'), ['int'])),
                        ('mldp_partitioned_mdt_identifier', (YLeaf(YType.uint32, 'mldp-partitioned-mdt-identifier'), ['int'])),
                        ('bgp_auto_discovery_configured', (YLeaf(YType.boolean, 'bgp-auto-discovery-configured'), ['bool'])),
                        ('suppress_pim_data_mdt_tlv', (YLeaf(YType.boolean, 'suppress-pim-data-mdt-tlv'), ['bool'])),
                        ('inter_autonomous_system_enabled', (YLeaf(YType.boolean, 'inter-autonomous-system-enabled'), ['bool'])),
                        ('bgp_source_active_announce', (YLeaf(YType.boolean, 'bgp-source-active-announce'), ['bool'])),
                        ('bgp_i_pmsi_added', (YLeaf(YType.boolean, 'bgp-i-pmsi-added'), ['bool'])),
                        ('mldp_bsr_control_tree_added', (YLeaf(YType.boolean, 'mldp-bsr-control-tree-added'), ['bool'])),
                        ('mldp_auto_rp_discovery_tree_added', (YLeaf(YType.boolean, 'mldp-auto-rp-discovery-tree-added'), ['bool'])),
                        ('mldp_auto_rp_announce_tree_added', (YLeaf(YType.boolean, 'mldp-auto-rp-announce-tree-added'), ['bool'])),
                        ('bgp_auto_discovery_type', (YLeaf(YType.uint32, 'bgp-auto-discovery-type'), ['int'])),
                        ('mdt_partitioned_mdt_control_identifier', (YLeaf(YType.uint32, 'mdt-partitioned-mdt-control-identifier'), ['int'])),
                        ('mdt_partitioned_ir_control_identifier', (YLeaf(YType.uint32, 'mdt-partitioned-ir-control-identifier'), ['int'])),
                        ('mldp_control_head_lsm_identifier', (YLeaf(YType.uint32, 'mldp-control-head-lsm-identifier'), ['int'])),
                        ('umh', (YLeaf(YType.boolean, 'umh'), ['bool'])),
                        ('suppress_shared_tree_join', (YLeaf(YType.boolean, 'suppress-shared-tree-join'), ['bool'])),
                        ('rsvp_te_mdt_name', (YLeaf(YType.str, 'rsvp-te-mdt-name'), ['str'])),
                        ('rsvp_te_mdt_interface', (YLeaf(YType.str, 'rsvp-te-mdt-interface'), ['str'])),
                        ('rsvp_te_mdt_mtu', (YLeaf(YType.uint32, 'rsvp-te-mdt-mtu'), ['int'])),
                        ('rsvp_te_maximum_mdt_aggregation', (YLeaf(YType.uint32, 'rsvp-te-maximum-mdt-aggregation'), ['int'])),
                        ('rsvp_te_mdt_data_switchover_interval', (YLeaf(YType.uint32, 'rsvp-te-mdt-data-switchover-interval'), ['int'])),
                        ('rsvp_te_mdt_data_announce_interval', (YLeaf(YType.uint32, 'rsvp-te-mdt-data-announce-interval'), ['int'])),
                        ('rsvp_te_mdt_rpf_identifier', (YLeaf(YType.uint32, 'rsvp-te-mdt-rpf-identifier'), ['int'])),
                        ('is_create_rsvp_te_mdt_interface', (YLeaf(YType.boolean, 'is-create-rsvp-te-mdt-interface'), ['bool'])),
                        ('is_rsvp_te_mdt_owner', (YLeaf(YType.boolean, 'is-rsvp-te-mdt-owner'), ['bool'])),
                        ('rsvp_te_mdt_static_p2mp_count', (YLeaf(YType.uint32, 'rsvp-te-mdt-static-p2mp-count'), ['int'])),
                        ('p2mpte_li_drop', (YLeaf(YType.uint32, 'p2mpte-li-drop'), ['int'])),
                        ('ir_mdt_name', (YLeaf(YType.str, 'ir-mdt-name'), ['str'])),
                        ('ir_mdt_interface', (YLeaf(YType.str, 'ir-mdt-interface'), ['str'])),
                        ('ir_mdt_mtu', (YLeaf(YType.uint32, 'ir-mdt-mtu'), ['int'])),
                        ('ir_maximum_mdt_aggregation', (YLeaf(YType.uint32, 'ir-maximum-mdt-aggregation'), ['int'])),
                        ('ir_mdt_data_switchover_interval', (YLeaf(YType.uint32, 'ir-mdt-data-switchover-interval'), ['int'])),
                        ('ir_mdt_data_announce_interval', (YLeaf(YType.uint32, 'ir-mdt-data-announce-interval'), ['int'])),
                        ('ir_mdt_rpf_identifier', (YLeaf(YType.uint32, 'ir-mdt-rpf-identifier'), ['int'])),
                        ('ir_mdt_tail_label', (YLeaf(YType.uint32, 'ir-mdt-tail-label'), ['int'])),
                        ('is_create_ir_mdt_interface', (YLeaf(YType.boolean, 'is-create-ir-mdt-interface'), ['bool'])),
                        ('is_ir_mdt_owner', (YLeaf(YType.boolean, 'is-ir-mdt-owner'), ['bool'])),
                        ('in_b_and_mdt_name', (YLeaf(YType.str, 'in-b-and-mdt-name'), ['str'])),
                        ('in_b_and_mdt_interface', (YLeaf(YType.str, 'in-b-and-mdt-interface'), ['str'])),
                        ('in_b_and_mdt_mtu', (YLeaf(YType.uint32, 'in-b-and-mdt-mtu'), ['int'])),
                        ('in_band_maximum_mdt_aggregation', (YLeaf(YType.uint32, 'in-band-maximum-mdt-aggregation'), ['int'])),
                        ('in_b_and_mdt_data_switchover_interval', (YLeaf(YType.uint32, 'in-b-and-mdt-data-switchover-interval'), ['int'])),
                        ('in_b_and_mdt_data_announce_interval', (YLeaf(YType.uint32, 'in-b-and-mdt-data-announce-interval'), ['int'])),
                        ('in_b_and_mdt_rpf_identifier', (YLeaf(YType.uint32, 'in-b-and-mdt-rpf-identifier'), ['int'])),
                        ('is_create_in_b_and_mdt_interface', (YLeaf(YType.boolean, 'is-create-in-b-and-mdt-interface'), ['bool'])),
                        ('is_in_b_and_mdt_owner', (YLeaf(YType.boolean, 'is-in-b-and-mdt-owner'), ['bool'])),
                        ('in_band_signaling_local_enabled', (YLeaf(YType.boolean, 'in-band-signaling-local-enabled'), ['bool'])),
                        ('in_band_signaling_remote_enabled', (YLeaf(YType.boolean, 'in-band-signaling-remote-enabled'), ['bool'])),
                        ('valid_rd_present', (YLeaf(YType.boolean, 'valid-rd-present'), ['bool'])),
                        ('stale_rd_present', (YLeaf(YType.boolean, 'stale-rd-present'), ['bool'])),
                        ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                        ('gin_b_and_mdt_name', (YLeaf(YType.str, 'gin-b-and-mdt-name'), ['str'])),
                        ('gin_b_and_mdt_interface', (YLeaf(YType.str, 'gin-b-and-mdt-interface'), ['str'])),
                        ('gin_b_and_mdt_mtu', (YLeaf(YType.uint32, 'gin-b-and-mdt-mtu'), ['int'])),
                        ('gin_band_maximum_mdt_aggregation', (YLeaf(YType.uint32, 'gin-band-maximum-mdt-aggregation'), ['int'])),
                        ('gin_b_and_mdt_data_switchover_interval', (YLeaf(YType.uint32, 'gin-b-and-mdt-data-switchover-interval'), ['int'])),
                        ('gin_b_and_mdt_data_announce_interval', (YLeaf(YType.uint32, 'gin-b-and-mdt-data-announce-interval'), ['int'])),
                        ('gin_b_and_mdt_rpf_identifier', (YLeaf(YType.uint32, 'gin-b-and-mdt-rpf-identifier'), ['int'])),
                        ('is_create_gin_b_and_mdt_interface', (YLeaf(YType.boolean, 'is-create-gin-b-and-mdt-interface'), ['bool'])),
                        ('is_gin_b_and_mdt_owner', (YLeaf(YType.boolean, 'is-gin-b-and-mdt-owner'), ['bool'])),
                        ('is_pim_nsf_rib_converged', (YLeaf(YType.boolean, 'is-pim-nsf-rib-converged'), ['bool'])),
                        ('is_pim_nsf_rib_converge_received', (YLeaf(YType.boolean, 'is-pim-nsf-rib-converge-received'), ['bool'])),
                        ('is_rib_multipath_enabled', (YLeaf(YType.boolean, 'is-rib-multipath-enabled'), ['bool'])),
                        ('is_rib_multipath_interface_hash', (YLeaf(YType.boolean, 'is-rib-multipath-interface-hash'), ['bool'])),
                        ('is_rib_multipath_source_hash', (YLeaf(YType.boolean, 'is-rib-multipath-source-hash'), ['bool'])),
                        ('is_rib_multipath_source_next_hop_hash', (YLeaf(YType.boolean, 'is-rib-multipath-source-next-hop-hash'), ['bool'])),
                        ('rump_enabled', (YLeaf(YType.boolean, 'rump-enabled'), ['bool'])),
                        ('is_create_mdt_interface', (YLeaf(YType.boolean, 'is-create-mdt-interface'), ['bool'])),
                        ('is_auto_rp_listen_enabled', (YLeaf(YType.boolean, 'is-auto-rp-listen-enabled'), ['bool'])),
                        ('is_all_interface_disable_operation', (YLeaf(YType.boolean, 'is-all-interface-disable-operation'), ['bool'])),
                        ('is_default_granges', (YLeaf(YType.boolean, 'is-default-granges'), ['bool'])),
                        ('is_auto_rp_listen_sock_add', (YLeaf(YType.boolean, 'is-auto-rp-listen-sock-add'), ['bool'])),
                        ('is_redistribution_reset', (YLeaf(YType.boolean, 'is-redistribution-reset'), ['bool'])),
                        ('redistribution_reset_count', (YLeaf(YType.uint32, 'redistribution-reset-count'), ['int'])),
                        ('rpf_policy_name', (YLeaf(YType.str, 'rpf-policy-name'), ['str'])),
                        ('table_count', (YLeaf(YType.uint32, 'table-count'), ['int'])),
                        ('active_table_count', (YLeaf(YType.uint32, 'active-table-count'), ['int'])),
                        ('anycast_rp_policy_name', (YLeaf(YType.str, 'anycast-rp-policy-name'), ['str'])),
                        ('anycast_rp_configured', (YLeaf(YType.boolean, 'anycast-rp-configured'), ['bool'])),
                        ('bgp_remote_on', (YLeaf(YType.boolean, 'bgp-remote-on'), ['bool'])),
                        ('bgp_remote_interface_name', (YLeaf(YType.str, 'bgp-remote-interface-name'), ['str'])),
                        ('bgp_remote_interface', (YLeaf(YType.str, 'bgp-remote-interface'), ['str'])),
                        ('bgp_remote_address', (YLeaf(YType.str, 'bgp-remote-address'), ['str'])),
                        ('bgp_remote_state', (YLeaf(YType.uint32, 'bgp-remote-state'), ['int'])),
                        ('physical_interface_count', (YLeaf(YType.uint64, 'physical-interface-count'), ['int'])),
                        ('virtual_interface_count', (YLeaf(YType.uint64, 'virtual-interface-count'), ['int'])),
                        ('virtual_mlc_interface_name', (YLeaf(YType.str, 'virtual-mlc-interface-name'), ['str'])),
                        ('mdt_immediate_switch', (YLeaf(YType.boolean, 'mdt-immediate-switch'), ['bool'])),
                        ('mldp_root_address', (YLeafList(YType.uint32, 'mldp-root-address'), ['int'])),
                    ])
                    self.vrf_id = None
                    self.table_id = None
                    self.murib_id = None
                    self.rpf_id = None
                    self.remote_table_id = None
                    self.mdt_default_group = None
                    self.mdt_source = None
                    self.mdt_source_interface = None
                    self.mdt_interface = None
                    self.mdt_gre_rpf_identifier = None
                    self.mdt_gre_remote_rpf_identifier = None
                    self.is_unicast_rib_registration = None
                    self.is_multicast_rib_registration = None
                    self.is_active = None
                    self.is_active_ital = None
                    self.is_mrib_register = None
                    self.is_mdt_owner = None
                    self.is_routing_enabled = None
                    self.is_socket_add_required = None
                    self.is_socket_added = None
                    self.is_lpts_socket_add_required = None
                    self.is_lpts_socket_added = None
                    self.is_udp_socket_add_required = None
                    self.is_udp_socket_added = None
                    self.is_udp_socket_bind_required = None
                    self.is_udp_socket_bind = None
                    self.is_register_injection_socket_add_required = None
                    self.is_register_injection_socket_added = None
                    self.is_register_injection_lpts_socket_add_required = None
                    self.is_register_injection_lpts_socket_added = None
                    self.is_m_host_publish_pending = None
                    self.mhost_interface = None
                    self.mhost_default_interface_config = None
                    self.mdt_mtu = None
                    self.maximum_mdt_aggregation = None
                    self.mdt_data_switchover_interval = None
                    self.mdt_data_announce_interval = None
                    self.non_default_vrf_count_on_socket = None
                    self.neighbor_filter_name = None
                    self.mdt_neighbor_filter_name = None
                    self.allow_rp_configured = None
                    self.allow_rp_group_list = None
                    self.allow_rp_rp_list = None
                    self.sg_expiry_timer_configured = None
                    self.sg_expiry_time = None
                    self.sg_expiry_timer_sg_list = None
                    self.mldp_mdt_name = None
                    self.mldp_mdt_interface = None
                    self.mldp_mdt_mtu = None
                    self.mldp_maximum_mdt_aggregation = None
                    self.mldp_mdt_data_switchover_interval = None
                    self.mldp_mdt_data_announce_interval = None
                    self.mldp_mdt_rpf_identifier = None
                    self.mldp_mdt_remote_rpf_identifier = None
                    self.is_create_mldp_mdt_interface = None
                    self.is_mldp_mdt_owner = None
                    self.mldp_root_count = None
                    self.mldp_head_lsm_identifier = None
                    self.mldp_remote_head_lsm_identifier = None
                    self.organization_unique_identifier = None
                    self.vpn_index = None
                    self.mldp_partitioned_mdt_configured = None
                    self.mldp_remote_partitioned_mdt_configured = None
                    self.mldp_partioned_mp2m_ptree = None
                    self.mldp_partitioned_head_lsm_identifier = None
                    self.mldp_head_local_label = None
                    self.mldp_partitioned_mdt_identifier = None
                    self.bgp_auto_discovery_configured = None
                    self.suppress_pim_data_mdt_tlv = None
                    self.inter_autonomous_system_enabled = None
                    self.bgp_source_active_announce = None
                    self.bgp_i_pmsi_added = None
                    self.mldp_bsr_control_tree_added = None
                    self.mldp_auto_rp_discovery_tree_added = None
                    self.mldp_auto_rp_announce_tree_added = None
                    self.bgp_auto_discovery_type = None
                    self.mdt_partitioned_mdt_control_identifier = None
                    self.mdt_partitioned_ir_control_identifier = None
                    self.mldp_control_head_lsm_identifier = None
                    self.umh = None
                    self.suppress_shared_tree_join = None
                    self.rsvp_te_mdt_name = None
                    self.rsvp_te_mdt_interface = None
                    self.rsvp_te_mdt_mtu = None
                    self.rsvp_te_maximum_mdt_aggregation = None
                    self.rsvp_te_mdt_data_switchover_interval = None
                    self.rsvp_te_mdt_data_announce_interval = None
                    self.rsvp_te_mdt_rpf_identifier = None
                    self.is_create_rsvp_te_mdt_interface = None
                    self.is_rsvp_te_mdt_owner = None
                    self.rsvp_te_mdt_static_p2mp_count = None
                    self.p2mpte_li_drop = None
                    self.ir_mdt_name = None
                    self.ir_mdt_interface = None
                    self.ir_mdt_mtu = None
                    self.ir_maximum_mdt_aggregation = None
                    self.ir_mdt_data_switchover_interval = None
                    self.ir_mdt_data_announce_interval = None
                    self.ir_mdt_rpf_identifier = None
                    self.ir_mdt_tail_label = None
                    self.is_create_ir_mdt_interface = None
                    self.is_ir_mdt_owner = None
                    self.in_b_and_mdt_name = None
                    self.in_b_and_mdt_interface = None
                    self.in_b_and_mdt_mtu = None
                    self.in_band_maximum_mdt_aggregation = None
                    self.in_b_and_mdt_data_switchover_interval = None
                    self.in_b_and_mdt_data_announce_interval = None
                    self.in_b_and_mdt_rpf_identifier = None
                    self.is_create_in_b_and_mdt_interface = None
                    self.is_in_b_and_mdt_owner = None
                    self.in_band_signaling_local_enabled = None
                    self.in_band_signaling_remote_enabled = None
                    self.valid_rd_present = None
                    self.stale_rd_present = None
                    self.route_distinguisher = None
                    self.gin_b_and_mdt_name = None
                    self.gin_b_and_mdt_interface = None
                    self.gin_b_and_mdt_mtu = None
                    self.gin_band_maximum_mdt_aggregation = None
                    self.gin_b_and_mdt_data_switchover_interval = None
                    self.gin_b_and_mdt_data_announce_interval = None
                    self.gin_b_and_mdt_rpf_identifier = None
                    self.is_create_gin_b_and_mdt_interface = None
                    self.is_gin_b_and_mdt_owner = None
                    self.is_pim_nsf_rib_converged = None
                    self.is_pim_nsf_rib_converge_received = None
                    self.is_rib_multipath_enabled = None
                    self.is_rib_multipath_interface_hash = None
                    self.is_rib_multipath_source_hash = None
                    self.is_rib_multipath_source_next_hop_hash = None
                    self.rump_enabled = None
                    self.is_create_mdt_interface = None
                    self.is_auto_rp_listen_enabled = None
                    self.is_all_interface_disable_operation = None
                    self.is_default_granges = None
                    self.is_auto_rp_listen_sock_add = None
                    self.is_redistribution_reset = None
                    self.redistribution_reset_count = None
                    self.rpf_policy_name = None
                    self.table_count = None
                    self.active_table_count = None
                    self.anycast_rp_policy_name = None
                    self.anycast_rp_configured = None
                    self.bgp_remote_on = None
                    self.bgp_remote_interface_name = None
                    self.bgp_remote_interface = None
                    self.bgp_remote_address = None
                    self.bgp_remote_state = None
                    self.physical_interface_count = None
                    self.virtual_interface_count = None
                    self.virtual_mlc_interface_name = None
                    self.mdt_immediate_switch = None
                    self.mldp_root_address = []

                    self.remote_default_group = Ipv6Pim.Standby.DefaultContext.Context.RemoteDefaultGroup()
                    self.remote_default_group.parent = self
                    self._children_name_map["remote_default_group"] = "remote-default-group"

                    self.rpf_default_table = Ipv6Pim.Standby.DefaultContext.Context.RpfDefaultTable()
                    self.rpf_default_table.parent = self
                    self._children_name_map["rpf_default_table"] = "rpf-default-table"

                    self.export_route_target = YList(self)
                    self.import_route_target = YList(self)
                    self.anycast_rp_range = YList(self)
                    self._segment_path = lambda: "context"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Context, ['vrf_id', 'table_id', 'murib_id', 'rpf_id', 'remote_table_id', 'mdt_default_group', 'mdt_source', 'mdt_source_interface', 'mdt_interface', 'mdt_gre_rpf_identifier', 'mdt_gre_remote_rpf_identifier', 'is_unicast_rib_registration', 'is_multicast_rib_registration', 'is_active', 'is_active_ital', 'is_mrib_register', 'is_mdt_owner', 'is_routing_enabled', 'is_socket_add_required', 'is_socket_added', 'is_lpts_socket_add_required', 'is_lpts_socket_added', 'is_udp_socket_add_required', 'is_udp_socket_added', 'is_udp_socket_bind_required', 'is_udp_socket_bind', 'is_register_injection_socket_add_required', 'is_register_injection_socket_added', 'is_register_injection_lpts_socket_add_required', 'is_register_injection_lpts_socket_added', 'is_m_host_publish_pending', 'mhost_interface', 'mhost_default_interface_config', 'mdt_mtu', 'maximum_mdt_aggregation', 'mdt_data_switchover_interval', 'mdt_data_announce_interval', 'non_default_vrf_count_on_socket', 'neighbor_filter_name', 'mdt_neighbor_filter_name', 'allow_rp_configured', 'allow_rp_group_list', 'allow_rp_rp_list', 'sg_expiry_timer_configured', 'sg_expiry_time', 'sg_expiry_timer_sg_list', 'mldp_mdt_name', 'mldp_mdt_interface', 'mldp_mdt_mtu', 'mldp_maximum_mdt_aggregation', 'mldp_mdt_data_switchover_interval', 'mldp_mdt_data_announce_interval', 'mldp_mdt_rpf_identifier', 'mldp_mdt_remote_rpf_identifier', 'is_create_mldp_mdt_interface', 'is_mldp_mdt_owner', 'mldp_root_count', 'mldp_head_lsm_identifier', 'mldp_remote_head_lsm_identifier', 'organization_unique_identifier', 'vpn_index', 'mldp_partitioned_mdt_configured', 'mldp_remote_partitioned_mdt_configured', 'mldp_partioned_mp2m_ptree', 'mldp_partitioned_head_lsm_identifier', 'mldp_head_local_label', 'mldp_partitioned_mdt_identifier', 'bgp_auto_discovery_configured', 'suppress_pim_data_mdt_tlv', 'inter_autonomous_system_enabled', 'bgp_source_active_announce', 'bgp_i_pmsi_added', 'mldp_bsr_control_tree_added', 'mldp_auto_rp_discovery_tree_added', 'mldp_auto_rp_announce_tree_added', 'bgp_auto_discovery_type', 'mdt_partitioned_mdt_control_identifier', 'mdt_partitioned_ir_control_identifier', 'mldp_control_head_lsm_identifier', 'umh', 'suppress_shared_tree_join', 'rsvp_te_mdt_name', 'rsvp_te_mdt_interface', 'rsvp_te_mdt_mtu', 'rsvp_te_maximum_mdt_aggregation', 'rsvp_te_mdt_data_switchover_interval', 'rsvp_te_mdt_data_announce_interval', 'rsvp_te_mdt_rpf_identifier', 'is_create_rsvp_te_mdt_interface', 'is_rsvp_te_mdt_owner', 'rsvp_te_mdt_static_p2mp_count', 'p2mpte_li_drop', 'ir_mdt_name', 'ir_mdt_interface', 'ir_mdt_mtu', 'ir_maximum_mdt_aggregation', 'ir_mdt_data_switchover_interval', 'ir_mdt_data_announce_interval', 'ir_mdt_rpf_identifier', 'ir_mdt_tail_label', 'is_create_ir_mdt_interface', 'is_ir_mdt_owner', 'in_b_and_mdt_name', 'in_b_and_mdt_interface', 'in_b_and_mdt_mtu', 'in_band_maximum_mdt_aggregation', 'in_b_and_mdt_data_switchover_interval', 'in_b_and_mdt_data_announce_interval', 'in_b_and_mdt_rpf_identifier', 'is_create_in_b_and_mdt_interface', 'is_in_b_and_mdt_owner', 'in_band_signaling_local_enabled', 'in_band_signaling_remote_enabled', 'valid_rd_present', 'stale_rd_present', 'route_distinguisher', 'gin_b_and_mdt_name', 'gin_b_and_mdt_interface', 'gin_b_and_mdt_mtu', 'gin_band_maximum_mdt_aggregation', 'gin_b_and_mdt_data_switchover_interval', 'gin_b_and_mdt_data_announce_interval', 'gin_b_and_mdt_rpf_identifier', 'is_create_gin_b_and_mdt_interface', 'is_gin_b_and_mdt_owner', 'is_pim_nsf_rib_converged', 'is_pim_nsf_rib_converge_received', 'is_rib_multipath_enabled', 'is_rib_multipath_interface_hash', 'is_rib_multipath_source_hash', 'is_rib_multipath_source_next_hop_hash', 'rump_enabled', 'is_create_mdt_interface', 'is_auto_rp_listen_enabled', 'is_all_interface_disable_operation', 'is_default_granges', 'is_auto_rp_listen_sock_add', 'is_redistribution_reset', 'redistribution_reset_count', 'rpf_policy_name', 'table_count', 'active_table_count', 'anycast_rp_policy_name', 'anycast_rp_configured', 'bgp_remote_on', 'bgp_remote_interface_name', 'bgp_remote_interface', 'bgp_remote_address', 'bgp_remote_state', 'physical_interface_count', 'virtual_interface_count', 'virtual_mlc_interface_name', 'mdt_immediate_switch', 'mldp_root_address'], name, value)


                class RemoteDefaultGroup(Entity):
                    """
                    Remote Default Group
                    
                    .. attribute:: af_name
                    
                    	AFName
                    	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                    
                    .. attribute:: ipv4_address
                    
                    	IPv4 Address
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: ipv6_address
                    
                    	IPV6 Address
                    	**type**\: str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.Context.RemoteDefaultGroup, self).__init__()

                        self.yang_name = "remote-default-group"
                        self.yang_parent_name = "context"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                        ])
                        self.af_name = None
                        self.ipv4_address = None
                        self.ipv6_address = None
                        self._segment_path = lambda: "remote-default-group"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/context/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Context.RemoteDefaultGroup, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class RpfDefaultTable(Entity):
                    """
                    RPF Default Table
                    
                    .. attribute:: afi
                    
                    	AFI
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: safi
                    
                    	SAFI
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_name
                    
                    	Table name
                    	**type**\: str
                    
                    .. attribute:: vrf_id
                    
                    	VRF ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_id
                    
                    	Table ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_active
                    
                    	Active status
                    	**type**\: bool
                    
                    .. attribute:: is_ital_registration_done
                    
                    	ITAL reg status
                    	**type**\: bool
                    
                    .. attribute:: is_rib_registration_done
                    
                    	RIB reg status
                    	**type**\: bool
                    
                    .. attribute:: is_rib_convergence_received
                    
                    	RIB Convergence receive status
                    	**type**\: bool
                    
                    .. attribute:: is_rib_convergence
                    
                    	RIB Convergence status
                    	**type**\: bool
                    
                    .. attribute:: rpf_registrations
                    
                    	RPF Registration count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.Context.RpfDefaultTable, self).__init__()

                        self.yang_name = "rpf-default-table"
                        self.yang_parent_name = "context"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('afi', (YLeaf(YType.uint32, 'afi'), ['int'])),
                            ('safi', (YLeaf(YType.uint32, 'safi'), ['int'])),
                            ('table_name', (YLeaf(YType.str, 'table-name'), ['str'])),
                            ('vrf_id', (YLeaf(YType.uint32, 'vrf-id'), ['int'])),
                            ('table_id', (YLeaf(YType.uint32, 'table-id'), ['int'])),
                            ('is_active', (YLeaf(YType.boolean, 'is-active'), ['bool'])),
                            ('is_ital_registration_done', (YLeaf(YType.boolean, 'is-ital-registration-done'), ['bool'])),
                            ('is_rib_registration_done', (YLeaf(YType.boolean, 'is-rib-registration-done'), ['bool'])),
                            ('is_rib_convergence_received', (YLeaf(YType.boolean, 'is-rib-convergence-received'), ['bool'])),
                            ('is_rib_convergence', (YLeaf(YType.boolean, 'is-rib-convergence'), ['bool'])),
                            ('rpf_registrations', (YLeaf(YType.uint32, 'rpf-registrations'), ['int'])),
                        ])
                        self.afi = None
                        self.safi = None
                        self.table_name = None
                        self.vrf_id = None
                        self.table_id = None
                        self.is_active = None
                        self.is_ital_registration_done = None
                        self.is_rib_registration_done = None
                        self.is_rib_convergence_received = None
                        self.is_rib_convergence = None
                        self.rpf_registrations = None
                        self._segment_path = lambda: "rpf-default-table"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/context/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Context.RpfDefaultTable, ['afi', 'safi', 'table_name', 'vrf_id', 'table_id', 'is_active', 'is_ital_registration_done', 'is_rib_registration_done', 'is_rib_convergence_received', 'is_rib_convergence', 'rpf_registrations'], name, value)


                class ExportRouteTarget(Entity):
                    """
                    Export Route Targets
                    
                    .. attribute:: route_target
                    
                    	Route Target Extended community value
                    	**type**\: str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: configured
                    
                    	Configured Route Target
                    	**type**\: bool
                    
                    .. attribute:: anycast_rp
                    
                    	Anycast\-RP Group
                    	**type**\: bool
                    
                    .. attribute:: anycast_rp_marked
                    
                    	Anycast\-RP Group marked
                    	**type**\: bool
                    
                    .. attribute:: update_pending
                    
                    	Update Pending to BGP
                    	**type**\: bool
                    
                    .. attribute:: bgp_auto_discovery
                    
                    	BGP Auto Discovery
                    	**type**\: bool
                    
                    .. attribute:: segment_border
                    
                    	Segment Border
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.Context.ExportRouteTarget, self).__init__()

                        self.yang_name = "export-route-target"
                        self.yang_parent_name = "context"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_target', (YLeaf(YType.str, 'route-target'), ['str'])),
                            ('configured', (YLeaf(YType.boolean, 'configured'), ['bool'])),
                            ('anycast_rp', (YLeaf(YType.boolean, 'anycast-rp'), ['bool'])),
                            ('anycast_rp_marked', (YLeaf(YType.boolean, 'anycast-rp-marked'), ['bool'])),
                            ('update_pending', (YLeaf(YType.boolean, 'update-pending'), ['bool'])),
                            ('bgp_auto_discovery', (YLeaf(YType.boolean, 'bgp-auto-discovery'), ['bool'])),
                            ('segment_border', (YLeaf(YType.boolean, 'segment-border'), ['bool'])),
                        ])
                        self.route_target = None
                        self.configured = None
                        self.anycast_rp = None
                        self.anycast_rp_marked = None
                        self.update_pending = None
                        self.bgp_auto_discovery = None
                        self.segment_border = None
                        self._segment_path = lambda: "export-route-target"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/context/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Context.ExportRouteTarget, ['route_target', 'configured', 'anycast_rp', 'anycast_rp_marked', 'update_pending', 'bgp_auto_discovery', 'segment_border'], name, value)


                class ImportRouteTarget(Entity):
                    """
                    Import Route Targets
                    
                    .. attribute:: route_target
                    
                    	Route Target Extended community value
                    	**type**\: str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: configured
                    
                    	Configured Route Target
                    	**type**\: bool
                    
                    .. attribute:: anycast_rp
                    
                    	Anycast\-RP Group
                    	**type**\: bool
                    
                    .. attribute:: anycast_rp_marked
                    
                    	Anycast\-RP Group marked
                    	**type**\: bool
                    
                    .. attribute:: update_pending
                    
                    	Update Pending to BGP
                    	**type**\: bool
                    
                    .. attribute:: bgp_auto_discovery
                    
                    	BGP Auto Discovery
                    	**type**\: bool
                    
                    .. attribute:: segment_border
                    
                    	Segment Border
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.Context.ImportRouteTarget, self).__init__()

                        self.yang_name = "import-route-target"
                        self.yang_parent_name = "context"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_target', (YLeaf(YType.str, 'route-target'), ['str'])),
                            ('configured', (YLeaf(YType.boolean, 'configured'), ['bool'])),
                            ('anycast_rp', (YLeaf(YType.boolean, 'anycast-rp'), ['bool'])),
                            ('anycast_rp_marked', (YLeaf(YType.boolean, 'anycast-rp-marked'), ['bool'])),
                            ('update_pending', (YLeaf(YType.boolean, 'update-pending'), ['bool'])),
                            ('bgp_auto_discovery', (YLeaf(YType.boolean, 'bgp-auto-discovery'), ['bool'])),
                            ('segment_border', (YLeaf(YType.boolean, 'segment-border'), ['bool'])),
                        ])
                        self.route_target = None
                        self.configured = None
                        self.anycast_rp = None
                        self.anycast_rp_marked = None
                        self.update_pending = None
                        self.bgp_auto_discovery = None
                        self.segment_border = None
                        self._segment_path = lambda: "import-route-target"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/context/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Context.ImportRouteTarget, ['route_target', 'configured', 'anycast_rp', 'anycast_rp_marked', 'update_pending', 'bgp_auto_discovery', 'segment_border'], name, value)


                class AnycastRpRange(Entity):
                    """
                    Anycast\-RP Ranges
                    
                    .. attribute:: prefix
                    
                    	Anycast\-RP Range Prefix
                    	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Context.AnycastRpRange.Prefix>`
                    
                    .. attribute:: prefix_length
                    
                    	Anycast\-RP Range Prefix Length
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: ancast_rp_marked
                    
                    	Anycast\-RP Range marked
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.Context.AnycastRpRange, self).__init__()

                        self.yang_name = "anycast-rp-range"
                        self.yang_parent_name = "context"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("prefix", ("prefix", Ipv6Pim.Standby.DefaultContext.Context.AnycastRpRange.Prefix))])
                        self._leafs = OrderedDict([
                            ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                            ('ancast_rp_marked', (YLeaf(YType.boolean, 'ancast-rp-marked'), ['bool'])),
                        ])
                        self.prefix_length = None
                        self.ancast_rp_marked = None

                        self.prefix = Ipv6Pim.Standby.DefaultContext.Context.AnycastRpRange.Prefix()
                        self.prefix.parent = self
                        self._children_name_map["prefix"] = "prefix"
                        self._segment_path = lambda: "anycast-rp-range"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/context/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Context.AnycastRpRange, ['prefix_length', 'ancast_rp_marked'], name, value)


                    class Prefix(Entity):
                        """
                        Anycast\-RP Range Prefix
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Context.AnycastRpRange.Prefix, self).__init__()

                            self.yang_name = "prefix"
                            self.yang_parent_name = "anycast-rp-range"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "prefix"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/context/anycast-rp-range/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Context.AnycastRpRange.Prefix, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class TopologyEntryFlagRouteCounts(Entity):
                """
                Route count for topology with entry flag set
                
                .. attribute:: topology_entry_flag_route_count
                
                	Route count for topology with entry flag set
                	**type**\: list of  		 :py:class:`TopologyEntryFlagRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts, self).__init__()

                    self.yang_name = "topology-entry-flag-route-counts"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("topology-entry-flag-route-count", ("topology_entry_flag_route_count", Ipv6Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount))])
                    self._leafs = OrderedDict()

                    self.topology_entry_flag_route_count = YList(self)
                    self._segment_path = lambda: "topology-entry-flag-route-counts"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts, [], name, value)


                class TopologyEntryFlagRouteCount(Entity):
                    """
                    Route count for topology with entry flag set
                    
                    .. attribute:: entry_flag  (key)
                    
                    	entry flag
                    	**type**\:  :py:class:`PimTopologyEntryFlag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimTopologyEntryFlag>`
                    
                    .. attribute:: group_ranges
                    
                    	No. of (\*,G/M) routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: active_group_ranges
                    
                    	No. of (\*,G/M) routes active in mrib
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: groute_count
                    
                    	No. of (\*,G) routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sg_route_count
                    
                    	No. of (S,G) routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sgr_route_count
                    
                    	No. of (S,G)RPT routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount, self).__init__()

                        self.yang_name = "topology-entry-flag-route-count"
                        self.yang_parent_name = "topology-entry-flag-route-counts"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['entry_flag']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('entry_flag', (YLeaf(YType.enumeration, 'entry-flag'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimTopologyEntryFlag', '')])),
                            ('group_ranges', (YLeaf(YType.uint32, 'group-ranges'), ['int'])),
                            ('active_group_ranges', (YLeaf(YType.uint32, 'active-group-ranges'), ['int'])),
                            ('groute_count', (YLeaf(YType.uint32, 'groute-count'), ['int'])),
                            ('sg_route_count', (YLeaf(YType.uint32, 'sg-route-count'), ['int'])),
                            ('sgr_route_count', (YLeaf(YType.uint32, 'sgr-route-count'), ['int'])),
                            ('is_node_low_memory', (YLeaf(YType.boolean, 'is-node-low-memory'), ['bool'])),
                        ])
                        self.entry_flag = None
                        self.group_ranges = None
                        self.active_group_ranges = None
                        self.groute_count = None
                        self.sg_route_count = None
                        self.sgr_route_count = None
                        self.is_node_low_memory = None
                        self._segment_path = lambda: "topology-entry-flag-route-count" + "[entry-flag='" + str(self.entry_flag) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/topology-entry-flag-route-counts/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount, ['entry_flag', 'group_ranges', 'active_group_ranges', 'groute_count', 'sg_route_count', 'sgr_route_count', 'is_node_low_memory'], name, value)


            class RpfRedirect(Entity):
                """
                PIM ECMP RPF\-redirect bundle
                
                .. attribute:: redirect_route_databases
                
                	PIM ECMP RPF\-redirect route database
                	**type**\:  :py:class:`RedirectRouteDatabases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases>`
                
                .. attribute:: bundle_interfaces
                
                	PIM ECMP RPF\-redirect bundle information
                	**type**\:  :py:class:`BundleInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.RpfRedirect, self).__init__()

                    self.yang_name = "rpf-redirect"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("redirect-route-databases", ("redirect_route_databases", Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases)), ("bundle-interfaces", ("bundle_interfaces", Ipv6Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces))])
                    self._leafs = OrderedDict()

                    self.redirect_route_databases = Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases()
                    self.redirect_route_databases.parent = self
                    self._children_name_map["redirect_route_databases"] = "redirect-route-databases"

                    self.bundle_interfaces = Ipv6Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces()
                    self.bundle_interfaces.parent = self
                    self._children_name_map["bundle_interfaces"] = "bundle-interfaces"
                    self._segment_path = lambda: "rpf-redirect"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.RpfRedirect, [], name, value)


                class RedirectRouteDatabases(Entity):
                    """
                    PIM ECMP RPF\-redirect route database
                    
                    .. attribute:: redirect_route_database
                    
                    	PIM ECMP RPF\-redirect route information
                    	**type**\: list of  		 :py:class:`RedirectRouteDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases, self).__init__()

                        self.yang_name = "redirect-route-databases"
                        self.yang_parent_name = "rpf-redirect"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("redirect-route-database", ("redirect_route_database", Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase))])
                        self._leafs = OrderedDict()

                        self.redirect_route_database = YList(self)
                        self._segment_path = lambda: "redirect-route-databases"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/rpf-redirect/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases, [], name, value)


                    class RedirectRouteDatabase(Entity):
                        """
                        PIM ECMP RPF\-redirect route information
                        
                        .. attribute:: source_address
                        
                        	Source address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: group_address
                        
                        	Group address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: group_address_xr
                        
                        	Group ddress
                        	**type**\:  :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr>`
                        
                        .. attribute:: source_address_xr
                        
                        	Source address
                        	**type**\:  :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr>`
                        
                        .. attribute:: bandwidth
                        
                        	Bandwidth in Kbps
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: interface
                        
                        	Outgoing interface list
                        	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase, self).__init__()

                            self.yang_name = "redirect-route-database"
                            self.yang_parent_name = "redirect-route-databases"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("group-address-xr", ("group_address_xr", Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr)), ("source-address-xr", ("source_address_xr", Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr)), ("interface", ("interface", Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface))])
                            self._leafs = OrderedDict([
                                ('source_address', (YLeaf(YType.str, 'source-address'), ['str','str'])),
                                ('group_address', (YLeaf(YType.str, 'group-address'), ['str','str'])),
                                ('bandwidth', (YLeaf(YType.uint32, 'bandwidth'), ['int'])),
                                ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                            ])
                            self.source_address = None
                            self.group_address = None
                            self.bandwidth = None
                            self.uptime = None

                            self.group_address_xr = Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"

                            self.source_address_xr = Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr()
                            self.source_address_xr.parent = self
                            self._children_name_map["source_address_xr"] = "source-address-xr"

                            self.interface = YList(self)
                            self._segment_path = lambda: "redirect-route-database"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/rpf-redirect/redirect-route-databases/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase, ['source_address', 'group_address', 'bandwidth', 'uptime'], name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group ddress
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "redirect-route-database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "group-address-xr"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/rpf-redirect/redirect-route-databases/redirect-route-database/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class SourceAddressXr(Entity):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr, self).__init__()

                                self.yang_name = "source-address-xr"
                                self.yang_parent_name = "redirect-route-database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "source-address-xr"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/rpf-redirect/redirect-route-databases/redirect-route-database/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class Interface(Entity):
                            """
                            Outgoing interface list
                            
                            .. attribute:: rpf_address
                            
                            	RPF Address
                            	**type**\:  :py:class:`RpfAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress>`
                            
                            .. attribute:: interface_name
                            
                            	Interface name
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: expiry
                            
                            	Expiry in seconds
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: is_rpf_interface
                            
                            	Is RPF Interface
                            	**type**\: bool
                            
                            .. attribute:: is_outgoing_interface
                            
                            	Is outgoing Interface
                            	**type**\: bool
                            
                            .. attribute:: is_snoop_interface
                            
                            	Is snooping Interface
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface, self).__init__()

                                self.yang_name = "interface"
                                self.yang_parent_name = "redirect-route-database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("rpf-address", ("rpf_address", Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress))])
                                self._leafs = OrderedDict([
                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                    ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                                    ('expiry', (YLeaf(YType.uint64, 'expiry'), ['int'])),
                                    ('is_rpf_interface', (YLeaf(YType.boolean, 'is-rpf-interface'), ['bool'])),
                                    ('is_outgoing_interface', (YLeaf(YType.boolean, 'is-outgoing-interface'), ['bool'])),
                                    ('is_snoop_interface', (YLeaf(YType.boolean, 'is-snoop-interface'), ['bool'])),
                                ])
                                self.interface_name = None
                                self.uptime = None
                                self.expiry = None
                                self.is_rpf_interface = None
                                self.is_outgoing_interface = None
                                self.is_snoop_interface = None

                                self.rpf_address = Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress()
                                self.rpf_address.parent = self
                                self._children_name_map["rpf_address"] = "rpf-address"
                                self._segment_path = lambda: "interface"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/rpf-redirect/redirect-route-databases/redirect-route-database/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface, ['interface_name', 'uptime', 'expiry', 'is_rpf_interface', 'is_outgoing_interface', 'is_snoop_interface'], name, value)


                            class RpfAddress(Entity):
                                """
                                RPF Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress, self).__init__()

                                    self.yang_name = "rpf-address"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "rpf-address"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/rpf-redirect/redirect-route-databases/redirect-route-database/interface/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class BundleInterfaces(Entity):
                    """
                    PIM ECMP RPF\-redirect bundle information
                    
                    .. attribute:: bundle_interface
                    
                    	PIM ECMP RPF\-redirect bundle interface information
                    	**type**\: list of  		 :py:class:`BundleInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces.BundleInterface>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces, self).__init__()

                        self.yang_name = "bundle-interfaces"
                        self.yang_parent_name = "rpf-redirect"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("bundle-interface", ("bundle_interface", Ipv6Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces.BundleInterface))])
                        self._leafs = OrderedDict()

                        self.bundle_interface = YList(self)
                        self._segment_path = lambda: "bundle-interfaces"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/rpf-redirect/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces, [], name, value)


                    class BundleInterface(Entity):
                        """
                        PIM ECMP RPF\-redirect bundle interface
                        information
                        
                        .. attribute:: bundle_name
                        
                        	Bundle name
                        	**type**\: str
                        
                        	**length:** 1..32
                        
                        .. attribute:: interface_name
                        
                        	Bundle interface name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: rpf_redirect_bundle_name
                        
                        	RPF redirect bundle name
                        	**type**\: str
                        
                        	**length:** 0..33
                        
                        .. attribute:: rpf_redirect_interface_name
                        
                        	RPF redirect interface name
                        	**type**\: str
                        
                        	**length:** 0..33
                        
                        .. attribute:: available_bandwidth
                        
                        	Bandwidth available in Kbps
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: allocated_bandwidth
                        
                        	Bandwidth allocated in Kbps
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: total_bandwidth
                        
                        	Total bandwidth used in Kbps
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: topology_bandwidth_used
                        
                        	Bandwidth used by topology in Kbps
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: snooping_bandwidth_used
                        
                        	Bandwidth used by snooped entries in Kbps
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: allocated_threshold_bandwidth
                        
                        	Configured threshold in Kbps
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: available_threshold_bandwidth
                        
                        	Available threshold in Kbps
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces.BundleInterface, self).__init__()

                            self.yang_name = "bundle-interface"
                            self.yang_parent_name = "bundle-interfaces"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('bundle_name', (YLeaf(YType.str, 'bundle-name'), ['str'])),
                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ('rpf_redirect_bundle_name', (YLeaf(YType.str, 'rpf-redirect-bundle-name'), ['str'])),
                                ('rpf_redirect_interface_name', (YLeaf(YType.str, 'rpf-redirect-interface-name'), ['str'])),
                                ('available_bandwidth', (YLeaf(YType.int32, 'available-bandwidth'), ['int'])),
                                ('allocated_bandwidth', (YLeaf(YType.int32, 'allocated-bandwidth'), ['int'])),
                                ('total_bandwidth', (YLeaf(YType.int32, 'total-bandwidth'), ['int'])),
                                ('topology_bandwidth_used', (YLeaf(YType.int32, 'topology-bandwidth-used'), ['int'])),
                                ('snooping_bandwidth_used', (YLeaf(YType.int32, 'snooping-bandwidth-used'), ['int'])),
                                ('allocated_threshold_bandwidth', (YLeaf(YType.int32, 'allocated-threshold-bandwidth'), ['int'])),
                                ('available_threshold_bandwidth', (YLeaf(YType.int32, 'available-threshold-bandwidth'), ['int'])),
                            ])
                            self.bundle_name = None
                            self.interface_name = None
                            self.rpf_redirect_bundle_name = None
                            self.rpf_redirect_interface_name = None
                            self.available_bandwidth = None
                            self.allocated_bandwidth = None
                            self.total_bandwidth = None
                            self.topology_bandwidth_used = None
                            self.snooping_bandwidth_used = None
                            self.allocated_threshold_bandwidth = None
                            self.available_threshold_bandwidth = None
                            self._segment_path = lambda: "bundle-interface"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/rpf-redirect/bundle-interfaces/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces.BundleInterface, ['bundle_name', 'interface_name', 'rpf_redirect_bundle_name', 'rpf_redirect_interface_name', 'available_bandwidth', 'allocated_bandwidth', 'total_bandwidth', 'topology_bandwidth_used', 'snooping_bandwidth_used', 'allocated_threshold_bandwidth', 'available_threshold_bandwidth'], name, value)


            class Tunnels(Entity):
                """
                Tunnels information that PIM has
                
                .. attribute:: tunnel
                
                	PIM tunnel information
                	**type**\: list of  		 :py:class:`Tunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.Tunnels, self).__init__()

                    self.yang_name = "tunnels"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("tunnel", ("tunnel", Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel))])
                    self._leafs = OrderedDict()

                    self.tunnel = YList(self)
                    self._segment_path = lambda: "tunnels"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Tunnels, [], name, value)


                class Tunnel(Entity):
                    """
                    PIM tunnel information
                    
                    .. attribute:: tunnel_name  (key)
                    
                    	Tunnel name
                    	**type**\: str
                    
                    	**length:** 1..64
                    
                    .. attribute:: source_address
                    
                    	Source addr known to PIM
                    	**type**\:  :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddress>`
                    
                    .. attribute:: rp_address
                    
                    	RP addr known to PIM
                    	**type**\:  :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.RpAddress>`
                    
                    .. attribute:: source_address_netio
                    
                    	Source addr from netio
                    	**type**\:  :py:class:`SourceAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddressNetio>`
                    
                    .. attribute:: group_address_netio
                    
                    	Group addr from netio
                    	**type**\:  :py:class:`GroupAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.GroupAddressNetio>`
                    
                    .. attribute:: vrf_name
                    
                    	VRF Name
                    	**type**\: str
                    
                    	**length:** 0..33
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel, self).__init__()

                        self.yang_name = "tunnel"
                        self.yang_parent_name = "tunnels"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['tunnel_name']
                        self._child_classes = OrderedDict([("source-address", ("source_address", Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddress)), ("rp-address", ("rp_address", Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.RpAddress)), ("source-address-netio", ("source_address_netio", Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddressNetio)), ("group-address-netio", ("group_address_netio", Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.GroupAddressNetio))])
                        self._leafs = OrderedDict([
                            ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                        ])
                        self.tunnel_name = None
                        self.vrf_name = None

                        self.source_address = Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddress()
                        self.source_address.parent = self
                        self._children_name_map["source_address"] = "source-address"

                        self.rp_address = Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.RpAddress()
                        self.rp_address.parent = self
                        self._children_name_map["rp_address"] = "rp-address"

                        self.source_address_netio = Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddressNetio()
                        self.source_address_netio.parent = self
                        self._children_name_map["source_address_netio"] = "source-address-netio"

                        self.group_address_netio = Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.GroupAddressNetio()
                        self.group_address_netio.parent = self
                        self._children_name_map["group_address_netio"] = "group-address-netio"
                        self._segment_path = lambda: "tunnel" + "[tunnel-name='" + str(self.tunnel_name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/tunnels/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel, ['tunnel_name', 'vrf_name'], name, value)


                    class SourceAddress(Entity):
                        """
                        Source addr known to PIM
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddress, self).__init__()

                            self.yang_name = "source-address"
                            self.yang_parent_name = "tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "source-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class RpAddress(Entity):
                        """
                        RP addr known to PIM
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.RpAddress, self).__init__()

                            self.yang_name = "rp-address"
                            self.yang_parent_name = "tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "rp-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.RpAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class SourceAddressNetio(Entity):
                        """
                        Source addr from netio
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddressNetio, self).__init__()

                            self.yang_name = "source-address-netio"
                            self.yang_parent_name = "tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "source-address-netio"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddressNetio, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class GroupAddressNetio(Entity):
                        """
                        Group addr from netio
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.GroupAddressNetio, self).__init__()

                            self.yang_name = "group-address-netio"
                            self.yang_parent_name = "tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "group-address-netio"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.GroupAddressNetio, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class MulticastStaticRoutes(Entity):
                """
                PIM multicast static route table
                
                .. attribute:: multicast_static_route
                
                	PIM multicast static route information
                	**type**\: list of  		 :py:class:`MulticastStaticRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes, self).__init__()

                    self.yang_name = "multicast-static-routes"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("multicast-static-route", ("multicast_static_route", Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute))])
                    self._leafs = OrderedDict()

                    self.multicast_static_route = YList(self)
                    self._segment_path = lambda: "multicast-static-routes"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes, [], name, value)


                class MulticastStaticRoute(Entity):
                    """
                    PIM multicast static route information
                    
                    .. attribute:: address
                    
                    	Network address
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: prefix
                    
                    	Prefix
                    	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix>`
                    
                    .. attribute:: nexthop
                    
                    	Next Hop
                    	**type**\:  :py:class:`Nexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop>`
                    
                    .. attribute:: interface_name
                    
                    	Interface Handle
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: distance
                    
                    	Distance
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: prefix_length_xr
                    
                    	Prefix Length
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: is_via_lsm
                    
                    	LSM flag
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute, self).__init__()

                        self.yang_name = "multicast-static-route"
                        self.yang_parent_name = "multicast-static-routes"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("prefix", ("prefix", Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix)), ("nexthop", ("nexthop", Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop))])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str','str'])),
                            ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                            ('distance', (YLeaf(YType.uint32, 'distance'), ['int'])),
                            ('prefix_length_xr', (YLeaf(YType.uint8, 'prefix-length-xr'), ['int'])),
                            ('is_via_lsm', (YLeaf(YType.boolean, 'is-via-lsm'), ['bool'])),
                        ])
                        self.address = None
                        self.prefix_length = None
                        self.interface_name = None
                        self.distance = None
                        self.prefix_length_xr = None
                        self.is_via_lsm = None

                        self.prefix = Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix()
                        self.prefix.parent = self
                        self._children_name_map["prefix"] = "prefix"

                        self.nexthop = Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop()
                        self.nexthop.parent = self
                        self._children_name_map["nexthop"] = "nexthop"
                        self._segment_path = lambda: "multicast-static-route"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/multicast-static-routes/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute, ['address', 'prefix_length', 'interface_name', 'distance', 'prefix_length_xr', 'is_via_lsm'], name, value)


                    class Prefix(Entity):
                        """
                        Prefix
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix, self).__init__()

                            self.yang_name = "prefix"
                            self.yang_parent_name = "multicast-static-route"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "prefix"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/multicast-static-routes/multicast-static-route/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class Nexthop(Entity):
                        """
                        Next Hop
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop, self).__init__()

                            self.yang_name = "nexthop"
                            self.yang_parent_name = "multicast-static-route"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "nexthop"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/multicast-static-routes/multicast-static-route/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class Neighbors(Entity):
                """
                PIM neighbor table
                
                .. attribute:: neighbor
                
                	PIM neighbor information
                	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Neighbors.Neighbor>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.Neighbors, self).__init__()

                    self.yang_name = "neighbors"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("neighbor", ("neighbor", Ipv6Pim.Standby.DefaultContext.Neighbors.Neighbor))])
                    self._leafs = OrderedDict()

                    self.neighbor = YList(self)
                    self._segment_path = lambda: "neighbors"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Neighbors, [], name, value)


                class Neighbor(Entity):
                    """
                    PIM neighbor information
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: neighbor_address
                    
                    	Neighbor address
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identifier
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: expires
                    
                    	Neighbor expiry in seconds
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: expiry_timer
                    
                    	Expiry timer in seconds
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: is_this_neighbor_us
                    
                    	Is this neighbor us ?
                    	**type**\: bool
                    
                    .. attribute:: is_this_neighbor_dr
                    
                    	Is this neighbor the DR
                    	**type**\: bool
                    
                    .. attribute:: is_dr_priority_capable
                    
                    	Is this neighbor DR priority capable ?
                    	**type**\: bool
                    
                    .. attribute:: dr_priority
                    
                    	DR priority
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Is this neighbor bidir capable ?
                    	**type**\: bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Is this neighbor proxy capable?
                    	**type**\: bool
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Is this neighbor capable of batching asserts?
                    	**type**\: bool
                    
                    .. attribute:: is_ecmp_redirect_capable
                    
                    	Is this neighbor capable of Ecmp Redirect?
                    	**type**\: bool
                    
                    .. attribute:: is_bfd_state
                    
                    	Is the neighbor bfd session created
                    	**type**\: bool
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_address_xr
                    
                    	List of Neighbor Addresses
                    	**type**\: list of  		 :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Neighbors.Neighbor.NeighborAddressXr>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.Neighbors.Neighbor, self).__init__()

                        self.yang_name = "neighbor"
                        self.yang_parent_name = "neighbors"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("neighbor-address-xr", ("neighbor_address_xr", Ipv6Pim.Standby.DefaultContext.Neighbors.Neighbor.NeighborAddressXr))])
                        self._leafs = OrderedDict([
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                            ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                            ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                            ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                            ('expires', (YLeaf(YType.uint64, 'expires'), ['int'])),
                            ('expiry_timer', (YLeaf(YType.uint64, 'expiry-timer'), ['int'])),
                            ('is_this_neighbor_us', (YLeaf(YType.boolean, 'is-this-neighbor-us'), ['bool'])),
                            ('is_this_neighbor_dr', (YLeaf(YType.boolean, 'is-this-neighbor-dr'), ['bool'])),
                            ('is_dr_priority_capable', (YLeaf(YType.boolean, 'is-dr-priority-capable'), ['bool'])),
                            ('dr_priority', (YLeaf(YType.uint32, 'dr-priority'), ['int'])),
                            ('is_bidirectional_capable', (YLeaf(YType.boolean, 'is-bidirectional-capable'), ['bool'])),
                            ('is_proxy_capable', (YLeaf(YType.boolean, 'is-proxy-capable'), ['bool'])),
                            ('is_batch_asserts_capable', (YLeaf(YType.boolean, 'is-batch-asserts-capable'), ['bool'])),
                            ('is_ecmp_redirect_capable', (YLeaf(YType.boolean, 'is-ecmp-redirect-capable'), ['bool'])),
                            ('is_bfd_state', (YLeaf(YType.boolean, 'is-bfd-state'), ['bool'])),
                            ('propagation_delay', (YLeaf(YType.uint16, 'propagation-delay'), ['int'])),
                            ('override_interval', (YLeaf(YType.uint16, 'override-interval'), ['int'])),
                        ])
                        self.interface_name = None
                        self.neighbor_address = None
                        self.interface_name_xr = None
                        self.uptime = None
                        self.expires = None
                        self.expiry_timer = None
                        self.is_this_neighbor_us = None
                        self.is_this_neighbor_dr = None
                        self.is_dr_priority_capable = None
                        self.dr_priority = None
                        self.is_bidirectional_capable = None
                        self.is_proxy_capable = None
                        self.is_batch_asserts_capable = None
                        self.is_ecmp_redirect_capable = None
                        self.is_bfd_state = None
                        self.propagation_delay = None
                        self.override_interval = None

                        self.neighbor_address_xr = YList(self)
                        self._segment_path = lambda: "neighbor"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/neighbors/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Neighbors.Neighbor, ['interface_name', 'neighbor_address', 'interface_name_xr', 'uptime', 'expires', 'expiry_timer', 'is_this_neighbor_us', 'is_this_neighbor_dr', 'is_dr_priority_capable', 'dr_priority', 'is_bidirectional_capable', 'is_proxy_capable', 'is_batch_asserts_capable', 'is_ecmp_redirect_capable', 'is_bfd_state', 'propagation_delay', 'override_interval'], name, value)


                    class NeighborAddressXr(Entity):
                        """
                        List of Neighbor Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Neighbors.Neighbor.NeighborAddressXr, self).__init__()

                            self.yang_name = "neighbor-address-xr"
                            self.yang_parent_name = "neighbor"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "neighbor-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/neighbors/neighbor/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.DefaultContext.Neighbors.Neighbor.NeighborAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


        class Process(Entity):
            """
            Process
            
            .. attribute:: nsr
            
            	NSR Information
            	**type**\:  :py:class:`Nsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Process.Nsr>`
            
            .. attribute:: summary
            
            	PIM Global Summary
            	**type**\:  :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Process.Summary>`
            
            .. attribute:: nsf
            
            	PIM NSF information
            	**type**\:  :py:class:`Nsf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Process.Nsf>`
            
            .. attribute:: issu
            
            	ISSU Information
            	**type**\:  :py:class:`Issu <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Process.Issu>`
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(Ipv6Pim.Standby.Process, self).__init__()

                self.yang_name = "process"
                self.yang_parent_name = "standby"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("nsr", ("nsr", Ipv6Pim.Standby.Process.Nsr)), ("summary", ("summary", Ipv6Pim.Standby.Process.Summary)), ("nsf", ("nsf", Ipv6Pim.Standby.Process.Nsf)), ("issu", ("issu", Ipv6Pim.Standby.Process.Issu))])
                self._leafs = OrderedDict()

                self.nsr = Ipv6Pim.Standby.Process.Nsr()
                self.nsr.parent = self
                self._children_name_map["nsr"] = "nsr"

                self.summary = Ipv6Pim.Standby.Process.Summary()
                self.summary.parent = self
                self._children_name_map["summary"] = "summary"

                self.nsf = Ipv6Pim.Standby.Process.Nsf()
                self.nsf.parent = self
                self._children_name_map["nsf"] = "nsf"

                self.issu = Ipv6Pim.Standby.Process.Issu()
                self.issu.parent = self
                self._children_name_map["issu"] = "issu"
                self._segment_path = lambda: "process"
                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Ipv6Pim.Standby.Process, [], name, value)


            class Nsr(Entity):
                """
                NSR Information
                
                .. attribute:: state
                
                	NSR state
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: partner_connected
                
                	Partner process connected
                	**type**\: bool
                
                .. attribute:: rmf_notification_done
                
                	RMF Notification done
                	**type**\: bool
                
                .. attribute:: rmf_timer_valid
                
                	Is RMF timer running ?
                	**type**\: bool
                
                .. attribute:: rmf_timer_expiry
                
                	Time for RMF timer to expire
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_connection_up
                
                	Time when connection went up
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_connection_dn
                
                	Time when connection went down
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_rmf_ready
                
                	Time when RMF Rdy notif was sent
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_rmf_not_ready
                
                	Time when RMF Not\-Rdy notif was sent
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: count_connection_up
                
                	No. of times connection went up
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_connection_dn
                
                	No. of times connection went down
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_rmf_ready
                
                	No. of times RMF Ready notif was sent
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_rmf_not_ready
                
                	No. of times RMF Not Ready notif was sent
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Standby.Process.Nsr, self).__init__()

                    self.yang_name = "nsr"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('state', (YLeaf(YType.uint8, 'state'), ['int'])),
                        ('partner_connected', (YLeaf(YType.boolean, 'partner-connected'), ['bool'])),
                        ('rmf_notification_done', (YLeaf(YType.boolean, 'rmf-notification-done'), ['bool'])),
                        ('rmf_timer_valid', (YLeaf(YType.boolean, 'rmf-timer-valid'), ['bool'])),
                        ('rmf_timer_expiry', (YLeaf(YType.uint64, 'rmf-timer-expiry'), ['int'])),
                        ('last_connection_up', (YLeaf(YType.uint64, 'last-connection-up'), ['int'])),
                        ('last_connection_dn', (YLeaf(YType.uint64, 'last-connection-dn'), ['int'])),
                        ('last_rmf_ready', (YLeaf(YType.uint64, 'last-rmf-ready'), ['int'])),
                        ('last_rmf_not_ready', (YLeaf(YType.uint64, 'last-rmf-not-ready'), ['int'])),
                        ('count_connection_up', (YLeaf(YType.uint32, 'count-connection-up'), ['int'])),
                        ('count_connection_dn', (YLeaf(YType.uint32, 'count-connection-dn'), ['int'])),
                        ('count_rmf_ready', (YLeaf(YType.uint32, 'count-rmf-ready'), ['int'])),
                        ('count_rmf_not_ready', (YLeaf(YType.uint32, 'count-rmf-not-ready'), ['int'])),
                    ])
                    self.state = None
                    self.partner_connected = None
                    self.rmf_notification_done = None
                    self.rmf_timer_valid = None
                    self.rmf_timer_expiry = None
                    self.last_connection_up = None
                    self.last_connection_dn = None
                    self.last_rmf_ready = None
                    self.last_rmf_not_ready = None
                    self.count_connection_up = None
                    self.count_connection_dn = None
                    self.count_rmf_ready = None
                    self.count_rmf_not_ready = None
                    self._segment_path = lambda: "nsr"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/process/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.Process.Nsr, ['state', 'partner_connected', 'rmf_notification_done', 'rmf_timer_valid', 'rmf_timer_expiry', 'last_connection_up', 'last_connection_dn', 'last_rmf_ready', 'last_rmf_not_ready', 'count_connection_up', 'count_connection_dn', 'count_rmf_ready', 'count_rmf_not_ready'], name, value)


            class Summary(Entity):
                """
                PIM Global Summary
                
                .. attribute:: route_limit
                
                	Maximum routes
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_count
                
                	Current routes
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_low_water_mark
                
                	The number of routes below which the throttle on route creation will be lifted
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_route_limit_reached
                
                	Is route creation throttled
                	**type**\: bool
                
                .. attribute:: topology_interface_state_limit
                
                	Maximum Topology Interface State count
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_count
                
                	Current Topology Interface State count
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: rxi_low_water_mark
                
                	The rxi below which the throttle on interface creation will be lifted
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: rxi_limit_reached
                
                	Is interface creation throttled
                	**type**\: bool
                
                .. attribute:: register_limit
                
                	Maximum registers
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_count
                
                	Current registers
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_limit_reached
                
                	Is PIM SM register handling throttled
                	**type**\: bool
                
                .. attribute:: ranges_limit
                
                	Maximum group ranges from Autorp
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: ranges_count
                
                	Current group ranges from Autorp
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: ranges_threshold
                
                	OOR theshold of grange ranges from AutoRP
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_ranges_limit_reached
                
                	Is Auto\-RP group\-to\-RP mapping range creation throttled
                	**type**\: bool
                
                .. attribute:: bsr_ranges_limit
                
                	Maximum group ranges from BSR
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_ranges_count
                
                	Current group ranges from BSR
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_range_threshold
                
                	Threshold group range from BSR
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_bsr_ranges_threshold_reached
                
                	Is VRF\-specific BSR group\-to\-RP mapping range creation throttled
                	**type**\: bool
                
                .. attribute:: bsr_candidate_rp_set_limit
                
                	Maximum crp\-set from BSR
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_candidate_rp_set_count
                
                	Current crp\-set count from BSR
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_candidate_rp_set_threshold
                
                	Threshold crp\-set from BSR
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_maximum_enforcement_disabled
                
                	Is maximum enforcement disabled
                	**type**\: bool
                
                .. attribute:: is_node_low_memory
                
                	Is node in low memory condition
                	**type**\: bool
                
                .. attribute:: route_threshold
                
                	Threshold routes
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_auto_rp_ranges_limit
                
                	Global Auto\-RP maximum group ranges
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_global_auto_rp_ranges_limit_reached
                
                	Is global AutoRP group\-to\-RP mapping range creation throttled
                	**type**\: bool
                
                .. attribute:: global_bsr_ranges_limit
                
                	Global BSR maximum group ranges
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_count
                
                	Global BSR current group ranges
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_threshold
                
                	Global BSR Threshold group ranges
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_global_bsr_ranges_limit_reached
                
                	Is global BSR group\-to\-RP mapping range creation throttled
                	**type**\: bool
                
                .. attribute:: global_bsr_candidate_rp_set_limit
                
                	Global BSR maximum crp\-set
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_count
                
                	Global BSR current crp\-set count
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_threshold
                
                	Global BSR Threshold crp\-set
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_global_route_limit_reached
                
                	Is global route creation throttled
                	**type**\: bool
                
                .. attribute:: topology_interface_state_threshold
                
                	Topology Interface State threshold
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_global_rxi_limit_reached
                
                	Is global interface creation throttled
                	**type**\: bool
                
                .. attribute:: register_threshold
                
                	Threshold registers
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_register_limit
                
                	Maximum global registers
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_global_register_limit_reached
                
                	Is global PIM SM register handling throttled
                	**type**\: bool
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Standby.Process.Summary, self).__init__()

                    self.yang_name = "summary"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('route_limit', (YLeaf(YType.uint32, 'route-limit'), ['int'])),
                        ('route_count', (YLeaf(YType.uint32, 'route-count'), ['int'])),
                        ('route_low_water_mark', (YLeaf(YType.uint32, 'route-low-water-mark'), ['int'])),
                        ('is_route_limit_reached', (YLeaf(YType.boolean, 'is-route-limit-reached'), ['bool'])),
                        ('topology_interface_state_limit', (YLeaf(YType.uint32, 'topology-interface-state-limit'), ['int'])),
                        ('topology_interface_state_count', (YLeaf(YType.uint32, 'topology-interface-state-count'), ['int'])),
                        ('rxi_low_water_mark', (YLeaf(YType.uint32, 'rxi-low-water-mark'), ['int'])),
                        ('rxi_limit_reached', (YLeaf(YType.boolean, 'rxi-limit-reached'), ['bool'])),
                        ('register_limit', (YLeaf(YType.uint32, 'register-limit'), ['int'])),
                        ('register_count', (YLeaf(YType.uint32, 'register-count'), ['int'])),
                        ('register_limit_reached', (YLeaf(YType.boolean, 'register-limit-reached'), ['bool'])),
                        ('ranges_limit', (YLeaf(YType.uint32, 'ranges-limit'), ['int'])),
                        ('ranges_count', (YLeaf(YType.uint32, 'ranges-count'), ['int'])),
                        ('ranges_threshold', (YLeaf(YType.uint32, 'ranges-threshold'), ['int'])),
                        ('is_ranges_limit_reached', (YLeaf(YType.boolean, 'is-ranges-limit-reached'), ['bool'])),
                        ('bsr_ranges_limit', (YLeaf(YType.uint32, 'bsr-ranges-limit'), ['int'])),
                        ('bsr_ranges_count', (YLeaf(YType.uint32, 'bsr-ranges-count'), ['int'])),
                        ('bsr_range_threshold', (YLeaf(YType.uint32, 'bsr-range-threshold'), ['int'])),
                        ('is_bsr_ranges_threshold_reached', (YLeaf(YType.boolean, 'is-bsr-ranges-threshold-reached'), ['bool'])),
                        ('bsr_candidate_rp_set_limit', (YLeaf(YType.uint32, 'bsr-candidate-rp-set-limit'), ['int'])),
                        ('bsr_candidate_rp_set_count', (YLeaf(YType.uint32, 'bsr-candidate-rp-set-count'), ['int'])),
                        ('bsr_candidate_rp_set_threshold', (YLeaf(YType.uint32, 'bsr-candidate-rp-set-threshold'), ['int'])),
                        ('is_maximum_enforcement_disabled', (YLeaf(YType.boolean, 'is-maximum-enforcement-disabled'), ['bool'])),
                        ('is_node_low_memory', (YLeaf(YType.boolean, 'is-node-low-memory'), ['bool'])),
                        ('route_threshold', (YLeaf(YType.uint32, 'route-threshold'), ['int'])),
                        ('global_auto_rp_ranges_limit', (YLeaf(YType.uint32, 'global-auto-rp-ranges-limit'), ['int'])),
                        ('is_global_auto_rp_ranges_limit_reached', (YLeaf(YType.boolean, 'is-global-auto-rp-ranges-limit-reached'), ['bool'])),
                        ('global_bsr_ranges_limit', (YLeaf(YType.uint32, 'global-bsr-ranges-limit'), ['int'])),
                        ('global_bsr_ranges_count', (YLeaf(YType.uint32, 'global-bsr-ranges-count'), ['int'])),
                        ('global_bsr_ranges_threshold', (YLeaf(YType.uint32, 'global-bsr-ranges-threshold'), ['int'])),
                        ('is_global_bsr_ranges_limit_reached', (YLeaf(YType.boolean, 'is-global-bsr-ranges-limit-reached'), ['bool'])),
                        ('global_bsr_candidate_rp_set_limit', (YLeaf(YType.uint32, 'global-bsr-candidate-rp-set-limit'), ['int'])),
                        ('global_bsr_candidate_rp_set_count', (YLeaf(YType.uint32, 'global-bsr-candidate-rp-set-count'), ['int'])),
                        ('global_bsr_candidate_rp_set_threshold', (YLeaf(YType.uint32, 'global-bsr-candidate-rp-set-threshold'), ['int'])),
                        ('is_global_route_limit_reached', (YLeaf(YType.boolean, 'is-global-route-limit-reached'), ['bool'])),
                        ('topology_interface_state_threshold', (YLeaf(YType.uint32, 'topology-interface-state-threshold'), ['int'])),
                        ('is_global_rxi_limit_reached', (YLeaf(YType.boolean, 'is-global-rxi-limit-reached'), ['bool'])),
                        ('register_threshold', (YLeaf(YType.uint32, 'register-threshold'), ['int'])),
                        ('global_register_limit', (YLeaf(YType.uint32, 'global-register-limit'), ['int'])),
                        ('is_global_register_limit_reached', (YLeaf(YType.boolean, 'is-global-register-limit-reached'), ['bool'])),
                    ])
                    self.route_limit = None
                    self.route_count = None
                    self.route_low_water_mark = None
                    self.is_route_limit_reached = None
                    self.topology_interface_state_limit = None
                    self.topology_interface_state_count = None
                    self.rxi_low_water_mark = None
                    self.rxi_limit_reached = None
                    self.register_limit = None
                    self.register_count = None
                    self.register_limit_reached = None
                    self.ranges_limit = None
                    self.ranges_count = None
                    self.ranges_threshold = None
                    self.is_ranges_limit_reached = None
                    self.bsr_ranges_limit = None
                    self.bsr_ranges_count = None
                    self.bsr_range_threshold = None
                    self.is_bsr_ranges_threshold_reached = None
                    self.bsr_candidate_rp_set_limit = None
                    self.bsr_candidate_rp_set_count = None
                    self.bsr_candidate_rp_set_threshold = None
                    self.is_maximum_enforcement_disabled = None
                    self.is_node_low_memory = None
                    self.route_threshold = None
                    self.global_auto_rp_ranges_limit = None
                    self.is_global_auto_rp_ranges_limit_reached = None
                    self.global_bsr_ranges_limit = None
                    self.global_bsr_ranges_count = None
                    self.global_bsr_ranges_threshold = None
                    self.is_global_bsr_ranges_limit_reached = None
                    self.global_bsr_candidate_rp_set_limit = None
                    self.global_bsr_candidate_rp_set_count = None
                    self.global_bsr_candidate_rp_set_threshold = None
                    self.is_global_route_limit_reached = None
                    self.topology_interface_state_threshold = None
                    self.is_global_rxi_limit_reached = None
                    self.register_threshold = None
                    self.global_register_limit = None
                    self.is_global_register_limit_reached = None
                    self._segment_path = lambda: "summary"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/process/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.Process.Summary, ['route_limit', 'route_count', 'route_low_water_mark', 'is_route_limit_reached', 'topology_interface_state_limit', 'topology_interface_state_count', 'rxi_low_water_mark', 'rxi_limit_reached', 'register_limit', 'register_count', 'register_limit_reached', 'ranges_limit', 'ranges_count', 'ranges_threshold', 'is_ranges_limit_reached', 'bsr_ranges_limit', 'bsr_ranges_count', 'bsr_range_threshold', 'is_bsr_ranges_threshold_reached', 'bsr_candidate_rp_set_limit', 'bsr_candidate_rp_set_count', 'bsr_candidate_rp_set_threshold', 'is_maximum_enforcement_disabled', 'is_node_low_memory', 'route_threshold', 'global_auto_rp_ranges_limit', 'is_global_auto_rp_ranges_limit_reached', 'global_bsr_ranges_limit', 'global_bsr_ranges_count', 'global_bsr_ranges_threshold', 'is_global_bsr_ranges_limit_reached', 'global_bsr_candidate_rp_set_limit', 'global_bsr_candidate_rp_set_count', 'global_bsr_candidate_rp_set_threshold', 'is_global_route_limit_reached', 'topology_interface_state_threshold', 'is_global_rxi_limit_reached', 'register_threshold', 'global_register_limit', 'is_global_register_limit_reached'], name, value)


            class Nsf(Entity):
                """
                PIM NSF information
                
                .. attribute:: configured_state
                
                	Is Multicast NSF Configured
                	**type**\: bool
                
                .. attribute:: nsf_state
                
                	Are we currently in NSF
                	**type**\: bool
                
                .. attribute:: nsf_timeout
                
                	Multicast NSF timeout in seconds
                	**type**\: int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: nsf_time_left
                
                	Multicast NSF time left in seconds
                	**type**\: int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: waiting_timer
                
                	Waiting for NSF timer expiry
                	**type**\: bool
                
                .. attribute:: waiting_membership
                
                	Waiting for IGMP/MLD
                	**type**\: bool
                
                .. attribute:: respawn_count
                
                	Respawn Count
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: last_nsf_on
                
                	Last NSF time ON
                	**type**\: int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_nsf_off
                
                	Last NSF time off
                	**type**\: int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_nsf_on_sec
                
                	Last NSF time ON in Seconds
                	**type**\: int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: last_nsf_off_sec
                
                	Last NSF time OFF in Seconds
                	**type**\: int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: last_icd_notif_recv
                
                	Last ICD Notif Recv
                	**type**\: int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_icd_notif_recv_sec
                
                	Last ICD Notif Recv in Seconds
                	**type**\: int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Standby.Process.Nsf, self).__init__()

                    self.yang_name = "nsf"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('configured_state', (YLeaf(YType.boolean, 'configured-state'), ['bool'])),
                        ('nsf_state', (YLeaf(YType.boolean, 'nsf-state'), ['bool'])),
                        ('nsf_timeout', (YLeaf(YType.uint32, 'nsf-timeout'), ['int'])),
                        ('nsf_time_left', (YLeaf(YType.uint32, 'nsf-time-left'), ['int'])),
                        ('waiting_timer', (YLeaf(YType.boolean, 'waiting-timer'), ['bool'])),
                        ('waiting_membership', (YLeaf(YType.boolean, 'waiting-membership'), ['bool'])),
                        ('respawn_count', (YLeaf(YType.uint32, 'respawn-count'), ['int'])),
                        ('last_nsf_on', (YLeaf(YType.int64, 'last-nsf-on'), ['int'])),
                        ('last_nsf_off', (YLeaf(YType.int64, 'last-nsf-off'), ['int'])),
                        ('last_nsf_on_sec', (YLeaf(YType.int32, 'last-nsf-on-sec'), ['int'])),
                        ('last_nsf_off_sec', (YLeaf(YType.int32, 'last-nsf-off-sec'), ['int'])),
                        ('last_icd_notif_recv', (YLeaf(YType.int64, 'last-icd-notif-recv'), ['int'])),
                        ('last_icd_notif_recv_sec', (YLeaf(YType.int32, 'last-icd-notif-recv-sec'), ['int'])),
                    ])
                    self.configured_state = None
                    self.nsf_state = None
                    self.nsf_timeout = None
                    self.nsf_time_left = None
                    self.waiting_timer = None
                    self.waiting_membership = None
                    self.respawn_count = None
                    self.last_nsf_on = None
                    self.last_nsf_off = None
                    self.last_nsf_on_sec = None
                    self.last_nsf_off_sec = None
                    self.last_icd_notif_recv = None
                    self.last_icd_notif_recv_sec = None
                    self._segment_path = lambda: "nsf"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/process/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.Process.Nsf, ['configured_state', 'nsf_state', 'nsf_timeout', 'nsf_time_left', 'waiting_timer', 'waiting_membership', 'respawn_count', 'last_nsf_on', 'last_nsf_off', 'last_nsf_on_sec', 'last_nsf_off_sec', 'last_icd_notif_recv', 'last_icd_notif_recv_sec'], name, value)


            class Issu(Entity):
                """
                ISSU Information
                
                .. attribute:: informationvalid
                
                	Is Information valid ?
                	**type**\: bool
                
                .. attribute:: role_ha
                
                	HA role
                	**type**\: int
                
                	**range:** \-2147483648..2147483647
                
                .. attribute:: role_issu
                
                	ISSU role
                	**type**\: int
                
                	**range:** \-2147483648..2147483647
                
                .. attribute:: phase_issu
                
                	ISSU Phase
                	**type**\: int
                
                	**range:** \-2147483648..2147483647
                
                .. attribute:: last_ha_role_notification_received
                
                	Time when last HA role nfn was received
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_issu_role_notification_received
                
                	Time when last ISSU role nfn was received
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_issu_phase_notification_received
                
                	Time when last ISSU Phase nfn was received
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: is_eoc_received
                
                	Was EOC received ?
                	**type**\: bool
                
                .. attribute:: eoc_received_timestamp
                
                	Time when EOC was received
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: is_ihms_done_received
                
                	Was IHMS done received ?
                	**type**\: bool
                
                .. attribute:: ihms_received_timestamp
                
                	Time when IHMS done was received
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: is_rib_sync_received
                
                	Was RIB Sync received ?
                	**type**\: bool
                
                .. attribute:: rib_sync_received_timestamp
                
                	Time when RIB Sync was received
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: is_nbr_sync_received
                
                	Was NBR Sync achieved ?
                	**type**\: bool
                
                .. attribute:: nbr_sync_received_timestamp
                
                	Time when NBR Sync was achieved
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: is_checkpoint_idt_done
                
                	Was Checkpoint IDT done ?
                	**type**\: bool
                
                .. attribute:: checkpoint_idt_timestamp
                
                	Time when Checkpoint IDT done
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Standby.Process.Issu, self).__init__()

                    self.yang_name = "issu"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('informationvalid', (YLeaf(YType.boolean, 'informationvalid'), ['bool'])),
                        ('role_ha', (YLeaf(YType.int32, 'role-ha'), ['int'])),
                        ('role_issu', (YLeaf(YType.int32, 'role-issu'), ['int'])),
                        ('phase_issu', (YLeaf(YType.int32, 'phase-issu'), ['int'])),
                        ('last_ha_role_notification_received', (YLeaf(YType.uint64, 'last-ha-role-notification-received'), ['int'])),
                        ('last_issu_role_notification_received', (YLeaf(YType.uint64, 'last-issu-role-notification-received'), ['int'])),
                        ('last_issu_phase_notification_received', (YLeaf(YType.uint64, 'last-issu-phase-notification-received'), ['int'])),
                        ('is_eoc_received', (YLeaf(YType.boolean, 'is-eoc-received'), ['bool'])),
                        ('eoc_received_timestamp', (YLeaf(YType.uint64, 'eoc-received-timestamp'), ['int'])),
                        ('is_ihms_done_received', (YLeaf(YType.boolean, 'is-ihms-done-received'), ['bool'])),
                        ('ihms_received_timestamp', (YLeaf(YType.uint64, 'ihms-received-timestamp'), ['int'])),
                        ('is_rib_sync_received', (YLeaf(YType.boolean, 'is-rib-sync-received'), ['bool'])),
                        ('rib_sync_received_timestamp', (YLeaf(YType.uint64, 'rib-sync-received-timestamp'), ['int'])),
                        ('is_nbr_sync_received', (YLeaf(YType.boolean, 'is-nbr-sync-received'), ['bool'])),
                        ('nbr_sync_received_timestamp', (YLeaf(YType.uint64, 'nbr-sync-received-timestamp'), ['int'])),
                        ('is_checkpoint_idt_done', (YLeaf(YType.boolean, 'is-checkpoint-idt-done'), ['bool'])),
                        ('checkpoint_idt_timestamp', (YLeaf(YType.uint64, 'checkpoint-idt-timestamp'), ['int'])),
                    ])
                    self.informationvalid = None
                    self.role_ha = None
                    self.role_issu = None
                    self.phase_issu = None
                    self.last_ha_role_notification_received = None
                    self.last_issu_role_notification_received = None
                    self.last_issu_phase_notification_received = None
                    self.is_eoc_received = None
                    self.eoc_received_timestamp = None
                    self.is_ihms_done_received = None
                    self.ihms_received_timestamp = None
                    self.is_rib_sync_received = None
                    self.rib_sync_received_timestamp = None
                    self.is_nbr_sync_received = None
                    self.nbr_sync_received_timestamp = None
                    self.is_checkpoint_idt_done = None
                    self.checkpoint_idt_timestamp = None
                    self._segment_path = lambda: "issu"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/process/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.Process.Issu, ['informationvalid', 'role_ha', 'role_issu', 'phase_issu', 'last_ha_role_notification_received', 'last_issu_role_notification_received', 'last_issu_phase_notification_received', 'is_eoc_received', 'eoc_received_timestamp', 'is_ihms_done_received', 'ihms_received_timestamp', 'is_rib_sync_received', 'rib_sync_received_timestamp', 'is_nbr_sync_received', 'nbr_sync_received_timestamp', 'is_checkpoint_idt_done', 'checkpoint_idt_timestamp'], name, value)


        class Vrfs(Entity):
            """
            VRF Table
            
            .. attribute:: vrf
            
            	VRF name
            	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf>`
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(Ipv6Pim.Standby.Vrfs, self).__init__()

                self.yang_name = "vrfs"
                self.yang_parent_name = "standby"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("vrf", ("vrf", Ipv6Pim.Standby.Vrfs.Vrf))])
                self._leafs = OrderedDict()

                self.vrf = YList(self)
                self._segment_path = lambda: "vrfs"
                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Ipv6Pim.Standby.Vrfs, [], name, value)


            class Vrf(Entity):
                """
                VRF name
                
                .. attribute:: vrf_name  (key)
                
                	VRF name 
                	**type**\: str
                
                	**length:** 1..32
                
                .. attribute:: ifrs_interfaces
                
                	PIM interfaces in forward reference store table
                	**type**\:  :py:class:`IfrsInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces>`
                
                .. attribute:: safs
                
                	SAFI table and type
                	**type**\:  :py:class:`Safs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Safs>`
                
                .. attribute:: interface_statistics
                
                	PIM interface statistics
                	**type**\:  :py:class:`InterfaceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.InterfaceStatistics>`
                
                .. attribute:: topology_route_count
                
                	Topology route count information from PIM topology table
                	**type**\:  :py:class:`TopologyRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.TopologyRouteCount>`
                
                .. attribute:: jp_statistics
                
                	PIM join prune statistics table
                	**type**\:  :py:class:`JpStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.JpStatistics>`
                
                .. attribute:: mib_databases
                
                	PIM group database for mroute mibs table
                	**type**\:  :py:class:`MibDatabases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases>`
                
                .. attribute:: neighbor_old_formats
                
                	PIM neighbor table old format
                	**type**\:  :py:class:`NeighborOldFormats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.NeighborOldFormats>`
                
                .. attribute:: ifrs_summary
                
                	PIM interfaces in forward reference store summary
                	**type**\:  :py:class:`IfrsSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.IfrsSummary>`
                
                .. attribute:: ranges
                
                	PIM range list information
                	**type**\:  :py:class:`Ranges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Ranges>`
                
                .. attribute:: interface_old_formats
                
                	PIM interfaces in old format
                	**type**\:  :py:class:`InterfaceOldFormats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats>`
                
                .. attribute:: bsr
                
                	PIM BSR information
                	**type**\:  :py:class:`Bsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Bsr>`
                
                .. attribute:: route_policy
                
                	PIM route policy
                	**type**\:  :py:class:`RoutePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy>`
                
                .. attribute:: rpf_summary
                
                	PIM RPF registration summary
                	**type**\:  :py:class:`RpfSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.RpfSummary>`
                
                .. attribute:: interfaces
                
                	PIM interfaces
                	**type**\:  :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Interfaces>`
                
                .. attribute:: net_io_tunnels
                
                	Tunnel information that NETIO has 
                	**type**\:  :py:class:`NetIoTunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels>`
                
                .. attribute:: bidir_df_states
                
                	Bidirectional PIM DF election state table
                	**type**\:  :py:class:`BidirDfStates <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.BidirDfStates>`
                
                .. attribute:: topologies
                
                	PIM topology table
                	**type**\:  :py:class:`Topologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Topologies>`
                
                .. attribute:: bgp_afs
                
                	PIM BGP SAFI table
                	**type**\:  :py:class:`BgpAfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs>`
                
                .. attribute:: auto_rp
                
                	PIM Auto\-RP information
                	**type**\:  :py:class:`AutoRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.AutoRp>`
                
                .. attribute:: topology_interface_flag_route_counts
                
                	Route count for topology with interface flag set
                	**type**\:  :py:class:`TopologyInterfaceFlagRouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts>`
                
                .. attribute:: group_map_sources
                
                	PIM group\-mapping with source information
                	**type**\:  :py:class:`GroupMapSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources>`
                
                .. attribute:: traffic_counters
                
                	PIM message traffic counters
                	**type**\:  :py:class:`TrafficCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters>`
                
                .. attribute:: group_map_rpfs
                
                	PIM group mapping information
                	**type**\:  :py:class:`GroupMapRpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs>`
                
                .. attribute:: summary
                
                	PIM summary
                	**type**\:  :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Summary>`
                
                .. attribute:: gre
                
                	GRE information
                	**type**\:  :py:class:`Gre <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Gre>`
                
                .. attribute:: bidir_df_winners
                
                	Bidirectional PIM DF election winner table
                	**type**\:  :py:class:`BidirDfWinners <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners>`
                
                .. attribute:: table_contexts
                
                	PIM table context list
                	**type**\:  :py:class:`TableContexts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.TableContexts>`
                
                .. attribute:: neighbor_summaries
                
                	PIM neighbor summary table
                	**type**\:  :py:class:`NeighborSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.NeighborSummaries>`
                
                .. attribute:: context
                
                	PIM context information
                	**type**\:  :py:class:`Context <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Context>`
                
                .. attribute:: topology_entry_flag_route_counts
                
                	Route count for topology with entry flag set
                	**type**\:  :py:class:`TopologyEntryFlagRouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts>`
                
                .. attribute:: rpf_redirect
                
                	PIM ECMP RPF\-redirect bundle
                	**type**\:  :py:class:`RpfRedirect <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect>`
                
                .. attribute:: tunnels
                
                	Tunnels information that PIM has
                	**type**\:  :py:class:`Tunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Tunnels>`
                
                .. attribute:: multicast_static_routes
                
                	PIM multicast static route table
                	**type**\:  :py:class:`MulticastStaticRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes>`
                
                .. attribute:: neighbors
                
                	PIM neighbor table
                	**type**\:  :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Neighbors>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Standby.Vrfs.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "vrfs"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['vrf_name']
                    self._child_classes = OrderedDict([("ifrs-interfaces", ("ifrs_interfaces", Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces)), ("safs", ("safs", Ipv6Pim.Standby.Vrfs.Vrf.Safs)), ("interface-statistics", ("interface_statistics", Ipv6Pim.Standby.Vrfs.Vrf.InterfaceStatistics)), ("topology-route-count", ("topology_route_count", Ipv6Pim.Standby.Vrfs.Vrf.TopologyRouteCount)), ("jp-statistics", ("jp_statistics", Ipv6Pim.Standby.Vrfs.Vrf.JpStatistics)), ("mib-databases", ("mib_databases", Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases)), ("neighbor-old-formats", ("neighbor_old_formats", Ipv6Pim.Standby.Vrfs.Vrf.NeighborOldFormats)), ("ifrs-summary", ("ifrs_summary", Ipv6Pim.Standby.Vrfs.Vrf.IfrsSummary)), ("ranges", ("ranges", Ipv6Pim.Standby.Vrfs.Vrf.Ranges)), ("interface-old-formats", ("interface_old_formats", Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats)), ("bsr", ("bsr", Ipv6Pim.Standby.Vrfs.Vrf.Bsr)), ("route-policy", ("route_policy", Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy)), ("rpf-summary", ("rpf_summary", Ipv6Pim.Standby.Vrfs.Vrf.RpfSummary)), ("interfaces", ("interfaces", Ipv6Pim.Standby.Vrfs.Vrf.Interfaces)), ("net-io-tunnels", ("net_io_tunnels", Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels)), ("bidir-df-states", ("bidir_df_states", Ipv6Pim.Standby.Vrfs.Vrf.BidirDfStates)), ("topologies", ("topologies", Ipv6Pim.Standby.Vrfs.Vrf.Topologies)), ("bgp-afs", ("bgp_afs", Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs)), ("auto-rp", ("auto_rp", Ipv6Pim.Standby.Vrfs.Vrf.AutoRp)), ("topology-interface-flag-route-counts", ("topology_interface_flag_route_counts", Ipv6Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts)), ("group-map-sources", ("group_map_sources", Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources)), ("traffic-counters", ("traffic_counters", Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters)), ("group-map-rpfs", ("group_map_rpfs", Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs)), ("summary", ("summary", Ipv6Pim.Standby.Vrfs.Vrf.Summary)), ("gre", ("gre", Ipv6Pim.Standby.Vrfs.Vrf.Gre)), ("bidir-df-winners", ("bidir_df_winners", Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners)), ("table-contexts", ("table_contexts", Ipv6Pim.Standby.Vrfs.Vrf.TableContexts)), ("neighbor-summaries", ("neighbor_summaries", Ipv6Pim.Standby.Vrfs.Vrf.NeighborSummaries)), ("context", ("context", Ipv6Pim.Standby.Vrfs.Vrf.Context)), ("topology-entry-flag-route-counts", ("topology_entry_flag_route_counts", Ipv6Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts)), ("rpf-redirect", ("rpf_redirect", Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect)), ("tunnels", ("tunnels", Ipv6Pim.Standby.Vrfs.Vrf.Tunnels)), ("multicast-static-routes", ("multicast_static_routes", Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes)), ("neighbors", ("neighbors", Ipv6Pim.Standby.Vrfs.Vrf.Neighbors))])
                    self._leafs = OrderedDict([
                        ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                    ])
                    self.vrf_name = None

                    self.ifrs_interfaces = Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces()
                    self.ifrs_interfaces.parent = self
                    self._children_name_map["ifrs_interfaces"] = "ifrs-interfaces"

                    self.safs = Ipv6Pim.Standby.Vrfs.Vrf.Safs()
                    self.safs.parent = self
                    self._children_name_map["safs"] = "safs"

                    self.interface_statistics = Ipv6Pim.Standby.Vrfs.Vrf.InterfaceStatistics()
                    self.interface_statistics.parent = self
                    self._children_name_map["interface_statistics"] = "interface-statistics"

                    self.topology_route_count = Ipv6Pim.Standby.Vrfs.Vrf.TopologyRouteCount()
                    self.topology_route_count.parent = self
                    self._children_name_map["topology_route_count"] = "topology-route-count"

                    self.jp_statistics = Ipv6Pim.Standby.Vrfs.Vrf.JpStatistics()
                    self.jp_statistics.parent = self
                    self._children_name_map["jp_statistics"] = "jp-statistics"

                    self.mib_databases = Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases()
                    self.mib_databases.parent = self
                    self._children_name_map["mib_databases"] = "mib-databases"

                    self.neighbor_old_formats = Ipv6Pim.Standby.Vrfs.Vrf.NeighborOldFormats()
                    self.neighbor_old_formats.parent = self
                    self._children_name_map["neighbor_old_formats"] = "neighbor-old-formats"

                    self.ifrs_summary = Ipv6Pim.Standby.Vrfs.Vrf.IfrsSummary()
                    self.ifrs_summary.parent = self
                    self._children_name_map["ifrs_summary"] = "ifrs-summary"

                    self.ranges = Ipv6Pim.Standby.Vrfs.Vrf.Ranges()
                    self.ranges.parent = self
                    self._children_name_map["ranges"] = "ranges"

                    self.interface_old_formats = Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats()
                    self.interface_old_formats.parent = self
                    self._children_name_map["interface_old_formats"] = "interface-old-formats"

                    self.bsr = Ipv6Pim.Standby.Vrfs.Vrf.Bsr()
                    self.bsr.parent = self
                    self._children_name_map["bsr"] = "bsr"

                    self.route_policy = Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy()
                    self.route_policy.parent = self
                    self._children_name_map["route_policy"] = "route-policy"

                    self.rpf_summary = Ipv6Pim.Standby.Vrfs.Vrf.RpfSummary()
                    self.rpf_summary.parent = self
                    self._children_name_map["rpf_summary"] = "rpf-summary"

                    self.interfaces = Ipv6Pim.Standby.Vrfs.Vrf.Interfaces()
                    self.interfaces.parent = self
                    self._children_name_map["interfaces"] = "interfaces"

                    self.net_io_tunnels = Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels()
                    self.net_io_tunnels.parent = self
                    self._children_name_map["net_io_tunnels"] = "net-io-tunnels"

                    self.bidir_df_states = Ipv6Pim.Standby.Vrfs.Vrf.BidirDfStates()
                    self.bidir_df_states.parent = self
                    self._children_name_map["bidir_df_states"] = "bidir-df-states"

                    self.topologies = Ipv6Pim.Standby.Vrfs.Vrf.Topologies()
                    self.topologies.parent = self
                    self._children_name_map["topologies"] = "topologies"

                    self.bgp_afs = Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs()
                    self.bgp_afs.parent = self
                    self._children_name_map["bgp_afs"] = "bgp-afs"

                    self.auto_rp = Ipv6Pim.Standby.Vrfs.Vrf.AutoRp()
                    self.auto_rp.parent = self
                    self._children_name_map["auto_rp"] = "auto-rp"

                    self.topology_interface_flag_route_counts = Ipv6Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts()
                    self.topology_interface_flag_route_counts.parent = self
                    self._children_name_map["topology_interface_flag_route_counts"] = "topology-interface-flag-route-counts"

                    self.group_map_sources = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources()
                    self.group_map_sources.parent = self
                    self._children_name_map["group_map_sources"] = "group-map-sources"

                    self.traffic_counters = Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters()
                    self.traffic_counters.parent = self
                    self._children_name_map["traffic_counters"] = "traffic-counters"

                    self.group_map_rpfs = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs()
                    self.group_map_rpfs.parent = self
                    self._children_name_map["group_map_rpfs"] = "group-map-rpfs"

                    self.summary = Ipv6Pim.Standby.Vrfs.Vrf.Summary()
                    self.summary.parent = self
                    self._children_name_map["summary"] = "summary"

                    self.gre = Ipv6Pim.Standby.Vrfs.Vrf.Gre()
                    self.gre.parent = self
                    self._children_name_map["gre"] = "gre"

                    self.bidir_df_winners = Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners()
                    self.bidir_df_winners.parent = self
                    self._children_name_map["bidir_df_winners"] = "bidir-df-winners"

                    self.table_contexts = Ipv6Pim.Standby.Vrfs.Vrf.TableContexts()
                    self.table_contexts.parent = self
                    self._children_name_map["table_contexts"] = "table-contexts"

                    self.neighbor_summaries = Ipv6Pim.Standby.Vrfs.Vrf.NeighborSummaries()
                    self.neighbor_summaries.parent = self
                    self._children_name_map["neighbor_summaries"] = "neighbor-summaries"

                    self.context = Ipv6Pim.Standby.Vrfs.Vrf.Context()
                    self.context.parent = self
                    self._children_name_map["context"] = "context"

                    self.topology_entry_flag_route_counts = Ipv6Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts()
                    self.topology_entry_flag_route_counts.parent = self
                    self._children_name_map["topology_entry_flag_route_counts"] = "topology-entry-flag-route-counts"

                    self.rpf_redirect = Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect()
                    self.rpf_redirect.parent = self
                    self._children_name_map["rpf_redirect"] = "rpf-redirect"

                    self.tunnels = Ipv6Pim.Standby.Vrfs.Vrf.Tunnels()
                    self.tunnels.parent = self
                    self._children_name_map["tunnels"] = "tunnels"

                    self.multicast_static_routes = Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes()
                    self.multicast_static_routes.parent = self
                    self._children_name_map["multicast_static_routes"] = "multicast-static-routes"

                    self.neighbors = Ipv6Pim.Standby.Vrfs.Vrf.Neighbors()
                    self.neighbors.parent = self
                    self._children_name_map["neighbors"] = "neighbors"
                    self._segment_path = lambda: "vrf" + "[vrf-name='" + str(self.vrf_name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/vrfs/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf, ['vrf_name'], name, value)


                class IfrsInterfaces(Entity):
                    """
                    PIM interfaces in forward reference store table
                    
                    .. attribute:: ifrs_interface
                    
                    	PIM IFRS interface information
                    	**type**\: list of  		 :py:class:`IfrsInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces, self).__init__()

                        self.yang_name = "ifrs-interfaces"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ifrs-interface", ("ifrs_interface", Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface))])
                        self._leafs = OrderedDict()

                        self.ifrs_interface = YList(self)
                        self._segment_path = lambda: "ifrs-interfaces"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces, [], name, value)


                    class IfrsInterface(Entity):
                        """
                        PIM IFRS interface information
                        
                        .. attribute:: interface_name  (key)
                        
                        	Interface name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: dr_address
                        
                        	PIM Designated Router
                        	**type**\:  :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress>`
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identfier
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: interface_address_mask
                        
                        	Interface IP Address Mask
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: is_enabled
                        
                        	Is PIM enabled on this IF ?
                        	**type**\: bool
                        
                        .. attribute:: neighbor_count
                        
                        	No. of neighbors on this IF
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: external_neighbor_count
                        
                        	No. of external neighbors on this IF
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: hello_interval
                        
                        	Hello Interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: dr_priority
                        
                        	DR Priority
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: hello_expiry
                        
                        	Hello Timer Expiry
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: are_we_dr
                        
                        	Are we the DR on this IF ?
                        	**type**\: bool
                        
                        .. attribute:: bfd_enabled
                        
                        	BFD state
                        	**type**\: bool
                        
                        .. attribute:: bfd_interval
                        
                        	BFD Interval
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bfd_multiplier
                        
                        	BFD Multiplier
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_interface
                        
                        	 is this a Virtual Interfaces ?
                        	**type**\: bool
                        
                        .. attribute:: passive_interface
                        
                        	Passive PIM interface
                        	**type**\: bool
                        
                        .. attribute:: neighbor_filter_name
                        
                        	Neighbor Filter Name
                        	**type**\: str
                        
                        .. attribute:: join_prune_interval
                        
                        	Join\-Prune Interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: prune_delay_enabled
                        
                        	Prune Delay Enabled
                        	**type**\: bool
                        
                        .. attribute:: configured_propagation_delay
                        
                        	Configured Propagation Delay
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: configured_override_interval
                        
                        	Configured Override Interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: generation_id
                        
                        	Generation Identifier
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Bidir Capable
                        	**type**\: bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Proxy Capable
                        	**type**\: bool
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Batch Asserts Capable
                        	**type**\: bool
                        
                        .. attribute:: idb_oor_enabled
                        
                        	Interface oor enabled
                        	**type**\: bool
                        
                        .. attribute:: idb_acl_provided
                        
                        	ACL name provided
                        	**type**\: bool
                        
                        .. attribute:: idb_max_count
                        
                        	Interface ole max count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_threshold_count
                        
                        	Interface ole threshold count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_current_count
                        
                        	Interface ole current count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_acl_name
                        
                        	Interface ole ACL Name
                        	**type**\: str
                        
                        	**length:** 0..64
                        
                        .. attribute:: interface_address
                        
                        	List of Interface IP Addresses
                        	**type**\: list of  		 :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.InterfaceAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface, self).__init__()

                            self.yang_name = "ifrs-interface"
                            self.yang_parent_name = "ifrs-interfaces"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['interface_name']
                            self._child_classes = OrderedDict([("dr-address", ("dr_address", Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress)), ("interface-address", ("interface_address", Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.InterfaceAddress))])
                            self._leafs = OrderedDict([
                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                                ('interface_address_mask', (YLeaf(YType.uint8, 'interface-address-mask'), ['int'])),
                                ('is_enabled', (YLeaf(YType.boolean, 'is-enabled'), ['bool'])),
                                ('neighbor_count', (YLeaf(YType.uint16, 'neighbor-count'), ['int'])),
                                ('external_neighbor_count', (YLeaf(YType.uint16, 'external-neighbor-count'), ['int'])),
                                ('hello_interval', (YLeaf(YType.uint16, 'hello-interval'), ['int'])),
                                ('dr_priority', (YLeaf(YType.uint32, 'dr-priority'), ['int'])),
                                ('hello_expiry', (YLeaf(YType.uint64, 'hello-expiry'), ['int'])),
                                ('are_we_dr', (YLeaf(YType.boolean, 'are-we-dr'), ['bool'])),
                                ('bfd_enabled', (YLeaf(YType.boolean, 'bfd-enabled'), ['bool'])),
                                ('bfd_interval', (YLeaf(YType.uint32, 'bfd-interval'), ['int'])),
                                ('bfd_multiplier', (YLeaf(YType.uint32, 'bfd-multiplier'), ['int'])),
                                ('virtual_interface', (YLeaf(YType.boolean, 'virtual-interface'), ['bool'])),
                                ('passive_interface', (YLeaf(YType.boolean, 'passive-interface'), ['bool'])),
                                ('neighbor_filter_name', (YLeaf(YType.str, 'neighbor-filter-name'), ['str'])),
                                ('join_prune_interval', (YLeaf(YType.uint16, 'join-prune-interval'), ['int'])),
                                ('prune_delay_enabled', (YLeaf(YType.boolean, 'prune-delay-enabled'), ['bool'])),
                                ('configured_propagation_delay', (YLeaf(YType.uint16, 'configured-propagation-delay'), ['int'])),
                                ('propagation_delay', (YLeaf(YType.uint16, 'propagation-delay'), ['int'])),
                                ('configured_override_interval', (YLeaf(YType.uint16, 'configured-override-interval'), ['int'])),
                                ('override_interval', (YLeaf(YType.uint16, 'override-interval'), ['int'])),
                                ('generation_id', (YLeaf(YType.uint32, 'generation-id'), ['int'])),
                                ('is_bidirectional_capable', (YLeaf(YType.boolean, 'is-bidirectional-capable'), ['bool'])),
                                ('is_proxy_capable', (YLeaf(YType.boolean, 'is-proxy-capable'), ['bool'])),
                                ('is_batch_asserts_capable', (YLeaf(YType.boolean, 'is-batch-asserts-capable'), ['bool'])),
                                ('idb_oor_enabled', (YLeaf(YType.boolean, 'idb-oor-enabled'), ['bool'])),
                                ('idb_acl_provided', (YLeaf(YType.boolean, 'idb-acl-provided'), ['bool'])),
                                ('idb_max_count', (YLeaf(YType.uint32, 'idb-max-count'), ['int'])),
                                ('idb_threshold_count', (YLeaf(YType.uint32, 'idb-threshold-count'), ['int'])),
                                ('idb_current_count', (YLeaf(YType.uint32, 'idb-current-count'), ['int'])),
                                ('idb_acl_name', (YLeaf(YType.str, 'idb-acl-name'), ['str'])),
                            ])
                            self.interface_name = None
                            self.interface_name_xr = None
                            self.interface_address_mask = None
                            self.is_enabled = None
                            self.neighbor_count = None
                            self.external_neighbor_count = None
                            self.hello_interval = None
                            self.dr_priority = None
                            self.hello_expiry = None
                            self.are_we_dr = None
                            self.bfd_enabled = None
                            self.bfd_interval = None
                            self.bfd_multiplier = None
                            self.virtual_interface = None
                            self.passive_interface = None
                            self.neighbor_filter_name = None
                            self.join_prune_interval = None
                            self.prune_delay_enabled = None
                            self.configured_propagation_delay = None
                            self.propagation_delay = None
                            self.configured_override_interval = None
                            self.override_interval = None
                            self.generation_id = None
                            self.is_bidirectional_capable = None
                            self.is_proxy_capable = None
                            self.is_batch_asserts_capable = None
                            self.idb_oor_enabled = None
                            self.idb_acl_provided = None
                            self.idb_max_count = None
                            self.idb_threshold_count = None
                            self.idb_current_count = None
                            self.idb_acl_name = None

                            self.dr_address = Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress()
                            self.dr_address.parent = self
                            self._children_name_map["dr_address"] = "dr-address"

                            self.interface_address = YList(self)
                            self._segment_path = lambda: "ifrs-interface" + "[interface-name='" + str(self.interface_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface, ['interface_name', 'interface_name_xr', 'interface_address_mask', 'is_enabled', 'neighbor_count', 'external_neighbor_count', 'hello_interval', 'dr_priority', 'hello_expiry', 'are_we_dr', 'bfd_enabled', 'bfd_interval', 'bfd_multiplier', 'virtual_interface', 'passive_interface', 'neighbor_filter_name', 'join_prune_interval', 'prune_delay_enabled', 'configured_propagation_delay', 'propagation_delay', 'configured_override_interval', 'override_interval', 'generation_id', 'is_bidirectional_capable', 'is_proxy_capable', 'is_batch_asserts_capable', 'idb_oor_enabled', 'idb_acl_provided', 'idb_max_count', 'idb_threshold_count', 'idb_current_count', 'idb_acl_name'], name, value)


                        class DrAddress(Entity):
                            """
                            PIM Designated Router
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress, self).__init__()

                                self.yang_name = "dr-address"
                                self.yang_parent_name = "ifrs-interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "dr-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class InterfaceAddress(Entity):
                            """
                            List of Interface IP Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.InterfaceAddress, self).__init__()

                                self.yang_name = "interface-address"
                                self.yang_parent_name = "ifrs-interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "interface-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.InterfaceAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class Safs(Entity):
                    """
                    SAFI table and type
                    
                    .. attribute:: saf
                    
                    	SAF name 
                    	**type**\: list of  		 :py:class:`Saf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.Safs, self).__init__()

                        self.yang_name = "safs"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("saf", ("saf", Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf))])
                        self._leafs = OrderedDict()

                        self.saf = YList(self)
                        self._segment_path = lambda: "safs"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Safs, [], name, value)


                    class Saf(Entity):
                        """
                        SAF name 
                        
                        .. attribute:: rpf_hash_source_groups
                        
                        	PIM RPF multipath hash outcome
                        	**type**\:  :py:class:`RpfHashSourceGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups>`
                        
                        .. attribute:: rpf_hash_sources
                        
                        	PIM RPF multipath hash outcome
                        	**type**\:  :py:class:`RpfHashSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources>`
                        
                        .. attribute:: rpfs
                        
                        	PIM RPF information table
                        	**type**\:  :py:class:`Rpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs>`
                        
                        .. attribute:: saf_name
                        
                        	SAF name 
                        	**type**\:  :py:class:`PimSafi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimSafi>`
                        
                        .. attribute:: topology_name
                        
                        	Topology name 
                        	**type**\: str
                        
                        	**length:** 1..32
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf, self).__init__()

                            self.yang_name = "saf"
                            self.yang_parent_name = "safs"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rpf-hash-source-groups", ("rpf_hash_source_groups", Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups)), ("rpf-hash-sources", ("rpf_hash_sources", Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources)), ("rpfs", ("rpfs", Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs))])
                            self._leafs = OrderedDict([
                                ('saf_name', (YLeaf(YType.enumeration, 'saf-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimSafi', '')])),
                                ('topology_name', (YLeaf(YType.str, 'topology-name'), ['str'])),
                            ])
                            self.saf_name = None
                            self.topology_name = None

                            self.rpf_hash_source_groups = Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups()
                            self.rpf_hash_source_groups.parent = self
                            self._children_name_map["rpf_hash_source_groups"] = "rpf-hash-source-groups"

                            self.rpf_hash_sources = Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources()
                            self.rpf_hash_sources.parent = self
                            self._children_name_map["rpf_hash_sources"] = "rpf-hash-sources"

                            self.rpfs = Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs()
                            self.rpfs.parent = self
                            self._children_name_map["rpfs"] = "rpfs"
                            self._segment_path = lambda: "saf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf, ['saf_name', 'topology_name'], name, value)


                        class RpfHashSourceGroups(Entity):
                            """
                            PIM RPF multipath hash outcome
                            
                            .. attribute:: rpf_hash_source_group
                            
                            	PIM RPF hash outcome for S,G
                            	**type**\: list of  		 :py:class:`RpfHashSourceGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups, self).__init__()

                                self.yang_name = "rpf-hash-source-groups"
                                self.yang_parent_name = "saf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("rpf-hash-source-group", ("rpf_hash_source_group", Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup))])
                                self._leafs = OrderedDict()

                                self.rpf_hash_source_group = YList(self)
                                self._segment_path = lambda: "rpf-hash-source-groups"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups, [], name, value)


                            class RpfHashSourceGroup(Entity):
                                """
                                PIM RPF hash outcome for S,G
                                
                                .. attribute:: source_address
                                
                                	Source address
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: group_address
                                
                                	Group address
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: mask_length
                                
                                	Hash mask length
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: mofrr
                                
                                	MOFRR
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_address
                                
                                	Next hop neighbor address
                                	**type**\:  :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress>`
                                
                                .. attribute:: secondary_next_hop_address
                                
                                	Secondary Next hop neighbor address
                                	**type**\:  :py:class:`SecondaryNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress>`
                                
                                .. attribute:: next_hop_multipath_enabled
                                
                                	Next hop multipath enabled?
                                	**type**\: bool
                                
                                .. attribute:: next_hop_interface
                                
                                	Next hop neighbor interface
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                .. attribute:: secondary_next_hop_interface
                                
                                	Secondary Next hop neighbor interface
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup, self).__init__()

                                    self.yang_name = "rpf-hash-source-group"
                                    self.yang_parent_name = "rpf-hash-source-groups"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("next-hop-address", ("next_hop_address", Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress)), ("secondary-next-hop-address", ("secondary_next_hop_address", Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress))])
                                    self._leafs = OrderedDict([
                                        ('source_address', (YLeaf(YType.str, 'source-address'), ['str','str'])),
                                        ('group_address', (YLeaf(YType.str, 'group-address'), ['str','str'])),
                                        ('mask_length', (YLeaf(YType.uint32, 'mask-length'), ['int'])),
                                        ('mofrr', (YLeaf(YType.uint32, 'mofrr'), ['int'])),
                                        ('next_hop_multipath_enabled', (YLeaf(YType.boolean, 'next-hop-multipath-enabled'), ['bool'])),
                                        ('next_hop_interface', (YLeaf(YType.str, 'next-hop-interface'), ['str'])),
                                        ('secondary_next_hop_interface', (YLeaf(YType.str, 'secondary-next-hop-interface'), ['str'])),
                                    ])
                                    self.source_address = None
                                    self.group_address = None
                                    self.mask_length = None
                                    self.mofrr = None
                                    self.next_hop_multipath_enabled = None
                                    self.next_hop_interface = None
                                    self.secondary_next_hop_interface = None

                                    self.next_hop_address = Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress()
                                    self.next_hop_address.parent = self
                                    self._children_name_map["next_hop_address"] = "next-hop-address"

                                    self.secondary_next_hop_address = Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress()
                                    self.secondary_next_hop_address.parent = self
                                    self._children_name_map["secondary_next_hop_address"] = "secondary-next-hop-address"
                                    self._segment_path = lambda: "rpf-hash-source-group"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup, ['source_address', 'group_address', 'mask_length', 'mofrr', 'next_hop_multipath_enabled', 'next_hop_interface', 'secondary_next_hop_interface'], name, value)


                                class NextHopAddress(Entity):
                                    """
                                    Next hop neighbor address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress, self).__init__()

                                        self.yang_name = "next-hop-address"
                                        self.yang_parent_name = "rpf-hash-source-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ])
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None
                                        self._segment_path = lambda: "next-hop-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                                class SecondaryNextHopAddress(Entity):
                                    """
                                    Secondary Next hop neighbor address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress, self).__init__()

                                        self.yang_name = "secondary-next-hop-address"
                                        self.yang_parent_name = "rpf-hash-source-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ])
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None
                                        self._segment_path = lambda: "secondary-next-hop-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class RpfHashSources(Entity):
                            """
                            PIM RPF multipath hash outcome
                            
                            .. attribute:: rpf_hash_source
                            
                            	PIM RPF hash outcome for S,G
                            	**type**\: list of  		 :py:class:`RpfHashSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources, self).__init__()

                                self.yang_name = "rpf-hash-sources"
                                self.yang_parent_name = "saf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("rpf-hash-source", ("rpf_hash_source", Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource))])
                                self._leafs = OrderedDict()

                                self.rpf_hash_source = YList(self)
                                self._segment_path = lambda: "rpf-hash-sources"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources, [], name, value)


                            class RpfHashSource(Entity):
                                """
                                PIM RPF hash outcome for S,G
                                
                                .. attribute:: source_address
                                
                                	Source address
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: mofrr
                                
                                	MOFRR
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_address
                                
                                	Next hop neighbor address
                                	**type**\:  :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress>`
                                
                                .. attribute:: secondary_next_hop_address
                                
                                	Secondary Next hop neighbor address
                                	**type**\:  :py:class:`SecondaryNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress>`
                                
                                .. attribute:: next_hop_multipath_enabled
                                
                                	Next hop multipath enabled?
                                	**type**\: bool
                                
                                .. attribute:: next_hop_interface
                                
                                	Next hop neighbor interface
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                .. attribute:: secondary_next_hop_interface
                                
                                	Secondary Next hop neighbor interface
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource, self).__init__()

                                    self.yang_name = "rpf-hash-source"
                                    self.yang_parent_name = "rpf-hash-sources"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("next-hop-address", ("next_hop_address", Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress)), ("secondary-next-hop-address", ("secondary_next_hop_address", Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress))])
                                    self._leafs = OrderedDict([
                                        ('source_address', (YLeaf(YType.str, 'source-address'), ['str','str'])),
                                        ('mofrr', (YLeaf(YType.uint32, 'mofrr'), ['int'])),
                                        ('next_hop_multipath_enabled', (YLeaf(YType.boolean, 'next-hop-multipath-enabled'), ['bool'])),
                                        ('next_hop_interface', (YLeaf(YType.str, 'next-hop-interface'), ['str'])),
                                        ('secondary_next_hop_interface', (YLeaf(YType.str, 'secondary-next-hop-interface'), ['str'])),
                                    ])
                                    self.source_address = None
                                    self.mofrr = None
                                    self.next_hop_multipath_enabled = None
                                    self.next_hop_interface = None
                                    self.secondary_next_hop_interface = None

                                    self.next_hop_address = Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress()
                                    self.next_hop_address.parent = self
                                    self._children_name_map["next_hop_address"] = "next-hop-address"

                                    self.secondary_next_hop_address = Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress()
                                    self.secondary_next_hop_address.parent = self
                                    self._children_name_map["secondary_next_hop_address"] = "secondary-next-hop-address"
                                    self._segment_path = lambda: "rpf-hash-source"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource, ['source_address', 'mofrr', 'next_hop_multipath_enabled', 'next_hop_interface', 'secondary_next_hop_interface'], name, value)


                                class NextHopAddress(Entity):
                                    """
                                    Next hop neighbor address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress, self).__init__()

                                        self.yang_name = "next-hop-address"
                                        self.yang_parent_name = "rpf-hash-source"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ])
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None
                                        self._segment_path = lambda: "next-hop-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                                class SecondaryNextHopAddress(Entity):
                                    """
                                    Secondary Next hop neighbor address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress, self).__init__()

                                        self.yang_name = "secondary-next-hop-address"
                                        self.yang_parent_name = "rpf-hash-source"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ])
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None
                                        self._segment_path = lambda: "secondary-next-hop-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class Rpfs(Entity):
                            """
                            PIM RPF information table
                            
                            .. attribute:: rpf
                            
                            	PIM RPF information
                            	**type**\: list of  		 :py:class:`Rpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs, self).__init__()

                                self.yang_name = "rpfs"
                                self.yang_parent_name = "saf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("rpf", ("rpf", Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf))])
                                self._leafs = OrderedDict()

                                self.rpf = YList(self)
                                self._segment_path = lambda: "rpfs"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs, [], name, value)


                            class Rpf(Entity):
                                """
                                PIM RPF information
                                
                                .. attribute:: registered_address  (key)
                                
                                	Address for which RPF lookup
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: registered_address_xr
                                
                                	Address registered
                                	**type**\:  :py:class:`RegisteredAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr>`
                                
                                .. attribute:: metric
                                
                                	Metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_preference
                                
                                	Metric preference
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_connected
                                
                                	Are we connected ?
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: is_rpf_bgp_route
                                
                                	Is RPF through BGP route
                                	**type**\: bool
                                
                                .. attribute:: rpf_path
                                
                                	RPF Paths list
                                	**type**\: list of  		 :py:class:`RpfPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf, self).__init__()

                                    self.yang_name = "rpf"
                                    self.yang_parent_name = "rpfs"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['registered_address']
                                    self._child_classes = OrderedDict([("registered-address-xr", ("registered_address_xr", Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr)), ("rpf-path", ("rpf_path", Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath))])
                                    self._leafs = OrderedDict([
                                        ('registered_address', (YLeaf(YType.str, 'registered-address'), ['str','str'])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_preference', (YLeaf(YType.uint32, 'metric-preference'), ['int'])),
                                        ('is_connected', (YLeaf(YType.uint8, 'is-connected'), ['int'])),
                                        ('is_rpf_bgp_route', (YLeaf(YType.boolean, 'is-rpf-bgp-route'), ['bool'])),
                                    ])
                                    self.registered_address = None
                                    self.metric = None
                                    self.metric_preference = None
                                    self.is_connected = None
                                    self.is_rpf_bgp_route = None

                                    self.registered_address_xr = Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr()
                                    self.registered_address_xr.parent = self
                                    self._children_name_map["registered_address_xr"] = "registered-address-xr"

                                    self.rpf_path = YList(self)
                                    self._segment_path = lambda: "rpf" + "[registered-address='" + str(self.registered_address) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf, ['registered_address', 'metric', 'metric_preference', 'is_connected', 'is_rpf_bgp_route'], name, value)


                                class RegisteredAddressXr(Entity):
                                    """
                                    Address registered
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr, self).__init__()

                                        self.yang_name = "registered-address-xr"
                                        self.yang_parent_name = "rpf"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ])
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None
                                        self._segment_path = lambda: "registered-address-xr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                                class RpfPath(Entity):
                                    """
                                    RPF Paths list
                                    
                                    .. attribute:: rpf_neighbor
                                    
                                    	RPF neighbor
                                    	**type**\:  :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor>`
                                    
                                    .. attribute:: rpf_nexthop
                                    
                                    	RPF nexthop
                                    	**type**\:  :py:class:`RpfNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop>`
                                    
                                    .. attribute:: rpf_interface_name
                                    
                                    	RPF Interface
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: is_rpf_interface_disabled
                                    
                                    	Is the rpf interface disabled ?
                                    	**type**\: bool
                                    
                                    .. attribute:: is_via_lsm
                                    
                                    	Via LSM
                                    	**type**\: bool
                                    
                                    .. attribute:: is_via_mlsm
                                    
                                    	Via Mstatic LSM
                                    	**type**\: bool
                                    
                                    .. attribute:: is_connector_attribute_present
                                    
                                    	Connector attribute present
                                    	**type**\: bool
                                    
                                    .. attribute:: connector
                                    
                                    	Connector Attribute
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    .. attribute:: extranet_vrf_name
                                    
                                    	Extranet VRF name
                                    	**type**\: str
                                    
                                    	**length:** 0..33
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath, self).__init__()

                                        self.yang_name = "rpf-path"
                                        self.yang_parent_name = "rpf"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("rpf-neighbor", ("rpf_neighbor", Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor)), ("rpf-nexthop", ("rpf_nexthop", Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop))])
                                        self._leafs = OrderedDict([
                                            ('rpf_interface_name', (YLeaf(YType.str, 'rpf-interface-name'), ['str'])),
                                            ('is_rpf_interface_disabled', (YLeaf(YType.boolean, 'is-rpf-interface-disabled'), ['bool'])),
                                            ('is_via_lsm', (YLeaf(YType.boolean, 'is-via-lsm'), ['bool'])),
                                            ('is_via_mlsm', (YLeaf(YType.boolean, 'is-via-mlsm'), ['bool'])),
                                            ('is_connector_attribute_present', (YLeaf(YType.boolean, 'is-connector-attribute-present'), ['bool'])),
                                            ('connector', (YLeaf(YType.str, 'connector'), ['str'])),
                                            ('extranet_vrf_name', (YLeaf(YType.str, 'extranet-vrf-name'), ['str'])),
                                        ])
                                        self.rpf_interface_name = None
                                        self.is_rpf_interface_disabled = None
                                        self.is_via_lsm = None
                                        self.is_via_mlsm = None
                                        self.is_connector_attribute_present = None
                                        self.connector = None
                                        self.extranet_vrf_name = None

                                        self.rpf_neighbor = Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor()
                                        self.rpf_neighbor.parent = self
                                        self._children_name_map["rpf_neighbor"] = "rpf-neighbor"

                                        self.rpf_nexthop = Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop()
                                        self.rpf_nexthop.parent = self
                                        self._children_name_map["rpf_nexthop"] = "rpf-nexthop"
                                        self._segment_path = lambda: "rpf-path"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath, ['rpf_interface_name', 'is_rpf_interface_disabled', 'is_via_lsm', 'is_via_mlsm', 'is_connector_attribute_present', 'connector', 'extranet_vrf_name'], name, value)


                                    class RpfNeighbor(Entity):
                                        """
                                        RPF neighbor
                                        
                                        .. attribute:: af_name
                                        
                                        	AFName
                                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Address
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-pim-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor, self).__init__()

                                            self.yang_name = "rpf-neighbor"
                                            self.yang_parent_name = "rpf-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                            ])
                                            self.af_name = None
                                            self.ipv4_address = None
                                            self.ipv6_address = None
                                            self._segment_path = lambda: "rpf-neighbor"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                                    class RpfNexthop(Entity):
                                        """
                                        RPF nexthop
                                        
                                        .. attribute:: af_name
                                        
                                        	AFName
                                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Address
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-pim-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop, self).__init__()

                                            self.yang_name = "rpf-nexthop"
                                            self.yang_parent_name = "rpf-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                            ])
                                            self.af_name = None
                                            self.ipv4_address = None
                                            self.ipv6_address = None
                                            self._segment_path = lambda: "rpf-nexthop"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class InterfaceStatistics(Entity):
                    """
                    PIM interface statistics
                    
                    .. attribute:: interface_statistic
                    
                    	PIM interface statistics
                    	**type**\: list of  		 :py:class:`InterfaceStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.InterfaceStatistics.InterfaceStatistic>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.InterfaceStatistics, self).__init__()

                        self.yang_name = "interface-statistics"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("interface-statistic", ("interface_statistic", Ipv6Pim.Standby.Vrfs.Vrf.InterfaceStatistics.InterfaceStatistic))])
                        self._leafs = OrderedDict()

                        self.interface_statistic = YList(self)
                        self._segment_path = lambda: "interface-statistics"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.InterfaceStatistics, [], name, value)


                    class InterfaceStatistic(Entity):
                        """
                        PIM interface statistics
                        
                        .. attribute:: interface_name  (key)
                        
                        	Interface name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: input_hello
                        
                        	Hello packets in
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_hello
                        
                        	Hello packets out
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_register
                        
                        	Register packets in
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_register
                        
                        	Register packets out
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_register_stop
                        
                        	Register Stop packets in
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_register_stop
                        
                        	Register Stop packets out
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_jp
                        
                        	Join Prune packets in
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_jp
                        
                        	Join Prune packets out
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_bsr_message
                        
                        	Input BSR Messages
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_bsr_message
                        
                        	Output BSR Messages
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_assert
                        
                        	Assert packets in
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_assert
                        
                        	Assert packets out
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_graft_message
                        
                        	Input Graft Messages
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_graft_message
                        
                        	Output Graft Messages
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_graft_ack_message
                        
                        	Input Graft Ack Messages
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_graft_ack_message
                        
                        	Output Graft Ack Messages
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_candidate_rp_advertisement
                        
                        	Input Candidate\-RP Advertisment
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_candidate_rp_advertisement
                        
                        	Output Candidate\-RP Advertisment
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_df_election
                        
                        	DF Election packets in
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_df_election
                        
                        	DF Election packets out
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_miscellaneous
                        
                        	Miscellaneous packet in
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.InterfaceStatistics.InterfaceStatistic, self).__init__()

                            self.yang_name = "interface-statistic"
                            self.yang_parent_name = "interface-statistics"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['interface_name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ('input_hello', (YLeaf(YType.uint32, 'input-hello'), ['int'])),
                                ('output_hello', (YLeaf(YType.uint32, 'output-hello'), ['int'])),
                                ('input_register', (YLeaf(YType.uint32, 'input-register'), ['int'])),
                                ('output_register', (YLeaf(YType.uint32, 'output-register'), ['int'])),
                                ('input_register_stop', (YLeaf(YType.uint32, 'input-register-stop'), ['int'])),
                                ('output_register_stop', (YLeaf(YType.uint32, 'output-register-stop'), ['int'])),
                                ('input_jp', (YLeaf(YType.uint32, 'input-jp'), ['int'])),
                                ('output_jp', (YLeaf(YType.uint32, 'output-jp'), ['int'])),
                                ('input_bsr_message', (YLeaf(YType.uint32, 'input-bsr-message'), ['int'])),
                                ('output_bsr_message', (YLeaf(YType.uint32, 'output-bsr-message'), ['int'])),
                                ('input_assert', (YLeaf(YType.uint32, 'input-assert'), ['int'])),
                                ('output_assert', (YLeaf(YType.uint32, 'output-assert'), ['int'])),
                                ('input_graft_message', (YLeaf(YType.uint32, 'input-graft-message'), ['int'])),
                                ('output_graft_message', (YLeaf(YType.uint32, 'output-graft-message'), ['int'])),
                                ('input_graft_ack_message', (YLeaf(YType.uint32, 'input-graft-ack-message'), ['int'])),
                                ('output_graft_ack_message', (YLeaf(YType.uint32, 'output-graft-ack-message'), ['int'])),
                                ('input_candidate_rp_advertisement', (YLeaf(YType.uint32, 'input-candidate-rp-advertisement'), ['int'])),
                                ('output_candidate_rp_advertisement', (YLeaf(YType.uint32, 'output-candidate-rp-advertisement'), ['int'])),
                                ('input_df_election', (YLeaf(YType.uint32, 'input-df-election'), ['int'])),
                                ('output_df_election', (YLeaf(YType.uint32, 'output-df-election'), ['int'])),
                                ('input_miscellaneous', (YLeaf(YType.uint32, 'input-miscellaneous'), ['int'])),
                            ])
                            self.interface_name = None
                            self.input_hello = None
                            self.output_hello = None
                            self.input_register = None
                            self.output_register = None
                            self.input_register_stop = None
                            self.output_register_stop = None
                            self.input_jp = None
                            self.output_jp = None
                            self.input_bsr_message = None
                            self.output_bsr_message = None
                            self.input_assert = None
                            self.output_assert = None
                            self.input_graft_message = None
                            self.output_graft_message = None
                            self.input_graft_ack_message = None
                            self.output_graft_ack_message = None
                            self.input_candidate_rp_advertisement = None
                            self.output_candidate_rp_advertisement = None
                            self.input_df_election = None
                            self.output_df_election = None
                            self.input_miscellaneous = None
                            self._segment_path = lambda: "interface-statistic" + "[interface-name='" + str(self.interface_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.InterfaceStatistics.InterfaceStatistic, ['interface_name', 'input_hello', 'output_hello', 'input_register', 'output_register', 'input_register_stop', 'output_register_stop', 'input_jp', 'output_jp', 'input_bsr_message', 'output_bsr_message', 'input_assert', 'output_assert', 'input_graft_message', 'output_graft_message', 'input_graft_ack_message', 'output_graft_ack_message', 'input_candidate_rp_advertisement', 'output_candidate_rp_advertisement', 'input_df_election', 'output_df_election', 'input_miscellaneous'], name, value)


                class TopologyRouteCount(Entity):
                    """
                    Topology route count information from PIM
                    topology table
                    
                    .. attribute:: group_ranges
                    
                    	No. of (\*,G/M) routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: active_group_ranges
                    
                    	No. of (\*,G/M) routes active in mrib
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: groute_count
                    
                    	No. of (\*,G) routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sg_route_count
                    
                    	No. of (S,G) routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sgr_route_count
                    
                    	No. of (S,G)RPT routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.TopologyRouteCount, self).__init__()

                        self.yang_name = "topology-route-count"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('group_ranges', (YLeaf(YType.uint32, 'group-ranges'), ['int'])),
                            ('active_group_ranges', (YLeaf(YType.uint32, 'active-group-ranges'), ['int'])),
                            ('groute_count', (YLeaf(YType.uint32, 'groute-count'), ['int'])),
                            ('sg_route_count', (YLeaf(YType.uint32, 'sg-route-count'), ['int'])),
                            ('sgr_route_count', (YLeaf(YType.uint32, 'sgr-route-count'), ['int'])),
                            ('is_node_low_memory', (YLeaf(YType.boolean, 'is-node-low-memory'), ['bool'])),
                        ])
                        self.group_ranges = None
                        self.active_group_ranges = None
                        self.groute_count = None
                        self.sg_route_count = None
                        self.sgr_route_count = None
                        self.is_node_low_memory = None
                        self._segment_path = lambda: "topology-route-count"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.TopologyRouteCount, ['group_ranges', 'active_group_ranges', 'groute_count', 'sg_route_count', 'sgr_route_count', 'is_node_low_memory'], name, value)


                class JpStatistics(Entity):
                    """
                    PIM join prune statistics table
                    
                    .. attribute:: jp_statistic
                    
                    	PIM Join Prune Statistics
                    	**type**\: list of  		 :py:class:`JpStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.JpStatistics.JpStatistic>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.JpStatistics, self).__init__()

                        self.yang_name = "jp-statistics"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("jp-statistic", ("jp_statistic", Ipv6Pim.Standby.Vrfs.Vrf.JpStatistics.JpStatistic))])
                        self._leafs = OrderedDict()

                        self.jp_statistic = YList(self)
                        self._segment_path = lambda: "jp-statistics"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.JpStatistics, [], name, value)


                    class JpStatistic(Entity):
                        """
                        PIM Join Prune Statistics
                        
                        .. attribute:: interface_name  (key)
                        
                        	Interface name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identifier
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: mtu
                        
                        	Interface MTU
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: transmitted
                        
                        	Transmitted
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: transmitted100
                        
                        	Transmitted 100 average
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: transmitted_1k
                        
                        	Transmitted 1K average
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: transmitted_10k
                        
                        	Transmitted 10K average
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: transmitted_50k
                        
                        	Deprecated by Transmitted100
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: received
                        
                        	Received
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: received100
                        
                        	Received 100 average
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: received_1k
                        
                        	Received 1K average
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: received_10k
                        
                        	Received 10K average
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: received_50k
                        
                        	Deprecated by Received100
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.JpStatistics.JpStatistic, self).__init__()

                            self.yang_name = "jp-statistic"
                            self.yang_parent_name = "jp-statistics"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['interface_name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                                ('mtu', (YLeaf(YType.uint32, 'mtu'), ['int'])),
                                ('transmitted', (YLeaf(YType.uint32, 'transmitted'), ['int'])),
                                ('transmitted100', (YLeaf(YType.uint16, 'transmitted100'), ['int'])),
                                ('transmitted_1k', (YLeaf(YType.uint16, 'transmitted-1k'), ['int'])),
                                ('transmitted_10k', (YLeaf(YType.uint16, 'transmitted-10k'), ['int'])),
                                ('transmitted_50k', (YLeaf(YType.uint16, 'transmitted-50k'), ['int'])),
                                ('received', (YLeaf(YType.uint32, 'received'), ['int'])),
                                ('received100', (YLeaf(YType.uint16, 'received100'), ['int'])),
                                ('received_1k', (YLeaf(YType.uint16, 'received-1k'), ['int'])),
                                ('received_10k', (YLeaf(YType.uint16, 'received-10k'), ['int'])),
                                ('received_50k', (YLeaf(YType.uint16, 'received-50k'), ['int'])),
                            ])
                            self.interface_name = None
                            self.interface_name_xr = None
                            self.mtu = None
                            self.transmitted = None
                            self.transmitted100 = None
                            self.transmitted_1k = None
                            self.transmitted_10k = None
                            self.transmitted_50k = None
                            self.received = None
                            self.received100 = None
                            self.received_1k = None
                            self.received_10k = None
                            self.received_50k = None
                            self._segment_path = lambda: "jp-statistic" + "[interface-name='" + str(self.interface_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.JpStatistics.JpStatistic, ['interface_name', 'interface_name_xr', 'mtu', 'transmitted', 'transmitted100', 'transmitted_1k', 'transmitted_10k', 'transmitted_50k', 'received', 'received100', 'received_1k', 'received_10k', 'received_50k'], name, value)


                class MibDatabases(Entity):
                    """
                    PIM group database for mroute mibs table
                    
                    .. attribute:: mib_database
                    
                    	PIM multicast static route information
                    	**type**\: list of  		 :py:class:`MibDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases, self).__init__()

                        self.yang_name = "mib-databases"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("mib-database", ("mib_database", Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase))])
                        self._leafs = OrderedDict()

                        self.mib_database = YList(self)
                        self._segment_path = lambda: "mib-databases"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases, [], name, value)


                    class MibDatabase(Entity):
                        """
                        PIM multicast static route information
                        
                        .. attribute:: source_address
                        
                        	Multicast static route source address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: group_address
                        
                        	Multicast satic route group address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source_netmask
                        
                        	Source mask
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: source_address_xr
                        
                        	Source Address
                        	**type**\:  :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr>`
                        
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:  :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr>`
                        
                        .. attribute:: rpf_neighbor
                        
                        	The RPF Neighbor
                        	**type**\:  :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor>`
                        
                        .. attribute:: rpf_root
                        
                        	Root of this mcast tree
                        	**type**\:  :py:class:`RpfRoot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot>`
                        
                        .. attribute:: upstream_assert_timer
                        
                        	Upstream Assert Timer
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: assert_metric
                        
                        	Assert Metric
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: assert_metric_preference
                        
                        	Assert Metric Preference
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: assert_rpt_bit
                        
                        	Assert RPT Bit
                        	**type**\: bool
                        
                        .. attribute:: spt_bit
                        
                        	Is SPT bit set ?
                        	**type**\: bool
                        
                        .. attribute:: rpf_mask
                        
                        	Mask of the multicast root
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rpf_safi
                        
                        	Unicast or mcast
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: rpf_table_name
                        
                        	RPF Table name
                        	**type**\: str
                        
                        .. attribute:: rpf_drop
                        
                        	RPF route\-policy drop
                        	**type**\: bool
                        
                        .. attribute:: rpf_extranet
                        
                        	Extranet RPF route\-policy
                        	**type**\: bool
                        
                        .. attribute:: rpf_interface_name
                        
                        	RPF interface name 
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: rpf_vrf_name
                        
                        	RPF VRF Name
                        	**type**\: str
                        
                        	**length:** 0..33
                        
                        .. attribute:: bidirectional_route
                        
                        	Is this Bidir ?
                        	**type**\: bool
                        
                        .. attribute:: uptime
                        
                        	Uptime of route
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: protocol
                        
                        	The PIM protocol
                        	**type**\:  :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase, self).__init__()

                            self.yang_name = "mib-database"
                            self.yang_parent_name = "mib-databases"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("source-address-xr", ("source_address_xr", Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr)), ("group-address-xr", ("group_address_xr", Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr)), ("rpf-neighbor", ("rpf_neighbor", Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor)), ("rpf-root", ("rpf_root", Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot))])
                            self._leafs = OrderedDict([
                                ('source_address', (YLeaf(YType.str, 'source-address'), ['str','str'])),
                                ('group_address', (YLeaf(YType.str, 'group-address'), ['str','str'])),
                                ('source_netmask', (YLeaf(YType.uint32, 'source-netmask'), ['int'])),
                                ('upstream_assert_timer', (YLeaf(YType.int32, 'upstream-assert-timer'), ['int'])),
                                ('assert_metric', (YLeaf(YType.uint32, 'assert-metric'), ['int'])),
                                ('assert_metric_preference', (YLeaf(YType.uint32, 'assert-metric-preference'), ['int'])),
                                ('assert_rpt_bit', (YLeaf(YType.boolean, 'assert-rpt-bit'), ['bool'])),
                                ('spt_bit', (YLeaf(YType.boolean, 'spt-bit'), ['bool'])),
                                ('rpf_mask', (YLeaf(YType.uint32, 'rpf-mask'), ['int'])),
                                ('rpf_safi', (YLeaf(YType.uint8, 'rpf-safi'), ['int'])),
                                ('rpf_table_name', (YLeaf(YType.str, 'rpf-table-name'), ['str'])),
                                ('rpf_drop', (YLeaf(YType.boolean, 'rpf-drop'), ['bool'])),
                                ('rpf_extranet', (YLeaf(YType.boolean, 'rpf-extranet'), ['bool'])),
                                ('rpf_interface_name', (YLeaf(YType.str, 'rpf-interface-name'), ['str'])),
                                ('rpf_vrf_name', (YLeaf(YType.str, 'rpf-vrf-name'), ['str'])),
                                ('bidirectional_route', (YLeaf(YType.boolean, 'bidirectional-route'), ['bool'])),
                                ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                                ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowProtocol', '')])),
                            ])
                            self.source_address = None
                            self.group_address = None
                            self.source_netmask = None
                            self.upstream_assert_timer = None
                            self.assert_metric = None
                            self.assert_metric_preference = None
                            self.assert_rpt_bit = None
                            self.spt_bit = None
                            self.rpf_mask = None
                            self.rpf_safi = None
                            self.rpf_table_name = None
                            self.rpf_drop = None
                            self.rpf_extranet = None
                            self.rpf_interface_name = None
                            self.rpf_vrf_name = None
                            self.bidirectional_route = None
                            self.uptime = None
                            self.protocol = None

                            self.source_address_xr = Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr()
                            self.source_address_xr.parent = self
                            self._children_name_map["source_address_xr"] = "source-address-xr"

                            self.group_address_xr = Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"

                            self.rpf_neighbor = Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor()
                            self.rpf_neighbor.parent = self
                            self._children_name_map["rpf_neighbor"] = "rpf-neighbor"

                            self.rpf_root = Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot()
                            self.rpf_root.parent = self
                            self._children_name_map["rpf_root"] = "rpf-root"
                            self._segment_path = lambda: "mib-database"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase, ['source_address', 'group_address', 'source_netmask', 'upstream_assert_timer', 'assert_metric', 'assert_metric_preference', 'assert_rpt_bit', 'spt_bit', 'rpf_mask', 'rpf_safi', 'rpf_table_name', 'rpf_drop', 'rpf_extranet', 'rpf_interface_name', 'rpf_vrf_name', 'bidirectional_route', 'uptime', 'protocol'], name, value)


                        class SourceAddressXr(Entity):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr, self).__init__()

                                self.yang_name = "source-address-xr"
                                self.yang_parent_name = "mib-database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "source-address-xr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "mib-database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "group-address-xr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class RpfNeighbor(Entity):
                            """
                            The RPF Neighbor
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor, self).__init__()

                                self.yang_name = "rpf-neighbor"
                                self.yang_parent_name = "mib-database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "rpf-neighbor"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class RpfRoot(Entity):
                            """
                            Root of this mcast tree
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot, self).__init__()

                                self.yang_name = "rpf-root"
                                self.yang_parent_name = "mib-database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "rpf-root"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class NeighborOldFormats(Entity):
                    """
                    PIM neighbor table old format
                    
                    .. attribute:: neighbor_old_format
                    
                    	PIM neighbor information
                    	**type**\: list of  		 :py:class:`NeighborOldFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.NeighborOldFormats, self).__init__()

                        self.yang_name = "neighbor-old-formats"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("neighbor-old-format", ("neighbor_old_format", Ipv6Pim.Standby.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat))])
                        self._leafs = OrderedDict()

                        self.neighbor_old_format = YList(self)
                        self._segment_path = lambda: "neighbor-old-formats"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.NeighborOldFormats, [], name, value)


                    class NeighborOldFormat(Entity):
                        """
                        PIM neighbor information
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: neighbor_address
                        
                        	Neighbor address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identifier
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: expires
                        
                        	Neighbor expiry in seconds
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: expiry_timer
                        
                        	Expiry timer in seconds
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: is_this_neighbor_us
                        
                        	Is this neighbor us ?
                        	**type**\: bool
                        
                        .. attribute:: is_this_neighbor_dr
                        
                        	Is this neighbor the DR
                        	**type**\: bool
                        
                        .. attribute:: is_dr_priority_capable
                        
                        	Is this neighbor DR priority capable ?
                        	**type**\: bool
                        
                        .. attribute:: dr_priority
                        
                        	DR priority
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Is this neighbor bidir capable ?
                        	**type**\: bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Is this neighbor proxy capable?
                        	**type**\: bool
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Is this neighbor capable of batching asserts?
                        	**type**\: bool
                        
                        .. attribute:: is_ecmp_redirect_capable
                        
                        	Is this neighbor capable of Ecmp Redirect?
                        	**type**\: bool
                        
                        .. attribute:: is_bfd_state
                        
                        	Is the neighbor bfd session created
                        	**type**\: bool
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_address_xr
                        
                        	List of Neighbor Addresses
                        	**type**\: list of  		 :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat, self).__init__()

                            self.yang_name = "neighbor-old-format"
                            self.yang_parent_name = "neighbor-old-formats"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("neighbor-address-xr", ("neighbor_address_xr", Ipv6Pim.Standby.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr))])
                            self._leafs = OrderedDict([
                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                                ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                                ('expires', (YLeaf(YType.uint64, 'expires'), ['int'])),
                                ('expiry_timer', (YLeaf(YType.uint64, 'expiry-timer'), ['int'])),
                                ('is_this_neighbor_us', (YLeaf(YType.boolean, 'is-this-neighbor-us'), ['bool'])),
                                ('is_this_neighbor_dr', (YLeaf(YType.boolean, 'is-this-neighbor-dr'), ['bool'])),
                                ('is_dr_priority_capable', (YLeaf(YType.boolean, 'is-dr-priority-capable'), ['bool'])),
                                ('dr_priority', (YLeaf(YType.uint32, 'dr-priority'), ['int'])),
                                ('is_bidirectional_capable', (YLeaf(YType.boolean, 'is-bidirectional-capable'), ['bool'])),
                                ('is_proxy_capable', (YLeaf(YType.boolean, 'is-proxy-capable'), ['bool'])),
                                ('is_batch_asserts_capable', (YLeaf(YType.boolean, 'is-batch-asserts-capable'), ['bool'])),
                                ('is_ecmp_redirect_capable', (YLeaf(YType.boolean, 'is-ecmp-redirect-capable'), ['bool'])),
                                ('is_bfd_state', (YLeaf(YType.boolean, 'is-bfd-state'), ['bool'])),
                                ('propagation_delay', (YLeaf(YType.uint16, 'propagation-delay'), ['int'])),
                                ('override_interval', (YLeaf(YType.uint16, 'override-interval'), ['int'])),
                            ])
                            self.interface_name = None
                            self.neighbor_address = None
                            self.interface_name_xr = None
                            self.uptime = None
                            self.expires = None
                            self.expiry_timer = None
                            self.is_this_neighbor_us = None
                            self.is_this_neighbor_dr = None
                            self.is_dr_priority_capable = None
                            self.dr_priority = None
                            self.is_bidirectional_capable = None
                            self.is_proxy_capable = None
                            self.is_batch_asserts_capable = None
                            self.is_ecmp_redirect_capable = None
                            self.is_bfd_state = None
                            self.propagation_delay = None
                            self.override_interval = None

                            self.neighbor_address_xr = YList(self)
                            self._segment_path = lambda: "neighbor-old-format"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat, ['interface_name', 'neighbor_address', 'interface_name_xr', 'uptime', 'expires', 'expiry_timer', 'is_this_neighbor_us', 'is_this_neighbor_dr', 'is_dr_priority_capable', 'dr_priority', 'is_bidirectional_capable', 'is_proxy_capable', 'is_batch_asserts_capable', 'is_ecmp_redirect_capable', 'is_bfd_state', 'propagation_delay', 'override_interval'], name, value)


                        class NeighborAddressXr(Entity):
                            """
                            List of Neighbor Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr, self).__init__()

                                self.yang_name = "neighbor-address-xr"
                                self.yang_parent_name = "neighbor-old-format"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "neighbor-address-xr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class IfrsSummary(Entity):
                    """
                    PIM interfaces in forward reference store
                    summary
                    
                    .. attribute:: interface_count
                    
                    	Number of interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: configuration_count
                    
                    	Configuration counts
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.IfrsSummary, self).__init__()

                        self.yang_name = "ifrs-summary"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('interface_count', (YLeaf(YType.uint32, 'interface-count'), ['int'])),
                            ('configuration_count', (YLeaf(YType.uint32, 'configuration-count'), ['int'])),
                        ])
                        self.interface_count = None
                        self.configuration_count = None
                        self._segment_path = lambda: "ifrs-summary"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.IfrsSummary, ['interface_count', 'configuration_count'], name, value)


                class Ranges(Entity):
                    """
                    PIM range list information
                    
                    .. attribute:: range
                    
                    	PIM range list information
                    	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.Ranges, self).__init__()

                        self.yang_name = "ranges"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("range", ("range", Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range))])
                        self._leafs = OrderedDict()

                        self.range = YList(self)
                        self._segment_path = lambda: "ranges"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Ranges, [], name, value)


                    class Range(Entity):
                        """
                        PIM range list information
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: client
                        
                        	Client
                        	**type**\:  :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                        
                        .. attribute:: rp_address_xr
                        
                        	Rendezvous point address
                        	**type**\:  :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.RpAddressXr>`
                        
                        .. attribute:: source_of_information
                        
                        	Source of information
                        	**type**\:  :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.SourceOfInformation>`
                        
                        .. attribute:: protocol
                        
                        	PIM protocol
                        	**type**\:  :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: client_xr
                        
                        	Client mapping learnt via
                        	**type**\:  :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                        
                        .. attribute:: expires
                        
                        	When mapping expires
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: group_range
                        
                        	List of group ranges
                        	**type**\: list of  		 :py:class:`GroupRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range, self).__init__()

                            self.yang_name = "range"
                            self.yang_parent_name = "ranges"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rp-address-xr", ("rp_address_xr", Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.RpAddressXr)), ("source-of-information", ("source_of_information", Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.SourceOfInformation)), ("group-range", ("group_range", Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange))])
                            self._leafs = OrderedDict([
                                ('rp_address', (YLeaf(YType.str, 'rp-address'), ['str','str'])),
                                ('client', (YLeaf(YType.enumeration, 'client'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimClient', '')])),
                                ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowProtocol', '')])),
                                ('client_xr', (YLeaf(YType.enumeration, 'client-xr'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowRangeClient', '')])),
                                ('expires', (YLeaf(YType.uint64, 'expires'), ['int'])),
                            ])
                            self.rp_address = None
                            self.client = None
                            self.protocol = None
                            self.client_xr = None
                            self.expires = None

                            self.rp_address_xr = Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.RpAddressXr()
                            self.rp_address_xr.parent = self
                            self._children_name_map["rp_address_xr"] = "rp-address-xr"

                            self.source_of_information = Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.SourceOfInformation()
                            self.source_of_information.parent = self
                            self._children_name_map["source_of_information"] = "source-of-information"

                            self.group_range = YList(self)
                            self._segment_path = lambda: "range"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range, ['rp_address', 'client', 'protocol', 'client_xr', 'expires'], name, value)


                        class RpAddressXr(Entity):
                            """
                            Rendezvous point address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.RpAddressXr, self).__init__()

                                self.yang_name = "rp-address-xr"
                                self.yang_parent_name = "range"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "rp-address-xr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.RpAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class SourceOfInformation(Entity):
                            """
                            Source of information
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.SourceOfInformation, self).__init__()

                                self.yang_name = "source-of-information"
                                self.yang_parent_name = "range"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "source-of-information"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.SourceOfInformation, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class GroupRange(Entity):
                            """
                            List of group ranges
                            
                            .. attribute:: prefix
                            
                            	Group range prefix
                            	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix>`
                            
                            .. attribute:: source_of_information
                            
                            	Source of information
                            	**type**\:  :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation>`
                            
                            .. attribute:: prefix_length
                            
                            	Group range prefix length
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: expires
                            
                            	When mapping expires
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange, self).__init__()

                                self.yang_name = "group-range"
                                self.yang_parent_name = "range"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("prefix", ("prefix", Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix)), ("source-of-information", ("source_of_information", Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation))])
                                self._leafs = OrderedDict([
                                    ('prefix_length', (YLeaf(YType.int32, 'prefix-length'), ['int'])),
                                    ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                                    ('expires', (YLeaf(YType.uint64, 'expires'), ['int'])),
                                ])
                                self.prefix_length = None
                                self.uptime = None
                                self.expires = None

                                self.prefix = Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix()
                                self.prefix.parent = self
                                self._children_name_map["prefix"] = "prefix"

                                self.source_of_information = Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation()
                                self.source_of_information.parent = self
                                self._children_name_map["source_of_information"] = "source-of-information"
                                self._segment_path = lambda: "group-range"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange, ['prefix_length', 'uptime', 'expires'], name, value)


                            class Prefix(Entity):
                                """
                                Group range prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix, self).__init__()

                                    self.yang_name = "prefix"
                                    self.yang_parent_name = "group-range"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "prefix"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                            class SourceOfInformation(Entity):
                                """
                                Source of information
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation, self).__init__()

                                    self.yang_name = "source-of-information"
                                    self.yang_parent_name = "group-range"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "source-of-information"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class InterfaceOldFormats(Entity):
                    """
                    PIM interfaces in old format
                    
                    .. attribute:: interface_old_format
                    
                    	PIM interface name
                    	**type**\: list of  		 :py:class:`InterfaceOldFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats, self).__init__()

                        self.yang_name = "interface-old-formats"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("interface-old-format", ("interface_old_format", Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat))])
                        self._leafs = OrderedDict()

                        self.interface_old_format = YList(self)
                        self._segment_path = lambda: "interface-old-formats"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats, [], name, value)


                    class InterfaceOldFormat(Entity):
                        """
                        PIM interface name
                        
                        .. attribute:: interface_name  (key)
                        
                        	Interface name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: dr_address
                        
                        	PIM Designated Router
                        	**type**\:  :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress>`
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identfier
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: interface_address_mask
                        
                        	Interface IP Address Mask
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: is_enabled
                        
                        	Is PIM enabled on this IF ?
                        	**type**\: bool
                        
                        .. attribute:: neighbor_count
                        
                        	No. of neighbors on this IF
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: external_neighbor_count
                        
                        	No. of external neighbors on this IF
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: hello_interval
                        
                        	Hello Interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: dr_priority
                        
                        	DR Priority
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: hello_expiry
                        
                        	Hello Timer Expiry
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: are_we_dr
                        
                        	Are we the DR on this IF ?
                        	**type**\: bool
                        
                        .. attribute:: bfd_enabled
                        
                        	BFD state
                        	**type**\: bool
                        
                        .. attribute:: bfd_interval
                        
                        	BFD Interval
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bfd_multiplier
                        
                        	BFD Multiplier
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_interface
                        
                        	 is this a Virtual Interfaces ?
                        	**type**\: bool
                        
                        .. attribute:: passive_interface
                        
                        	Passive PIM interface
                        	**type**\: bool
                        
                        .. attribute:: neighbor_filter_name
                        
                        	Neighbor Filter Name
                        	**type**\: str
                        
                        .. attribute:: join_prune_interval
                        
                        	Join\-Prune Interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: prune_delay_enabled
                        
                        	Prune Delay Enabled
                        	**type**\: bool
                        
                        .. attribute:: configured_propagation_delay
                        
                        	Configured Propagation Delay
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: configured_override_interval
                        
                        	Configured Override Interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: generation_id
                        
                        	Generation Identifier
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Bidir Capable
                        	**type**\: bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Proxy Capable
                        	**type**\: bool
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Batch Asserts Capable
                        	**type**\: bool
                        
                        .. attribute:: idb_oor_enabled
                        
                        	Interface oor enabled
                        	**type**\: bool
                        
                        .. attribute:: idb_acl_provided
                        
                        	ACL name provided
                        	**type**\: bool
                        
                        .. attribute:: idb_max_count
                        
                        	Interface ole max count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_threshold_count
                        
                        	Interface ole threshold count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_current_count
                        
                        	Interface ole current count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_acl_name
                        
                        	Interface ole ACL Name
                        	**type**\: str
                        
                        	**length:** 0..64
                        
                        .. attribute:: interface_address
                        
                        	List of Interface IP Addresses
                        	**type**\: list of  		 :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat, self).__init__()

                            self.yang_name = "interface-old-format"
                            self.yang_parent_name = "interface-old-formats"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['interface_name']
                            self._child_classes = OrderedDict([("dr-address", ("dr_address", Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress)), ("interface-address", ("interface_address", Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress))])
                            self._leafs = OrderedDict([
                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                                ('interface_address_mask', (YLeaf(YType.uint8, 'interface-address-mask'), ['int'])),
                                ('is_enabled', (YLeaf(YType.boolean, 'is-enabled'), ['bool'])),
                                ('neighbor_count', (YLeaf(YType.uint16, 'neighbor-count'), ['int'])),
                                ('external_neighbor_count', (YLeaf(YType.uint16, 'external-neighbor-count'), ['int'])),
                                ('hello_interval', (YLeaf(YType.uint16, 'hello-interval'), ['int'])),
                                ('dr_priority', (YLeaf(YType.uint32, 'dr-priority'), ['int'])),
                                ('hello_expiry', (YLeaf(YType.uint64, 'hello-expiry'), ['int'])),
                                ('are_we_dr', (YLeaf(YType.boolean, 'are-we-dr'), ['bool'])),
                                ('bfd_enabled', (YLeaf(YType.boolean, 'bfd-enabled'), ['bool'])),
                                ('bfd_interval', (YLeaf(YType.uint32, 'bfd-interval'), ['int'])),
                                ('bfd_multiplier', (YLeaf(YType.uint32, 'bfd-multiplier'), ['int'])),
                                ('virtual_interface', (YLeaf(YType.boolean, 'virtual-interface'), ['bool'])),
                                ('passive_interface', (YLeaf(YType.boolean, 'passive-interface'), ['bool'])),
                                ('neighbor_filter_name', (YLeaf(YType.str, 'neighbor-filter-name'), ['str'])),
                                ('join_prune_interval', (YLeaf(YType.uint16, 'join-prune-interval'), ['int'])),
                                ('prune_delay_enabled', (YLeaf(YType.boolean, 'prune-delay-enabled'), ['bool'])),
                                ('configured_propagation_delay', (YLeaf(YType.uint16, 'configured-propagation-delay'), ['int'])),
                                ('propagation_delay', (YLeaf(YType.uint16, 'propagation-delay'), ['int'])),
                                ('configured_override_interval', (YLeaf(YType.uint16, 'configured-override-interval'), ['int'])),
                                ('override_interval', (YLeaf(YType.uint16, 'override-interval'), ['int'])),
                                ('generation_id', (YLeaf(YType.uint32, 'generation-id'), ['int'])),
                                ('is_bidirectional_capable', (YLeaf(YType.boolean, 'is-bidirectional-capable'), ['bool'])),
                                ('is_proxy_capable', (YLeaf(YType.boolean, 'is-proxy-capable'), ['bool'])),
                                ('is_batch_asserts_capable', (YLeaf(YType.boolean, 'is-batch-asserts-capable'), ['bool'])),
                                ('idb_oor_enabled', (YLeaf(YType.boolean, 'idb-oor-enabled'), ['bool'])),
                                ('idb_acl_provided', (YLeaf(YType.boolean, 'idb-acl-provided'), ['bool'])),
                                ('idb_max_count', (YLeaf(YType.uint32, 'idb-max-count'), ['int'])),
                                ('idb_threshold_count', (YLeaf(YType.uint32, 'idb-threshold-count'), ['int'])),
                                ('idb_current_count', (YLeaf(YType.uint32, 'idb-current-count'), ['int'])),
                                ('idb_acl_name', (YLeaf(YType.str, 'idb-acl-name'), ['str'])),
                            ])
                            self.interface_name = None
                            self.interface_name_xr = None
                            self.interface_address_mask = None
                            self.is_enabled = None
                            self.neighbor_count = None
                            self.external_neighbor_count = None
                            self.hello_interval = None
                            self.dr_priority = None
                            self.hello_expiry = None
                            self.are_we_dr = None
                            self.bfd_enabled = None
                            self.bfd_interval = None
                            self.bfd_multiplier = None
                            self.virtual_interface = None
                            self.passive_interface = None
                            self.neighbor_filter_name = None
                            self.join_prune_interval = None
                            self.prune_delay_enabled = None
                            self.configured_propagation_delay = None
                            self.propagation_delay = None
                            self.configured_override_interval = None
                            self.override_interval = None
                            self.generation_id = None
                            self.is_bidirectional_capable = None
                            self.is_proxy_capable = None
                            self.is_batch_asserts_capable = None
                            self.idb_oor_enabled = None
                            self.idb_acl_provided = None
                            self.idb_max_count = None
                            self.idb_threshold_count = None
                            self.idb_current_count = None
                            self.idb_acl_name = None

                            self.dr_address = Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress()
                            self.dr_address.parent = self
                            self._children_name_map["dr_address"] = "dr-address"

                            self.interface_address = YList(self)
                            self._segment_path = lambda: "interface-old-format" + "[interface-name='" + str(self.interface_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat, ['interface_name', 'interface_name_xr', 'interface_address_mask', 'is_enabled', 'neighbor_count', 'external_neighbor_count', 'hello_interval', 'dr_priority', 'hello_expiry', 'are_we_dr', 'bfd_enabled', 'bfd_interval', 'bfd_multiplier', 'virtual_interface', 'passive_interface', 'neighbor_filter_name', 'join_prune_interval', 'prune_delay_enabled', 'configured_propagation_delay', 'propagation_delay', 'configured_override_interval', 'override_interval', 'generation_id', 'is_bidirectional_capable', 'is_proxy_capable', 'is_batch_asserts_capable', 'idb_oor_enabled', 'idb_acl_provided', 'idb_max_count', 'idb_threshold_count', 'idb_current_count', 'idb_acl_name'], name, value)


                        class DrAddress(Entity):
                            """
                            PIM Designated Router
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress, self).__init__()

                                self.yang_name = "dr-address"
                                self.yang_parent_name = "interface-old-format"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "dr-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class InterfaceAddress(Entity):
                            """
                            List of Interface IP Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress, self).__init__()

                                self.yang_name = "interface-address"
                                self.yang_parent_name = "interface-old-format"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "interface-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class Bsr(Entity):
                    """
                    PIM BSR information
                    
                    .. attribute:: rp_caches
                    
                    	PIM BSR RP cache table
                    	**type**\:  :py:class:`RpCaches <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches>`
                    
                    .. attribute:: candidate_rps
                    
                    	PIM candidate\-RP
                    	**type**\:  :py:class:`CandidateRps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps>`
                    
                    .. attribute:: bsr_elections
                    
                    	PIM BSR election state
                    	**type**\:  :py:class:`BsrElections <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr, self).__init__()

                        self.yang_name = "bsr"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("rp-caches", ("rp_caches", Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches)), ("candidate-rps", ("candidate_rps", Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps)), ("bsr-elections", ("bsr_elections", Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections))])
                        self._leafs = OrderedDict()

                        self.rp_caches = Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches()
                        self.rp_caches.parent = self
                        self._children_name_map["rp_caches"] = "rp-caches"

                        self.candidate_rps = Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps()
                        self.candidate_rps.parent = self
                        self._children_name_map["candidate_rps"] = "candidate-rps"

                        self.bsr_elections = Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections()
                        self.bsr_elections.parent = self
                        self._children_name_map["bsr_elections"] = "bsr-elections"
                        self._segment_path = lambda: "bsr"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Bsr, [], name, value)


                    class RpCaches(Entity):
                        """
                        PIM BSR RP cache table
                        
                        .. attribute:: rp_cache
                        
                        	PIM BSR RP cache
                        	**type**\: list of  		 :py:class:`RpCache <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches, self).__init__()

                            self.yang_name = "rp-caches"
                            self.yang_parent_name = "bsr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rp-cache", ("rp_cache", Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache))])
                            self._leafs = OrderedDict()

                            self.rp_cache = YList(self)
                            self._segment_path = lambda: "rp-caches"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches, [], name, value)


                        class RpCache(Entity):
                            """
                            PIM BSR RP cache
                            
                            .. attribute:: group_prefix  (key)
                            
                            	Group prefix
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: group_prefix_xr
                            
                            	Group Prefix
                            	**type**\:  :py:class:`GroupPrefixXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr>`
                            
                            .. attribute:: candidate_rp_list
                            
                            	C\-RP list for this prefix
                            	**type**\:  :py:class:`CandidateRpList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList>`
                            
                            .. attribute:: group_prefix_length
                            
                            	Group Prefix Length
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: candidate_rp_group_count
                            
                            	C\-RP count for this Prefix
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache, self).__init__()

                                self.yang_name = "rp-cache"
                                self.yang_parent_name = "rp-caches"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['group_prefix']
                                self._child_classes = OrderedDict([("group-prefix-xr", ("group_prefix_xr", Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr)), ("candidate-rp-list", ("candidate_rp_list", Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList))])
                                self._leafs = OrderedDict([
                                    ('group_prefix', (YLeaf(YType.str, 'group-prefix'), ['str','str'])),
                                    ('group_prefix_length', (YLeaf(YType.uint32, 'group-prefix-length'), ['int'])),
                                    ('candidate_rp_group_count', (YLeaf(YType.uint32, 'candidate-rp-group-count'), ['int'])),
                                ])
                                self.group_prefix = None
                                self.group_prefix_length = None
                                self.candidate_rp_group_count = None

                                self.group_prefix_xr = Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr()
                                self.group_prefix_xr.parent = self
                                self._children_name_map["group_prefix_xr"] = "group-prefix-xr"

                                self.candidate_rp_list = Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList()
                                self.candidate_rp_list.parent = self
                                self._children_name_map["candidate_rp_list"] = "candidate-rp-list"
                                self._segment_path = lambda: "rp-cache" + "[group-prefix='" + str(self.group_prefix) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache, ['group_prefix', 'group_prefix_length', 'candidate_rp_group_count'], name, value)


                            class GroupPrefixXr(Entity):
                                """
                                Group Prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr, self).__init__()

                                    self.yang_name = "group-prefix-xr"
                                    self.yang_parent_name = "rp-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "group-prefix-xr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                            class CandidateRpList(Entity):
                                """
                                C\-RP list for this prefix
                                
                                .. attribute:: pim_bsr_crp_bag
                                
                                	pim bsr crp bag
                                	**type**\: list of  		 :py:class:`PimBsrCrpBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList, self).__init__()

                                    self.yang_name = "candidate-rp-list"
                                    self.yang_parent_name = "rp-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("pim-bsr-crp-bag", ("pim_bsr_crp_bag", Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag))])
                                    self._leafs = OrderedDict()

                                    self.pim_bsr_crp_bag = YList(self)
                                    self._segment_path = lambda: "candidate-rp-list"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList, [], name, value)


                                class PimBsrCrpBag(Entity):
                                    """
                                    pim bsr crp bag
                                    
                                    .. attribute:: candidate_rp_address
                                    
                                    	C\-RP address
                                    	**type**\:  :py:class:`CandidateRpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress>`
                                    
                                    .. attribute:: candidate_rp_holdtime
                                    
                                    	C\-RP Holdtime
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: candidate_rp_priority
                                    
                                    	C\-RP Priority
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: candidate_rp_up_time
                                    
                                    	C\-RP Uptime
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: candidate_rp_expires
                                    
                                    	C\-RP Expires
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: protocol
                                    
                                    	PIM Protocol
                                    	**type**\:  :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag, self).__init__()

                                        self.yang_name = "pim-bsr-crp-bag"
                                        self.yang_parent_name = "candidate-rp-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("candidate-rp-address", ("candidate_rp_address", Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress))])
                                        self._leafs = OrderedDict([
                                            ('candidate_rp_holdtime', (YLeaf(YType.uint16, 'candidate-rp-holdtime'), ['int'])),
                                            ('candidate_rp_priority', (YLeaf(YType.uint8, 'candidate-rp-priority'), ['int'])),
                                            ('candidate_rp_up_time', (YLeaf(YType.uint16, 'candidate-rp-up-time'), ['int'])),
                                            ('candidate_rp_expires', (YLeaf(YType.uint16, 'candidate-rp-expires'), ['int'])),
                                            ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowProtocol', '')])),
                                        ])
                                        self.candidate_rp_holdtime = None
                                        self.candidate_rp_priority = None
                                        self.candidate_rp_up_time = None
                                        self.candidate_rp_expires = None
                                        self.protocol = None

                                        self.candidate_rp_address = Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress()
                                        self.candidate_rp_address.parent = self
                                        self._children_name_map["candidate_rp_address"] = "candidate-rp-address"
                                        self._segment_path = lambda: "pim-bsr-crp-bag"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag, ['candidate_rp_holdtime', 'candidate_rp_priority', 'candidate_rp_up_time', 'candidate_rp_expires', 'protocol'], name, value)


                                    class CandidateRpAddress(Entity):
                                        """
                                        C\-RP address
                                        
                                        .. attribute:: af_name
                                        
                                        	AFName
                                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Address
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-pim-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress, self).__init__()

                                            self.yang_name = "candidate-rp-address"
                                            self.yang_parent_name = "pim-bsr-crp-bag"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                            ])
                                            self.af_name = None
                                            self.ipv4_address = None
                                            self.ipv6_address = None
                                            self._segment_path = lambda: "candidate-rp-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class CandidateRps(Entity):
                        """
                        PIM candidate\-RP
                        
                        .. attribute:: candidate_rp
                        
                        	PIM BSR candidate RP information
                        	**type**\: list of  		 :py:class:`CandidateRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps, self).__init__()

                            self.yang_name = "candidate-rps"
                            self.yang_parent_name = "bsr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("candidate-rp", ("candidate_rp", Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp))])
                            self._leafs = OrderedDict()

                            self.candidate_rp = YList(self)
                            self._segment_path = lambda: "candidate-rps"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps, [], name, value)


                        class CandidateRp(Entity):
                            """
                            PIM BSR candidate RP information
                            
                            .. attribute:: rp_address  (key)
                            
                            	Candidate\-RP address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: candidate_rp
                            
                            	Cand\-RP Address
                            	**type**\:  :py:class:`CandidateRp_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp_>`
                            
                            .. attribute:: candidate_rp_mode
                            
                            	Cand\-RP Mode
                            	**type**\:  :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                            
                            .. attribute:: candidate_rp_scope
                            
                            	Cand\-RP Scope
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: crp_priority
                            
                            	Cand\-RP Priority
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: crp_holdtime
                            
                            	Cand\-RP Holdtime
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: candidate_rp_advance_interval
                            
                            	Cand\-RP Adv Interval in seconds
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: candidate_rp_uptime
                            
                            	Cand\-RP uptime
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: acl_name
                            
                            	Group Access\-List Name
                            	**type**\: str
                            
                            	**length:** 0..33
                            
                            .. attribute:: crp_access
                            
                            	Group Ranges Using this Cand\-RP
                            	**type**\: list of  		 :py:class:`CrpAccess <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CrpAccess>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp, self).__init__()

                                self.yang_name = "candidate-rp"
                                self.yang_parent_name = "candidate-rps"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['rp_address']
                                self._child_classes = OrderedDict([("candidate-rp", ("candidate_rp", Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp_)), ("crp-access", ("crp_access", Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CrpAccess))])
                                self._leafs = OrderedDict([
                                    ('rp_address', (YLeaf(YType.str, 'rp-address'), ['str','str'])),
                                    ('candidate_rp_mode', (YLeaf(YType.enumeration, 'candidate-rp-mode'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowProtocol', '')])),
                                    ('candidate_rp_scope', (YLeaf(YType.int32, 'candidate-rp-scope'), ['int'])),
                                    ('crp_priority', (YLeaf(YType.uint8, 'crp-priority'), ['int'])),
                                    ('crp_holdtime', (YLeaf(YType.uint16, 'crp-holdtime'), ['int'])),
                                    ('candidate_rp_advance_interval', (YLeaf(YType.uint16, 'candidate-rp-advance-interval'), ['int'])),
                                    ('candidate_rp_uptime', (YLeaf(YType.uint16, 'candidate-rp-uptime'), ['int'])),
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                                ])
                                self.rp_address = None
                                self.candidate_rp_mode = None
                                self.candidate_rp_scope = None
                                self.crp_priority = None
                                self.crp_holdtime = None
                                self.candidate_rp_advance_interval = None
                                self.candidate_rp_uptime = None
                                self.acl_name = None

                                self.candidate_rp = Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp_()
                                self.candidate_rp.parent = self
                                self._children_name_map["candidate_rp"] = "candidate-rp"

                                self.crp_access = YList(self)
                                self._segment_path = lambda: "candidate-rp" + "[rp-address='" + str(self.rp_address) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp, ['rp_address', 'candidate_rp_mode', 'candidate_rp_scope', 'crp_priority', 'crp_holdtime', 'candidate_rp_advance_interval', 'candidate_rp_uptime', 'acl_name'], name, value)


                            class CandidateRp_(Entity):
                                """
                                Cand\-RP Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp_, self).__init__()

                                    self.yang_name = "candidate-rp"
                                    self.yang_parent_name = "candidate-rp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "candidate-rp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp_, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                            class CrpAccess(Entity):
                                """
                                Group Ranges Using this Cand\-RP
                                
                                .. attribute:: candidate_rp_mode
                                
                                	Cand\-RP Mode
                                	**type**\:  :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                                
                                .. attribute:: acl_name
                                
                                	Group Access\-List Name
                                	**type**\: str
                                
                                	**length:** 0..33
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CrpAccess, self).__init__()

                                    self.yang_name = "crp-access"
                                    self.yang_parent_name = "candidate-rp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('candidate_rp_mode', (YLeaf(YType.enumeration, 'candidate-rp-mode'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowProtocol', '')])),
                                        ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                                    ])
                                    self.candidate_rp_mode = None
                                    self.acl_name = None
                                    self._segment_path = lambda: "crp-access"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CrpAccess, ['candidate_rp_mode', 'acl_name'], name, value)


                    class BsrElections(Entity):
                        """
                        PIM BSR election state
                        
                        .. attribute:: bsr_election
                        
                        	PIM BSR information
                        	**type**\: list of  		 :py:class:`BsrElection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections, self).__init__()

                            self.yang_name = "bsr-elections"
                            self.yang_parent_name = "bsr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("bsr-election", ("bsr_election", Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection))])
                            self._leafs = OrderedDict()

                            self.bsr_election = YList(self)
                            self._segment_path = lambda: "bsr-elections"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections, [], name, value)


                        class BsrElection(Entity):
                            """
                            PIM BSR information
                            
                            .. attribute:: pim_scope  (key)
                            
                            	BSR information
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bsr_address
                            
                            	BSR address
                            	**type**\:  :py:class:`BsrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress>`
                            
                            .. attribute:: candidate_bsr_address
                            
                            	C\-BSR address
                            	**type**\:  :py:class:`CandidateBsrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress>`
                            
                            .. attribute:: bsr_priority
                            
                            	BSR Priority
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: bsr_mask_length
                            
                            	Hash Function Mask Length
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: bsr_up_time
                            
                            	BSR Uptime
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: bootstrap_timeout
                            
                            	Bootstrap Timeout
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: candidate_bsr_state
                            
                            	BSR Candidate State
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bsr_election_state
                            
                            	BSR Election State
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bsr_scope
                            
                            	BSR Scope
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: candidate_bsr_flag
                            
                            	BSR Candidate Config Flag
                            	**type**\: bool
                            
                            .. attribute:: candidate_bsr_priority
                            
                            	C\-BSR Priority
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: candidate_bsr_mask_length
                            
                            	C\-BSR Hash Func. Mask Len
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection, self).__init__()

                                self.yang_name = "bsr-election"
                                self.yang_parent_name = "bsr-elections"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['pim_scope']
                                self._child_classes = OrderedDict([("bsr-address", ("bsr_address", Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress)), ("candidate-bsr-address", ("candidate_bsr_address", Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress))])
                                self._leafs = OrderedDict([
                                    ('pim_scope', (YLeaf(YType.uint32, 'pim-scope'), ['int'])),
                                    ('bsr_priority', (YLeaf(YType.uint8, 'bsr-priority'), ['int'])),
                                    ('bsr_mask_length', (YLeaf(YType.uint8, 'bsr-mask-length'), ['int'])),
                                    ('bsr_up_time', (YLeaf(YType.uint16, 'bsr-up-time'), ['int'])),
                                    ('bootstrap_timeout', (YLeaf(YType.uint16, 'bootstrap-timeout'), ['int'])),
                                    ('candidate_bsr_state', (YLeaf(YType.uint32, 'candidate-bsr-state'), ['int'])),
                                    ('bsr_election_state', (YLeaf(YType.uint32, 'bsr-election-state'), ['int'])),
                                    ('bsr_scope', (YLeaf(YType.uint16, 'bsr-scope'), ['int'])),
                                    ('candidate_bsr_flag', (YLeaf(YType.boolean, 'candidate-bsr-flag'), ['bool'])),
                                    ('candidate_bsr_priority', (YLeaf(YType.uint8, 'candidate-bsr-priority'), ['int'])),
                                    ('candidate_bsr_mask_length', (YLeaf(YType.uint8, 'candidate-bsr-mask-length'), ['int'])),
                                ])
                                self.pim_scope = None
                                self.bsr_priority = None
                                self.bsr_mask_length = None
                                self.bsr_up_time = None
                                self.bootstrap_timeout = None
                                self.candidate_bsr_state = None
                                self.bsr_election_state = None
                                self.bsr_scope = None
                                self.candidate_bsr_flag = None
                                self.candidate_bsr_priority = None
                                self.candidate_bsr_mask_length = None

                                self.bsr_address = Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress()
                                self.bsr_address.parent = self
                                self._children_name_map["bsr_address"] = "bsr-address"

                                self.candidate_bsr_address = Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress()
                                self.candidate_bsr_address.parent = self
                                self._children_name_map["candidate_bsr_address"] = "candidate-bsr-address"
                                self._segment_path = lambda: "bsr-election" + "[pim-scope='" + str(self.pim_scope) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection, ['pim_scope', 'bsr_priority', 'bsr_mask_length', 'bsr_up_time', 'bootstrap_timeout', 'candidate_bsr_state', 'bsr_election_state', 'bsr_scope', 'candidate_bsr_flag', 'candidate_bsr_priority', 'candidate_bsr_mask_length'], name, value)


                            class BsrAddress(Entity):
                                """
                                BSR address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress, self).__init__()

                                    self.yang_name = "bsr-address"
                                    self.yang_parent_name = "bsr-election"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "bsr-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                            class CandidateBsrAddress(Entity):
                                """
                                C\-BSR address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress, self).__init__()

                                    self.yang_name = "candidate-bsr-address"
                                    self.yang_parent_name = "bsr-election"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "candidate-bsr-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class RoutePolicy(Entity):
                    """
                    PIM route policy
                    
                    .. attribute:: route_policy_statistics
                    
                    	PIM route policy statistics
                    	**type**\:  :py:class:`RoutePolicyStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics>`
                    
                    .. attribute:: route_policy_tests
                    
                    	PIM route policy test run table
                    	**type**\:  :py:class:`RoutePolicyTests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy, self).__init__()

                        self.yang_name = "route-policy"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("route-policy-statistics", ("route_policy_statistics", Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics)), ("route-policy-tests", ("route_policy_tests", Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests))])
                        self._leafs = OrderedDict()

                        self.route_policy_statistics = Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics()
                        self.route_policy_statistics.parent = self
                        self._children_name_map["route_policy_statistics"] = "route-policy-statistics"

                        self.route_policy_tests = Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests()
                        self.route_policy_tests.parent = self
                        self._children_name_map["route_policy_tests"] = "route-policy-tests"
                        self._segment_path = lambda: "route-policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy, [], name, value)


                    class RoutePolicyStatistics(Entity):
                        """
                        PIM route policy statistics
                        
                        .. attribute:: policy_name
                        
                        	RPF policy name
                        	**type**\: str
                        
                        .. attribute:: requests
                        
                        	Number of RPF lookup requests
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pass_
                        
                        	Number of RPF pass
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: drop
                        
                        	Number of RPF drops
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: default_table
                        
                        	Number of RPF lookup in default\-only Table
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: any_table
                        
                        	Number of RPF lookup in any Table
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics, self).__init__()

                            self.yang_name = "route-policy-statistics"
                            self.yang_parent_name = "route-policy"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('policy_name', (YLeaf(YType.str, 'policy-name'), ['str'])),
                                ('requests', (YLeaf(YType.uint32, 'requests'), ['int'])),
                                ('pass_', (YLeaf(YType.uint32, 'pass'), ['int'])),
                                ('drop', (YLeaf(YType.uint32, 'drop'), ['int'])),
                                ('default_table', (YLeaf(YType.uint32, 'default-table'), ['int'])),
                                ('any_table', (YLeaf(YType.uint32, 'any-table'), ['int'])),
                            ])
                            self.policy_name = None
                            self.requests = None
                            self.pass_ = None
                            self.drop = None
                            self.default_table = None
                            self.any_table = None
                            self._segment_path = lambda: "route-policy-statistics"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics, ['policy_name', 'requests', 'pass_', 'drop', 'default_table', 'any_table'], name, value)


                    class RoutePolicyTests(Entity):
                        """
                        PIM route policy test run table
                        
                        .. attribute:: route_policy_test
                        
                        	PIM route policy test run
                        	**type**\: list of  		 :py:class:`RoutePolicyTest <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests, self).__init__()

                            self.yang_name = "route-policy-tests"
                            self.yang_parent_name = "route-policy"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("route-policy-test", ("route_policy_test", Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest))])
                            self._leafs = OrderedDict()

                            self.route_policy_test = YList(self)
                            self._segment_path = lambda: "route-policy-tests"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests, [], name, value)


                        class RoutePolicyTest(Entity):
                            """
                            PIM route policy test run
                            
                            .. attribute:: source_address
                            
                            	Source IP address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: group_address
                            
                            	Group IP address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ext_comm
                            
                            	Extended Community
                            	**type**\: str
                            
                            	**length:** 1..8
                            
                            .. attribute:: source_address_xr
                            
                            	Source address
                            	**type**\:  :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr>`
                            
                            .. attribute:: group_address_xr
                            
                            	Source address
                            	**type**\:  :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr>`
                            
                            .. attribute:: policy_name
                            
                            	RPF policy name
                            	**type**\: str
                            
                            .. attribute:: extended_community_rt
                            
                            	Route Target
                            	**type**\: str
                            
                            	**length:** 0..33
                            
                            .. attribute:: pass_
                            
                            	Pass
                            	**type**\: bool
                            
                            .. attribute:: default_table
                            
                            	Default table selected
                            	**type**\: bool
                            
                            .. attribute:: vrf_name
                            
                            	VRF name
                            	**type**\: str
                            
                            	**length:** 0..33
                            
                            .. attribute:: afi
                            
                            	AFI
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: safi
                            
                            	SAFI
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: table_name
                            
                            	Table name
                            	**type**\: str
                            
                            .. attribute:: table_exists
                            
                            	Table exists
                            	**type**\: bool
                            
                            .. attribute:: table_active
                            
                            	Table active
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest, self).__init__()

                                self.yang_name = "route-policy-test"
                                self.yang_parent_name = "route-policy-tests"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("source-address-xr", ("source_address_xr", Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr)), ("group-address-xr", ("group_address_xr", Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr))])
                                self._leafs = OrderedDict([
                                    ('source_address', (YLeaf(YType.str, 'source-address'), ['str','str'])),
                                    ('group_address', (YLeaf(YType.str, 'group-address'), ['str','str'])),
                                    ('ext_comm', (YLeaf(YType.str, 'ext-comm'), ['str'])),
                                    ('policy_name', (YLeaf(YType.str, 'policy-name'), ['str'])),
                                    ('extended_community_rt', (YLeaf(YType.str, 'extended-community-rt'), ['str'])),
                                    ('pass_', (YLeaf(YType.boolean, 'pass'), ['bool'])),
                                    ('default_table', (YLeaf(YType.boolean, 'default-table'), ['bool'])),
                                    ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                    ('afi', (YLeaf(YType.uint32, 'afi'), ['int'])),
                                    ('safi', (YLeaf(YType.uint32, 'safi'), ['int'])),
                                    ('table_name', (YLeaf(YType.str, 'table-name'), ['str'])),
                                    ('table_exists', (YLeaf(YType.boolean, 'table-exists'), ['bool'])),
                                    ('table_active', (YLeaf(YType.boolean, 'table-active'), ['bool'])),
                                ])
                                self.source_address = None
                                self.group_address = None
                                self.ext_comm = None
                                self.policy_name = None
                                self.extended_community_rt = None
                                self.pass_ = None
                                self.default_table = None
                                self.vrf_name = None
                                self.afi = None
                                self.safi = None
                                self.table_name = None
                                self.table_exists = None
                                self.table_active = None

                                self.source_address_xr = Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr()
                                self.source_address_xr.parent = self
                                self._children_name_map["source_address_xr"] = "source-address-xr"

                                self.group_address_xr = Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"
                                self._segment_path = lambda: "route-policy-test"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest, ['source_address', 'group_address', 'ext_comm', 'policy_name', 'extended_community_rt', 'pass_', 'default_table', 'vrf_name', 'afi', 'safi', 'table_name', 'table_exists', 'table_active'], name, value)


                            class SourceAddressXr(Entity):
                                """
                                Source address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr, self).__init__()

                                    self.yang_name = "source-address-xr"
                                    self.yang_parent_name = "route-policy-test"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "source-address-xr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                            class GroupAddressXr(Entity):
                                """
                                Source address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr, self).__init__()

                                    self.yang_name = "group-address-xr"
                                    self.yang_parent_name = "route-policy-test"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "group-address-xr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class RpfSummary(Entity):
                    """
                    PIM RPF registration summary
                    
                    .. attribute:: default_safi
                    
                    	Default RPF Table SAFI
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: default_table_name
                    
                    	Default RPF Table Name
                    	**type**\: str
                    
                    .. attribute:: is_mbgp_configured
                    
                    	Is MBGP configured?
                    	**type**\: bool
                    
                    .. attribute:: is_ospf_te_configured
                    
                    	Is OSPF TE configured?
                    	**type**\: bool
                    
                    .. attribute:: is_isis_te_configured
                    
                    	Is ISIS TE configured?
                    	**type**\: bool
                    
                    .. attribute:: is_isis_mtr_configured
                    
                    	Is ISIS MTR configured?
                    	**type**\: bool
                    
                    .. attribute:: mo_frr_configured
                    
                    	Is MoFRR configured?
                    	**type**\: bool
                    
                    .. attribute:: rib_mo_frr_configured
                    
                    	Is MoFRR RIB configured?
                    	**type**\: bool
                    
                    .. attribute:: rump_enabled
                    
                    	Is RUMP MuRIB enabled?
                    	**type**\: bool
                    
                    .. attribute:: rib_convergence_timeout
                    
                    	RIB convergence timeout in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: rib_convergence_time_left
                    
                    	RIB convergence time left in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: is_multipath_enabled
                    
                    	Is Multipath Enabled ?
                    	**type**\: bool
                    
                    .. attribute:: is_multipath_interface_hash_enabled
                    
                    	Is Multipath Interface Hash Extension Enabled ?
                    	**type**\: bool
                    
                    .. attribute:: is_multipath_source_hash_enabled
                    
                    	Is Multipath Source based Hash Enabled ?
                    	**type**\: bool
                    
                    .. attribute:: is_multipath_source_next_hop_hash_enabled
                    
                    	Is Multipath Source\-Nexthop Hash Enabled ?
                    	**type**\: bool
                    
                    .. attribute:: rpf_registrations
                    
                    	RPF Registration count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_rib_convergence
                    
                    	RIB Convergence status
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.RpfSummary, self).__init__()

                        self.yang_name = "rpf-summary"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('default_safi', (YLeaf(YType.uint32, 'default-safi'), ['int'])),
                            ('default_table_name', (YLeaf(YType.str, 'default-table-name'), ['str'])),
                            ('is_mbgp_configured', (YLeaf(YType.boolean, 'is-mbgp-configured'), ['bool'])),
                            ('is_ospf_te_configured', (YLeaf(YType.boolean, 'is-ospf-te-configured'), ['bool'])),
                            ('is_isis_te_configured', (YLeaf(YType.boolean, 'is-isis-te-configured'), ['bool'])),
                            ('is_isis_mtr_configured', (YLeaf(YType.boolean, 'is-isis-mtr-configured'), ['bool'])),
                            ('mo_frr_configured', (YLeaf(YType.boolean, 'mo-frr-configured'), ['bool'])),
                            ('rib_mo_frr_configured', (YLeaf(YType.boolean, 'rib-mo-frr-configured'), ['bool'])),
                            ('rump_enabled', (YLeaf(YType.boolean, 'rump-enabled'), ['bool'])),
                            ('rib_convergence_timeout', (YLeaf(YType.uint32, 'rib-convergence-timeout'), ['int'])),
                            ('rib_convergence_time_left', (YLeaf(YType.uint32, 'rib-convergence-time-left'), ['int'])),
                            ('is_multipath_enabled', (YLeaf(YType.boolean, 'is-multipath-enabled'), ['bool'])),
                            ('is_multipath_interface_hash_enabled', (YLeaf(YType.boolean, 'is-multipath-interface-hash-enabled'), ['bool'])),
                            ('is_multipath_source_hash_enabled', (YLeaf(YType.boolean, 'is-multipath-source-hash-enabled'), ['bool'])),
                            ('is_multipath_source_next_hop_hash_enabled', (YLeaf(YType.boolean, 'is-multipath-source-next-hop-hash-enabled'), ['bool'])),
                            ('rpf_registrations', (YLeaf(YType.uint32, 'rpf-registrations'), ['int'])),
                            ('is_rib_convergence', (YLeaf(YType.boolean, 'is-rib-convergence'), ['bool'])),
                        ])
                        self.default_safi = None
                        self.default_table_name = None
                        self.is_mbgp_configured = None
                        self.is_ospf_te_configured = None
                        self.is_isis_te_configured = None
                        self.is_isis_mtr_configured = None
                        self.mo_frr_configured = None
                        self.rib_mo_frr_configured = None
                        self.rump_enabled = None
                        self.rib_convergence_timeout = None
                        self.rib_convergence_time_left = None
                        self.is_multipath_enabled = None
                        self.is_multipath_interface_hash_enabled = None
                        self.is_multipath_source_hash_enabled = None
                        self.is_multipath_source_next_hop_hash_enabled = None
                        self.rpf_registrations = None
                        self.is_rib_convergence = None
                        self._segment_path = lambda: "rpf-summary"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.RpfSummary, ['default_safi', 'default_table_name', 'is_mbgp_configured', 'is_ospf_te_configured', 'is_isis_te_configured', 'is_isis_mtr_configured', 'mo_frr_configured', 'rib_mo_frr_configured', 'rump_enabled', 'rib_convergence_timeout', 'rib_convergence_time_left', 'is_multipath_enabled', 'is_multipath_interface_hash_enabled', 'is_multipath_source_hash_enabled', 'is_multipath_source_next_hop_hash_enabled', 'rpf_registrations', 'is_rib_convergence'], name, value)


                class Interfaces(Entity):
                    """
                    PIM interfaces
                    
                    .. attribute:: interface
                    
                    	PIM interface name
                    	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Interfaces.Interface>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.Interfaces, self).__init__()

                        self.yang_name = "interfaces"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("interface", ("interface", Ipv6Pim.Standby.Vrfs.Vrf.Interfaces.Interface))])
                        self._leafs = OrderedDict()

                        self.interface = YList(self)
                        self._segment_path = lambda: "interfaces"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Interfaces, [], name, value)


                    class Interface(Entity):
                        """
                        PIM interface name
                        
                        .. attribute:: interface_name  (key)
                        
                        	Interface name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: dr_address
                        
                        	PIM Designated Router
                        	**type**\:  :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Interfaces.Interface.DrAddress>`
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identfier
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: interface_address_mask
                        
                        	Interface IP Address Mask
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: is_enabled
                        
                        	Is PIM enabled on this IF ?
                        	**type**\: bool
                        
                        .. attribute:: neighbor_count
                        
                        	No. of neighbors on this IF
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: external_neighbor_count
                        
                        	No. of external neighbors on this IF
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: hello_interval
                        
                        	Hello Interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: dr_priority
                        
                        	DR Priority
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: hello_expiry
                        
                        	Hello Timer Expiry
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: are_we_dr
                        
                        	Are we the DR on this IF ?
                        	**type**\: bool
                        
                        .. attribute:: bfd_enabled
                        
                        	BFD state
                        	**type**\: bool
                        
                        .. attribute:: bfd_interval
                        
                        	BFD Interval
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bfd_multiplier
                        
                        	BFD Multiplier
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_interface
                        
                        	 is this a Virtual Interfaces ?
                        	**type**\: bool
                        
                        .. attribute:: passive_interface
                        
                        	Passive PIM interface
                        	**type**\: bool
                        
                        .. attribute:: neighbor_filter_name
                        
                        	Neighbor Filter Name
                        	**type**\: str
                        
                        .. attribute:: join_prune_interval
                        
                        	Join\-Prune Interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: prune_delay_enabled
                        
                        	Prune Delay Enabled
                        	**type**\: bool
                        
                        .. attribute:: configured_propagation_delay
                        
                        	Configured Propagation Delay
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: configured_override_interval
                        
                        	Configured Override Interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: generation_id
                        
                        	Generation Identifier
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Bidir Capable
                        	**type**\: bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Proxy Capable
                        	**type**\: bool
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Batch Asserts Capable
                        	**type**\: bool
                        
                        .. attribute:: idb_oor_enabled
                        
                        	Interface oor enabled
                        	**type**\: bool
                        
                        .. attribute:: idb_acl_provided
                        
                        	ACL name provided
                        	**type**\: bool
                        
                        .. attribute:: idb_max_count
                        
                        	Interface ole max count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_threshold_count
                        
                        	Interface ole threshold count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_current_count
                        
                        	Interface ole current count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_acl_name
                        
                        	Interface ole ACL Name
                        	**type**\: str
                        
                        	**length:** 0..64
                        
                        .. attribute:: interface_address
                        
                        	List of Interface IP Addresses
                        	**type**\: list of  		 :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Interfaces.Interface.InterfaceAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.Interfaces.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "interfaces"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['interface_name']
                            self._child_classes = OrderedDict([("dr-address", ("dr_address", Ipv6Pim.Standby.Vrfs.Vrf.Interfaces.Interface.DrAddress)), ("interface-address", ("interface_address", Ipv6Pim.Standby.Vrfs.Vrf.Interfaces.Interface.InterfaceAddress))])
                            self._leafs = OrderedDict([
                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                                ('interface_address_mask', (YLeaf(YType.uint8, 'interface-address-mask'), ['int'])),
                                ('is_enabled', (YLeaf(YType.boolean, 'is-enabled'), ['bool'])),
                                ('neighbor_count', (YLeaf(YType.uint16, 'neighbor-count'), ['int'])),
                                ('external_neighbor_count', (YLeaf(YType.uint16, 'external-neighbor-count'), ['int'])),
                                ('hello_interval', (YLeaf(YType.uint16, 'hello-interval'), ['int'])),
                                ('dr_priority', (YLeaf(YType.uint32, 'dr-priority'), ['int'])),
                                ('hello_expiry', (YLeaf(YType.uint64, 'hello-expiry'), ['int'])),
                                ('are_we_dr', (YLeaf(YType.boolean, 'are-we-dr'), ['bool'])),
                                ('bfd_enabled', (YLeaf(YType.boolean, 'bfd-enabled'), ['bool'])),
                                ('bfd_interval', (YLeaf(YType.uint32, 'bfd-interval'), ['int'])),
                                ('bfd_multiplier', (YLeaf(YType.uint32, 'bfd-multiplier'), ['int'])),
                                ('virtual_interface', (YLeaf(YType.boolean, 'virtual-interface'), ['bool'])),
                                ('passive_interface', (YLeaf(YType.boolean, 'passive-interface'), ['bool'])),
                                ('neighbor_filter_name', (YLeaf(YType.str, 'neighbor-filter-name'), ['str'])),
                                ('join_prune_interval', (YLeaf(YType.uint16, 'join-prune-interval'), ['int'])),
                                ('prune_delay_enabled', (YLeaf(YType.boolean, 'prune-delay-enabled'), ['bool'])),
                                ('configured_propagation_delay', (YLeaf(YType.uint16, 'configured-propagation-delay'), ['int'])),
                                ('propagation_delay', (YLeaf(YType.uint16, 'propagation-delay'), ['int'])),
                                ('configured_override_interval', (YLeaf(YType.uint16, 'configured-override-interval'), ['int'])),
                                ('override_interval', (YLeaf(YType.uint16, 'override-interval'), ['int'])),
                                ('generation_id', (YLeaf(YType.uint32, 'generation-id'), ['int'])),
                                ('is_bidirectional_capable', (YLeaf(YType.boolean, 'is-bidirectional-capable'), ['bool'])),
                                ('is_proxy_capable', (YLeaf(YType.boolean, 'is-proxy-capable'), ['bool'])),
                                ('is_batch_asserts_capable', (YLeaf(YType.boolean, 'is-batch-asserts-capable'), ['bool'])),
                                ('idb_oor_enabled', (YLeaf(YType.boolean, 'idb-oor-enabled'), ['bool'])),
                                ('idb_acl_provided', (YLeaf(YType.boolean, 'idb-acl-provided'), ['bool'])),
                                ('idb_max_count', (YLeaf(YType.uint32, 'idb-max-count'), ['int'])),
                                ('idb_threshold_count', (YLeaf(YType.uint32, 'idb-threshold-count'), ['int'])),
                                ('idb_current_count', (YLeaf(YType.uint32, 'idb-current-count'), ['int'])),
                                ('idb_acl_name', (YLeaf(YType.str, 'idb-acl-name'), ['str'])),
                            ])
                            self.interface_name = None
                            self.interface_name_xr = None
                            self.interface_address_mask = None
                            self.is_enabled = None
                            self.neighbor_count = None
                            self.external_neighbor_count = None
                            self.hello_interval = None
                            self.dr_priority = None
                            self.hello_expiry = None
                            self.are_we_dr = None
                            self.bfd_enabled = None
                            self.bfd_interval = None
                            self.bfd_multiplier = None
                            self.virtual_interface = None
                            self.passive_interface = None
                            self.neighbor_filter_name = None
                            self.join_prune_interval = None
                            self.prune_delay_enabled = None
                            self.configured_propagation_delay = None
                            self.propagation_delay = None
                            self.configured_override_interval = None
                            self.override_interval = None
                            self.generation_id = None
                            self.is_bidirectional_capable = None
                            self.is_proxy_capable = None
                            self.is_batch_asserts_capable = None
                            self.idb_oor_enabled = None
                            self.idb_acl_provided = None
                            self.idb_max_count = None
                            self.idb_threshold_count = None
                            self.idb_current_count = None
                            self.idb_acl_name = None

                            self.dr_address = Ipv6Pim.Standby.Vrfs.Vrf.Interfaces.Interface.DrAddress()
                            self.dr_address.parent = self
                            self._children_name_map["dr_address"] = "dr-address"

                            self.interface_address = YList(self)
                            self._segment_path = lambda: "interface" + "[interface-name='" + str(self.interface_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Interfaces.Interface, ['interface_name', 'interface_name_xr', 'interface_address_mask', 'is_enabled', 'neighbor_count', 'external_neighbor_count', 'hello_interval', 'dr_priority', 'hello_expiry', 'are_we_dr', 'bfd_enabled', 'bfd_interval', 'bfd_multiplier', 'virtual_interface', 'passive_interface', 'neighbor_filter_name', 'join_prune_interval', 'prune_delay_enabled', 'configured_propagation_delay', 'propagation_delay', 'configured_override_interval', 'override_interval', 'generation_id', 'is_bidirectional_capable', 'is_proxy_capable', 'is_batch_asserts_capable', 'idb_oor_enabled', 'idb_acl_provided', 'idb_max_count', 'idb_threshold_count', 'idb_current_count', 'idb_acl_name'], name, value)


                        class DrAddress(Entity):
                            """
                            PIM Designated Router
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Interfaces.Interface.DrAddress, self).__init__()

                                self.yang_name = "dr-address"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "dr-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Interfaces.Interface.DrAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class InterfaceAddress(Entity):
                            """
                            List of Interface IP Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Interfaces.Interface.InterfaceAddress, self).__init__()

                                self.yang_name = "interface-address"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "interface-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Interfaces.Interface.InterfaceAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class NetIoTunnels(Entity):
                    """
                    Tunnel information that NETIO has 
                    
                    .. attribute:: net_io_tunnel
                    
                    	PIM netio tunnel information
                    	**type**\: list of  		 :py:class:`NetIoTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels, self).__init__()

                        self.yang_name = "net-io-tunnels"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("net-io-tunnel", ("net_io_tunnel", Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel))])
                        self._leafs = OrderedDict()

                        self.net_io_tunnel = YList(self)
                        self._segment_path = lambda: "net-io-tunnels"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels, [], name, value)


                    class NetIoTunnel(Entity):
                        """
                        PIM netio tunnel information
                        
                        .. attribute:: tunnel_name  (key)
                        
                        	Tunnel name
                        	**type**\: str
                        
                        	**length:** 1..64
                        
                        .. attribute:: source_address
                        
                        	Source addr known to PIM
                        	**type**\:  :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress>`
                        
                        .. attribute:: rp_address
                        
                        	RP addr known to PIM
                        	**type**\:  :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress>`
                        
                        .. attribute:: source_address_netio
                        
                        	Source addr from netio
                        	**type**\:  :py:class:`SourceAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio>`
                        
                        .. attribute:: group_address_netio
                        
                        	Group addr from netio
                        	**type**\:  :py:class:`GroupAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio>`
                        
                        .. attribute:: vrf_name
                        
                        	VRF Name
                        	**type**\: str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel, self).__init__()

                            self.yang_name = "net-io-tunnel"
                            self.yang_parent_name = "net-io-tunnels"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['tunnel_name']
                            self._child_classes = OrderedDict([("source-address", ("source_address", Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress)), ("rp-address", ("rp_address", Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress)), ("source-address-netio", ("source_address_netio", Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio)), ("group-address-netio", ("group_address_netio", Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio))])
                            self._leafs = OrderedDict([
                                ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                            ])
                            self.tunnel_name = None
                            self.vrf_name = None

                            self.source_address = Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"

                            self.rp_address = Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"

                            self.source_address_netio = Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio()
                            self.source_address_netio.parent = self
                            self._children_name_map["source_address_netio"] = "source-address-netio"

                            self.group_address_netio = Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio()
                            self.group_address_netio.parent = self
                            self._children_name_map["group_address_netio"] = "group-address-netio"
                            self._segment_path = lambda: "net-io-tunnel" + "[tunnel-name='" + str(self.tunnel_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel, ['tunnel_name', 'vrf_name'], name, value)


                        class SourceAddress(Entity):
                            """
                            Source addr known to PIM
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "net-io-tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "source-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class RpAddress(Entity):
                            """
                            RP addr known to PIM
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "net-io-tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "rp-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class SourceAddressNetio(Entity):
                            """
                            Source addr from netio
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio, self).__init__()

                                self.yang_name = "source-address-netio"
                                self.yang_parent_name = "net-io-tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "source-address-netio"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class GroupAddressNetio(Entity):
                            """
                            Group addr from netio
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio, self).__init__()

                                self.yang_name = "group-address-netio"
                                self.yang_parent_name = "net-io-tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "group-address-netio"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class BidirDfStates(Entity):
                    """
                    Bidirectional PIM DF election state table
                    
                    .. attribute:: bidir_df_state
                    
                    	Bidirectional PIM DF Election Table Entry
                    	**type**\: list of  		 :py:class:`BidirDfState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.BidirDfStates, self).__init__()

                        self.yang_name = "bidir-df-states"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("bidir-df-state", ("bidir_df_state", Ipv6Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState))])
                        self._leafs = OrderedDict()

                        self.bidir_df_state = YList(self)
                        self._segment_path = lambda: "bidir-df-states"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.BidirDfStates, [], name, value)


                    class BidirDfState(Entity):
                        """
                        Bidirectional PIM DF Election Table Entry
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: rp_address_xr
                        
                        	RP Address
                        	**type**\:  :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr>`
                        
                        .. attribute:: pim_interface_name
                        
                        	Interface Name
                        	**type**\: str
                        
                        .. attribute:: election_state
                        
                        	DF Election State
                        	**type**\: str
                        
                        .. attribute:: time_seconds
                        
                        	Timer expires (seconds)
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: time_nano_seconds
                        
                        	Timer expires (nseconds)
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: nanosecond
                        
                        .. attribute:: our_metric
                        
                        	Metric
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: our_metric_preference
                        
                        	MetricPreference
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState, self).__init__()

                            self.yang_name = "bidir-df-state"
                            self.yang_parent_name = "bidir-df-states"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rp-address-xr", ("rp_address_xr", Ipv6Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr))])
                            self._leafs = OrderedDict([
                                ('rp_address', (YLeaf(YType.str, 'rp-address'), ['str','str'])),
                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ('pim_interface_name', (YLeaf(YType.str, 'pim-interface-name'), ['str'])),
                                ('election_state', (YLeaf(YType.str, 'election-state'), ['str'])),
                                ('time_seconds', (YLeaf(YType.uint64, 'time-seconds'), ['int'])),
                                ('time_nano_seconds', (YLeaf(YType.uint64, 'time-nano-seconds'), ['int'])),
                                ('our_metric', (YLeaf(YType.uint32, 'our-metric'), ['int'])),
                                ('our_metric_preference', (YLeaf(YType.uint32, 'our-metric-preference'), ['int'])),
                            ])
                            self.rp_address = None
                            self.interface_name = None
                            self.pim_interface_name = None
                            self.election_state = None
                            self.time_seconds = None
                            self.time_nano_seconds = None
                            self.our_metric = None
                            self.our_metric_preference = None

                            self.rp_address_xr = Ipv6Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr()
                            self.rp_address_xr.parent = self
                            self._children_name_map["rp_address_xr"] = "rp-address-xr"
                            self._segment_path = lambda: "bidir-df-state"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState, ['rp_address', 'interface_name', 'pim_interface_name', 'election_state', 'time_seconds', 'time_nano_seconds', 'our_metric', 'our_metric_preference'], name, value)


                        class RpAddressXr(Entity):
                            """
                            RP Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr, self).__init__()

                                self.yang_name = "rp-address-xr"
                                self.yang_parent_name = "bidir-df-state"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "rp-address-xr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class Topologies(Entity):
                    """
                    PIM topology table
                    
                    .. attribute:: topology
                    
                    	PIM topology information
                    	**type**\: list of  		 :py:class:`Topology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.Topologies, self).__init__()

                        self.yang_name = "topologies"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("topology", ("topology", Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology))])
                        self._leafs = OrderedDict()

                        self.topology = YList(self)
                        self._segment_path = lambda: "topologies"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Topologies, [], name, value)


                    class Topology(Entity):
                        """
                        PIM topology information
                        
                        .. attribute:: source_address
                        
                        	Source address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: group_address
                        
                        	Group address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: rpt
                        
                        	RPT bit
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:  :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.GroupAddressXr>`
                        
                        .. attribute:: source_address_xr
                        
                        	Source Address
                        	**type**\:  :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.SourceAddressXr>`
                        
                        .. attribute:: rp_address
                        
                        	RP Address (If rpt)
                        	**type**\:  :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpAddress>`
                        
                        .. attribute:: rpf_neighbor
                        
                        	RPF Neighbor
                        	**type**\:  :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfNeighbor>`
                        
                        .. attribute:: secondary_rpf_neighbor
                        
                        	Secondary RPF Neighbor
                        	**type**\:  :py:class:`SecondaryRpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor>`
                        
                        .. attribute:: rpf_root
                        
                        	Root of this mcast tree
                        	**type**\:  :py:class:`RpfRoot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfRoot>`
                        
                        .. attribute:: proxy_address
                        
                        	RPF Proxy address
                        	**type**\:  :py:class:`ProxyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.ProxyAddress>`
                        
                        .. attribute:: orig_src_address
                        
                        	Orig Src Address
                        	**type**\:  :py:class:`OrigSrcAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress>`
                        
                        .. attribute:: limit_reached
                        
                        	Have we throttled the creation of routes or interfaces ?
                        	**type**\: bool
                        
                        .. attribute:: low_memory
                        
                        	Node is running low on memory
                        	**type**\: bool
                        
                        .. attribute:: protocol
                        
                        	The PIM protocol
                        	**type**\:  :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: wildcard
                        
                        	WC \-Wildcard
                        	**type**\: bool
                        
                        .. attribute:: rpt_xr
                        
                        	Is this on the RPT ?
                        	**type**\: bool
                        
                        .. attribute:: spt
                        
                        	Is this on the SPT ?
                        	**type**\: bool
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: expiry
                        
                        	When this entry expires
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: alive
                        
                        	Alive time in seconds (\-1 if never)
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: register_received_timer
                        
                        	Register Received Timer in seconds (\-1 if never)
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: remote_source
                        
                        	MSDP told us
                        	**type**\: bool
                        
                        .. attribute:: crossed_threshold
                        
                        	Incoming traffic crossed threshold. MT flag set
                        	**type**\: bool
                        
                        .. attribute:: data_mdt_addr_assigned
                        
                        	PIM has assigned a Data MDT Address
                        	**type**\: bool
                        
                        .. attribute:: rpf_interface_name
                        
                        	Interface Identifier
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: rpf_vrf_name
                        
                        	RPF VRF Name
                        	**type**\: str
                        
                        	**length:** 0..33
                        
                        .. attribute:: rpf_safi
                        
                        	Unicast or mcast
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: rpf_table_name
                        
                        	RPF Table name
                        	**type**\: str
                        
                        .. attribute:: rpf_drop
                        
                        	RPF route\-policy drop
                        	**type**\: bool
                        
                        .. attribute:: rpf_extranet
                        
                        	Extranet RPF route\-policy
                        	**type**\: bool
                        
                        .. attribute:: is_via_lsm
                        
                        	Via LSM
                        	**type**\: bool
                        
                        .. attribute:: secondary_rpf_interface_name
                        
                        	Secondary Interface Identifier
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: connected
                        
                        	Is Connected ?
                        	**type**\: bool
                        
                        .. attribute:: proxy
                        
                        	Is the RPF target a proxy?
                        	**type**\: bool
                        
                        .. attribute:: rpf_proxy_enabled
                        
                        	Is rpf if proxy enabled?
                        	**type**\: bool
                        
                        .. attribute:: mofrr_enabled
                        
                        	Is this SG MoFRR enabled?
                        	**type**\: bool
                        
                        .. attribute:: rib_mo_frr_enabled
                        
                        	Is this SG MoFRR enabled?
                        	**type**\: bool
                        
                        .. attribute:: jp_timer
                        
                        	Join\-Prune Timer
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: jp_status
                        
                        	Join\-Prune Status
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: suppress_registers
                        
                        	When the Null register probe expires
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: assume_alive
                        
                        	The Assume Alive Bit
                        	**type**\: bool
                        
                        .. attribute:: probe_alive
                        
                        	The Probe Alive Bit
                        	**type**\: bool
                        
                        .. attribute:: really_alive
                        
                        	The Really Alive Bit
                        	**type**\: bool
                        
                        .. attribute:: inherit_alive
                        
                        	The Inherit Alive Bit
                        	**type**\: bool
                        
                        .. attribute:: inherit_spt
                        
                        	The Inherit SPT Bit
                        	**type**\: bool
                        
                        .. attribute:: signal_sources
                        
                        	Signal Sources on route?
                        	**type**\: bool
                        
                        .. attribute:: dont_check_connected
                        
                        	Do we need to make the connected check on this route ?
                        	**type**\: bool
                        
                        .. attribute:: register_received
                        
                        	Have registers been received for this source ?
                        	**type**\: bool
                        
                        .. attribute:: last_hop
                        
                        	Are we last hop ?
                        	**type**\: bool
                        
                        .. attribute:: sending_registers
                        
                        	Are we sending registers for this route ?
                        	**type**\: bool
                        
                        .. attribute:: sending_null_registers
                        
                        	Are we sending null registers for this route ?
                        	**type**\: bool
                        
                        .. attribute:: sa_sent
                        
                        	BGP SA sent
                        	**type**\: bool
                        
                        .. attribute:: sa_received
                        
                        	BGP SA received
                        	**type**\: bool
                        
                        .. attribute:: sa_joined
                        
                        	BGP SA join
                        	**type**\: bool
                        
                        .. attribute:: anycast_rp_match
                        
                        	Group matches Anycast\-RP policy
                        	**type**\: bool
                        
                        .. attribute:: anycast_rp_route_target
                        
                        	Anycast\-RP RT
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: bgp_join
                        
                        	BGP C JOIN
                        	**type**\: bool
                        
                        .. attribute:: bgp_jp_time
                        
                        	BGP C JP Time
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: customer_routing_type
                        
                        	Type of Customer Routing in the MVPN
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: extranet_route
                        
                        	Is a Extranet route ?
                        	**type**\: bool
                        
                        .. attribute:: mofrr_active
                        
                        	Is MoFRR Active?
                        	**type**\: bool
                        
                        .. attribute:: mofrr_primary
                        
                        	Is this Mofrr Primary?
                        	**type**\: bool
                        
                        .. attribute:: mofrr_backup
                        
                        	Is this Mofrr Backup?
                        	**type**\: bool
                        
                        .. attribute:: vxlan
                        
                        	Is this VXLAN?
                        	**type**\: bool
                        
                        .. attribute:: kat_state
                        
                        	Keep Alive Timer State
                        	**type**\: bool
                        
                        .. attribute:: outgoing_interface
                        
                        	Outgoing interface list
                        	**type**\: list of  		 :py:class:`OutgoingInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology, self).__init__()

                            self.yang_name = "topology"
                            self.yang_parent_name = "topologies"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("group-address-xr", ("group_address_xr", Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.GroupAddressXr)), ("source-address-xr", ("source_address_xr", Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.SourceAddressXr)), ("rp-address", ("rp_address", Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpAddress)), ("rpf-neighbor", ("rpf_neighbor", Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfNeighbor)), ("secondary-rpf-neighbor", ("secondary_rpf_neighbor", Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor)), ("rpf-root", ("rpf_root", Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfRoot)), ("proxy-address", ("proxy_address", Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.ProxyAddress)), ("orig-src-address", ("orig_src_address", Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress)), ("outgoing-interface", ("outgoing_interface", Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface))])
                            self._leafs = OrderedDict([
                                ('source_address', (YLeaf(YType.str, 'source-address'), ['str','str'])),
                                ('group_address', (YLeaf(YType.str, 'group-address'), ['str','str'])),
                                ('rpt', (YLeaf(YType.uint32, 'rpt'), ['int'])),
                                ('limit_reached', (YLeaf(YType.boolean, 'limit-reached'), ['bool'])),
                                ('low_memory', (YLeaf(YType.boolean, 'low-memory'), ['bool'])),
                                ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowProtocol', '')])),
                                ('wildcard', (YLeaf(YType.boolean, 'wildcard'), ['bool'])),
                                ('rpt_xr', (YLeaf(YType.boolean, 'rpt-xr'), ['bool'])),
                                ('spt', (YLeaf(YType.boolean, 'spt'), ['bool'])),
                                ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                                ('expiry', (YLeaf(YType.uint64, 'expiry'), ['int'])),
                                ('alive', (YLeaf(YType.int32, 'alive'), ['int'])),
                                ('register_received_timer', (YLeaf(YType.int32, 'register-received-timer'), ['int'])),
                                ('remote_source', (YLeaf(YType.boolean, 'remote-source'), ['bool'])),
                                ('crossed_threshold', (YLeaf(YType.boolean, 'crossed-threshold'), ['bool'])),
                                ('data_mdt_addr_assigned', (YLeaf(YType.boolean, 'data-mdt-addr-assigned'), ['bool'])),
                                ('rpf_interface_name', (YLeaf(YType.str, 'rpf-interface-name'), ['str'])),
                                ('rpf_vrf_name', (YLeaf(YType.str, 'rpf-vrf-name'), ['str'])),
                                ('rpf_safi', (YLeaf(YType.uint8, 'rpf-safi'), ['int'])),
                                ('rpf_table_name', (YLeaf(YType.str, 'rpf-table-name'), ['str'])),
                                ('rpf_drop', (YLeaf(YType.boolean, 'rpf-drop'), ['bool'])),
                                ('rpf_extranet', (YLeaf(YType.boolean, 'rpf-extranet'), ['bool'])),
                                ('is_via_lsm', (YLeaf(YType.boolean, 'is-via-lsm'), ['bool'])),
                                ('secondary_rpf_interface_name', (YLeaf(YType.str, 'secondary-rpf-interface-name'), ['str'])),
                                ('connected', (YLeaf(YType.boolean, 'connected'), ['bool'])),
                                ('proxy', (YLeaf(YType.boolean, 'proxy'), ['bool'])),
                                ('rpf_proxy_enabled', (YLeaf(YType.boolean, 'rpf-proxy-enabled'), ['bool'])),
                                ('mofrr_enabled', (YLeaf(YType.boolean, 'mofrr-enabled'), ['bool'])),
                                ('rib_mo_frr_enabled', (YLeaf(YType.boolean, 'rib-mo-frr-enabled'), ['bool'])),
                                ('jp_timer', (YLeaf(YType.int32, 'jp-timer'), ['int'])),
                                ('jp_status', (YLeaf(YType.int32, 'jp-status'), ['int'])),
                                ('suppress_registers', (YLeaf(YType.int32, 'suppress-registers'), ['int'])),
                                ('assume_alive', (YLeaf(YType.boolean, 'assume-alive'), ['bool'])),
                                ('probe_alive', (YLeaf(YType.boolean, 'probe-alive'), ['bool'])),
                                ('really_alive', (YLeaf(YType.boolean, 'really-alive'), ['bool'])),
                                ('inherit_alive', (YLeaf(YType.boolean, 'inherit-alive'), ['bool'])),
                                ('inherit_spt', (YLeaf(YType.boolean, 'inherit-spt'), ['bool'])),
                                ('signal_sources', (YLeaf(YType.boolean, 'signal-sources'), ['bool'])),
                                ('dont_check_connected', (YLeaf(YType.boolean, 'dont-check-connected'), ['bool'])),
                                ('register_received', (YLeaf(YType.boolean, 'register-received'), ['bool'])),
                                ('last_hop', (YLeaf(YType.boolean, 'last-hop'), ['bool'])),
                                ('sending_registers', (YLeaf(YType.boolean, 'sending-registers'), ['bool'])),
                                ('sending_null_registers', (YLeaf(YType.boolean, 'sending-null-registers'), ['bool'])),
                                ('sa_sent', (YLeaf(YType.boolean, 'sa-sent'), ['bool'])),
                                ('sa_received', (YLeaf(YType.boolean, 'sa-received'), ['bool'])),
                                ('sa_joined', (YLeaf(YType.boolean, 'sa-joined'), ['bool'])),
                                ('anycast_rp_match', (YLeaf(YType.boolean, 'anycast-rp-match'), ['bool'])),
                                ('anycast_rp_route_target', (YLeaf(YType.str, 'anycast-rp-route-target'), ['str'])),
                                ('bgp_join', (YLeaf(YType.boolean, 'bgp-join'), ['bool'])),
                                ('bgp_jp_time', (YLeaf(YType.uint64, 'bgp-jp-time'), ['int'])),
                                ('customer_routing_type', (YLeaf(YType.int32, 'customer-routing-type'), ['int'])),
                                ('extranet_route', (YLeaf(YType.boolean, 'extranet-route'), ['bool'])),
                                ('mofrr_active', (YLeaf(YType.boolean, 'mofrr-active'), ['bool'])),
                                ('mofrr_primary', (YLeaf(YType.boolean, 'mofrr-primary'), ['bool'])),
                                ('mofrr_backup', (YLeaf(YType.boolean, 'mofrr-backup'), ['bool'])),
                                ('vxlan', (YLeaf(YType.boolean, 'vxlan'), ['bool'])),
                                ('kat_state', (YLeaf(YType.boolean, 'kat-state'), ['bool'])),
                            ])
                            self.source_address = None
                            self.group_address = None
                            self.rpt = None
                            self.limit_reached = None
                            self.low_memory = None
                            self.protocol = None
                            self.wildcard = None
                            self.rpt_xr = None
                            self.spt = None
                            self.uptime = None
                            self.expiry = None
                            self.alive = None
                            self.register_received_timer = None
                            self.remote_source = None
                            self.crossed_threshold = None
                            self.data_mdt_addr_assigned = None
                            self.rpf_interface_name = None
                            self.rpf_vrf_name = None
                            self.rpf_safi = None
                            self.rpf_table_name = None
                            self.rpf_drop = None
                            self.rpf_extranet = None
                            self.is_via_lsm = None
                            self.secondary_rpf_interface_name = None
                            self.connected = None
                            self.proxy = None
                            self.rpf_proxy_enabled = None
                            self.mofrr_enabled = None
                            self.rib_mo_frr_enabled = None
                            self.jp_timer = None
                            self.jp_status = None
                            self.suppress_registers = None
                            self.assume_alive = None
                            self.probe_alive = None
                            self.really_alive = None
                            self.inherit_alive = None
                            self.inherit_spt = None
                            self.signal_sources = None
                            self.dont_check_connected = None
                            self.register_received = None
                            self.last_hop = None
                            self.sending_registers = None
                            self.sending_null_registers = None
                            self.sa_sent = None
                            self.sa_received = None
                            self.sa_joined = None
                            self.anycast_rp_match = None
                            self.anycast_rp_route_target = None
                            self.bgp_join = None
                            self.bgp_jp_time = None
                            self.customer_routing_type = None
                            self.extranet_route = None
                            self.mofrr_active = None
                            self.mofrr_primary = None
                            self.mofrr_backup = None
                            self.vxlan = None
                            self.kat_state = None

                            self.group_address_xr = Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"

                            self.source_address_xr = Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.SourceAddressXr()
                            self.source_address_xr.parent = self
                            self._children_name_map["source_address_xr"] = "source-address-xr"

                            self.rp_address = Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"

                            self.rpf_neighbor = Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfNeighbor()
                            self.rpf_neighbor.parent = self
                            self._children_name_map["rpf_neighbor"] = "rpf-neighbor"

                            self.secondary_rpf_neighbor = Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor()
                            self.secondary_rpf_neighbor.parent = self
                            self._children_name_map["secondary_rpf_neighbor"] = "secondary-rpf-neighbor"

                            self.rpf_root = Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfRoot()
                            self.rpf_root.parent = self
                            self._children_name_map["rpf_root"] = "rpf-root"

                            self.proxy_address = Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.ProxyAddress()
                            self.proxy_address.parent = self
                            self._children_name_map["proxy_address"] = "proxy-address"

                            self.orig_src_address = Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress()
                            self.orig_src_address.parent = self
                            self._children_name_map["orig_src_address"] = "orig-src-address"

                            self.outgoing_interface = YList(self)
                            self._segment_path = lambda: "topology"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology, ['source_address', 'group_address', 'rpt', 'limit_reached', 'low_memory', 'protocol', 'wildcard', 'rpt_xr', 'spt', 'uptime', 'expiry', 'alive', 'register_received_timer', 'remote_source', 'crossed_threshold', 'data_mdt_addr_assigned', 'rpf_interface_name', 'rpf_vrf_name', 'rpf_safi', 'rpf_table_name', 'rpf_drop', 'rpf_extranet', 'is_via_lsm', 'secondary_rpf_interface_name', 'connected', 'proxy', 'rpf_proxy_enabled', 'mofrr_enabled', 'rib_mo_frr_enabled', 'jp_timer', 'jp_status', 'suppress_registers', 'assume_alive', 'probe_alive', 'really_alive', 'inherit_alive', 'inherit_spt', 'signal_sources', 'dont_check_connected', 'register_received', 'last_hop', 'sending_registers', 'sending_null_registers', 'sa_sent', 'sa_received', 'sa_joined', 'anycast_rp_match', 'anycast_rp_route_target', 'bgp_join', 'bgp_jp_time', 'customer_routing_type', 'extranet_route', 'mofrr_active', 'mofrr_primary', 'mofrr_backup', 'vxlan', 'kat_state'], name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "group-address-xr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.GroupAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class SourceAddressXr(Entity):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.SourceAddressXr, self).__init__()

                                self.yang_name = "source-address-xr"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "source-address-xr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.SourceAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class RpAddress(Entity):
                            """
                            RP Address (If rpt)
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "rp-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class RpfNeighbor(Entity):
                            """
                            RPF Neighbor
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfNeighbor, self).__init__()

                                self.yang_name = "rpf-neighbor"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "rpf-neighbor"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfNeighbor, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class SecondaryRpfNeighbor(Entity):
                            """
                            Secondary RPF Neighbor
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor, self).__init__()

                                self.yang_name = "secondary-rpf-neighbor"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "secondary-rpf-neighbor"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class RpfRoot(Entity):
                            """
                            Root of this mcast tree
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfRoot, self).__init__()

                                self.yang_name = "rpf-root"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "rpf-root"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfRoot, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class ProxyAddress(Entity):
                            """
                            RPF Proxy address.
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.ProxyAddress, self).__init__()

                                self.yang_name = "proxy-address"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "proxy-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.ProxyAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class OrigSrcAddress(Entity):
                            """
                            Orig Src Address.
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress, self).__init__()

                                self.yang_name = "orig-src-address"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "orig-src-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class OutgoingInterface(Entity):
                            """
                            Outgoing interface list
                            
                            .. attribute:: assert_winner
                            
                            	Assert Winner
                            	**type**\:  :py:class:`AssertWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner>`
                            
                            .. attribute:: interface_name
                            
                            	Interface Identifier
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: expiry
                            
                            	Expiry in seconds
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: bgp_c_mcast_prune_delay_timer
                            
                            	BGP C\-MCAST Prune Suppression in seconds
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: jp_timer
                            
                            	Join\-Prune Timer (secs)
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: second
                            
                            .. attribute:: jp_state
                            
                            	Join\-Prune State
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: assert_timer
                            
                            	Assert Timer in seconds
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: second
                            
                            .. attribute:: local_members
                            
                            	Local Information. Deprecated \- use 'local\-members\-information' instead
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: internal_interest_info
                            
                            	Internal Interest. Deprecated \- use 'internal\-interest\-information' instead
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: forwarding_state
                            
                            	Forward or Prune
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: immediate_state
                            
                            	Immediate fwding state
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: last_hop
                            
                            	Are we last hop ?
                            	**type**\: bool
                            
                            .. attribute:: mldp_inband_mdt
                            
                            	MLDP Inband MDT interface
                            	**type**\: bool
                            
                            .. attribute:: mldp_stale
                            
                            	OLE is stale
                            	**type**\: bool
                            
                            .. attribute:: sa_prune
                            
                            	BGP SA Prune state
                            	**type**\: bool
                            
                            .. attribute:: admin_boundary
                            
                            	Is this an administrative boundary ?
                            	**type**\: bool
                            
                            .. attribute:: igmp_membership
                            
                            	IGMP membership
                            	**type**\: bool
                            
                            .. attribute:: mdt_safi_join
                            
                            	MDT Safi join
                            	**type**\: bool
                            
                            .. attribute:: mvpn_safi_join
                            
                            	MVPN Safi join
                            	**type**\: bool
                            
                            .. attribute:: local_mdt_join
                            
                            	Default MDT Join
                            	**type**\: bool
                            
                            .. attribute:: data_mdt_join
                            
                            	Data MDT join
                            	**type**\: bool
                            
                            .. attribute:: mvpnv6_safi_join
                            
                            	MVPN IPv6 Safi join
                            	**type**\: bool
                            
                            .. attribute:: bgp_c_mcast_join
                            
                            	BGP C\-Mcast join
                            	**type**\: bool
                            
                            .. attribute:: vrf_name
                            
                            	VRF which physically owns
                            	**type**\: str
                            
                            	**length:** 0..33
                            
                            .. attribute:: extranet_interface
                            
                            	Is this an Extranet Interface ?
                            	**type**\: bool
                            
                            .. attribute:: internal_interest_information
                            
                            	Internal Interest. Replaces internal\-interest\-info
                            	**type**\:  :py:class:`PimInternalInterestInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimInternalInterestInfo>`
                            
                            .. attribute:: local_members_information
                            
                            	Local Information. Replaces local\-members
                            	**type**\:  :py:class:`PimShowLocalInterest <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowLocalInterest>`
                            
                            .. attribute:: assert_state
                            
                            	Assert State
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface, self).__init__()

                                self.yang_name = "outgoing-interface"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("assert-winner", ("assert_winner", Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner))])
                                self._leafs = OrderedDict([
                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                    ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                                    ('expiry', (YLeaf(YType.uint64, 'expiry'), ['int'])),
                                    ('bgp_c_mcast_prune_delay_timer', (YLeaf(YType.uint64, 'bgp-c-mcast-prune-delay-timer'), ['int'])),
                                    ('jp_timer', (YLeaf(YType.int32, 'jp-timer'), ['int'])),
                                    ('jp_state', (YLeaf(YType.int32, 'jp-state'), ['int'])),
                                    ('assert_timer', (YLeaf(YType.int32, 'assert-timer'), ['int'])),
                                    ('local_members', (YLeaf(YType.int32, 'local-members'), ['int'])),
                                    ('internal_interest_info', (YLeaf(YType.int32, 'internal-interest-info'), ['int'])),
                                    ('forwarding_state', (YLeaf(YType.int32, 'forwarding-state'), ['int'])),
                                    ('immediate_state', (YLeaf(YType.int32, 'immediate-state'), ['int'])),
                                    ('last_hop', (YLeaf(YType.boolean, 'last-hop'), ['bool'])),
                                    ('mldp_inband_mdt', (YLeaf(YType.boolean, 'mldp-inband-mdt'), ['bool'])),
                                    ('mldp_stale', (YLeaf(YType.boolean, 'mldp-stale'), ['bool'])),
                                    ('sa_prune', (YLeaf(YType.boolean, 'sa-prune'), ['bool'])),
                                    ('admin_boundary', (YLeaf(YType.boolean, 'admin-boundary'), ['bool'])),
                                    ('igmp_membership', (YLeaf(YType.boolean, 'igmp-membership'), ['bool'])),
                                    ('mdt_safi_join', (YLeaf(YType.boolean, 'mdt-safi-join'), ['bool'])),
                                    ('mvpn_safi_join', (YLeaf(YType.boolean, 'mvpn-safi-join'), ['bool'])),
                                    ('local_mdt_join', (YLeaf(YType.boolean, 'local-mdt-join'), ['bool'])),
                                    ('data_mdt_join', (YLeaf(YType.boolean, 'data-mdt-join'), ['bool'])),
                                    ('mvpnv6_safi_join', (YLeaf(YType.boolean, 'mvpnv6-safi-join'), ['bool'])),
                                    ('bgp_c_mcast_join', (YLeaf(YType.boolean, 'bgp-c-mcast-join'), ['bool'])),
                                    ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                    ('extranet_interface', (YLeaf(YType.boolean, 'extranet-interface'), ['bool'])),
                                    ('internal_interest_information', (YLeaf(YType.enumeration, 'internal-interest-information'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimInternalInterestInfo', '')])),
                                    ('local_members_information', (YLeaf(YType.enumeration, 'local-members-information'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowLocalInterest', '')])),
                                    ('assert_state', (YLeaf(YType.boolean, 'assert-state'), ['bool'])),
                                ])
                                self.interface_name = None
                                self.uptime = None
                                self.expiry = None
                                self.bgp_c_mcast_prune_delay_timer = None
                                self.jp_timer = None
                                self.jp_state = None
                                self.assert_timer = None
                                self.local_members = None
                                self.internal_interest_info = None
                                self.forwarding_state = None
                                self.immediate_state = None
                                self.last_hop = None
                                self.mldp_inband_mdt = None
                                self.mldp_stale = None
                                self.sa_prune = None
                                self.admin_boundary = None
                                self.igmp_membership = None
                                self.mdt_safi_join = None
                                self.mvpn_safi_join = None
                                self.local_mdt_join = None
                                self.data_mdt_join = None
                                self.mvpnv6_safi_join = None
                                self.bgp_c_mcast_join = None
                                self.vrf_name = None
                                self.extranet_interface = None
                                self.internal_interest_information = None
                                self.local_members_information = None
                                self.assert_state = None

                                self.assert_winner = Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner()
                                self.assert_winner.parent = self
                                self._children_name_map["assert_winner"] = "assert-winner"
                                self._segment_path = lambda: "outgoing-interface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface, ['interface_name', 'uptime', 'expiry', 'bgp_c_mcast_prune_delay_timer', 'jp_timer', 'jp_state', 'assert_timer', 'local_members', 'internal_interest_info', 'forwarding_state', 'immediate_state', 'last_hop', 'mldp_inband_mdt', 'mldp_stale', 'sa_prune', 'admin_boundary', 'igmp_membership', 'mdt_safi_join', 'mvpn_safi_join', 'local_mdt_join', 'data_mdt_join', 'mvpnv6_safi_join', 'bgp_c_mcast_join', 'vrf_name', 'extranet_interface', 'internal_interest_information', 'local_members_information', 'assert_state'], name, value)


                            class AssertWinner(Entity):
                                """
                                Assert Winner
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner, self).__init__()

                                    self.yang_name = "assert-winner"
                                    self.yang_parent_name = "outgoing-interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "assert-winner"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class BgpAfs(Entity):
                    """
                    PIM BGP SAFI table
                    
                    .. attribute:: bgp_af
                    
                    	PIM BGP SAFI information
                    	**type**\: list of  		 :py:class:`BgpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs, self).__init__()

                        self.yang_name = "bgp-afs"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("bgp-af", ("bgp_af", Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf))])
                        self._leafs = OrderedDict()

                        self.bgp_af = YList(self)
                        self._segment_path = lambda: "bgp-afs"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs, [], name, value)


                    class BgpAf(Entity):
                        """
                        PIM BGP SAFI information
                        
                        .. attribute:: source_address
                        
                        	Source IP address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: group_address
                        
                        	Group IP address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source
                        
                        	Source address
                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Source>`
                        
                        .. attribute:: group
                        
                        	Group address
                        	**type**\:  :py:class:`Group <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Group>`
                        
                        .. attribute:: next_hop
                        
                        	Next hop address
                        	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.NextHop>`
                        
                        .. attribute:: route_distinguisher
                        
                        	Router ID
                        	**type**\: str
                        
                        	**length:** 0..256
                        
                        .. attribute:: extranet_path_count
                        
                        	Count of dependent extranet paths
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_bgp_added
                        
                        	SAFI learnt from BGP
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf, self).__init__()

                            self.yang_name = "bgp-af"
                            self.yang_parent_name = "bgp-afs"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("source", ("source", Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Source)), ("group", ("group", Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Group)), ("next-hop", ("next_hop", Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.NextHop))])
                            self._leafs = OrderedDict([
                                ('source_address', (YLeaf(YType.str, 'source-address'), ['str','str'])),
                                ('group_address', (YLeaf(YType.str, 'group-address'), ['str','str'])),
                                ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                ('extranet_path_count', (YLeaf(YType.uint32, 'extranet-path-count'), ['int'])),
                                ('is_bgp_added', (YLeaf(YType.boolean, 'is-bgp-added'), ['bool'])),
                            ])
                            self.source_address = None
                            self.group_address = None
                            self.route_distinguisher = None
                            self.extranet_path_count = None
                            self.is_bgp_added = None

                            self.source = Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Source()
                            self.source.parent = self
                            self._children_name_map["source"] = "source"

                            self.group = Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Group()
                            self.group.parent = self
                            self._children_name_map["group"] = "group"

                            self.next_hop = Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.NextHop()
                            self.next_hop.parent = self
                            self._children_name_map["next_hop"] = "next-hop"
                            self._segment_path = lambda: "bgp-af"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf, ['source_address', 'group_address', 'route_distinguisher', 'extranet_path_count', 'is_bgp_added'], name, value)


                        class Source(Entity):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "bgp-af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "source"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Source, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class Group(Entity):
                            """
                            Group address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Group, self).__init__()

                                self.yang_name = "group"
                                self.yang_parent_name = "bgp-af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "group"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Group, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class NextHop(Entity):
                            """
                            Next hop address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.NextHop, self).__init__()

                                self.yang_name = "next-hop"
                                self.yang_parent_name = "bgp-af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "next-hop"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.NextHop, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class AutoRp(Entity):
                    """
                    PIM Auto\-RP information
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.AutoRp, self).__init__()

                        self.yang_name = "auto-rp"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "auto-rp"
                        self._is_frozen = True


                class TopologyInterfaceFlagRouteCounts(Entity):
                    """
                    Route count for topology with interface flag set
                    
                    .. attribute:: topology_interface_flag_route_count
                    
                    	Route count for topology with interface flag set
                    	**type**\: list of  		 :py:class:`TopologyInterfaceFlagRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts, self).__init__()

                        self.yang_name = "topology-interface-flag-route-counts"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("topology-interface-flag-route-count", ("topology_interface_flag_route_count", Ipv6Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount))])
                        self._leafs = OrderedDict()

                        self.topology_interface_flag_route_count = YList(self)
                        self._segment_path = lambda: "topology-interface-flag-route-counts"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts, [], name, value)


                    class TopologyInterfaceFlagRouteCount(Entity):
                        """
                        Route count for topology with interface flag
                        set
                        
                        .. attribute:: interface_flag  (key)
                        
                        	Interface flag
                        	**type**\:  :py:class:`PimTopologyInterfaceFlag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimTopologyInterfaceFlag>`
                        
                        .. attribute:: group_ranges
                        
                        	No. of (\*,G/M) routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: active_group_ranges
                        
                        	No. of (\*,G/M) routes active in mrib
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: groute_count
                        
                        	No. of (\*,G) routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sg_route_count
                        
                        	No. of (S,G) routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sgr_route_count
                        
                        	No. of (S,G)RPT routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_node_low_memory
                        
                        	Is node in low memory condition
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount, self).__init__()

                            self.yang_name = "topology-interface-flag-route-count"
                            self.yang_parent_name = "topology-interface-flag-route-counts"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['interface_flag']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface_flag', (YLeaf(YType.enumeration, 'interface-flag'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimTopologyInterfaceFlag', '')])),
                                ('group_ranges', (YLeaf(YType.uint32, 'group-ranges'), ['int'])),
                                ('active_group_ranges', (YLeaf(YType.uint32, 'active-group-ranges'), ['int'])),
                                ('groute_count', (YLeaf(YType.uint32, 'groute-count'), ['int'])),
                                ('sg_route_count', (YLeaf(YType.uint32, 'sg-route-count'), ['int'])),
                                ('sgr_route_count', (YLeaf(YType.uint32, 'sgr-route-count'), ['int'])),
                                ('is_node_low_memory', (YLeaf(YType.boolean, 'is-node-low-memory'), ['bool'])),
                            ])
                            self.interface_flag = None
                            self.group_ranges = None
                            self.active_group_ranges = None
                            self.groute_count = None
                            self.sg_route_count = None
                            self.sgr_route_count = None
                            self.is_node_low_memory = None
                            self._segment_path = lambda: "topology-interface-flag-route-count" + "[interface-flag='" + str(self.interface_flag) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount, ['interface_flag', 'group_ranges', 'active_group_ranges', 'groute_count', 'sg_route_count', 'sgr_route_count', 'is_node_low_memory'], name, value)


                class GroupMapSources(Entity):
                    """
                    PIM group\-mapping with source information
                    
                    .. attribute:: group_map_source
                    
                    	PIM Group Mapping Entry with source information
                    	**type**\: list of  		 :py:class:`GroupMapSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources, self).__init__()

                        self.yang_name = "group-map-sources"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("group-map-source", ("group_map_source", Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource))])
                        self._leafs = OrderedDict()

                        self.group_map_source = YList(self)
                        self._segment_path = lambda: "group-map-sources"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources, [], name, value)


                    class GroupMapSource(Entity):
                        """
                        PIM Group Mapping Entry with source information
                        
                        .. attribute:: prefix
                        
                        	Prefix
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: client
                        
                        	Client
                        	**type**\:  :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:  :py:class:`PimProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimProtocol>`
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: priority
                        
                        	RP Priority
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: source_of_information
                        
                        	The source of information
                        	**type**\:  :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation>`
                        
                        .. attribute:: group_map_information
                        
                        	Group Mapping information
                        	**type**\:  :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation>`
                        
                        .. attribute:: holdtime
                        
                        	Holdtime in seconds
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: expires
                        
                        	Mapping expiry time in seconds
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: uptime
                        
                        	Mapping uptime in seconds
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource, self).__init__()

                            self.yang_name = "group-map-source"
                            self.yang_parent_name = "group-map-sources"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("source-of-information", ("source_of_information", Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation)), ("group-map-information", ("group_map_information", Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation))])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                ('client', (YLeaf(YType.enumeration, 'client'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimClient', '')])),
                                ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimProtocol', '')])),
                                ('rp_address', (YLeaf(YType.str, 'rp-address'), ['str','str'])),
                                ('priority', (YLeaf(YType.uint32, 'priority'), ['int'])),
                                ('holdtime', (YLeaf(YType.int32, 'holdtime'), ['int'])),
                                ('expires', (YLeaf(YType.uint64, 'expires'), ['int'])),
                                ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                            ])
                            self.prefix = None
                            self.prefix_length = None
                            self.client = None
                            self.protocol = None
                            self.rp_address = None
                            self.priority = None
                            self.holdtime = None
                            self.expires = None
                            self.uptime = None

                            self.source_of_information = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation()
                            self.source_of_information.parent = self
                            self._children_name_map["source_of_information"] = "source-of-information"

                            self.group_map_information = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation()
                            self.group_map_information.parent = self
                            self._children_name_map["group_map_information"] = "group-map-information"
                            self._segment_path = lambda: "group-map-source"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource, ['prefix', 'prefix_length', 'client', 'protocol', 'rp_address', 'priority', 'holdtime', 'expires', 'uptime'], name, value)


                        class SourceOfInformation(Entity):
                            """
                            The source of information
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation, self).__init__()

                                self.yang_name = "source-of-information"
                                self.yang_parent_name = "group-map-source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "source-of-information"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class GroupMapInformation(Entity):
                            """
                            Group Mapping information
                            
                            .. attribute:: prefix
                            
                            	Group range prefix
                            	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix>`
                            
                            .. attribute:: rp_address
                            
                            	Rendezvous Point Address
                            	**type**\:  :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress>`
                            
                            .. attribute:: prefix_length
                            
                            	Group range prefix length
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: client
                            
                            	Client mapping learnt from
                            	**type**\:  :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                            
                            .. attribute:: protocol
                            
                            	Protocol mode of the range
                            	**type**\:  :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                            
                            .. attribute:: group_count
                            
                            	No. of groups in this range
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_used
                            
                            	Is this mapping being used?
                            	**type**\: bool
                            
                            .. attribute:: mrib_active
                            
                            	Is this mapping active in MRIB?
                            	**type**\: bool
                            
                            .. attribute:: is_override
                            
                            	Is this the override range?
                            	**type**\: bool
                            
                            .. attribute:: priority
                            
                            	Bootstrap priority
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation, self).__init__()

                                self.yang_name = "group-map-information"
                                self.yang_parent_name = "group-map-source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("prefix", ("prefix", Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix)), ("rp-address", ("rp_address", Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress))])
                                self._leafs = OrderedDict([
                                    ('prefix_length', (YLeaf(YType.int32, 'prefix-length'), ['int'])),
                                    ('client', (YLeaf(YType.enumeration, 'client'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowRangeClient', '')])),
                                    ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowProtocol', '')])),
                                    ('group_count', (YLeaf(YType.uint32, 'group-count'), ['int'])),
                                    ('is_used', (YLeaf(YType.boolean, 'is-used'), ['bool'])),
                                    ('mrib_active', (YLeaf(YType.boolean, 'mrib-active'), ['bool'])),
                                    ('is_override', (YLeaf(YType.boolean, 'is-override'), ['bool'])),
                                    ('priority', (YLeaf(YType.uint32, 'priority'), ['int'])),
                                ])
                                self.prefix_length = None
                                self.client = None
                                self.protocol = None
                                self.group_count = None
                                self.is_used = None
                                self.mrib_active = None
                                self.is_override = None
                                self.priority = None

                                self.prefix = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix()
                                self.prefix.parent = self
                                self._children_name_map["prefix"] = "prefix"

                                self.rp_address = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress()
                                self.rp_address.parent = self
                                self._children_name_map["rp_address"] = "rp-address"
                                self._segment_path = lambda: "group-map-information"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation, ['prefix_length', 'client', 'protocol', 'group_count', 'is_used', 'mrib_active', 'is_override', 'priority'], name, value)


                            class Prefix(Entity):
                                """
                                Group range prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix, self).__init__()

                                    self.yang_name = "prefix"
                                    self.yang_parent_name = "group-map-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "prefix"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                            class RpAddress(Entity):
                                """
                                Rendezvous Point Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress, self).__init__()

                                    self.yang_name = "rp-address"
                                    self.yang_parent_name = "group-map-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "rp-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class TrafficCounters(Entity):
                    """
                    PIM message traffic counters
                    
                    .. attribute:: elapsed_time
                    
                    	Running time for counters in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: inputs
                    
                    	Packets in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: outputs
                    
                    	Packets out
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: format_error
                    
                    	Malformed packets in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pakman_error
                    
                    	Pakman packets dropped
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: standby_packets_error
                    
                    	Packets received in standby state
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: checksum_error
                    
                    	Checksum errors
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: socket_error
                    
                    	Socket errors
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: send_queue_full
                    
                    	Packets dropped since send queue was full
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: boundary_acl_rx_drop
                    
                    	Inc. JP dropped since boundary ACL confg
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: boundary_acl_tx_drop
                    
                    	Out JP dropped since boundary ACL confg
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: no_socket_connection
                    
                    	Packets dropped since no socket connection
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: no_source_address
                    
                    	Packets dropped since no source address
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_hello
                    
                    	Hello packets in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_hello
                    
                    	Hello packets out
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_jp
                    
                    	Join Prune packets in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_jp
                    
                    	Join Prune packets out
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_data_register
                    
                    	Data Register packets in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_null_register
                    
                    	Null Register packets in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_null_register
                    
                    	Null Register packets out
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_register_stop
                    
                    	Register Stop packets in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_register_stop
                    
                    	Register Stop packets out
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_assert
                    
                    	Assert packets in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_assert_batched
                    
                    	Batched Assert packets in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_assert
                    
                    	Assert packets out
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_assert_batched
                    
                    	Batched Assert packets out
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_df_election
                    
                    	DF Election packets in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_df_election
                    
                    	DF Election packets out
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_bsr_message
                    
                    	Input BSR Messages
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_bsr_message
                    
                    	Output BSR Messages
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_candidate_rp_advertisement
                    
                    	Input Candidate\-RP Advertisment
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_candidate_rp_advertisement
                    
                    	Output Candidate\-RP Advertisment
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_ecmp_redirect
                    
                    	Input Ecmp Redirect
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_ecmp_redirect
                    
                    	Output Ecmp Redirect
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_loop_error
                    
                    	Output on loopback error
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_invalid_lsm_identifier
                    
                    	 Invalid LSM ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_idb_error
                    
                    	No IDB for intf error
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_vrf_error
                    
                    	No VRF for idb error
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_pim_error
                    
                    	PIM Disabled on intf error
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_pim_version_error
                    
                    	Invalid PIM version error
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_join_group
                    
                    	Output Join Groups
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_prune_group
                    
                    	Output Prune Groups
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_join_prune_bytes
                    
                    	Output JP Bytes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: byte
                    
                    .. attribute:: output_hello_bytes
                    
                    	Output Hello Bytes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: byte
                    
                    .. attribute:: non_supported_packets
                    
                    	PIM non supported pckets
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_registers
                    
                    	PIM invalid registers received
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_join_prunes
                    
                    	PIM invalid Join/Prunes received
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_packman_error
                    
                    	Packets Dropped due to Pakman Error
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_read_socket_error
                    
                    	Packet Read Socket Error
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_queue_last_clear
                    
                    	Time in seconds since the last clear of all packet queues stats
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: packets_standby
                    
                    	Packets Dropped due to Standby Error
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: no_mdt_socket_connection
                    
                    	Packets dropped since no mdt socket connection
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_send_queue_full
                    
                    	Packets dropped since mdt send queue was full
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_socket_error
                    
                    	MDT Socket errors
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_join_tlv_sent
                    
                    	Data MDT Join Msgs sent
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_join_tlv_received
                    
                    	Data MDT Join Msgs received
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_join_bad_type
                    
                    	Data MDT TLV bad type
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_drop_local_source_address
                    
                    	Data MDT Join msgs dropped due to local source addr
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_drop_null_local_address
                    
                    	Data MDT Join msgs dropped due to null local addr
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_drop_no_idb
                    
                    	Data MDT Join msgs dropped due to idb missing
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_drop_no_vrf
                    
                    	Data MDT Join msgs dropped due to vrf missing
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_destination_packets
                    
                    	Control Packets with Invalid Destination
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_joins_drop_multiple_encapsulation
                    
                    	MDT Join msgs dropped due to multiple Encap limitation
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: truncated_pim_packets
                    
                    	Packets dropped due to truncated Joins or Prunes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_source_encodings
                    
                    	Number of invalid source encodings received
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_hello_options
                    
                    	Number of invalid hello options received
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_queue
                    
                    	Packet queue state and statistics
                    	**type**\: list of  		 :py:class:`PacketQueue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters, self).__init__()

                        self.yang_name = "traffic-counters"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("packet-queue", ("packet_queue", Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue))])
                        self._leafs = OrderedDict([
                            ('elapsed_time', (YLeaf(YType.uint32, 'elapsed-time'), ['int'])),
                            ('inputs', (YLeaf(YType.uint32, 'inputs'), ['int'])),
                            ('outputs', (YLeaf(YType.uint32, 'outputs'), ['int'])),
                            ('format_error', (YLeaf(YType.uint32, 'format-error'), ['int'])),
                            ('pakman_error', (YLeaf(YType.uint32, 'pakman-error'), ['int'])),
                            ('standby_packets_error', (YLeaf(YType.uint32, 'standby-packets-error'), ['int'])),
                            ('checksum_error', (YLeaf(YType.uint32, 'checksum-error'), ['int'])),
                            ('socket_error', (YLeaf(YType.uint32, 'socket-error'), ['int'])),
                            ('send_queue_full', (YLeaf(YType.uint32, 'send-queue-full'), ['int'])),
                            ('boundary_acl_rx_drop', (YLeaf(YType.uint32, 'boundary-acl-rx-drop'), ['int'])),
                            ('boundary_acl_tx_drop', (YLeaf(YType.uint32, 'boundary-acl-tx-drop'), ['int'])),
                            ('no_socket_connection', (YLeaf(YType.uint32, 'no-socket-connection'), ['int'])),
                            ('no_source_address', (YLeaf(YType.uint32, 'no-source-address'), ['int'])),
                            ('input_hello', (YLeaf(YType.uint32, 'input-hello'), ['int'])),
                            ('output_hello', (YLeaf(YType.uint32, 'output-hello'), ['int'])),
                            ('input_jp', (YLeaf(YType.uint32, 'input-jp'), ['int'])),
                            ('output_jp', (YLeaf(YType.uint32, 'output-jp'), ['int'])),
                            ('input_data_register', (YLeaf(YType.uint32, 'input-data-register'), ['int'])),
                            ('input_null_register', (YLeaf(YType.uint32, 'input-null-register'), ['int'])),
                            ('output_null_register', (YLeaf(YType.uint32, 'output-null-register'), ['int'])),
                            ('input_register_stop', (YLeaf(YType.uint32, 'input-register-stop'), ['int'])),
                            ('output_register_stop', (YLeaf(YType.uint32, 'output-register-stop'), ['int'])),
                            ('input_assert', (YLeaf(YType.uint32, 'input-assert'), ['int'])),
                            ('input_assert_batched', (YLeaf(YType.uint32, 'input-assert-batched'), ['int'])),
                            ('output_assert', (YLeaf(YType.uint32, 'output-assert'), ['int'])),
                            ('output_assert_batched', (YLeaf(YType.uint32, 'output-assert-batched'), ['int'])),
                            ('input_df_election', (YLeaf(YType.uint32, 'input-df-election'), ['int'])),
                            ('output_df_election', (YLeaf(YType.uint32, 'output-df-election'), ['int'])),
                            ('input_bsr_message', (YLeaf(YType.uint32, 'input-bsr-message'), ['int'])),
                            ('output_bsr_message', (YLeaf(YType.uint32, 'output-bsr-message'), ['int'])),
                            ('input_candidate_rp_advertisement', (YLeaf(YType.uint32, 'input-candidate-rp-advertisement'), ['int'])),
                            ('output_candidate_rp_advertisement', (YLeaf(YType.uint32, 'output-candidate-rp-advertisement'), ['int'])),
                            ('input_ecmp_redirect', (YLeaf(YType.uint32, 'input-ecmp-redirect'), ['int'])),
                            ('output_ecmp_redirect', (YLeaf(YType.uint32, 'output-ecmp-redirect'), ['int'])),
                            ('output_loop_error', (YLeaf(YType.uint32, 'output-loop-error'), ['int'])),
                            ('mldp_mdt_invalid_lsm_identifier', (YLeaf(YType.uint32, 'mldp-mdt-invalid-lsm-identifier'), ['int'])),
                            ('input_no_idb_error', (YLeaf(YType.uint32, 'input-no-idb-error'), ['int'])),
                            ('input_no_vrf_error', (YLeaf(YType.uint32, 'input-no-vrf-error'), ['int'])),
                            ('input_no_pim_error', (YLeaf(YType.uint32, 'input-no-pim-error'), ['int'])),
                            ('input_pim_version_error', (YLeaf(YType.uint32, 'input-pim-version-error'), ['int'])),
                            ('output_join_group', (YLeaf(YType.uint32, 'output-join-group'), ['int'])),
                            ('output_prune_group', (YLeaf(YType.uint32, 'output-prune-group'), ['int'])),
                            ('output_join_prune_bytes', (YLeaf(YType.uint32, 'output-join-prune-bytes'), ['int'])),
                            ('output_hello_bytes', (YLeaf(YType.uint32, 'output-hello-bytes'), ['int'])),
                            ('non_supported_packets', (YLeaf(YType.uint32, 'non-supported-packets'), ['int'])),
                            ('invalid_registers', (YLeaf(YType.uint32, 'invalid-registers'), ['int'])),
                            ('invalid_join_prunes', (YLeaf(YType.uint32, 'invalid-join-prunes'), ['int'])),
                            ('packet_packman_error', (YLeaf(YType.uint32, 'packet-packman-error'), ['int'])),
                            ('packet_read_socket_error', (YLeaf(YType.uint32, 'packet-read-socket-error'), ['int'])),
                            ('packet_queue_last_clear', (YLeaf(YType.uint32, 'packet-queue-last-clear'), ['int'])),
                            ('packets_standby', (YLeaf(YType.uint32, 'packets-standby'), ['int'])),
                            ('no_mdt_socket_connection', (YLeaf(YType.uint32, 'no-mdt-socket-connection'), ['int'])),
                            ('mdt_send_queue_full', (YLeaf(YType.uint32, 'mdt-send-queue-full'), ['int'])),
                            ('mdt_socket_error', (YLeaf(YType.uint32, 'mdt-socket-error'), ['int'])),
                            ('mdt_join_tlv_sent', (YLeaf(YType.uint32, 'mdt-join-tlv-sent'), ['int'])),
                            ('mdt_join_tlv_received', (YLeaf(YType.uint32, 'mdt-join-tlv-received'), ['int'])),
                            ('mdt_join_bad_type', (YLeaf(YType.uint32, 'mdt-join-bad-type'), ['int'])),
                            ('mdt_drop_local_source_address', (YLeaf(YType.uint32, 'mdt-drop-local-source-address'), ['int'])),
                            ('mdt_drop_null_local_address', (YLeaf(YType.uint32, 'mdt-drop-null-local-address'), ['int'])),
                            ('mdt_drop_no_idb', (YLeaf(YType.uint32, 'mdt-drop-no-idb'), ['int'])),
                            ('mdt_drop_no_vrf', (YLeaf(YType.uint32, 'mdt-drop-no-vrf'), ['int'])),
                            ('invalid_destination_packets', (YLeaf(YType.uint32, 'invalid-destination-packets'), ['int'])),
                            ('mdt_joins_drop_multiple_encapsulation', (YLeaf(YType.uint32, 'mdt-joins-drop-multiple-encapsulation'), ['int'])),
                            ('truncated_pim_packets', (YLeaf(YType.uint32, 'truncated-pim-packets'), ['int'])),
                            ('invalid_source_encodings', (YLeaf(YType.uint32, 'invalid-source-encodings'), ['int'])),
                            ('invalid_hello_options', (YLeaf(YType.uint32, 'invalid-hello-options'), ['int'])),
                        ])
                        self.elapsed_time = None
                        self.inputs = None
                        self.outputs = None
                        self.format_error = None
                        self.pakman_error = None
                        self.standby_packets_error = None
                        self.checksum_error = None
                        self.socket_error = None
                        self.send_queue_full = None
                        self.boundary_acl_rx_drop = None
                        self.boundary_acl_tx_drop = None
                        self.no_socket_connection = None
                        self.no_source_address = None
                        self.input_hello = None
                        self.output_hello = None
                        self.input_jp = None
                        self.output_jp = None
                        self.input_data_register = None
                        self.input_null_register = None
                        self.output_null_register = None
                        self.input_register_stop = None
                        self.output_register_stop = None
                        self.input_assert = None
                        self.input_assert_batched = None
                        self.output_assert = None
                        self.output_assert_batched = None
                        self.input_df_election = None
                        self.output_df_election = None
                        self.input_bsr_message = None
                        self.output_bsr_message = None
                        self.input_candidate_rp_advertisement = None
                        self.output_candidate_rp_advertisement = None
                        self.input_ecmp_redirect = None
                        self.output_ecmp_redirect = None
                        self.output_loop_error = None
                        self.mldp_mdt_invalid_lsm_identifier = None
                        self.input_no_idb_error = None
                        self.input_no_vrf_error = None
                        self.input_no_pim_error = None
                        self.input_pim_version_error = None
                        self.output_join_group = None
                        self.output_prune_group = None
                        self.output_join_prune_bytes = None
                        self.output_hello_bytes = None
                        self.non_supported_packets = None
                        self.invalid_registers = None
                        self.invalid_join_prunes = None
                        self.packet_packman_error = None
                        self.packet_read_socket_error = None
                        self.packet_queue_last_clear = None
                        self.packets_standby = None
                        self.no_mdt_socket_connection = None
                        self.mdt_send_queue_full = None
                        self.mdt_socket_error = None
                        self.mdt_join_tlv_sent = None
                        self.mdt_join_tlv_received = None
                        self.mdt_join_bad_type = None
                        self.mdt_drop_local_source_address = None
                        self.mdt_drop_null_local_address = None
                        self.mdt_drop_no_idb = None
                        self.mdt_drop_no_vrf = None
                        self.invalid_destination_packets = None
                        self.mdt_joins_drop_multiple_encapsulation = None
                        self.truncated_pim_packets = None
                        self.invalid_source_encodings = None
                        self.invalid_hello_options = None

                        self.packet_queue = YList(self)
                        self._segment_path = lambda: "traffic-counters"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters, ['elapsed_time', 'inputs', 'outputs', 'format_error', 'pakman_error', 'standby_packets_error', 'checksum_error', 'socket_error', 'send_queue_full', 'boundary_acl_rx_drop', 'boundary_acl_tx_drop', 'no_socket_connection', 'no_source_address', 'input_hello', 'output_hello', 'input_jp', 'output_jp', 'input_data_register', 'input_null_register', 'output_null_register', 'input_register_stop', 'output_register_stop', 'input_assert', 'input_assert_batched', 'output_assert', 'output_assert_batched', 'input_df_election', 'output_df_election', 'input_bsr_message', 'output_bsr_message', 'input_candidate_rp_advertisement', 'output_candidate_rp_advertisement', 'input_ecmp_redirect', 'output_ecmp_redirect', 'output_loop_error', 'mldp_mdt_invalid_lsm_identifier', 'input_no_idb_error', 'input_no_vrf_error', 'input_no_pim_error', 'input_pim_version_error', 'output_join_group', 'output_prune_group', 'output_join_prune_bytes', 'output_hello_bytes', 'non_supported_packets', 'invalid_registers', 'invalid_join_prunes', 'packet_packman_error', 'packet_read_socket_error', 'packet_queue_last_clear', 'packets_standby', 'no_mdt_socket_connection', 'mdt_send_queue_full', 'mdt_socket_error', 'mdt_join_tlv_sent', 'mdt_join_tlv_received', 'mdt_join_bad_type', 'mdt_drop_local_source_address', 'mdt_drop_null_local_address', 'mdt_drop_no_idb', 'mdt_drop_no_vrf', 'invalid_destination_packets', 'mdt_joins_drop_multiple_encapsulation', 'truncated_pim_packets', 'invalid_source_encodings', 'invalid_hello_options'], name, value)


                    class PacketQueue(Entity):
                        """
                        Packet queue state and statistics
                        
                        .. attribute:: packet_queue_state
                        
                        	State of the queue
                        	**type**\:  :py:class:`PacketQueueState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState>`
                        
                        .. attribute:: packet_queue_stats
                        
                        	Statistics about the queue
                        	**type**\:  :py:class:`PacketQueueStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats>`
                        
                        .. attribute:: packet_queue_priority
                        
                        	Priority of this packet queue
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue, self).__init__()

                            self.yang_name = "packet-queue"
                            self.yang_parent_name = "traffic-counters"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("packet-queue-state", ("packet_queue_state", Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState)), ("packet-queue-stats", ("packet_queue_stats", Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats))])
                            self._leafs = OrderedDict([
                                ('packet_queue_priority', (YLeaf(YType.uint32, 'packet-queue-priority'), ['int'])),
                            ])
                            self.packet_queue_priority = None

                            self.packet_queue_state = Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState()
                            self.packet_queue_state.parent = self
                            self._children_name_map["packet_queue_state"] = "packet-queue-state"

                            self.packet_queue_stats = Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats()
                            self.packet_queue_stats.parent = self
                            self._children_name_map["packet_queue_stats"] = "packet-queue-stats"
                            self._segment_path = lambda: "packet-queue"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue, ['packet_queue_priority'], name, value)


                        class PacketQueueState(Entity):
                            """
                            State of the queue
                            
                            .. attribute:: max_queue_size
                            
                            	Maximum size of queue in bytes
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: queue_size_bytes
                            
                            	Size of queue in bytes
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: queue_size_packets
                            
                            	Size of queue in number of packets
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState, self).__init__()

                                self.yang_name = "packet-queue-state"
                                self.yang_parent_name = "packet-queue"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('max_queue_size', (YLeaf(YType.uint32, 'max-queue-size'), ['int'])),
                                    ('queue_size_bytes', (YLeaf(YType.uint32, 'queue-size-bytes'), ['int'])),
                                    ('queue_size_packets', (YLeaf(YType.uint32, 'queue-size-packets'), ['int'])),
                                ])
                                self.max_queue_size = None
                                self.queue_size_bytes = None
                                self.queue_size_packets = None
                                self._segment_path = lambda: "packet-queue-state"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState, ['max_queue_size', 'queue_size_bytes', 'queue_size_packets'], name, value)


                        class PacketQueueStats(Entity):
                            """
                            Statistics about the queue
                            
                            .. attribute:: enqueued_packets
                            
                            	Total number of packets enqueued to this queue
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: dequeued_packets
                            
                            	Total number of packets dequeued from this queue
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: high_water_mark_packets
                            
                            	Highest number of packets enqueued in this queue
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: high_water_mark_bytes
                            
                            	Highest number of bytes enqueued in this queue
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: tail_drops
                            
                            	Number packets dropped from this queue due to max size
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats, self).__init__()

                                self.yang_name = "packet-queue-stats"
                                self.yang_parent_name = "packet-queue"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('enqueued_packets', (YLeaf(YType.uint32, 'enqueued-packets'), ['int'])),
                                    ('dequeued_packets', (YLeaf(YType.uint32, 'dequeued-packets'), ['int'])),
                                    ('high_water_mark_packets', (YLeaf(YType.uint32, 'high-water-mark-packets'), ['int'])),
                                    ('high_water_mark_bytes', (YLeaf(YType.uint32, 'high-water-mark-bytes'), ['int'])),
                                    ('tail_drops', (YLeaf(YType.uint32, 'tail-drops'), ['int'])),
                                ])
                                self.enqueued_packets = None
                                self.dequeued_packets = None
                                self.high_water_mark_packets = None
                                self.high_water_mark_bytes = None
                                self.tail_drops = None
                                self._segment_path = lambda: "packet-queue-stats"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats, ['enqueued_packets', 'dequeued_packets', 'high_water_mark_packets', 'high_water_mark_bytes', 'tail_drops'], name, value)


                class GroupMapRpfs(Entity):
                    """
                    PIM group mapping information
                    
                    .. attribute:: group_map_rpf
                    
                    	PIM group mapping entry
                    	**type**\: list of  		 :py:class:`GroupMapRpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs, self).__init__()

                        self.yang_name = "group-map-rpfs"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("group-map-rpf", ("group_map_rpf", Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf))])
                        self._leafs = OrderedDict()

                        self.group_map_rpf = YList(self)
                        self._segment_path = lambda: "group-map-rpfs"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs, [], name, value)


                    class GroupMapRpf(Entity):
                        """
                        PIM group mapping entry
                        
                        .. attribute:: prefix
                        
                        	Prefix
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: client
                        
                        	Client
                        	**type**\:  :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:  :py:class:`PimProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimProtocol>`
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: rp_priority
                        
                        	RP priority
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rpf_neighbor
                        
                        	RPF neighbor to the RP
                        	**type**\:  :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor>`
                        
                        .. attribute:: group_map_information
                        
                        	Group Mapping information
                        	**type**\:  :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation>`
                        
                        .. attribute:: are_we_rp
                        
                        	Are we the RP?
                        	**type**\: bool
                        
                        .. attribute:: rpf_interface_name
                        
                        	RPF interface to the RP
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: rpf_vrf_name
                        
                        	RPF VRF Name
                        	**type**\: str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf, self).__init__()

                            self.yang_name = "group-map-rpf"
                            self.yang_parent_name = "group-map-rpfs"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rpf-neighbor", ("rpf_neighbor", Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor)), ("group-map-information", ("group_map_information", Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation))])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                ('client', (YLeaf(YType.enumeration, 'client'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimClient', '')])),
                                ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimProtocol', '')])),
                                ('rp_address', (YLeaf(YType.str, 'rp-address'), ['str','str'])),
                                ('rp_priority', (YLeaf(YType.uint32, 'rp-priority'), ['int'])),
                                ('are_we_rp', (YLeaf(YType.boolean, 'are-we-rp'), ['bool'])),
                                ('rpf_interface_name', (YLeaf(YType.str, 'rpf-interface-name'), ['str'])),
                                ('rpf_vrf_name', (YLeaf(YType.str, 'rpf-vrf-name'), ['str'])),
                            ])
                            self.prefix = None
                            self.prefix_length = None
                            self.client = None
                            self.protocol = None
                            self.rp_address = None
                            self.rp_priority = None
                            self.are_we_rp = None
                            self.rpf_interface_name = None
                            self.rpf_vrf_name = None

                            self.rpf_neighbor = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor()
                            self.rpf_neighbor.parent = self
                            self._children_name_map["rpf_neighbor"] = "rpf-neighbor"

                            self.group_map_information = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation()
                            self.group_map_information.parent = self
                            self._children_name_map["group_map_information"] = "group-map-information"
                            self._segment_path = lambda: "group-map-rpf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf, ['prefix', 'prefix_length', 'client', 'protocol', 'rp_address', 'rp_priority', 'are_we_rp', 'rpf_interface_name', 'rpf_vrf_name'], name, value)


                        class RpfNeighbor(Entity):
                            """
                            RPF neighbor to the RP
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor, self).__init__()

                                self.yang_name = "rpf-neighbor"
                                self.yang_parent_name = "group-map-rpf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "rpf-neighbor"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class GroupMapInformation(Entity):
                            """
                            Group Mapping information
                            
                            .. attribute:: prefix
                            
                            	Group range prefix
                            	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix>`
                            
                            .. attribute:: rp_address
                            
                            	Rendezvous Point Address
                            	**type**\:  :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress>`
                            
                            .. attribute:: prefix_length
                            
                            	Group range prefix length
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: client
                            
                            	Client mapping learnt from
                            	**type**\:  :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                            
                            .. attribute:: protocol
                            
                            	Protocol mode of the range
                            	**type**\:  :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                            
                            .. attribute:: group_count
                            
                            	No. of groups in this range
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_used
                            
                            	Is this mapping being used?
                            	**type**\: bool
                            
                            .. attribute:: mrib_active
                            
                            	Is this mapping active in MRIB?
                            	**type**\: bool
                            
                            .. attribute:: is_override
                            
                            	Is this the override range?
                            	**type**\: bool
                            
                            .. attribute:: priority
                            
                            	Bootstrap priority
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation, self).__init__()

                                self.yang_name = "group-map-information"
                                self.yang_parent_name = "group-map-rpf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("prefix", ("prefix", Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix)), ("rp-address", ("rp_address", Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress))])
                                self._leafs = OrderedDict([
                                    ('prefix_length', (YLeaf(YType.int32, 'prefix-length'), ['int'])),
                                    ('client', (YLeaf(YType.enumeration, 'client'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowRangeClient', '')])),
                                    ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowProtocol', '')])),
                                    ('group_count', (YLeaf(YType.uint32, 'group-count'), ['int'])),
                                    ('is_used', (YLeaf(YType.boolean, 'is-used'), ['bool'])),
                                    ('mrib_active', (YLeaf(YType.boolean, 'mrib-active'), ['bool'])),
                                    ('is_override', (YLeaf(YType.boolean, 'is-override'), ['bool'])),
                                    ('priority', (YLeaf(YType.uint32, 'priority'), ['int'])),
                                ])
                                self.prefix_length = None
                                self.client = None
                                self.protocol = None
                                self.group_count = None
                                self.is_used = None
                                self.mrib_active = None
                                self.is_override = None
                                self.priority = None

                                self.prefix = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix()
                                self.prefix.parent = self
                                self._children_name_map["prefix"] = "prefix"

                                self.rp_address = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress()
                                self.rp_address.parent = self
                                self._children_name_map["rp_address"] = "rp-address"
                                self._segment_path = lambda: "group-map-information"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation, ['prefix_length', 'client', 'protocol', 'group_count', 'is_used', 'mrib_active', 'is_override', 'priority'], name, value)


                            class Prefix(Entity):
                                """
                                Group range prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix, self).__init__()

                                    self.yang_name = "prefix"
                                    self.yang_parent_name = "group-map-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "prefix"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                            class RpAddress(Entity):
                                """
                                Rendezvous Point Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress, self).__init__()

                                    self.yang_name = "rp-address"
                                    self.yang_parent_name = "group-map-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "rp-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class Summary(Entity):
                    """
                    PIM summary
                    
                    .. attribute:: route_limit
                    
                    	Maximum routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_count
                    
                    	Current routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_low_water_mark
                    
                    	The number of routes below which the throttle on route creation will be lifted
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_route_limit_reached
                    
                    	Is route creation throttled
                    	**type**\: bool
                    
                    .. attribute:: topology_interface_state_limit
                    
                    	Maximum Topology Interface State count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: topology_interface_state_count
                    
                    	Current Topology Interface State count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rxi_low_water_mark
                    
                    	The rxi below which the throttle on interface creation will be lifted
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rxi_limit_reached
                    
                    	Is interface creation throttled
                    	**type**\: bool
                    
                    .. attribute:: register_limit
                    
                    	Maximum registers
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: register_count
                    
                    	Current registers
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: register_limit_reached
                    
                    	Is PIM SM register handling throttled
                    	**type**\: bool
                    
                    .. attribute:: ranges_limit
                    
                    	Maximum group ranges from Autorp
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ranges_count
                    
                    	Current group ranges from Autorp
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ranges_threshold
                    
                    	OOR theshold of grange ranges from AutoRP
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_ranges_limit_reached
                    
                    	Is Auto\-RP group\-to\-RP mapping range creation throttled
                    	**type**\: bool
                    
                    .. attribute:: bsr_ranges_limit
                    
                    	Maximum group ranges from BSR
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_ranges_count
                    
                    	Current group ranges from BSR
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_range_threshold
                    
                    	Threshold group range from BSR
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_bsr_ranges_threshold_reached
                    
                    	Is VRF\-specific BSR group\-to\-RP mapping range creation throttled
                    	**type**\: bool
                    
                    .. attribute:: bsr_candidate_rp_set_limit
                    
                    	Maximum crp\-set from BSR
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_candidate_rp_set_count
                    
                    	Current crp\-set count from BSR
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_candidate_rp_set_threshold
                    
                    	Threshold crp\-set from BSR
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_maximum_enforcement_disabled
                    
                    	Is maximum enforcement disabled
                    	**type**\: bool
                    
                    .. attribute:: is_node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\: bool
                    
                    .. attribute:: route_threshold
                    
                    	Threshold routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_auto_rp_ranges_limit
                    
                    	Global Auto\-RP maximum group ranges
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_global_auto_rp_ranges_limit_reached
                    
                    	Is global AutoRP group\-to\-RP mapping range creation throttled
                    	**type**\: bool
                    
                    .. attribute:: global_bsr_ranges_limit
                    
                    	Global BSR maximum group ranges
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_ranges_count
                    
                    	Global BSR current group ranges
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_ranges_threshold
                    
                    	Global BSR Threshold group ranges
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_global_bsr_ranges_limit_reached
                    
                    	Is global BSR group\-to\-RP mapping range creation throttled
                    	**type**\: bool
                    
                    .. attribute:: global_bsr_candidate_rp_set_limit
                    
                    	Global BSR maximum crp\-set
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_candidate_rp_set_count
                    
                    	Global BSR current crp\-set count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_candidate_rp_set_threshold
                    
                    	Global BSR Threshold crp\-set
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_global_route_limit_reached
                    
                    	Is global route creation throttled
                    	**type**\: bool
                    
                    .. attribute:: topology_interface_state_threshold
                    
                    	Topology Interface State threshold
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_global_rxi_limit_reached
                    
                    	Is global interface creation throttled
                    	**type**\: bool
                    
                    .. attribute:: register_threshold
                    
                    	Threshold registers
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_register_limit
                    
                    	Maximum global registers
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_global_register_limit_reached
                    
                    	Is global PIM SM register handling throttled
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.Summary, self).__init__()

                        self.yang_name = "summary"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_limit', (YLeaf(YType.uint32, 'route-limit'), ['int'])),
                            ('route_count', (YLeaf(YType.uint32, 'route-count'), ['int'])),
                            ('route_low_water_mark', (YLeaf(YType.uint32, 'route-low-water-mark'), ['int'])),
                            ('is_route_limit_reached', (YLeaf(YType.boolean, 'is-route-limit-reached'), ['bool'])),
                            ('topology_interface_state_limit', (YLeaf(YType.uint32, 'topology-interface-state-limit'), ['int'])),
                            ('topology_interface_state_count', (YLeaf(YType.uint32, 'topology-interface-state-count'), ['int'])),
                            ('rxi_low_water_mark', (YLeaf(YType.uint32, 'rxi-low-water-mark'), ['int'])),
                            ('rxi_limit_reached', (YLeaf(YType.boolean, 'rxi-limit-reached'), ['bool'])),
                            ('register_limit', (YLeaf(YType.uint32, 'register-limit'), ['int'])),
                            ('register_count', (YLeaf(YType.uint32, 'register-count'), ['int'])),
                            ('register_limit_reached', (YLeaf(YType.boolean, 'register-limit-reached'), ['bool'])),
                            ('ranges_limit', (YLeaf(YType.uint32, 'ranges-limit'), ['int'])),
                            ('ranges_count', (YLeaf(YType.uint32, 'ranges-count'), ['int'])),
                            ('ranges_threshold', (YLeaf(YType.uint32, 'ranges-threshold'), ['int'])),
                            ('is_ranges_limit_reached', (YLeaf(YType.boolean, 'is-ranges-limit-reached'), ['bool'])),
                            ('bsr_ranges_limit', (YLeaf(YType.uint32, 'bsr-ranges-limit'), ['int'])),
                            ('bsr_ranges_count', (YLeaf(YType.uint32, 'bsr-ranges-count'), ['int'])),
                            ('bsr_range_threshold', (YLeaf(YType.uint32, 'bsr-range-threshold'), ['int'])),
                            ('is_bsr_ranges_threshold_reached', (YLeaf(YType.boolean, 'is-bsr-ranges-threshold-reached'), ['bool'])),
                            ('bsr_candidate_rp_set_limit', (YLeaf(YType.uint32, 'bsr-candidate-rp-set-limit'), ['int'])),
                            ('bsr_candidate_rp_set_count', (YLeaf(YType.uint32, 'bsr-candidate-rp-set-count'), ['int'])),
                            ('bsr_candidate_rp_set_threshold', (YLeaf(YType.uint32, 'bsr-candidate-rp-set-threshold'), ['int'])),
                            ('is_maximum_enforcement_disabled', (YLeaf(YType.boolean, 'is-maximum-enforcement-disabled'), ['bool'])),
                            ('is_node_low_memory', (YLeaf(YType.boolean, 'is-node-low-memory'), ['bool'])),
                            ('route_threshold', (YLeaf(YType.uint32, 'route-threshold'), ['int'])),
                            ('global_auto_rp_ranges_limit', (YLeaf(YType.uint32, 'global-auto-rp-ranges-limit'), ['int'])),
                            ('is_global_auto_rp_ranges_limit_reached', (YLeaf(YType.boolean, 'is-global-auto-rp-ranges-limit-reached'), ['bool'])),
                            ('global_bsr_ranges_limit', (YLeaf(YType.uint32, 'global-bsr-ranges-limit'), ['int'])),
                            ('global_bsr_ranges_count', (YLeaf(YType.uint32, 'global-bsr-ranges-count'), ['int'])),
                            ('global_bsr_ranges_threshold', (YLeaf(YType.uint32, 'global-bsr-ranges-threshold'), ['int'])),
                            ('is_global_bsr_ranges_limit_reached', (YLeaf(YType.boolean, 'is-global-bsr-ranges-limit-reached'), ['bool'])),
                            ('global_bsr_candidate_rp_set_limit', (YLeaf(YType.uint32, 'global-bsr-candidate-rp-set-limit'), ['int'])),
                            ('global_bsr_candidate_rp_set_count', (YLeaf(YType.uint32, 'global-bsr-candidate-rp-set-count'), ['int'])),
                            ('global_bsr_candidate_rp_set_threshold', (YLeaf(YType.uint32, 'global-bsr-candidate-rp-set-threshold'), ['int'])),
                            ('is_global_route_limit_reached', (YLeaf(YType.boolean, 'is-global-route-limit-reached'), ['bool'])),
                            ('topology_interface_state_threshold', (YLeaf(YType.uint32, 'topology-interface-state-threshold'), ['int'])),
                            ('is_global_rxi_limit_reached', (YLeaf(YType.boolean, 'is-global-rxi-limit-reached'), ['bool'])),
                            ('register_threshold', (YLeaf(YType.uint32, 'register-threshold'), ['int'])),
                            ('global_register_limit', (YLeaf(YType.uint32, 'global-register-limit'), ['int'])),
                            ('is_global_register_limit_reached', (YLeaf(YType.boolean, 'is-global-register-limit-reached'), ['bool'])),
                        ])
                        self.route_limit = None
                        self.route_count = None
                        self.route_low_water_mark = None
                        self.is_route_limit_reached = None
                        self.topology_interface_state_limit = None
                        self.topology_interface_state_count = None
                        self.rxi_low_water_mark = None
                        self.rxi_limit_reached = None
                        self.register_limit = None
                        self.register_count = None
                        self.register_limit_reached = None
                        self.ranges_limit = None
                        self.ranges_count = None
                        self.ranges_threshold = None
                        self.is_ranges_limit_reached = None
                        self.bsr_ranges_limit = None
                        self.bsr_ranges_count = None
                        self.bsr_range_threshold = None
                        self.is_bsr_ranges_threshold_reached = None
                        self.bsr_candidate_rp_set_limit = None
                        self.bsr_candidate_rp_set_count = None
                        self.bsr_candidate_rp_set_threshold = None
                        self.is_maximum_enforcement_disabled = None
                        self.is_node_low_memory = None
                        self.route_threshold = None
                        self.global_auto_rp_ranges_limit = None
                        self.is_global_auto_rp_ranges_limit_reached = None
                        self.global_bsr_ranges_limit = None
                        self.global_bsr_ranges_count = None
                        self.global_bsr_ranges_threshold = None
                        self.is_global_bsr_ranges_limit_reached = None
                        self.global_bsr_candidate_rp_set_limit = None
                        self.global_bsr_candidate_rp_set_count = None
                        self.global_bsr_candidate_rp_set_threshold = None
                        self.is_global_route_limit_reached = None
                        self.topology_interface_state_threshold = None
                        self.is_global_rxi_limit_reached = None
                        self.register_threshold = None
                        self.global_register_limit = None
                        self.is_global_register_limit_reached = None
                        self._segment_path = lambda: "summary"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Summary, ['route_limit', 'route_count', 'route_low_water_mark', 'is_route_limit_reached', 'topology_interface_state_limit', 'topology_interface_state_count', 'rxi_low_water_mark', 'rxi_limit_reached', 'register_limit', 'register_count', 'register_limit_reached', 'ranges_limit', 'ranges_count', 'ranges_threshold', 'is_ranges_limit_reached', 'bsr_ranges_limit', 'bsr_ranges_count', 'bsr_range_threshold', 'is_bsr_ranges_threshold_reached', 'bsr_candidate_rp_set_limit', 'bsr_candidate_rp_set_count', 'bsr_candidate_rp_set_threshold', 'is_maximum_enforcement_disabled', 'is_node_low_memory', 'route_threshold', 'global_auto_rp_ranges_limit', 'is_global_auto_rp_ranges_limit_reached', 'global_bsr_ranges_limit', 'global_bsr_ranges_count', 'global_bsr_ranges_threshold', 'is_global_bsr_ranges_limit_reached', 'global_bsr_candidate_rp_set_limit', 'global_bsr_candidate_rp_set_count', 'global_bsr_candidate_rp_set_threshold', 'is_global_route_limit_reached', 'topology_interface_state_threshold', 'is_global_rxi_limit_reached', 'register_threshold', 'global_register_limit', 'is_global_register_limit_reached'], name, value)


                class Gre(Entity):
                    """
                    GRE information
                    
                    .. attribute:: gre_hashes
                    
                    	GRE hash
                    	**type**\:  :py:class:`GreHashes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreHashes>`
                    
                    .. attribute:: gre_next_hops
                    
                    	GRE destination neighbor table
                    	**type**\:  :py:class:`GreNextHops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.Gre, self).__init__()

                        self.yang_name = "gre"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("gre-hashes", ("gre_hashes", Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreHashes)), ("gre-next-hops", ("gre_next_hops", Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops))])
                        self._leafs = OrderedDict()

                        self.gre_hashes = Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreHashes()
                        self.gre_hashes.parent = self
                        self._children_name_map["gre_hashes"] = "gre-hashes"

                        self.gre_next_hops = Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops()
                        self.gre_next_hops.parent = self
                        self._children_name_map["gre_next_hops"] = "gre-next-hops"
                        self._segment_path = lambda: "gre"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Gre, [], name, value)


                    class GreHashes(Entity):
                        """
                        GRE hash
                        
                        .. attribute:: gre_hash
                        
                        	PIM GRE Hashed Underlying Interface
                        	**type**\: list of  		 :py:class:`GreHash <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreHashes.GreHash>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreHashes, self).__init__()

                            self.yang_name = "gre-hashes"
                            self.yang_parent_name = "gre"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("gre-hash", ("gre_hash", Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreHashes.GreHash))])
                            self._leafs = OrderedDict()

                            self.gre_hash = YList(self)
                            self._segment_path = lambda: "gre-hashes"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreHashes, [], name, value)


                        class GreHash(Entity):
                            """
                            PIM GRE Hashed Underlying Interface
                            
                            .. attribute:: source_address  (key)
                            
                            	Source address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: destination_address  (key)
                            
                            	Destination address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ifname  (key)
                            
                            	GRE Tunnel Interface
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: next_hop_interface
                            
                            	Next hop neighbor interface
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreHashes.GreHash, self).__init__()

                                self.yang_name = "gre-hash"
                                self.yang_parent_name = "gre-hashes"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['source_address','destination_address','ifname']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('source_address', (YLeaf(YType.str, 'source-address'), ['str','str'])),
                                    ('destination_address', (YLeaf(YType.str, 'destination-address'), ['str','str'])),
                                    ('ifname', (YLeaf(YType.str, 'ifname'), ['str'])),
                                    ('next_hop_interface', (YLeaf(YType.str, 'next-hop-interface'), ['str'])),
                                ])
                                self.source_address = None
                                self.destination_address = None
                                self.ifname = None
                                self.next_hop_interface = None
                                self._segment_path = lambda: "gre-hash" + "[source-address='" + str(self.source_address) + "']" + "[destination-address='" + str(self.destination_address) + "']" + "[ifname='" + str(self.ifname) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreHashes.GreHash, ['source_address', 'destination_address', 'ifname', 'next_hop_interface'], name, value)


                    class GreNextHops(Entity):
                        """
                        GRE destination neighbor table
                        
                        .. attribute:: gre_next_hop
                        
                        	PIM GRE address next\-hop information
                        	**type**\: list of  		 :py:class:`GreNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops, self).__init__()

                            self.yang_name = "gre-next-hops"
                            self.yang_parent_name = "gre"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("gre-next-hop", ("gre_next_hop", Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop))])
                            self._leafs = OrderedDict()

                            self.gre_next_hop = YList(self)
                            self._segment_path = lambda: "gre-next-hops"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops, [], name, value)


                        class GreNextHop(Entity):
                            """
                            PIM GRE address next\-hop information
                            
                            .. attribute:: destination_address  (key)
                            
                            	GRE destination address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: registered_address
                            
                            	Address registered
                            	**type**\:  :py:class:`RegisteredAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress>`
                            
                            .. attribute:: metric
                            
                            	Metric
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_preference
                            
                            	Metric preference
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_connected
                            
                            	Are we connected ?
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: gre_path
                            
                            	GRE Paths list
                            	**type**\: list of  		 :py:class:`GrePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop, self).__init__()

                                self.yang_name = "gre-next-hop"
                                self.yang_parent_name = "gre-next-hops"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['destination_address']
                                self._child_classes = OrderedDict([("registered-address", ("registered_address", Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress)), ("gre-path", ("gre_path", Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath))])
                                self._leafs = OrderedDict([
                                    ('destination_address', (YLeaf(YType.str, 'destination-address'), ['str','str'])),
                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                    ('metric_preference', (YLeaf(YType.uint32, 'metric-preference'), ['int'])),
                                    ('is_connected', (YLeaf(YType.uint8, 'is-connected'), ['int'])),
                                ])
                                self.destination_address = None
                                self.metric = None
                                self.metric_preference = None
                                self.is_connected = None

                                self.registered_address = Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress()
                                self.registered_address.parent = self
                                self._children_name_map["registered_address"] = "registered-address"

                                self.gre_path = YList(self)
                                self._segment_path = lambda: "gre-next-hop" + "[destination-address='" + str(self.destination_address) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop, ['destination_address', 'metric', 'metric_preference', 'is_connected'], name, value)


                            class RegisteredAddress(Entity):
                                """
                                Address registered
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress, self).__init__()

                                    self.yang_name = "registered-address"
                                    self.yang_parent_name = "gre-next-hop"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "registered-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                            class GrePath(Entity):
                                """
                                GRE Paths list
                                
                                .. attribute:: gre_neighbor
                                
                                	GRE neighbor
                                	**type**\:  :py:class:`GreNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor>`
                                
                                .. attribute:: gre_next_hop
                                
                                	GRE nexthop
                                	**type**\:  :py:class:`GreNextHop_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop_>`
                                
                                .. attribute:: gre_interface_name
                                
                                	GRE Interface
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                .. attribute:: is_gre_interface_disabled
                                
                                	Is the gre interface disabled ?
                                	**type**\: bool
                                
                                .. attribute:: is_via_lsm
                                
                                	Via LSM
                                	**type**\: bool
                                
                                .. attribute:: is_connector_attribute_present
                                
                                	Connector attribute present
                                	**type**\: bool
                                
                                .. attribute:: extranet_vrf_name
                                
                                	Extranet VRF name
                                	**type**\: str
                                
                                	**length:** 0..33
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath, self).__init__()

                                    self.yang_name = "gre-path"
                                    self.yang_parent_name = "gre-next-hop"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("gre-neighbor", ("gre_neighbor", Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor)), ("gre-next-hop", ("gre_next_hop", Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop_))])
                                    self._leafs = OrderedDict([
                                        ('gre_interface_name', (YLeaf(YType.str, 'gre-interface-name'), ['str'])),
                                        ('is_gre_interface_disabled', (YLeaf(YType.boolean, 'is-gre-interface-disabled'), ['bool'])),
                                        ('is_via_lsm', (YLeaf(YType.boolean, 'is-via-lsm'), ['bool'])),
                                        ('is_connector_attribute_present', (YLeaf(YType.boolean, 'is-connector-attribute-present'), ['bool'])),
                                        ('extranet_vrf_name', (YLeaf(YType.str, 'extranet-vrf-name'), ['str'])),
                                    ])
                                    self.gre_interface_name = None
                                    self.is_gre_interface_disabled = None
                                    self.is_via_lsm = None
                                    self.is_connector_attribute_present = None
                                    self.extranet_vrf_name = None

                                    self.gre_neighbor = Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor()
                                    self.gre_neighbor.parent = self
                                    self._children_name_map["gre_neighbor"] = "gre-neighbor"

                                    self.gre_next_hop = Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop_()
                                    self.gre_next_hop.parent = self
                                    self._children_name_map["gre_next_hop"] = "gre-next-hop"
                                    self._segment_path = lambda: "gre-path"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath, ['gre_interface_name', 'is_gre_interface_disabled', 'is_via_lsm', 'is_connector_attribute_present', 'extranet_vrf_name'], name, value)


                                class GreNeighbor(Entity):
                                    """
                                    GRE neighbor
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor, self).__init__()

                                        self.yang_name = "gre-neighbor"
                                        self.yang_parent_name = "gre-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ])
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None
                                        self._segment_path = lambda: "gre-neighbor"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                                class GreNextHop_(Entity):
                                    """
                                    GRE nexthop
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop_, self).__init__()

                                        self.yang_name = "gre-next-hop"
                                        self.yang_parent_name = "gre-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ])
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None
                                        self._segment_path = lambda: "gre-next-hop"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop_, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class BidirDfWinners(Entity):
                    """
                    Bidirectional PIM DF election winner table
                    
                    .. attribute:: bidir_df_winner
                    
                    	Bidirectional PIM DF election table entry
                    	**type**\: list of  		 :py:class:`BidirDfWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners, self).__init__()

                        self.yang_name = "bidir-df-winners"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("bidir-df-winner", ("bidir_df_winner", Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner))])
                        self._leafs = OrderedDict()

                        self.bidir_df_winner = YList(self)
                        self._segment_path = lambda: "bidir-df-winners"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners, [], name, value)


                    class BidirDfWinner(Entity):
                        """
                        Bidirectional PIM DF election table entry
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: rp_address_xr
                        
                        	RP Address
                        	**type**\:  :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr>`
                        
                        .. attribute:: df_winner
                        
                        	DF Winner
                        	**type**\:  :py:class:`DfWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner>`
                        
                        .. attribute:: pim_interface_name
                        
                        	Interface Name
                        	**type**\: str
                        
                        .. attribute:: are_we_df
                        
                        	Are we DF
                        	**type**\: bool
                        
                        .. attribute:: rp_lan
                        
                        	Is this the RP LAN
                        	**type**\: bool
                        
                        .. attribute:: metric
                        
                        	Metric
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: metric_preference
                        
                        	Metric Preference
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner, self).__init__()

                            self.yang_name = "bidir-df-winner"
                            self.yang_parent_name = "bidir-df-winners"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rp-address-xr", ("rp_address_xr", Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr)), ("df-winner", ("df_winner", Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner))])
                            self._leafs = OrderedDict([
                                ('rp_address', (YLeaf(YType.str, 'rp-address'), ['str','str'])),
                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ('pim_interface_name', (YLeaf(YType.str, 'pim-interface-name'), ['str'])),
                                ('are_we_df', (YLeaf(YType.boolean, 'are-we-df'), ['bool'])),
                                ('rp_lan', (YLeaf(YType.boolean, 'rp-lan'), ['bool'])),
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                ('metric_preference', (YLeaf(YType.uint32, 'metric-preference'), ['int'])),
                                ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                            ])
                            self.rp_address = None
                            self.interface_name = None
                            self.pim_interface_name = None
                            self.are_we_df = None
                            self.rp_lan = None
                            self.metric = None
                            self.metric_preference = None
                            self.uptime = None

                            self.rp_address_xr = Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr()
                            self.rp_address_xr.parent = self
                            self._children_name_map["rp_address_xr"] = "rp-address-xr"

                            self.df_winner = Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner()
                            self.df_winner.parent = self
                            self._children_name_map["df_winner"] = "df-winner"
                            self._segment_path = lambda: "bidir-df-winner"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner, ['rp_address', 'interface_name', 'pim_interface_name', 'are_we_df', 'rp_lan', 'metric', 'metric_preference', 'uptime'], name, value)


                        class RpAddressXr(Entity):
                            """
                            RP Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr, self).__init__()

                                self.yang_name = "rp-address-xr"
                                self.yang_parent_name = "bidir-df-winner"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "rp-address-xr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class DfWinner(Entity):
                            """
                            DF Winner
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner, self).__init__()

                                self.yang_name = "df-winner"
                                self.yang_parent_name = "bidir-df-winner"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "df-winner"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class TableContexts(Entity):
                    """
                    PIM table context list
                    
                    .. attribute:: table_context
                    
                    	PIM table context information
                    	**type**\: list of  		 :py:class:`TableContext <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.TableContexts.TableContext>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.TableContexts, self).__init__()

                        self.yang_name = "table-contexts"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("table-context", ("table_context", Ipv6Pim.Standby.Vrfs.Vrf.TableContexts.TableContext))])
                        self._leafs = OrderedDict()

                        self.table_context = YList(self)
                        self._segment_path = lambda: "table-contexts"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.TableContexts, [], name, value)


                    class TableContext(Entity):
                        """
                        PIM table context information
                        
                        .. attribute:: saf_name
                        
                        	SAF name
                        	**type**\:  :py:class:`PimSafi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimSafi>`
                        
                        .. attribute:: topology_name
                        
                        	Topology name
                        	**type**\: str
                        
                        	**length:** 1..32
                        
                        .. attribute:: afi
                        
                        	AFI
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: safi
                        
                        	SAFI
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_name
                        
                        	Table name
                        	**type**\: str
                        
                        .. attribute:: vrf_id
                        
                        	VRF ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_id
                        
                        	Table ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_active
                        
                        	Active status
                        	**type**\: bool
                        
                        .. attribute:: is_ital_registration_done
                        
                        	ITAL reg status
                        	**type**\: bool
                        
                        .. attribute:: is_rib_registration_done
                        
                        	RIB reg status
                        	**type**\: bool
                        
                        .. attribute:: is_rib_convergence_received
                        
                        	RIB Convergence receive status
                        	**type**\: bool
                        
                        .. attribute:: is_rib_convergence
                        
                        	RIB Convergence status
                        	**type**\: bool
                        
                        .. attribute:: rpf_registrations
                        
                        	RPF Registration count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.TableContexts.TableContext, self).__init__()

                            self.yang_name = "table-context"
                            self.yang_parent_name = "table-contexts"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('saf_name', (YLeaf(YType.enumeration, 'saf-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimSafi', '')])),
                                ('topology_name', (YLeaf(YType.str, 'topology-name'), ['str'])),
                                ('afi', (YLeaf(YType.uint32, 'afi'), ['int'])),
                                ('safi', (YLeaf(YType.uint32, 'safi'), ['int'])),
                                ('table_name', (YLeaf(YType.str, 'table-name'), ['str'])),
                                ('vrf_id', (YLeaf(YType.uint32, 'vrf-id'), ['int'])),
                                ('table_id', (YLeaf(YType.uint32, 'table-id'), ['int'])),
                                ('is_active', (YLeaf(YType.boolean, 'is-active'), ['bool'])),
                                ('is_ital_registration_done', (YLeaf(YType.boolean, 'is-ital-registration-done'), ['bool'])),
                                ('is_rib_registration_done', (YLeaf(YType.boolean, 'is-rib-registration-done'), ['bool'])),
                                ('is_rib_convergence_received', (YLeaf(YType.boolean, 'is-rib-convergence-received'), ['bool'])),
                                ('is_rib_convergence', (YLeaf(YType.boolean, 'is-rib-convergence'), ['bool'])),
                                ('rpf_registrations', (YLeaf(YType.uint32, 'rpf-registrations'), ['int'])),
                            ])
                            self.saf_name = None
                            self.topology_name = None
                            self.afi = None
                            self.safi = None
                            self.table_name = None
                            self.vrf_id = None
                            self.table_id = None
                            self.is_active = None
                            self.is_ital_registration_done = None
                            self.is_rib_registration_done = None
                            self.is_rib_convergence_received = None
                            self.is_rib_convergence = None
                            self.rpf_registrations = None
                            self._segment_path = lambda: "table-context"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.TableContexts.TableContext, ['saf_name', 'topology_name', 'afi', 'safi', 'table_name', 'vrf_id', 'table_id', 'is_active', 'is_ital_registration_done', 'is_rib_registration_done', 'is_rib_convergence_received', 'is_rib_convergence', 'rpf_registrations'], name, value)


                class NeighborSummaries(Entity):
                    """
                    PIM neighbor summary table
                    
                    .. attribute:: neighbor_summary
                    
                    	PIM neighbor summary information
                    	**type**\: list of  		 :py:class:`NeighborSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.NeighborSummaries.NeighborSummary>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.NeighborSummaries, self).__init__()

                        self.yang_name = "neighbor-summaries"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("neighbor-summary", ("neighbor_summary", Ipv6Pim.Standby.Vrfs.Vrf.NeighborSummaries.NeighborSummary))])
                        self._leafs = OrderedDict()

                        self.neighbor_summary = YList(self)
                        self._segment_path = lambda: "neighbor-summaries"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.NeighborSummaries, [], name, value)


                    class NeighborSummary(Entity):
                        """
                        PIM neighbor summary information
                        
                        .. attribute:: interface_name  (key)
                        
                        	Interface name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: number_of_neighbors
                        
                        	Number of neighbors
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: number_of_external_neighbors
                        
                        	Number of external neighbors
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.NeighborSummaries.NeighborSummary, self).__init__()

                            self.yang_name = "neighbor-summary"
                            self.yang_parent_name = "neighbor-summaries"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['interface_name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ('number_of_neighbors', (YLeaf(YType.int32, 'number-of-neighbors'), ['int'])),
                                ('number_of_external_neighbors', (YLeaf(YType.int32, 'number-of-external-neighbors'), ['int'])),
                            ])
                            self.interface_name = None
                            self.number_of_neighbors = None
                            self.number_of_external_neighbors = None
                            self._segment_path = lambda: "neighbor-summary" + "[interface-name='" + str(self.interface_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.NeighborSummaries.NeighborSummary, ['interface_name', 'number_of_neighbors', 'number_of_external_neighbors'], name, value)


                class Context(Entity):
                    """
                    PIM context information
                    
                    .. attribute:: remote_default_group
                    
                    	Remote Default Group
                    	**type**\:  :py:class:`RemoteDefaultGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Context.RemoteDefaultGroup>`
                    
                    .. attribute:: rpf_default_table
                    
                    	RPF Default Table
                    	**type**\:  :py:class:`RpfDefaultTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Context.RpfDefaultTable>`
                    
                    .. attribute:: vrf_id
                    
                    	VRF ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_id
                    
                    	Table ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: murib_id
                    
                    	MURIB ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rpf_id
                    
                    	RPF ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: remote_table_id
                    
                    	Remote Table ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_default_group
                    
                    	MDT Default group
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: mdt_source
                    
                    	MDT source
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: mdt_source_interface
                    
                    	MDT Source Interface Name
                    	**type**\: str
                    
                    .. attribute:: mdt_interface
                    
                    	MDT handle
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: mdt_gre_rpf_identifier
                    
                    	GRE\-MDT RPF Identifier
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_gre_remote_rpf_identifier
                    
                    	GRE\-MDT Remote RPF Identifier
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_unicast_rib_registration
                    
                    	Ucast RIB Registration
                    	**type**\: bool
                    
                    .. attribute:: is_multicast_rib_registration
                    
                    	Mcast RIB Registration
                    	**type**\: bool
                    
                    .. attribute:: is_active
                    
                    	Active
                    	**type**\: bool
                    
                    .. attribute:: is_active_ital
                    
                    	Active ITAL
                    	**type**\: bool
                    
                    .. attribute:: is_mrib_register
                    
                    	MRIB Register
                    	**type**\: bool
                    
                    .. attribute:: is_mdt_owner
                    
                    	MDT Owner
                    	**type**\: bool
                    
                    .. attribute:: is_routing_enabled
                    
                    	Routing Enabled
                    	**type**\: bool
                    
                    .. attribute:: is_socket_add_required
                    
                    	VRF required on Socket
                    	**type**\: bool
                    
                    .. attribute:: is_socket_added
                    
                    	VRF added on Socket
                    	**type**\: bool
                    
                    .. attribute:: is_lpts_socket_add_required
                    
                    	VRF LPTS filter required on Socket
                    	**type**\: bool
                    
                    .. attribute:: is_lpts_socket_added
                    
                    	VRF LPTS filter added on Socket
                    	**type**\: bool
                    
                    .. attribute:: is_udp_socket_add_required
                    
                    	VRF added on UDP Socket
                    	**type**\: bool
                    
                    .. attribute:: is_udp_socket_added
                    
                    	VRF added on UDP Socket
                    	**type**\: bool
                    
                    .. attribute:: is_udp_socket_bind_required
                    
                    	VRF bind required on UDP Socket
                    	**type**\: bool
                    
                    .. attribute:: is_udp_socket_bind
                    
                    	VRF bound on UDP Socket
                    	**type**\: bool
                    
                    .. attribute:: is_register_injection_socket_add_required
                    
                    	VRF required on Register Injection Socket
                    	**type**\: bool
                    
                    .. attribute:: is_register_injection_socket_added
                    
                    	VRF added on Register Injection Socket
                    	**type**\: bool
                    
                    .. attribute:: is_register_injection_lpts_socket_add_required
                    
                    	VRF LPTS filter required on Register Injection Socket
                    	**type**\: bool
                    
                    .. attribute:: is_register_injection_lpts_socket_added
                    
                    	VRF LPTS filter added on Register Injection Socket
                    	**type**\: bool
                    
                    .. attribute:: is_m_host_publish_pending
                    
                    	Publish pending for MHost Default interface
                    	**type**\: bool
                    
                    .. attribute:: mhost_interface
                    
                    	MHost handle
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: mhost_default_interface_config
                    
                    	Configured Mhost Defint
                    	**type**\: str
                    
                    .. attribute:: mdt_mtu
                    
                    	MDT MTU
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: maximum_mdt_aggregation
                    
                    	MDT max aggregation
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_data_switchover_interval
                    
                    	Data MDT Switchover interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_data_announce_interval
                    
                    	Data MDT Announce interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: non_default_vrf_count_on_socket
                    
                    	Count of non\-default vrfs on raw socket
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\: str
                    
                    .. attribute:: mdt_neighbor_filter_name
                    
                    	MDT Neighbor Filter Name
                    	**type**\: str
                    
                    .. attribute:: allow_rp_configured
                    
                    	Allow RP Configured
                    	**type**\: bool
                    
                    .. attribute:: allow_rp_group_list
                    
                    	Allow RP Group\-List ACL Name
                    	**type**\: str
                    
                    	**length:** 0..64
                    
                    .. attribute:: allow_rp_rp_list
                    
                    	Allow RP RP\-list ACL Name
                    	**type**\: str
                    
                    	**length:** 0..64
                    
                    .. attribute:: sg_expiry_timer_configured
                    
                    	S,G Expiry Timer Configured
                    	**type**\: bool
                    
                    .. attribute:: sg_expiry_time
                    
                    	S,G Expiry Time Configured, in seconds
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    	**units**\: second
                    
                    .. attribute:: sg_expiry_timer_sg_list
                    
                    	S,G expiry timer ACL name
                    	**type**\: str
                    
                    	**length:** 0..64
                    
                    .. attribute:: mldp_mdt_name
                    
                    	MLDP MDT Name
                    	**type**\: str
                    
                    .. attribute:: mldp_mdt_interface
                    
                    	MLDP MDT handle
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: mldp_mdt_mtu
                    
                    	MLDP MDT MTU
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_maximum_mdt_aggregation
                    
                    	MLDP MDT max aggregation
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_data_switchover_interval
                    
                    	MLDP Data MDT Switchover interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_data_announce_interval
                    
                    	MLDP Data MDT Announce interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_rpf_identifier
                    
                    	MLDP RPF\-ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_remote_rpf_identifier
                    
                    	MLDP Remote RPF\-ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_create_mldp_mdt_interface
                    
                    	Create MLDP MDT interface
                    	**type**\: bool
                    
                    .. attribute:: is_mldp_mdt_owner
                    
                    	MLDP MDT Owner
                    	**type**\: bool
                    
                    .. attribute:: mldp_root_count
                    
                    	MLDP Root count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_head_lsm_identifier
                    
                    	MLDP Head LSM\-ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_remote_head_lsm_identifier
                    
                    	MLDP Remote Head LSM\-ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: organization_unique_identifier
                    
                    	OUI for VPN\-ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vpn_index
                    
                    	VPN Index
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_partitioned_mdt_configured
                    
                    	MLDP Partitioned MDT
                    	**type**\: bool
                    
                    .. attribute:: mldp_remote_partitioned_mdt_configured
                    
                    	MLDP Remote Partitioned MDT
                    	**type**\: bool
                    
                    .. attribute:: mldp_partioned_mp2m_ptree
                    
                    	MP2MP Partitioned MDT tree
                    	**type**\: bool
                    
                    .. attribute:: mldp_partitioned_head_lsm_identifier
                    
                    	Partitioned MDT Head LSM\-ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_head_local_label
                    
                    	Partitioned MDT Head local label
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_partitioned_mdt_identifier
                    
                    	MLDP Partitioned MDT Identifier
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bgp_auto_discovery_configured
                    
                    	BGP Auto\-Discovery configured
                    	**type**\: bool
                    
                    .. attribute:: suppress_pim_data_mdt_tlv
                    
                    	Suppress PIM Data\-MDT TLV Announcements
                    	**type**\: bool
                    
                    .. attribute:: inter_autonomous_system_enabled
                    
                    	Inter\-AS Enabled
                    	**type**\: bool
                    
                    .. attribute:: bgp_source_active_announce
                    
                    	Send BGP Source\-Active Announcements
                    	**type**\: bool
                    
                    .. attribute:: bgp_i_pmsi_added
                    
                    	BGP I\-PMSI Added
                    	**type**\: bool
                    
                    .. attribute:: mldp_bsr_control_tree_added
                    
                    	MLDP BSR Control tree added
                    	**type**\: bool
                    
                    .. attribute:: mldp_auto_rp_discovery_tree_added
                    
                    	MLDP Autorp Discovery Control tree added
                    	**type**\: bool
                    
                    .. attribute:: mldp_auto_rp_announce_tree_added
                    
                    	MLDP Autorp Announce Control tree added
                    	**type**\: bool
                    
                    .. attribute:: bgp_auto_discovery_type
                    
                    	BGP Auto Discovery Type
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_partitioned_mdt_control_identifier
                    
                    	Partitioned MDT Control Identifier
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_partitioned_ir_control_identifier
                    
                    	Partitioned IR MDT Control Identifier
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_control_head_lsm_identifier
                    
                    	MLDP MVPN Identifier
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: umh
                    
                    	Join UMH Core\-Tree
                    	**type**\: bool
                    
                    .. attribute:: suppress_shared_tree_join
                    
                    	Suppress Shared\-Tree Joins
                    	**type**\: bool
                    
                    .. attribute:: rsvp_te_mdt_name
                    
                    	RSVP\-TE MDT Name
                    	**type**\: str
                    
                    .. attribute:: rsvp_te_mdt_interface
                    
                    	RSVP\-TEMDT handle
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: rsvp_te_mdt_mtu
                    
                    	RSVP\-TEMDT MTU
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_maximum_mdt_aggregation
                    
                    	RSVP\-TE MDT max aggregation
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_data_switchover_interval
                    
                    	RSVP\-TE Data MDT Switchover interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_data_announce_interval
                    
                    	RSVP\-TE Data MDT Announce interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_rpf_identifier
                    
                    	RSVP\-TE RPF\-ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_create_rsvp_te_mdt_interface
                    
                    	Create RSVP\-TE MDT interface
                    	**type**\: bool
                    
                    .. attribute:: is_rsvp_te_mdt_owner
                    
                    	RSVP\-TE MDT Owner
                    	**type**\: bool
                    
                    .. attribute:: rsvp_te_mdt_static_p2mp_count
                    
                    	Number of Static P2MP\-TE MDT
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: p2mpte_li_drop
                    
                    	Route LI updates dropped for P2MP
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_name
                    
                    	IR MDT Name
                    	**type**\: str
                    
                    .. attribute:: ir_mdt_interface
                    
                    	IRMDT handle
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: ir_mdt_mtu
                    
                    	IRMDT MTU
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_maximum_mdt_aggregation
                    
                    	IR MDT max aggregation
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_data_switchover_interval
                    
                    	IR Data MDT Switchover interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_data_announce_interval
                    
                    	IR Data MDT Announce interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_rpf_identifier
                    
                    	IR RPF\-ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_tail_label
                    
                    	IR Tail Label
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_create_ir_mdt_interface
                    
                    	Create IR MDT interface
                    	**type**\: bool
                    
                    .. attribute:: is_ir_mdt_owner
                    
                    	IR MDT Owner
                    	**type**\: bool
                    
                    .. attribute:: in_b_and_mdt_name
                    
                    	Inband MDT Name
                    	**type**\: str
                    
                    .. attribute:: in_b_and_mdt_interface
                    
                    	Inband MDT handle
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: in_b_and_mdt_mtu
                    
                    	Inband MDT MTU
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_band_maximum_mdt_aggregation
                    
                    	Inband MDT max aggregation
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_b_and_mdt_data_switchover_interval
                    
                    	Inband Data MDT Switchover interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_b_and_mdt_data_announce_interval
                    
                    	Inband Data MDT Announce interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_b_and_mdt_rpf_identifier
                    
                    	Inband RPF\-ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_create_in_b_and_mdt_interface
                    
                    	Create Inband MDT interface
                    	**type**\: bool
                    
                    .. attribute:: is_in_b_and_mdt_owner
                    
                    	Inband MDT Owner
                    	**type**\: bool
                    
                    .. attribute:: in_band_signaling_local_enabled
                    
                    	Inband signaling Local enabled
                    	**type**\: bool
                    
                    .. attribute:: in_band_signaling_remote_enabled
                    
                    	Inband signaling Remote enabled
                    	**type**\: bool
                    
                    .. attribute:: valid_rd_present
                    
                    	RD is valid
                    	**type**\: bool
                    
                    .. attribute:: stale_rd_present
                    
                    	RD is stale
                    	**type**\: bool
                    
                    .. attribute:: route_distinguisher
                    
                    	RD value
                    	**type**\: str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: gin_b_and_mdt_name
                    
                    	Inband MDT Name
                    	**type**\: str
                    
                    .. attribute:: gin_b_and_mdt_interface
                    
                    	Inband MDT handle
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: gin_b_and_mdt_mtu
                    
                    	Inband MDT MTU
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gin_band_maximum_mdt_aggregation
                    
                    	Inband MDT max aggregation
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gin_b_and_mdt_data_switchover_interval
                    
                    	Inband Data MDT Switchover interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gin_b_and_mdt_data_announce_interval
                    
                    	Inband Data MDT Announce interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gin_b_and_mdt_rpf_identifier
                    
                    	Inband RPF\-ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_create_gin_b_and_mdt_interface
                    
                    	Create Inband MDT interface
                    	**type**\: bool
                    
                    .. attribute:: is_gin_b_and_mdt_owner
                    
                    	Inband MDT Owner
                    	**type**\: bool
                    
                    .. attribute:: is_pim_nsf_rib_converged
                    
                    	PIM NSF RIB converged
                    	**type**\: bool
                    
                    .. attribute:: is_pim_nsf_rib_converge_received
                    
                    	PIM NSF RIB converge received
                    	**type**\: bool
                    
                    .. attribute:: is_rib_multipath_enabled
                    
                    	PIM RIB multiplath enabled
                    	**type**\: bool
                    
                    .. attribute:: is_rib_multipath_interface_hash
                    
                    	PIM RIB multipath interface hash
                    	**type**\: bool
                    
                    .. attribute:: is_rib_multipath_source_hash
                    
                    	PIM RIB multipath source based hash
                    	**type**\: bool
                    
                    .. attribute:: is_rib_multipath_source_next_hop_hash
                    
                    	PIM RIB multipath source\-nexthop hash
                    	**type**\: bool
                    
                    .. attribute:: rump_enabled
                    
                    	PIM is using MuRIB
                    	**type**\: bool
                    
                    .. attribute:: is_create_mdt_interface
                    
                    	Create MDT interface
                    	**type**\: bool
                    
                    .. attribute:: is_auto_rp_listen_enabled
                    
                    	Auto RP Listen Enabled
                    	**type**\: bool
                    
                    .. attribute:: is_all_interface_disable_operation
                    
                    	PIM all interface disable operation
                    	**type**\: bool
                    
                    .. attribute:: is_default_granges
                    
                    	Default granges
                    	**type**\: bool
                    
                    .. attribute:: is_auto_rp_listen_sock_add
                    
                    	Auto RP listen sock add
                    	**type**\: bool
                    
                    .. attribute:: is_redistribution_reset
                    
                    	Pending redist reset
                    	**type**\: bool
                    
                    .. attribute:: redistribution_reset_count
                    
                    	Redist reset count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rpf_policy_name
                    
                    	RPF topology selection route\-policy name
                    	**type**\: str
                    
                    .. attribute:: table_count
                    
                    	Number of configured Tables
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: active_table_count
                    
                    	Number of active Tables
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: anycast_rp_policy_name
                    
                    	Anycast\-RP Policy Name
                    	**type**\: str
                    
                    .. attribute:: anycast_rp_configured
                    
                    	Anycast\-RP config
                    	**type**\: bool
                    
                    .. attribute:: bgp_remote_on
                    
                    	BGP remote interface status
                    	**type**\: bool
                    
                    .. attribute:: bgp_remote_interface_name
                    
                    	BGP remote interface name
                    	**type**\: str
                    
                    .. attribute:: bgp_remote_interface
                    
                    	BGP remote interface handle
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: bgp_remote_address
                    
                    	BGP remote interface address
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: bgp_remote_state
                    
                    	BGP remote interface state
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: physical_interface_count
                    
                    	Enabled Physical Interface Count
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: virtual_interface_count
                    
                    	Enabled Virtual Interface Count
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: virtual_mlc_interface_name
                    
                    	Virtual master line card Interface
                    	**type**\: str
                    
                    .. attribute:: mdt_immediate_switch
                    
                    	MDT Immediate Switch
                    	**type**\: bool
                    
                    .. attribute:: mldp_root_address
                    
                    	MLDP Root addresses
                    	**type**\: list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: export_route_target
                    
                    	Export Route Targets
                    	**type**\: list of  		 :py:class:`ExportRouteTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Context.ExportRouteTarget>`
                    
                    .. attribute:: import_route_target
                    
                    	Import Route Targets
                    	**type**\: list of  		 :py:class:`ImportRouteTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Context.ImportRouteTarget>`
                    
                    .. attribute:: anycast_rp_range
                    
                    	Anycast\-RP Ranges
                    	**type**\: list of  		 :py:class:`AnycastRpRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.Context, self).__init__()

                        self.yang_name = "context"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("remote-default-group", ("remote_default_group", Ipv6Pim.Standby.Vrfs.Vrf.Context.RemoteDefaultGroup)), ("rpf-default-table", ("rpf_default_table", Ipv6Pim.Standby.Vrfs.Vrf.Context.RpfDefaultTable)), ("export-route-target", ("export_route_target", Ipv6Pim.Standby.Vrfs.Vrf.Context.ExportRouteTarget)), ("import-route-target", ("import_route_target", Ipv6Pim.Standby.Vrfs.Vrf.Context.ImportRouteTarget)), ("anycast-rp-range", ("anycast_rp_range", Ipv6Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange))])
                        self._leafs = OrderedDict([
                            ('vrf_id', (YLeaf(YType.uint32, 'vrf-id'), ['int'])),
                            ('table_id', (YLeaf(YType.uint32, 'table-id'), ['int'])),
                            ('murib_id', (YLeaf(YType.uint32, 'murib-id'), ['int'])),
                            ('rpf_id', (YLeaf(YType.uint32, 'rpf-id'), ['int'])),
                            ('remote_table_id', (YLeaf(YType.uint32, 'remote-table-id'), ['int'])),
                            ('mdt_default_group', (YLeaf(YType.str, 'mdt-default-group'), ['str'])),
                            ('mdt_source', (YLeaf(YType.str, 'mdt-source'), ['str'])),
                            ('mdt_source_interface', (YLeaf(YType.str, 'mdt-source-interface'), ['str'])),
                            ('mdt_interface', (YLeaf(YType.str, 'mdt-interface'), ['str'])),
                            ('mdt_gre_rpf_identifier', (YLeaf(YType.uint32, 'mdt-gre-rpf-identifier'), ['int'])),
                            ('mdt_gre_remote_rpf_identifier', (YLeaf(YType.uint32, 'mdt-gre-remote-rpf-identifier'), ['int'])),
                            ('is_unicast_rib_registration', (YLeaf(YType.boolean, 'is-unicast-rib-registration'), ['bool'])),
                            ('is_multicast_rib_registration', (YLeaf(YType.boolean, 'is-multicast-rib-registration'), ['bool'])),
                            ('is_active', (YLeaf(YType.boolean, 'is-active'), ['bool'])),
                            ('is_active_ital', (YLeaf(YType.boolean, 'is-active-ital'), ['bool'])),
                            ('is_mrib_register', (YLeaf(YType.boolean, 'is-mrib-register'), ['bool'])),
                            ('is_mdt_owner', (YLeaf(YType.boolean, 'is-mdt-owner'), ['bool'])),
                            ('is_routing_enabled', (YLeaf(YType.boolean, 'is-routing-enabled'), ['bool'])),
                            ('is_socket_add_required', (YLeaf(YType.boolean, 'is-socket-add-required'), ['bool'])),
                            ('is_socket_added', (YLeaf(YType.boolean, 'is-socket-added'), ['bool'])),
                            ('is_lpts_socket_add_required', (YLeaf(YType.boolean, 'is-lpts-socket-add-required'), ['bool'])),
                            ('is_lpts_socket_added', (YLeaf(YType.boolean, 'is-lpts-socket-added'), ['bool'])),
                            ('is_udp_socket_add_required', (YLeaf(YType.boolean, 'is-udp-socket-add-required'), ['bool'])),
                            ('is_udp_socket_added', (YLeaf(YType.boolean, 'is-udp-socket-added'), ['bool'])),
                            ('is_udp_socket_bind_required', (YLeaf(YType.boolean, 'is-udp-socket-bind-required'), ['bool'])),
                            ('is_udp_socket_bind', (YLeaf(YType.boolean, 'is-udp-socket-bind'), ['bool'])),
                            ('is_register_injection_socket_add_required', (YLeaf(YType.boolean, 'is-register-injection-socket-add-required'), ['bool'])),
                            ('is_register_injection_socket_added', (YLeaf(YType.boolean, 'is-register-injection-socket-added'), ['bool'])),
                            ('is_register_injection_lpts_socket_add_required', (YLeaf(YType.boolean, 'is-register-injection-lpts-socket-add-required'), ['bool'])),
                            ('is_register_injection_lpts_socket_added', (YLeaf(YType.boolean, 'is-register-injection-lpts-socket-added'), ['bool'])),
                            ('is_m_host_publish_pending', (YLeaf(YType.boolean, 'is-m-host-publish-pending'), ['bool'])),
                            ('mhost_interface', (YLeaf(YType.str, 'mhost-interface'), ['str'])),
                            ('mhost_default_interface_config', (YLeaf(YType.str, 'mhost-default-interface-config'), ['str'])),
                            ('mdt_mtu', (YLeaf(YType.uint32, 'mdt-mtu'), ['int'])),
                            ('maximum_mdt_aggregation', (YLeaf(YType.uint32, 'maximum-mdt-aggregation'), ['int'])),
                            ('mdt_data_switchover_interval', (YLeaf(YType.uint32, 'mdt-data-switchover-interval'), ['int'])),
                            ('mdt_data_announce_interval', (YLeaf(YType.uint32, 'mdt-data-announce-interval'), ['int'])),
                            ('non_default_vrf_count_on_socket', (YLeaf(YType.uint32, 'non-default-vrf-count-on-socket'), ['int'])),
                            ('neighbor_filter_name', (YLeaf(YType.str, 'neighbor-filter-name'), ['str'])),
                            ('mdt_neighbor_filter_name', (YLeaf(YType.str, 'mdt-neighbor-filter-name'), ['str'])),
                            ('allow_rp_configured', (YLeaf(YType.boolean, 'allow-rp-configured'), ['bool'])),
                            ('allow_rp_group_list', (YLeaf(YType.str, 'allow-rp-group-list'), ['str'])),
                            ('allow_rp_rp_list', (YLeaf(YType.str, 'allow-rp-rp-list'), ['str'])),
                            ('sg_expiry_timer_configured', (YLeaf(YType.boolean, 'sg-expiry-timer-configured'), ['bool'])),
                            ('sg_expiry_time', (YLeaf(YType.uint16, 'sg-expiry-time'), ['int'])),
                            ('sg_expiry_timer_sg_list', (YLeaf(YType.str, 'sg-expiry-timer-sg-list'), ['str'])),
                            ('mldp_mdt_name', (YLeaf(YType.str, 'mldp-mdt-name'), ['str'])),
                            ('mldp_mdt_interface', (YLeaf(YType.str, 'mldp-mdt-interface'), ['str'])),
                            ('mldp_mdt_mtu', (YLeaf(YType.uint32, 'mldp-mdt-mtu'), ['int'])),
                            ('mldp_maximum_mdt_aggregation', (YLeaf(YType.uint32, 'mldp-maximum-mdt-aggregation'), ['int'])),
                            ('mldp_mdt_data_switchover_interval', (YLeaf(YType.uint32, 'mldp-mdt-data-switchover-interval'), ['int'])),
                            ('mldp_mdt_data_announce_interval', (YLeaf(YType.uint32, 'mldp-mdt-data-announce-interval'), ['int'])),
                            ('mldp_mdt_rpf_identifier', (YLeaf(YType.uint32, 'mldp-mdt-rpf-identifier'), ['int'])),
                            ('mldp_mdt_remote_rpf_identifier', (YLeaf(YType.uint32, 'mldp-mdt-remote-rpf-identifier'), ['int'])),
                            ('is_create_mldp_mdt_interface', (YLeaf(YType.boolean, 'is-create-mldp-mdt-interface'), ['bool'])),
                            ('is_mldp_mdt_owner', (YLeaf(YType.boolean, 'is-mldp-mdt-owner'), ['bool'])),
                            ('mldp_root_count', (YLeaf(YType.uint32, 'mldp-root-count'), ['int'])),
                            ('mldp_head_lsm_identifier', (YLeaf(YType.uint32, 'mldp-head-lsm-identifier'), ['int'])),
                            ('mldp_remote_head_lsm_identifier', (YLeaf(YType.uint32, 'mldp-remote-head-lsm-identifier'), ['int'])),
                            ('organization_unique_identifier', (YLeaf(YType.uint32, 'organization-unique-identifier'), ['int'])),
                            ('vpn_index', (YLeaf(YType.uint32, 'vpn-index'), ['int'])),
                            ('mldp_partitioned_mdt_configured', (YLeaf(YType.boolean, 'mldp-partitioned-mdt-configured'), ['bool'])),
                            ('mldp_remote_partitioned_mdt_configured', (YLeaf(YType.boolean, 'mldp-remote-partitioned-mdt-configured'), ['bool'])),
                            ('mldp_partioned_mp2m_ptree', (YLeaf(YType.boolean, 'mldp-partioned-mp2m-ptree'), ['bool'])),
                            ('mldp_partitioned_head_lsm_identifier', (YLeaf(YType.uint32, 'mldp-partitioned-head-lsm-identifier'), ['int'])),
                            ('mldp_head_local_label', (YLeaf(YType.uint32, 'mldp-head-local-label'), ['int'])),
                            ('mldp_partitioned_mdt_identifier', (YLeaf(YType.uint32, 'mldp-partitioned-mdt-identifier'), ['int'])),
                            ('bgp_auto_discovery_configured', (YLeaf(YType.boolean, 'bgp-auto-discovery-configured'), ['bool'])),
                            ('suppress_pim_data_mdt_tlv', (YLeaf(YType.boolean, 'suppress-pim-data-mdt-tlv'), ['bool'])),
                            ('inter_autonomous_system_enabled', (YLeaf(YType.boolean, 'inter-autonomous-system-enabled'), ['bool'])),
                            ('bgp_source_active_announce', (YLeaf(YType.boolean, 'bgp-source-active-announce'), ['bool'])),
                            ('bgp_i_pmsi_added', (YLeaf(YType.boolean, 'bgp-i-pmsi-added'), ['bool'])),
                            ('mldp_bsr_control_tree_added', (YLeaf(YType.boolean, 'mldp-bsr-control-tree-added'), ['bool'])),
                            ('mldp_auto_rp_discovery_tree_added', (YLeaf(YType.boolean, 'mldp-auto-rp-discovery-tree-added'), ['bool'])),
                            ('mldp_auto_rp_announce_tree_added', (YLeaf(YType.boolean, 'mldp-auto-rp-announce-tree-added'), ['bool'])),
                            ('bgp_auto_discovery_type', (YLeaf(YType.uint32, 'bgp-auto-discovery-type'), ['int'])),
                            ('mdt_partitioned_mdt_control_identifier', (YLeaf(YType.uint32, 'mdt-partitioned-mdt-control-identifier'), ['int'])),
                            ('mdt_partitioned_ir_control_identifier', (YLeaf(YType.uint32, 'mdt-partitioned-ir-control-identifier'), ['int'])),
                            ('mldp_control_head_lsm_identifier', (YLeaf(YType.uint32, 'mldp-control-head-lsm-identifier'), ['int'])),
                            ('umh', (YLeaf(YType.boolean, 'umh'), ['bool'])),
                            ('suppress_shared_tree_join', (YLeaf(YType.boolean, 'suppress-shared-tree-join'), ['bool'])),
                            ('rsvp_te_mdt_name', (YLeaf(YType.str, 'rsvp-te-mdt-name'), ['str'])),
                            ('rsvp_te_mdt_interface', (YLeaf(YType.str, 'rsvp-te-mdt-interface'), ['str'])),
                            ('rsvp_te_mdt_mtu', (YLeaf(YType.uint32, 'rsvp-te-mdt-mtu'), ['int'])),
                            ('rsvp_te_maximum_mdt_aggregation', (YLeaf(YType.uint32, 'rsvp-te-maximum-mdt-aggregation'), ['int'])),
                            ('rsvp_te_mdt_data_switchover_interval', (YLeaf(YType.uint32, 'rsvp-te-mdt-data-switchover-interval'), ['int'])),
                            ('rsvp_te_mdt_data_announce_interval', (YLeaf(YType.uint32, 'rsvp-te-mdt-data-announce-interval'), ['int'])),
                            ('rsvp_te_mdt_rpf_identifier', (YLeaf(YType.uint32, 'rsvp-te-mdt-rpf-identifier'), ['int'])),
                            ('is_create_rsvp_te_mdt_interface', (YLeaf(YType.boolean, 'is-create-rsvp-te-mdt-interface'), ['bool'])),
                            ('is_rsvp_te_mdt_owner', (YLeaf(YType.boolean, 'is-rsvp-te-mdt-owner'), ['bool'])),
                            ('rsvp_te_mdt_static_p2mp_count', (YLeaf(YType.uint32, 'rsvp-te-mdt-static-p2mp-count'), ['int'])),
                            ('p2mpte_li_drop', (YLeaf(YType.uint32, 'p2mpte-li-drop'), ['int'])),
                            ('ir_mdt_name', (YLeaf(YType.str, 'ir-mdt-name'), ['str'])),
                            ('ir_mdt_interface', (YLeaf(YType.str, 'ir-mdt-interface'), ['str'])),
                            ('ir_mdt_mtu', (YLeaf(YType.uint32, 'ir-mdt-mtu'), ['int'])),
                            ('ir_maximum_mdt_aggregation', (YLeaf(YType.uint32, 'ir-maximum-mdt-aggregation'), ['int'])),
                            ('ir_mdt_data_switchover_interval', (YLeaf(YType.uint32, 'ir-mdt-data-switchover-interval'), ['int'])),
                            ('ir_mdt_data_announce_interval', (YLeaf(YType.uint32, 'ir-mdt-data-announce-interval'), ['int'])),
                            ('ir_mdt_rpf_identifier', (YLeaf(YType.uint32, 'ir-mdt-rpf-identifier'), ['int'])),
                            ('ir_mdt_tail_label', (YLeaf(YType.uint32, 'ir-mdt-tail-label'), ['int'])),
                            ('is_create_ir_mdt_interface', (YLeaf(YType.boolean, 'is-create-ir-mdt-interface'), ['bool'])),
                            ('is_ir_mdt_owner', (YLeaf(YType.boolean, 'is-ir-mdt-owner'), ['bool'])),
                            ('in_b_and_mdt_name', (YLeaf(YType.str, 'in-b-and-mdt-name'), ['str'])),
                            ('in_b_and_mdt_interface', (YLeaf(YType.str, 'in-b-and-mdt-interface'), ['str'])),
                            ('in_b_and_mdt_mtu', (YLeaf(YType.uint32, 'in-b-and-mdt-mtu'), ['int'])),
                            ('in_band_maximum_mdt_aggregation', (YLeaf(YType.uint32, 'in-band-maximum-mdt-aggregation'), ['int'])),
                            ('in_b_and_mdt_data_switchover_interval', (YLeaf(YType.uint32, 'in-b-and-mdt-data-switchover-interval'), ['int'])),
                            ('in_b_and_mdt_data_announce_interval', (YLeaf(YType.uint32, 'in-b-and-mdt-data-announce-interval'), ['int'])),
                            ('in_b_and_mdt_rpf_identifier', (YLeaf(YType.uint32, 'in-b-and-mdt-rpf-identifier'), ['int'])),
                            ('is_create_in_b_and_mdt_interface', (YLeaf(YType.boolean, 'is-create-in-b-and-mdt-interface'), ['bool'])),
                            ('is_in_b_and_mdt_owner', (YLeaf(YType.boolean, 'is-in-b-and-mdt-owner'), ['bool'])),
                            ('in_band_signaling_local_enabled', (YLeaf(YType.boolean, 'in-band-signaling-local-enabled'), ['bool'])),
                            ('in_band_signaling_remote_enabled', (YLeaf(YType.boolean, 'in-band-signaling-remote-enabled'), ['bool'])),
                            ('valid_rd_present', (YLeaf(YType.boolean, 'valid-rd-present'), ['bool'])),
                            ('stale_rd_present', (YLeaf(YType.boolean, 'stale-rd-present'), ['bool'])),
                            ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                            ('gin_b_and_mdt_name', (YLeaf(YType.str, 'gin-b-and-mdt-name'), ['str'])),
                            ('gin_b_and_mdt_interface', (YLeaf(YType.str, 'gin-b-and-mdt-interface'), ['str'])),
                            ('gin_b_and_mdt_mtu', (YLeaf(YType.uint32, 'gin-b-and-mdt-mtu'), ['int'])),
                            ('gin_band_maximum_mdt_aggregation', (YLeaf(YType.uint32, 'gin-band-maximum-mdt-aggregation'), ['int'])),
                            ('gin_b_and_mdt_data_switchover_interval', (YLeaf(YType.uint32, 'gin-b-and-mdt-data-switchover-interval'), ['int'])),
                            ('gin_b_and_mdt_data_announce_interval', (YLeaf(YType.uint32, 'gin-b-and-mdt-data-announce-interval'), ['int'])),
                            ('gin_b_and_mdt_rpf_identifier', (YLeaf(YType.uint32, 'gin-b-and-mdt-rpf-identifier'), ['int'])),
                            ('is_create_gin_b_and_mdt_interface', (YLeaf(YType.boolean, 'is-create-gin-b-and-mdt-interface'), ['bool'])),
                            ('is_gin_b_and_mdt_owner', (YLeaf(YType.boolean, 'is-gin-b-and-mdt-owner'), ['bool'])),
                            ('is_pim_nsf_rib_converged', (YLeaf(YType.boolean, 'is-pim-nsf-rib-converged'), ['bool'])),
                            ('is_pim_nsf_rib_converge_received', (YLeaf(YType.boolean, 'is-pim-nsf-rib-converge-received'), ['bool'])),
                            ('is_rib_multipath_enabled', (YLeaf(YType.boolean, 'is-rib-multipath-enabled'), ['bool'])),
                            ('is_rib_multipath_interface_hash', (YLeaf(YType.boolean, 'is-rib-multipath-interface-hash'), ['bool'])),
                            ('is_rib_multipath_source_hash', (YLeaf(YType.boolean, 'is-rib-multipath-source-hash'), ['bool'])),
                            ('is_rib_multipath_source_next_hop_hash', (YLeaf(YType.boolean, 'is-rib-multipath-source-next-hop-hash'), ['bool'])),
                            ('rump_enabled', (YLeaf(YType.boolean, 'rump-enabled'), ['bool'])),
                            ('is_create_mdt_interface', (YLeaf(YType.boolean, 'is-create-mdt-interface'), ['bool'])),
                            ('is_auto_rp_listen_enabled', (YLeaf(YType.boolean, 'is-auto-rp-listen-enabled'), ['bool'])),
                            ('is_all_interface_disable_operation', (YLeaf(YType.boolean, 'is-all-interface-disable-operation'), ['bool'])),
                            ('is_default_granges', (YLeaf(YType.boolean, 'is-default-granges'), ['bool'])),
                            ('is_auto_rp_listen_sock_add', (YLeaf(YType.boolean, 'is-auto-rp-listen-sock-add'), ['bool'])),
                            ('is_redistribution_reset', (YLeaf(YType.boolean, 'is-redistribution-reset'), ['bool'])),
                            ('redistribution_reset_count', (YLeaf(YType.uint32, 'redistribution-reset-count'), ['int'])),
                            ('rpf_policy_name', (YLeaf(YType.str, 'rpf-policy-name'), ['str'])),
                            ('table_count', (YLeaf(YType.uint32, 'table-count'), ['int'])),
                            ('active_table_count', (YLeaf(YType.uint32, 'active-table-count'), ['int'])),
                            ('anycast_rp_policy_name', (YLeaf(YType.str, 'anycast-rp-policy-name'), ['str'])),
                            ('anycast_rp_configured', (YLeaf(YType.boolean, 'anycast-rp-configured'), ['bool'])),
                            ('bgp_remote_on', (YLeaf(YType.boolean, 'bgp-remote-on'), ['bool'])),
                            ('bgp_remote_interface_name', (YLeaf(YType.str, 'bgp-remote-interface-name'), ['str'])),
                            ('bgp_remote_interface', (YLeaf(YType.str, 'bgp-remote-interface'), ['str'])),
                            ('bgp_remote_address', (YLeaf(YType.str, 'bgp-remote-address'), ['str'])),
                            ('bgp_remote_state', (YLeaf(YType.uint32, 'bgp-remote-state'), ['int'])),
                            ('physical_interface_count', (YLeaf(YType.uint64, 'physical-interface-count'), ['int'])),
                            ('virtual_interface_count', (YLeaf(YType.uint64, 'virtual-interface-count'), ['int'])),
                            ('virtual_mlc_interface_name', (YLeaf(YType.str, 'virtual-mlc-interface-name'), ['str'])),
                            ('mdt_immediate_switch', (YLeaf(YType.boolean, 'mdt-immediate-switch'), ['bool'])),
                            ('mldp_root_address', (YLeafList(YType.uint32, 'mldp-root-address'), ['int'])),
                        ])
                        self.vrf_id = None
                        self.table_id = None
                        self.murib_id = None
                        self.rpf_id = None
                        self.remote_table_id = None
                        self.mdt_default_group = None
                        self.mdt_source = None
                        self.mdt_source_interface = None
                        self.mdt_interface = None
                        self.mdt_gre_rpf_identifier = None
                        self.mdt_gre_remote_rpf_identifier = None
                        self.is_unicast_rib_registration = None
                        self.is_multicast_rib_registration = None
                        self.is_active = None
                        self.is_active_ital = None
                        self.is_mrib_register = None
                        self.is_mdt_owner = None
                        self.is_routing_enabled = None
                        self.is_socket_add_required = None
                        self.is_socket_added = None
                        self.is_lpts_socket_add_required = None
                        self.is_lpts_socket_added = None
                        self.is_udp_socket_add_required = None
                        self.is_udp_socket_added = None
                        self.is_udp_socket_bind_required = None
                        self.is_udp_socket_bind = None
                        self.is_register_injection_socket_add_required = None
                        self.is_register_injection_socket_added = None
                        self.is_register_injection_lpts_socket_add_required = None
                        self.is_register_injection_lpts_socket_added = None
                        self.is_m_host_publish_pending = None
                        self.mhost_interface = None
                        self.mhost_default_interface_config = None
                        self.mdt_mtu = None
                        self.maximum_mdt_aggregation = None
                        self.mdt_data_switchover_interval = None
                        self.mdt_data_announce_interval = None
                        self.non_default_vrf_count_on_socket = None
                        self.neighbor_filter_name = None
                        self.mdt_neighbor_filter_name = None
                        self.allow_rp_configured = None
                        self.allow_rp_group_list = None
                        self.allow_rp_rp_list = None
                        self.sg_expiry_timer_configured = None
                        self.sg_expiry_time = None
                        self.sg_expiry_timer_sg_list = None
                        self.mldp_mdt_name = None
                        self.mldp_mdt_interface = None
                        self.mldp_mdt_mtu = None
                        self.mldp_maximum_mdt_aggregation = None
                        self.mldp_mdt_data_switchover_interval = None
                        self.mldp_mdt_data_announce_interval = None
                        self.mldp_mdt_rpf_identifier = None
                        self.mldp_mdt_remote_rpf_identifier = None
                        self.is_create_mldp_mdt_interface = None
                        self.is_mldp_mdt_owner = None
                        self.mldp_root_count = None
                        self.mldp_head_lsm_identifier = None
                        self.mldp_remote_head_lsm_identifier = None
                        self.organization_unique_identifier = None
                        self.vpn_index = None
                        self.mldp_partitioned_mdt_configured = None
                        self.mldp_remote_partitioned_mdt_configured = None
                        self.mldp_partioned_mp2m_ptree = None
                        self.mldp_partitioned_head_lsm_identifier = None
                        self.mldp_head_local_label = None
                        self.mldp_partitioned_mdt_identifier = None
                        self.bgp_auto_discovery_configured = None
                        self.suppress_pim_data_mdt_tlv = None
                        self.inter_autonomous_system_enabled = None
                        self.bgp_source_active_announce = None
                        self.bgp_i_pmsi_added = None
                        self.mldp_bsr_control_tree_added = None
                        self.mldp_auto_rp_discovery_tree_added = None
                        self.mldp_auto_rp_announce_tree_added = None
                        self.bgp_auto_discovery_type = None
                        self.mdt_partitioned_mdt_control_identifier = None
                        self.mdt_partitioned_ir_control_identifier = None
                        self.mldp_control_head_lsm_identifier = None
                        self.umh = None
                        self.suppress_shared_tree_join = None
                        self.rsvp_te_mdt_name = None
                        self.rsvp_te_mdt_interface = None
                        self.rsvp_te_mdt_mtu = None
                        self.rsvp_te_maximum_mdt_aggregation = None
                        self.rsvp_te_mdt_data_switchover_interval = None
                        self.rsvp_te_mdt_data_announce_interval = None
                        self.rsvp_te_mdt_rpf_identifier = None
                        self.is_create_rsvp_te_mdt_interface = None
                        self.is_rsvp_te_mdt_owner = None
                        self.rsvp_te_mdt_static_p2mp_count = None
                        self.p2mpte_li_drop = None
                        self.ir_mdt_name = None
                        self.ir_mdt_interface = None
                        self.ir_mdt_mtu = None
                        self.ir_maximum_mdt_aggregation = None
                        self.ir_mdt_data_switchover_interval = None
                        self.ir_mdt_data_announce_interval = None
                        self.ir_mdt_rpf_identifier = None
                        self.ir_mdt_tail_label = None
                        self.is_create_ir_mdt_interface = None
                        self.is_ir_mdt_owner = None
                        self.in_b_and_mdt_name = None
                        self.in_b_and_mdt_interface = None
                        self.in_b_and_mdt_mtu = None
                        self.in_band_maximum_mdt_aggregation = None
                        self.in_b_and_mdt_data_switchover_interval = None
                        self.in_b_and_mdt_data_announce_interval = None
                        self.in_b_and_mdt_rpf_identifier = None
                        self.is_create_in_b_and_mdt_interface = None
                        self.is_in_b_and_mdt_owner = None
                        self.in_band_signaling_local_enabled = None
                        self.in_band_signaling_remote_enabled = None
                        self.valid_rd_present = None
                        self.stale_rd_present = None
                        self.route_distinguisher = None
                        self.gin_b_and_mdt_name = None
                        self.gin_b_and_mdt_interface = None
                        self.gin_b_and_mdt_mtu = None
                        self.gin_band_maximum_mdt_aggregation = None
                        self.gin_b_and_mdt_data_switchover_interval = None
                        self.gin_b_and_mdt_data_announce_interval = None
                        self.gin_b_and_mdt_rpf_identifier = None
                        self.is_create_gin_b_and_mdt_interface = None
                        self.is_gin_b_and_mdt_owner = None
                        self.is_pim_nsf_rib_converged = None
                        self.is_pim_nsf_rib_converge_received = None
                        self.is_rib_multipath_enabled = None
                        self.is_rib_multipath_interface_hash = None
                        self.is_rib_multipath_source_hash = None
                        self.is_rib_multipath_source_next_hop_hash = None
                        self.rump_enabled = None
                        self.is_create_mdt_interface = None
                        self.is_auto_rp_listen_enabled = None
                        self.is_all_interface_disable_operation = None
                        self.is_default_granges = None
                        self.is_auto_rp_listen_sock_add = None
                        self.is_redistribution_reset = None
                        self.redistribution_reset_count = None
                        self.rpf_policy_name = None
                        self.table_count = None
                        self.active_table_count = None
                        self.anycast_rp_policy_name = None
                        self.anycast_rp_configured = None
                        self.bgp_remote_on = None
                        self.bgp_remote_interface_name = None
                        self.bgp_remote_interface = None
                        self.bgp_remote_address = None
                        self.bgp_remote_state = None
                        self.physical_interface_count = None
                        self.virtual_interface_count = None
                        self.virtual_mlc_interface_name = None
                        self.mdt_immediate_switch = None
                        self.mldp_root_address = []

                        self.remote_default_group = Ipv6Pim.Standby.Vrfs.Vrf.Context.RemoteDefaultGroup()
                        self.remote_default_group.parent = self
                        self._children_name_map["remote_default_group"] = "remote-default-group"

                        self.rpf_default_table = Ipv6Pim.Standby.Vrfs.Vrf.Context.RpfDefaultTable()
                        self.rpf_default_table.parent = self
                        self._children_name_map["rpf_default_table"] = "rpf-default-table"

                        self.export_route_target = YList(self)
                        self.import_route_target = YList(self)
                        self.anycast_rp_range = YList(self)
                        self._segment_path = lambda: "context"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Context, ['vrf_id', 'table_id', 'murib_id', 'rpf_id', 'remote_table_id', 'mdt_default_group', 'mdt_source', 'mdt_source_interface', 'mdt_interface', 'mdt_gre_rpf_identifier', 'mdt_gre_remote_rpf_identifier', 'is_unicast_rib_registration', 'is_multicast_rib_registration', 'is_active', 'is_active_ital', 'is_mrib_register', 'is_mdt_owner', 'is_routing_enabled', 'is_socket_add_required', 'is_socket_added', 'is_lpts_socket_add_required', 'is_lpts_socket_added', 'is_udp_socket_add_required', 'is_udp_socket_added', 'is_udp_socket_bind_required', 'is_udp_socket_bind', 'is_register_injection_socket_add_required', 'is_register_injection_socket_added', 'is_register_injection_lpts_socket_add_required', 'is_register_injection_lpts_socket_added', 'is_m_host_publish_pending', 'mhost_interface', 'mhost_default_interface_config', 'mdt_mtu', 'maximum_mdt_aggregation', 'mdt_data_switchover_interval', 'mdt_data_announce_interval', 'non_default_vrf_count_on_socket', 'neighbor_filter_name', 'mdt_neighbor_filter_name', 'allow_rp_configured', 'allow_rp_group_list', 'allow_rp_rp_list', 'sg_expiry_timer_configured', 'sg_expiry_time', 'sg_expiry_timer_sg_list', 'mldp_mdt_name', 'mldp_mdt_interface', 'mldp_mdt_mtu', 'mldp_maximum_mdt_aggregation', 'mldp_mdt_data_switchover_interval', 'mldp_mdt_data_announce_interval', 'mldp_mdt_rpf_identifier', 'mldp_mdt_remote_rpf_identifier', 'is_create_mldp_mdt_interface', 'is_mldp_mdt_owner', 'mldp_root_count', 'mldp_head_lsm_identifier', 'mldp_remote_head_lsm_identifier', 'organization_unique_identifier', 'vpn_index', 'mldp_partitioned_mdt_configured', 'mldp_remote_partitioned_mdt_configured', 'mldp_partioned_mp2m_ptree', 'mldp_partitioned_head_lsm_identifier', 'mldp_head_local_label', 'mldp_partitioned_mdt_identifier', 'bgp_auto_discovery_configured', 'suppress_pim_data_mdt_tlv', 'inter_autonomous_system_enabled', 'bgp_source_active_announce', 'bgp_i_pmsi_added', 'mldp_bsr_control_tree_added', 'mldp_auto_rp_discovery_tree_added', 'mldp_auto_rp_announce_tree_added', 'bgp_auto_discovery_type', 'mdt_partitioned_mdt_control_identifier', 'mdt_partitioned_ir_control_identifier', 'mldp_control_head_lsm_identifier', 'umh', 'suppress_shared_tree_join', 'rsvp_te_mdt_name', 'rsvp_te_mdt_interface', 'rsvp_te_mdt_mtu', 'rsvp_te_maximum_mdt_aggregation', 'rsvp_te_mdt_data_switchover_interval', 'rsvp_te_mdt_data_announce_interval', 'rsvp_te_mdt_rpf_identifier', 'is_create_rsvp_te_mdt_interface', 'is_rsvp_te_mdt_owner', 'rsvp_te_mdt_static_p2mp_count', 'p2mpte_li_drop', 'ir_mdt_name', 'ir_mdt_interface', 'ir_mdt_mtu', 'ir_maximum_mdt_aggregation', 'ir_mdt_data_switchover_interval', 'ir_mdt_data_announce_interval', 'ir_mdt_rpf_identifier', 'ir_mdt_tail_label', 'is_create_ir_mdt_interface', 'is_ir_mdt_owner', 'in_b_and_mdt_name', 'in_b_and_mdt_interface', 'in_b_and_mdt_mtu', 'in_band_maximum_mdt_aggregation', 'in_b_and_mdt_data_switchover_interval', 'in_b_and_mdt_data_announce_interval', 'in_b_and_mdt_rpf_identifier', 'is_create_in_b_and_mdt_interface', 'is_in_b_and_mdt_owner', 'in_band_signaling_local_enabled', 'in_band_signaling_remote_enabled', 'valid_rd_present', 'stale_rd_present', 'route_distinguisher', 'gin_b_and_mdt_name', 'gin_b_and_mdt_interface', 'gin_b_and_mdt_mtu', 'gin_band_maximum_mdt_aggregation', 'gin_b_and_mdt_data_switchover_interval', 'gin_b_and_mdt_data_announce_interval', 'gin_b_and_mdt_rpf_identifier', 'is_create_gin_b_and_mdt_interface', 'is_gin_b_and_mdt_owner', 'is_pim_nsf_rib_converged', 'is_pim_nsf_rib_converge_received', 'is_rib_multipath_enabled', 'is_rib_multipath_interface_hash', 'is_rib_multipath_source_hash', 'is_rib_multipath_source_next_hop_hash', 'rump_enabled', 'is_create_mdt_interface', 'is_auto_rp_listen_enabled', 'is_all_interface_disable_operation', 'is_default_granges', 'is_auto_rp_listen_sock_add', 'is_redistribution_reset', 'redistribution_reset_count', 'rpf_policy_name', 'table_count', 'active_table_count', 'anycast_rp_policy_name', 'anycast_rp_configured', 'bgp_remote_on', 'bgp_remote_interface_name', 'bgp_remote_interface', 'bgp_remote_address', 'bgp_remote_state', 'physical_interface_count', 'virtual_interface_count', 'virtual_mlc_interface_name', 'mdt_immediate_switch', 'mldp_root_address'], name, value)


                    class RemoteDefaultGroup(Entity):
                        """
                        Remote Default Group
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.Context.RemoteDefaultGroup, self).__init__()

                            self.yang_name = "remote-default-group"
                            self.yang_parent_name = "context"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "remote-default-group"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Context.RemoteDefaultGroup, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class RpfDefaultTable(Entity):
                        """
                        RPF Default Table
                        
                        .. attribute:: afi
                        
                        	AFI
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: safi
                        
                        	SAFI
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_name
                        
                        	Table name
                        	**type**\: str
                        
                        .. attribute:: vrf_id
                        
                        	VRF ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_id
                        
                        	Table ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_active
                        
                        	Active status
                        	**type**\: bool
                        
                        .. attribute:: is_ital_registration_done
                        
                        	ITAL reg status
                        	**type**\: bool
                        
                        .. attribute:: is_rib_registration_done
                        
                        	RIB reg status
                        	**type**\: bool
                        
                        .. attribute:: is_rib_convergence_received
                        
                        	RIB Convergence receive status
                        	**type**\: bool
                        
                        .. attribute:: is_rib_convergence
                        
                        	RIB Convergence status
                        	**type**\: bool
                        
                        .. attribute:: rpf_registrations
                        
                        	RPF Registration count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.Context.RpfDefaultTable, self).__init__()

                            self.yang_name = "rpf-default-table"
                            self.yang_parent_name = "context"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('afi', (YLeaf(YType.uint32, 'afi'), ['int'])),
                                ('safi', (YLeaf(YType.uint32, 'safi'), ['int'])),
                                ('table_name', (YLeaf(YType.str, 'table-name'), ['str'])),
                                ('vrf_id', (YLeaf(YType.uint32, 'vrf-id'), ['int'])),
                                ('table_id', (YLeaf(YType.uint32, 'table-id'), ['int'])),
                                ('is_active', (YLeaf(YType.boolean, 'is-active'), ['bool'])),
                                ('is_ital_registration_done', (YLeaf(YType.boolean, 'is-ital-registration-done'), ['bool'])),
                                ('is_rib_registration_done', (YLeaf(YType.boolean, 'is-rib-registration-done'), ['bool'])),
                                ('is_rib_convergence_received', (YLeaf(YType.boolean, 'is-rib-convergence-received'), ['bool'])),
                                ('is_rib_convergence', (YLeaf(YType.boolean, 'is-rib-convergence'), ['bool'])),
                                ('rpf_registrations', (YLeaf(YType.uint32, 'rpf-registrations'), ['int'])),
                            ])
                            self.afi = None
                            self.safi = None
                            self.table_name = None
                            self.vrf_id = None
                            self.table_id = None
                            self.is_active = None
                            self.is_ital_registration_done = None
                            self.is_rib_registration_done = None
                            self.is_rib_convergence_received = None
                            self.is_rib_convergence = None
                            self.rpf_registrations = None
                            self._segment_path = lambda: "rpf-default-table"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Context.RpfDefaultTable, ['afi', 'safi', 'table_name', 'vrf_id', 'table_id', 'is_active', 'is_ital_registration_done', 'is_rib_registration_done', 'is_rib_convergence_received', 'is_rib_convergence', 'rpf_registrations'], name, value)


                    class ExportRouteTarget(Entity):
                        """
                        Export Route Targets
                        
                        .. attribute:: route_target
                        
                        	Route Target Extended community value
                        	**type**\: str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        .. attribute:: configured
                        
                        	Configured Route Target
                        	**type**\: bool
                        
                        .. attribute:: anycast_rp
                        
                        	Anycast\-RP Group
                        	**type**\: bool
                        
                        .. attribute:: anycast_rp_marked
                        
                        	Anycast\-RP Group marked
                        	**type**\: bool
                        
                        .. attribute:: update_pending
                        
                        	Update Pending to BGP
                        	**type**\: bool
                        
                        .. attribute:: bgp_auto_discovery
                        
                        	BGP Auto Discovery
                        	**type**\: bool
                        
                        .. attribute:: segment_border
                        
                        	Segment Border
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.Context.ExportRouteTarget, self).__init__()

                            self.yang_name = "export-route-target"
                            self.yang_parent_name = "context"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('route_target', (YLeaf(YType.str, 'route-target'), ['str'])),
                                ('configured', (YLeaf(YType.boolean, 'configured'), ['bool'])),
                                ('anycast_rp', (YLeaf(YType.boolean, 'anycast-rp'), ['bool'])),
                                ('anycast_rp_marked', (YLeaf(YType.boolean, 'anycast-rp-marked'), ['bool'])),
                                ('update_pending', (YLeaf(YType.boolean, 'update-pending'), ['bool'])),
                                ('bgp_auto_discovery', (YLeaf(YType.boolean, 'bgp-auto-discovery'), ['bool'])),
                                ('segment_border', (YLeaf(YType.boolean, 'segment-border'), ['bool'])),
                            ])
                            self.route_target = None
                            self.configured = None
                            self.anycast_rp = None
                            self.anycast_rp_marked = None
                            self.update_pending = None
                            self.bgp_auto_discovery = None
                            self.segment_border = None
                            self._segment_path = lambda: "export-route-target"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Context.ExportRouteTarget, ['route_target', 'configured', 'anycast_rp', 'anycast_rp_marked', 'update_pending', 'bgp_auto_discovery', 'segment_border'], name, value)


                    class ImportRouteTarget(Entity):
                        """
                        Import Route Targets
                        
                        .. attribute:: route_target
                        
                        	Route Target Extended community value
                        	**type**\: str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        .. attribute:: configured
                        
                        	Configured Route Target
                        	**type**\: bool
                        
                        .. attribute:: anycast_rp
                        
                        	Anycast\-RP Group
                        	**type**\: bool
                        
                        .. attribute:: anycast_rp_marked
                        
                        	Anycast\-RP Group marked
                        	**type**\: bool
                        
                        .. attribute:: update_pending
                        
                        	Update Pending to BGP
                        	**type**\: bool
                        
                        .. attribute:: bgp_auto_discovery
                        
                        	BGP Auto Discovery
                        	**type**\: bool
                        
                        .. attribute:: segment_border
                        
                        	Segment Border
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.Context.ImportRouteTarget, self).__init__()

                            self.yang_name = "import-route-target"
                            self.yang_parent_name = "context"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('route_target', (YLeaf(YType.str, 'route-target'), ['str'])),
                                ('configured', (YLeaf(YType.boolean, 'configured'), ['bool'])),
                                ('anycast_rp', (YLeaf(YType.boolean, 'anycast-rp'), ['bool'])),
                                ('anycast_rp_marked', (YLeaf(YType.boolean, 'anycast-rp-marked'), ['bool'])),
                                ('update_pending', (YLeaf(YType.boolean, 'update-pending'), ['bool'])),
                                ('bgp_auto_discovery', (YLeaf(YType.boolean, 'bgp-auto-discovery'), ['bool'])),
                                ('segment_border', (YLeaf(YType.boolean, 'segment-border'), ['bool'])),
                            ])
                            self.route_target = None
                            self.configured = None
                            self.anycast_rp = None
                            self.anycast_rp_marked = None
                            self.update_pending = None
                            self.bgp_auto_discovery = None
                            self.segment_border = None
                            self._segment_path = lambda: "import-route-target"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Context.ImportRouteTarget, ['route_target', 'configured', 'anycast_rp', 'anycast_rp_marked', 'update_pending', 'bgp_auto_discovery', 'segment_border'], name, value)


                    class AnycastRpRange(Entity):
                        """
                        Anycast\-RP Ranges
                        
                        .. attribute:: prefix
                        
                        	Anycast\-RP Range Prefix
                        	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Anycast\-RP Range Prefix Length
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: ancast_rp_marked
                        
                        	Anycast\-RP Range marked
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange, self).__init__()

                            self.yang_name = "anycast-rp-range"
                            self.yang_parent_name = "context"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("prefix", ("prefix", Ipv6Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange.Prefix))])
                            self._leafs = OrderedDict([
                                ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                ('ancast_rp_marked', (YLeaf(YType.boolean, 'ancast-rp-marked'), ['bool'])),
                            ])
                            self.prefix_length = None
                            self.ancast_rp_marked = None

                            self.prefix = Ipv6Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"
                            self._segment_path = lambda: "anycast-rp-range"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange, ['prefix_length', 'ancast_rp_marked'], name, value)


                        class Prefix(Entity):
                            """
                            Anycast\-RP Range Prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "anycast-rp-range"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "prefix"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange.Prefix, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class TopologyEntryFlagRouteCounts(Entity):
                    """
                    Route count for topology with entry flag set
                    
                    .. attribute:: topology_entry_flag_route_count
                    
                    	Route count for topology with entry flag set
                    	**type**\: list of  		 :py:class:`TopologyEntryFlagRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts, self).__init__()

                        self.yang_name = "topology-entry-flag-route-counts"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("topology-entry-flag-route-count", ("topology_entry_flag_route_count", Ipv6Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount))])
                        self._leafs = OrderedDict()

                        self.topology_entry_flag_route_count = YList(self)
                        self._segment_path = lambda: "topology-entry-flag-route-counts"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts, [], name, value)


                    class TopologyEntryFlagRouteCount(Entity):
                        """
                        Route count for topology with entry flag set
                        
                        .. attribute:: entry_flag  (key)
                        
                        	entry flag
                        	**type**\:  :py:class:`PimTopologyEntryFlag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimTopologyEntryFlag>`
                        
                        .. attribute:: group_ranges
                        
                        	No. of (\*,G/M) routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: active_group_ranges
                        
                        	No. of (\*,G/M) routes active in mrib
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: groute_count
                        
                        	No. of (\*,G) routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sg_route_count
                        
                        	No. of (S,G) routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sgr_route_count
                        
                        	No. of (S,G)RPT routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_node_low_memory
                        
                        	Is node in low memory condition
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount, self).__init__()

                            self.yang_name = "topology-entry-flag-route-count"
                            self.yang_parent_name = "topology-entry-flag-route-counts"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['entry_flag']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('entry_flag', (YLeaf(YType.enumeration, 'entry-flag'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimTopologyEntryFlag', '')])),
                                ('group_ranges', (YLeaf(YType.uint32, 'group-ranges'), ['int'])),
                                ('active_group_ranges', (YLeaf(YType.uint32, 'active-group-ranges'), ['int'])),
                                ('groute_count', (YLeaf(YType.uint32, 'groute-count'), ['int'])),
                                ('sg_route_count', (YLeaf(YType.uint32, 'sg-route-count'), ['int'])),
                                ('sgr_route_count', (YLeaf(YType.uint32, 'sgr-route-count'), ['int'])),
                                ('is_node_low_memory', (YLeaf(YType.boolean, 'is-node-low-memory'), ['bool'])),
                            ])
                            self.entry_flag = None
                            self.group_ranges = None
                            self.active_group_ranges = None
                            self.groute_count = None
                            self.sg_route_count = None
                            self.sgr_route_count = None
                            self.is_node_low_memory = None
                            self._segment_path = lambda: "topology-entry-flag-route-count" + "[entry-flag='" + str(self.entry_flag) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount, ['entry_flag', 'group_ranges', 'active_group_ranges', 'groute_count', 'sg_route_count', 'sgr_route_count', 'is_node_low_memory'], name, value)


                class RpfRedirect(Entity):
                    """
                    PIM ECMP RPF\-redirect bundle
                    
                    .. attribute:: redirect_route_databases
                    
                    	PIM ECMP RPF\-redirect route database
                    	**type**\:  :py:class:`RedirectRouteDatabases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases>`
                    
                    .. attribute:: bundle_interfaces
                    
                    	PIM ECMP RPF\-redirect bundle information
                    	**type**\:  :py:class:`BundleInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect, self).__init__()

                        self.yang_name = "rpf-redirect"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("redirect-route-databases", ("redirect_route_databases", Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases)), ("bundle-interfaces", ("bundle_interfaces", Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces))])
                        self._leafs = OrderedDict()

                        self.redirect_route_databases = Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases()
                        self.redirect_route_databases.parent = self
                        self._children_name_map["redirect_route_databases"] = "redirect-route-databases"

                        self.bundle_interfaces = Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces()
                        self.bundle_interfaces.parent = self
                        self._children_name_map["bundle_interfaces"] = "bundle-interfaces"
                        self._segment_path = lambda: "rpf-redirect"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect, [], name, value)


                    class RedirectRouteDatabases(Entity):
                        """
                        PIM ECMP RPF\-redirect route database
                        
                        .. attribute:: redirect_route_database
                        
                        	PIM ECMP RPF\-redirect route information
                        	**type**\: list of  		 :py:class:`RedirectRouteDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases, self).__init__()

                            self.yang_name = "redirect-route-databases"
                            self.yang_parent_name = "rpf-redirect"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("redirect-route-database", ("redirect_route_database", Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase))])
                            self._leafs = OrderedDict()

                            self.redirect_route_database = YList(self)
                            self._segment_path = lambda: "redirect-route-databases"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases, [], name, value)


                        class RedirectRouteDatabase(Entity):
                            """
                            PIM ECMP RPF\-redirect route information
                            
                            .. attribute:: source_address
                            
                            	Source address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: group_address
                            
                            	Group address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: group_address_xr
                            
                            	Group ddress
                            	**type**\:  :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr>`
                            
                            .. attribute:: source_address_xr
                            
                            	Source address
                            	**type**\:  :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr>`
                            
                            .. attribute:: bandwidth
                            
                            	Bandwidth in Kbps
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: interface
                            
                            	Outgoing interface list
                            	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase, self).__init__()

                                self.yang_name = "redirect-route-database"
                                self.yang_parent_name = "redirect-route-databases"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("group-address-xr", ("group_address_xr", Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr)), ("source-address-xr", ("source_address_xr", Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr)), ("interface", ("interface", Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface))])
                                self._leafs = OrderedDict([
                                    ('source_address', (YLeaf(YType.str, 'source-address'), ['str','str'])),
                                    ('group_address', (YLeaf(YType.str, 'group-address'), ['str','str'])),
                                    ('bandwidth', (YLeaf(YType.uint32, 'bandwidth'), ['int'])),
                                    ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                                ])
                                self.source_address = None
                                self.group_address = None
                                self.bandwidth = None
                                self.uptime = None

                                self.group_address_xr = Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"

                                self.source_address_xr = Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr()
                                self.source_address_xr.parent = self
                                self._children_name_map["source_address_xr"] = "source-address-xr"

                                self.interface = YList(self)
                                self._segment_path = lambda: "redirect-route-database"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase, ['source_address', 'group_address', 'bandwidth', 'uptime'], name, value)


                            class GroupAddressXr(Entity):
                                """
                                Group ddress
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr, self).__init__()

                                    self.yang_name = "group-address-xr"
                                    self.yang_parent_name = "redirect-route-database"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "group-address-xr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                            class SourceAddressXr(Entity):
                                """
                                Source address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr, self).__init__()

                                    self.yang_name = "source-address-xr"
                                    self.yang_parent_name = "redirect-route-database"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "source-address-xr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                            class Interface(Entity):
                                """
                                Outgoing interface list
                                
                                .. attribute:: rpf_address
                                
                                	RPF Address
                                	**type**\:  :py:class:`RpfAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress>`
                                
                                .. attribute:: interface_name
                                
                                	Interface name
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                .. attribute:: uptime
                                
                                	Uptime in seconds
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: second
                                
                                .. attribute:: expiry
                                
                                	Expiry in seconds
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: second
                                
                                .. attribute:: is_rpf_interface
                                
                                	Is RPF Interface
                                	**type**\: bool
                                
                                .. attribute:: is_outgoing_interface
                                
                                	Is outgoing Interface
                                	**type**\: bool
                                
                                .. attribute:: is_snoop_interface
                                
                                	Is snooping Interface
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface, self).__init__()

                                    self.yang_name = "interface"
                                    self.yang_parent_name = "redirect-route-database"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("rpf-address", ("rpf_address", Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress))])
                                    self._leafs = OrderedDict([
                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                        ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                                        ('expiry', (YLeaf(YType.uint64, 'expiry'), ['int'])),
                                        ('is_rpf_interface', (YLeaf(YType.boolean, 'is-rpf-interface'), ['bool'])),
                                        ('is_outgoing_interface', (YLeaf(YType.boolean, 'is-outgoing-interface'), ['bool'])),
                                        ('is_snoop_interface', (YLeaf(YType.boolean, 'is-snoop-interface'), ['bool'])),
                                    ])
                                    self.interface_name = None
                                    self.uptime = None
                                    self.expiry = None
                                    self.is_rpf_interface = None
                                    self.is_outgoing_interface = None
                                    self.is_snoop_interface = None

                                    self.rpf_address = Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress()
                                    self.rpf_address.parent = self
                                    self._children_name_map["rpf_address"] = "rpf-address"
                                    self._segment_path = lambda: "interface"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface, ['interface_name', 'uptime', 'expiry', 'is_rpf_interface', 'is_outgoing_interface', 'is_snoop_interface'], name, value)


                                class RpfAddress(Entity):
                                    """
                                    RPF Address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress, self).__init__()

                                        self.yang_name = "rpf-address"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ])
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None
                                        self._segment_path = lambda: "rpf-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class BundleInterfaces(Entity):
                        """
                        PIM ECMP RPF\-redirect bundle information
                        
                        .. attribute:: bundle_interface
                        
                        	PIM ECMP RPF\-redirect bundle interface information
                        	**type**\: list of  		 :py:class:`BundleInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces.BundleInterface>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces, self).__init__()

                            self.yang_name = "bundle-interfaces"
                            self.yang_parent_name = "rpf-redirect"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("bundle-interface", ("bundle_interface", Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces.BundleInterface))])
                            self._leafs = OrderedDict()

                            self.bundle_interface = YList(self)
                            self._segment_path = lambda: "bundle-interfaces"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces, [], name, value)


                        class BundleInterface(Entity):
                            """
                            PIM ECMP RPF\-redirect bundle interface
                            information
                            
                            .. attribute:: bundle_name
                            
                            	Bundle name
                            	**type**\: str
                            
                            	**length:** 1..32
                            
                            .. attribute:: interface_name
                            
                            	Bundle interface name
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: rpf_redirect_bundle_name
                            
                            	RPF redirect bundle name
                            	**type**\: str
                            
                            	**length:** 0..33
                            
                            .. attribute:: rpf_redirect_interface_name
                            
                            	RPF redirect interface name
                            	**type**\: str
                            
                            	**length:** 0..33
                            
                            .. attribute:: available_bandwidth
                            
                            	Bandwidth available in Kbps
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: allocated_bandwidth
                            
                            	Bandwidth allocated in Kbps
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: total_bandwidth
                            
                            	Total bandwidth used in Kbps
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: topology_bandwidth_used
                            
                            	Bandwidth used by topology in Kbps
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: snooping_bandwidth_used
                            
                            	Bandwidth used by snooped entries in Kbps
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: allocated_threshold_bandwidth
                            
                            	Configured threshold in Kbps
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: available_threshold_bandwidth
                            
                            	Available threshold in Kbps
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces.BundleInterface, self).__init__()

                                self.yang_name = "bundle-interface"
                                self.yang_parent_name = "bundle-interfaces"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('bundle_name', (YLeaf(YType.str, 'bundle-name'), ['str'])),
                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                    ('rpf_redirect_bundle_name', (YLeaf(YType.str, 'rpf-redirect-bundle-name'), ['str'])),
                                    ('rpf_redirect_interface_name', (YLeaf(YType.str, 'rpf-redirect-interface-name'), ['str'])),
                                    ('available_bandwidth', (YLeaf(YType.int32, 'available-bandwidth'), ['int'])),
                                    ('allocated_bandwidth', (YLeaf(YType.int32, 'allocated-bandwidth'), ['int'])),
                                    ('total_bandwidth', (YLeaf(YType.int32, 'total-bandwidth'), ['int'])),
                                    ('topology_bandwidth_used', (YLeaf(YType.int32, 'topology-bandwidth-used'), ['int'])),
                                    ('snooping_bandwidth_used', (YLeaf(YType.int32, 'snooping-bandwidth-used'), ['int'])),
                                    ('allocated_threshold_bandwidth', (YLeaf(YType.int32, 'allocated-threshold-bandwidth'), ['int'])),
                                    ('available_threshold_bandwidth', (YLeaf(YType.int32, 'available-threshold-bandwidth'), ['int'])),
                                ])
                                self.bundle_name = None
                                self.interface_name = None
                                self.rpf_redirect_bundle_name = None
                                self.rpf_redirect_interface_name = None
                                self.available_bandwidth = None
                                self.allocated_bandwidth = None
                                self.total_bandwidth = None
                                self.topology_bandwidth_used = None
                                self.snooping_bandwidth_used = None
                                self.allocated_threshold_bandwidth = None
                                self.available_threshold_bandwidth = None
                                self._segment_path = lambda: "bundle-interface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces.BundleInterface, ['bundle_name', 'interface_name', 'rpf_redirect_bundle_name', 'rpf_redirect_interface_name', 'available_bandwidth', 'allocated_bandwidth', 'total_bandwidth', 'topology_bandwidth_used', 'snooping_bandwidth_used', 'allocated_threshold_bandwidth', 'available_threshold_bandwidth'], name, value)


                class Tunnels(Entity):
                    """
                    Tunnels information that PIM has
                    
                    .. attribute:: tunnel
                    
                    	PIM tunnel information
                    	**type**\: list of  		 :py:class:`Tunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.Tunnels, self).__init__()

                        self.yang_name = "tunnels"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("tunnel", ("tunnel", Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel))])
                        self._leafs = OrderedDict()

                        self.tunnel = YList(self)
                        self._segment_path = lambda: "tunnels"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Tunnels, [], name, value)


                    class Tunnel(Entity):
                        """
                        PIM tunnel information
                        
                        .. attribute:: tunnel_name  (key)
                        
                        	Tunnel name
                        	**type**\: str
                        
                        	**length:** 1..64
                        
                        .. attribute:: source_address
                        
                        	Source addr known to PIM
                        	**type**\:  :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress>`
                        
                        .. attribute:: rp_address
                        
                        	RP addr known to PIM
                        	**type**\:  :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.RpAddress>`
                        
                        .. attribute:: source_address_netio
                        
                        	Source addr from netio
                        	**type**\:  :py:class:`SourceAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio>`
                        
                        .. attribute:: group_address_netio
                        
                        	Group addr from netio
                        	**type**\:  :py:class:`GroupAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio>`
                        
                        .. attribute:: vrf_name
                        
                        	VRF Name
                        	**type**\: str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel, self).__init__()

                            self.yang_name = "tunnel"
                            self.yang_parent_name = "tunnels"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['tunnel_name']
                            self._child_classes = OrderedDict([("source-address", ("source_address", Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress)), ("rp-address", ("rp_address", Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.RpAddress)), ("source-address-netio", ("source_address_netio", Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio)), ("group-address-netio", ("group_address_netio", Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio))])
                            self._leafs = OrderedDict([
                                ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                            ])
                            self.tunnel_name = None
                            self.vrf_name = None

                            self.source_address = Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"

                            self.rp_address = Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"

                            self.source_address_netio = Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio()
                            self.source_address_netio.parent = self
                            self._children_name_map["source_address_netio"] = "source-address-netio"

                            self.group_address_netio = Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio()
                            self.group_address_netio.parent = self
                            self._children_name_map["group_address_netio"] = "group-address-netio"
                            self._segment_path = lambda: "tunnel" + "[tunnel-name='" + str(self.tunnel_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel, ['tunnel_name', 'vrf_name'], name, value)


                        class SourceAddress(Entity):
                            """
                            Source addr known to PIM
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "source-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class RpAddress(Entity):
                            """
                            RP addr known to PIM
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "rp-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.RpAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class SourceAddressNetio(Entity):
                            """
                            Source addr from netio
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio, self).__init__()

                                self.yang_name = "source-address-netio"
                                self.yang_parent_name = "tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "source-address-netio"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class GroupAddressNetio(Entity):
                            """
                            Group addr from netio
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio, self).__init__()

                                self.yang_name = "group-address-netio"
                                self.yang_parent_name = "tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "group-address-netio"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class MulticastStaticRoutes(Entity):
                    """
                    PIM multicast static route table
                    
                    .. attribute:: multicast_static_route
                    
                    	PIM multicast static route information
                    	**type**\: list of  		 :py:class:`MulticastStaticRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes, self).__init__()

                        self.yang_name = "multicast-static-routes"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("multicast-static-route", ("multicast_static_route", Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute))])
                        self._leafs = OrderedDict()

                        self.multicast_static_route = YList(self)
                        self._segment_path = lambda: "multicast-static-routes"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes, [], name, value)


                    class MulticastStaticRoute(Entity):
                        """
                        PIM multicast static route information
                        
                        .. attribute:: address
                        
                        	Network address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: prefix
                        
                        	Prefix
                        	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix>`
                        
                        .. attribute:: nexthop
                        
                        	Next Hop
                        	**type**\:  :py:class:`Nexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop>`
                        
                        .. attribute:: interface_name
                        
                        	Interface Handle
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: distance
                        
                        	Distance
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: prefix_length_xr
                        
                        	Prefix Length
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: is_via_lsm
                        
                        	LSM flag
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute, self).__init__()

                            self.yang_name = "multicast-static-route"
                            self.yang_parent_name = "multicast-static-routes"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("prefix", ("prefix", Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix)), ("nexthop", ("nexthop", Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop))])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str','str'])),
                                ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ('distance', (YLeaf(YType.uint32, 'distance'), ['int'])),
                                ('prefix_length_xr', (YLeaf(YType.uint8, 'prefix-length-xr'), ['int'])),
                                ('is_via_lsm', (YLeaf(YType.boolean, 'is-via-lsm'), ['bool'])),
                            ])
                            self.address = None
                            self.prefix_length = None
                            self.interface_name = None
                            self.distance = None
                            self.prefix_length_xr = None
                            self.is_via_lsm = None

                            self.prefix = Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"

                            self.nexthop = Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop()
                            self.nexthop.parent = self
                            self._children_name_map["nexthop"] = "nexthop"
                            self._segment_path = lambda: "multicast-static-route"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute, ['address', 'prefix_length', 'interface_name', 'distance', 'prefix_length_xr', 'is_via_lsm'], name, value)


                        class Prefix(Entity):
                            """
                            Prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "multicast-static-route"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "prefix"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class Nexthop(Entity):
                            """
                            Next Hop
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop, self).__init__()

                                self.yang_name = "nexthop"
                                self.yang_parent_name = "multicast-static-route"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "nexthop"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class Neighbors(Entity):
                    """
                    PIM neighbor table
                    
                    .. attribute:: neighbor
                    
                    	PIM neighbor information
                    	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Neighbors.Neighbor>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.Neighbors, self).__init__()

                        self.yang_name = "neighbors"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("neighbor", ("neighbor", Ipv6Pim.Standby.Vrfs.Vrf.Neighbors.Neighbor))])
                        self._leafs = OrderedDict()

                        self.neighbor = YList(self)
                        self._segment_path = lambda: "neighbors"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Neighbors, [], name, value)


                    class Neighbor(Entity):
                        """
                        PIM neighbor information
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: neighbor_address
                        
                        	Neighbor address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identifier
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: expires
                        
                        	Neighbor expiry in seconds
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: expiry_timer
                        
                        	Expiry timer in seconds
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: is_this_neighbor_us
                        
                        	Is this neighbor us ?
                        	**type**\: bool
                        
                        .. attribute:: is_this_neighbor_dr
                        
                        	Is this neighbor the DR
                        	**type**\: bool
                        
                        .. attribute:: is_dr_priority_capable
                        
                        	Is this neighbor DR priority capable ?
                        	**type**\: bool
                        
                        .. attribute:: dr_priority
                        
                        	DR priority
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Is this neighbor bidir capable ?
                        	**type**\: bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Is this neighbor proxy capable?
                        	**type**\: bool
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Is this neighbor capable of batching asserts?
                        	**type**\: bool
                        
                        .. attribute:: is_ecmp_redirect_capable
                        
                        	Is this neighbor capable of Ecmp Redirect?
                        	**type**\: bool
                        
                        .. attribute:: is_bfd_state
                        
                        	Is the neighbor bfd session created
                        	**type**\: bool
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_address_xr
                        
                        	List of Neighbor Addresses
                        	**type**\: list of  		 :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Neighbors.Neighbor.NeighborAddressXr>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.Neighbors.Neighbor, self).__init__()

                            self.yang_name = "neighbor"
                            self.yang_parent_name = "neighbors"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("neighbor-address-xr", ("neighbor_address_xr", Ipv6Pim.Standby.Vrfs.Vrf.Neighbors.Neighbor.NeighborAddressXr))])
                            self._leafs = OrderedDict([
                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                                ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                                ('expires', (YLeaf(YType.uint64, 'expires'), ['int'])),
                                ('expiry_timer', (YLeaf(YType.uint64, 'expiry-timer'), ['int'])),
                                ('is_this_neighbor_us', (YLeaf(YType.boolean, 'is-this-neighbor-us'), ['bool'])),
                                ('is_this_neighbor_dr', (YLeaf(YType.boolean, 'is-this-neighbor-dr'), ['bool'])),
                                ('is_dr_priority_capable', (YLeaf(YType.boolean, 'is-dr-priority-capable'), ['bool'])),
                                ('dr_priority', (YLeaf(YType.uint32, 'dr-priority'), ['int'])),
                                ('is_bidirectional_capable', (YLeaf(YType.boolean, 'is-bidirectional-capable'), ['bool'])),
                                ('is_proxy_capable', (YLeaf(YType.boolean, 'is-proxy-capable'), ['bool'])),
                                ('is_batch_asserts_capable', (YLeaf(YType.boolean, 'is-batch-asserts-capable'), ['bool'])),
                                ('is_ecmp_redirect_capable', (YLeaf(YType.boolean, 'is-ecmp-redirect-capable'), ['bool'])),
                                ('is_bfd_state', (YLeaf(YType.boolean, 'is-bfd-state'), ['bool'])),
                                ('propagation_delay', (YLeaf(YType.uint16, 'propagation-delay'), ['int'])),
                                ('override_interval', (YLeaf(YType.uint16, 'override-interval'), ['int'])),
                            ])
                            self.interface_name = None
                            self.neighbor_address = None
                            self.interface_name_xr = None
                            self.uptime = None
                            self.expires = None
                            self.expiry_timer = None
                            self.is_this_neighbor_us = None
                            self.is_this_neighbor_dr = None
                            self.is_dr_priority_capable = None
                            self.dr_priority = None
                            self.is_bidirectional_capable = None
                            self.is_proxy_capable = None
                            self.is_batch_asserts_capable = None
                            self.is_ecmp_redirect_capable = None
                            self.is_bfd_state = None
                            self.propagation_delay = None
                            self.override_interval = None

                            self.neighbor_address_xr = YList(self)
                            self._segment_path = lambda: "neighbor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Neighbors.Neighbor, ['interface_name', 'neighbor_address', 'interface_name_xr', 'uptime', 'expires', 'expiry_timer', 'is_this_neighbor_us', 'is_this_neighbor_dr', 'is_dr_priority_capable', 'dr_priority', 'is_bidirectional_capable', 'is_proxy_capable', 'is_batch_asserts_capable', 'is_ecmp_redirect_capable', 'is_bfd_state', 'propagation_delay', 'override_interval'], name, value)


                        class NeighborAddressXr(Entity):
                            """
                            List of Neighbor Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Neighbors.Neighbor.NeighborAddressXr, self).__init__()

                                self.yang_name = "neighbor-address-xr"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "neighbor-address-xr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Standby.Vrfs.Vrf.Neighbors.Neighbor.NeighborAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


    class Active(Entity):
        """
        Active Process
        
        .. attribute:: default_context
        
        	Default Context
        	**type**\:  :py:class:`DefaultContext <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext>`
        
        .. attribute:: process
        
        	Process
        	**type**\:  :py:class:`Process <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Process>`
        
        .. attribute:: vrfs
        
        	VRF Table
        	**type**\:  :py:class:`Vrfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs>`
        
        

        """

        _prefix = 'ipv4-pim-oper'
        _revision = '2017-09-07'

        def __init__(self):
            super(Ipv6Pim.Active, self).__init__()

            self.yang_name = "active"
            self.yang_parent_name = "ipv6-pim"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("default-context", ("default_context", Ipv6Pim.Active.DefaultContext)), ("process", ("process", Ipv6Pim.Active.Process)), ("vrfs", ("vrfs", Ipv6Pim.Active.Vrfs))])
            self._leafs = OrderedDict()

            self.default_context = Ipv6Pim.Active.DefaultContext()
            self.default_context.parent = self
            self._children_name_map["default_context"] = "default-context"

            self.process = Ipv6Pim.Active.Process()
            self.process.parent = self
            self._children_name_map["process"] = "process"

            self.vrfs = Ipv6Pim.Active.Vrfs()
            self.vrfs.parent = self
            self._children_name_map["vrfs"] = "vrfs"
            self._segment_path = lambda: "active"
            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Ipv6Pim.Active, [], name, value)


        class DefaultContext(Entity):
            """
            Default Context
            
            .. attribute:: global_interfaces
            
            	PIM global interface table
            	**type**\:  :py:class:`GlobalInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GlobalInterfaces>`
            
            .. attribute:: ifrs_interfaces
            
            	PIM interfaces in forward reference store table
            	**type**\:  :py:class:`IfrsInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.IfrsInterfaces>`
            
            .. attribute:: safs
            
            	SAFI table and type
            	**type**\:  :py:class:`Safs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Safs>`
            
            .. attribute:: interface_statistics
            
            	PIM interface statistics
            	**type**\:  :py:class:`InterfaceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.InterfaceStatistics>`
            
            .. attribute:: topology_route_count
            
            	Topology route count information from PIM topology table
            	**type**\:  :py:class:`TopologyRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.TopologyRouteCount>`
            
            .. attribute:: jp_statistics
            
            	PIM join prune statistics table
            	**type**\:  :py:class:`JpStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.JpStatistics>`
            
            .. attribute:: mib_databases
            
            	PIM group database for mroute mibs table
            	**type**\:  :py:class:`MibDatabases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.MibDatabases>`
            
            .. attribute:: neighbor_old_formats
            
            	PIM neighbor table old format
            	**type**\:  :py:class:`NeighborOldFormats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.NeighborOldFormats>`
            
            .. attribute:: ifrs_summary
            
            	PIM interfaces in forward reference store summary
            	**type**\:  :py:class:`IfrsSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.IfrsSummary>`
            
            .. attribute:: ranges
            
            	PIM range list information
            	**type**\:  :py:class:`Ranges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Ranges>`
            
            .. attribute:: interface_old_formats
            
            	PIM interfaces in old format
            	**type**\:  :py:class:`InterfaceOldFormats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.InterfaceOldFormats>`
            
            .. attribute:: bsr
            
            	PIM BSR information
            	**type**\:  :py:class:`Bsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Bsr>`
            
            .. attribute:: route_policy
            
            	PIM route policy
            	**type**\:  :py:class:`RoutePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.RoutePolicy>`
            
            .. attribute:: rpf_summary
            
            	PIM RPF registration summary
            	**type**\:  :py:class:`RpfSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.RpfSummary>`
            
            .. attribute:: interfaces
            
            	PIM interfaces
            	**type**\:  :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Interfaces>`
            
            .. attribute:: net_io_tunnels
            
            	Tunnel information that NETIO has 
            	**type**\:  :py:class:`NetIoTunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.NetIoTunnels>`
            
            .. attribute:: bidir_df_states
            
            	Bidirectional PIM DF election state table
            	**type**\:  :py:class:`BidirDfStates <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.BidirDfStates>`
            
            .. attribute:: topologies
            
            	PIM topology table
            	**type**\:  :py:class:`Topologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Topologies>`
            
            .. attribute:: bgp_afs
            
            	PIM BGP SAFI table
            	**type**\:  :py:class:`BgpAfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.BgpAfs>`
            
            .. attribute:: auto_rp
            
            	PIM Auto\-RP information
            	**type**\:  :py:class:`AutoRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.AutoRp>`
            
            .. attribute:: topology_interface_flag_route_counts
            
            	Route count for topology with interface flag set
            	**type**\:  :py:class:`TopologyInterfaceFlagRouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts>`
            
            .. attribute:: group_map_sources
            
            	PIM group\-mapping with source information
            	**type**\:  :py:class:`GroupMapSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapSources>`
            
            .. attribute:: traffic_counters
            
            	PIM message traffic counters
            	**type**\:  :py:class:`TrafficCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.TrafficCounters>`
            
            .. attribute:: group_map_rpfs
            
            	PIM group mapping information
            	**type**\:  :py:class:`GroupMapRpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapRpfs>`
            
            .. attribute:: summary
            
            	PIM summary
            	**type**\:  :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Summary>`
            
            .. attribute:: gre
            
            	GRE information
            	**type**\:  :py:class:`Gre <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Gre>`
            
            .. attribute:: bidir_df_winners
            
            	Bidirectional PIM DF election winner table
            	**type**\:  :py:class:`BidirDfWinners <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.BidirDfWinners>`
            
            .. attribute:: table_contexts
            
            	PIM table context list
            	**type**\:  :py:class:`TableContexts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.TableContexts>`
            
            .. attribute:: neighbor_summaries
            
            	PIM neighbor summary table
            	**type**\:  :py:class:`NeighborSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.NeighborSummaries>`
            
            .. attribute:: context
            
            	PIM context information
            	**type**\:  :py:class:`Context <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Context>`
            
            .. attribute:: topology_entry_flag_route_counts
            
            	Route count for topology with entry flag set
            	**type**\:  :py:class:`TopologyEntryFlagRouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts>`
            
            .. attribute:: rpf_redirect
            
            	PIM ECMP RPF\-redirect bundle
            	**type**\:  :py:class:`RpfRedirect <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.RpfRedirect>`
            
            .. attribute:: tunnels
            
            	Tunnels information that PIM has
            	**type**\:  :py:class:`Tunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Tunnels>`
            
            .. attribute:: multicast_static_routes
            
            	PIM multicast static route table
            	**type**\:  :py:class:`MulticastStaticRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes>`
            
            .. attribute:: neighbors
            
            	PIM neighbor table
            	**type**\:  :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Neighbors>`
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(Ipv6Pim.Active.DefaultContext, self).__init__()

                self.yang_name = "default-context"
                self.yang_parent_name = "active"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("global-interfaces", ("global_interfaces", Ipv6Pim.Active.DefaultContext.GlobalInterfaces)), ("ifrs-interfaces", ("ifrs_interfaces", Ipv6Pim.Active.DefaultContext.IfrsInterfaces)), ("safs", ("safs", Ipv6Pim.Active.DefaultContext.Safs)), ("interface-statistics", ("interface_statistics", Ipv6Pim.Active.DefaultContext.InterfaceStatistics)), ("topology-route-count", ("topology_route_count", Ipv6Pim.Active.DefaultContext.TopologyRouteCount)), ("jp-statistics", ("jp_statistics", Ipv6Pim.Active.DefaultContext.JpStatistics)), ("mib-databases", ("mib_databases", Ipv6Pim.Active.DefaultContext.MibDatabases)), ("neighbor-old-formats", ("neighbor_old_formats", Ipv6Pim.Active.DefaultContext.NeighborOldFormats)), ("ifrs-summary", ("ifrs_summary", Ipv6Pim.Active.DefaultContext.IfrsSummary)), ("ranges", ("ranges", Ipv6Pim.Active.DefaultContext.Ranges)), ("interface-old-formats", ("interface_old_formats", Ipv6Pim.Active.DefaultContext.InterfaceOldFormats)), ("bsr", ("bsr", Ipv6Pim.Active.DefaultContext.Bsr)), ("route-policy", ("route_policy", Ipv6Pim.Active.DefaultContext.RoutePolicy)), ("rpf-summary", ("rpf_summary", Ipv6Pim.Active.DefaultContext.RpfSummary)), ("interfaces", ("interfaces", Ipv6Pim.Active.DefaultContext.Interfaces)), ("net-io-tunnels", ("net_io_tunnels", Ipv6Pim.Active.DefaultContext.NetIoTunnels)), ("bidir-df-states", ("bidir_df_states", Ipv6Pim.Active.DefaultContext.BidirDfStates)), ("topologies", ("topologies", Ipv6Pim.Active.DefaultContext.Topologies)), ("bgp-afs", ("bgp_afs", Ipv6Pim.Active.DefaultContext.BgpAfs)), ("auto-rp", ("auto_rp", Ipv6Pim.Active.DefaultContext.AutoRp)), ("topology-interface-flag-route-counts", ("topology_interface_flag_route_counts", Ipv6Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts)), ("group-map-sources", ("group_map_sources", Ipv6Pim.Active.DefaultContext.GroupMapSources)), ("traffic-counters", ("traffic_counters", Ipv6Pim.Active.DefaultContext.TrafficCounters)), ("group-map-rpfs", ("group_map_rpfs", Ipv6Pim.Active.DefaultContext.GroupMapRpfs)), ("summary", ("summary", Ipv6Pim.Active.DefaultContext.Summary)), ("gre", ("gre", Ipv6Pim.Active.DefaultContext.Gre)), ("bidir-df-winners", ("bidir_df_winners", Ipv6Pim.Active.DefaultContext.BidirDfWinners)), ("table-contexts", ("table_contexts", Ipv6Pim.Active.DefaultContext.TableContexts)), ("neighbor-summaries", ("neighbor_summaries", Ipv6Pim.Active.DefaultContext.NeighborSummaries)), ("context", ("context", Ipv6Pim.Active.DefaultContext.Context)), ("topology-entry-flag-route-counts", ("topology_entry_flag_route_counts", Ipv6Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts)), ("rpf-redirect", ("rpf_redirect", Ipv6Pim.Active.DefaultContext.RpfRedirect)), ("tunnels", ("tunnels", Ipv6Pim.Active.DefaultContext.Tunnels)), ("multicast-static-routes", ("multicast_static_routes", Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes)), ("neighbors", ("neighbors", Ipv6Pim.Active.DefaultContext.Neighbors))])
                self._leafs = OrderedDict()

                self.global_interfaces = Ipv6Pim.Active.DefaultContext.GlobalInterfaces()
                self.global_interfaces.parent = self
                self._children_name_map["global_interfaces"] = "global-interfaces"

                self.ifrs_interfaces = Ipv6Pim.Active.DefaultContext.IfrsInterfaces()
                self.ifrs_interfaces.parent = self
                self._children_name_map["ifrs_interfaces"] = "ifrs-interfaces"

                self.safs = Ipv6Pim.Active.DefaultContext.Safs()
                self.safs.parent = self
                self._children_name_map["safs"] = "safs"

                self.interface_statistics = Ipv6Pim.Active.DefaultContext.InterfaceStatistics()
                self.interface_statistics.parent = self
                self._children_name_map["interface_statistics"] = "interface-statistics"

                self.topology_route_count = Ipv6Pim.Active.DefaultContext.TopologyRouteCount()
                self.topology_route_count.parent = self
                self._children_name_map["topology_route_count"] = "topology-route-count"

                self.jp_statistics = Ipv6Pim.Active.DefaultContext.JpStatistics()
                self.jp_statistics.parent = self
                self._children_name_map["jp_statistics"] = "jp-statistics"

                self.mib_databases = Ipv6Pim.Active.DefaultContext.MibDatabases()
                self.mib_databases.parent = self
                self._children_name_map["mib_databases"] = "mib-databases"

                self.neighbor_old_formats = Ipv6Pim.Active.DefaultContext.NeighborOldFormats()
                self.neighbor_old_formats.parent = self
                self._children_name_map["neighbor_old_formats"] = "neighbor-old-formats"

                self.ifrs_summary = Ipv6Pim.Active.DefaultContext.IfrsSummary()
                self.ifrs_summary.parent = self
                self._children_name_map["ifrs_summary"] = "ifrs-summary"

                self.ranges = Ipv6Pim.Active.DefaultContext.Ranges()
                self.ranges.parent = self
                self._children_name_map["ranges"] = "ranges"

                self.interface_old_formats = Ipv6Pim.Active.DefaultContext.InterfaceOldFormats()
                self.interface_old_formats.parent = self
                self._children_name_map["interface_old_formats"] = "interface-old-formats"

                self.bsr = Ipv6Pim.Active.DefaultContext.Bsr()
                self.bsr.parent = self
                self._children_name_map["bsr"] = "bsr"

                self.route_policy = Ipv6Pim.Active.DefaultContext.RoutePolicy()
                self.route_policy.parent = self
                self._children_name_map["route_policy"] = "route-policy"

                self.rpf_summary = Ipv6Pim.Active.DefaultContext.RpfSummary()
                self.rpf_summary.parent = self
                self._children_name_map["rpf_summary"] = "rpf-summary"

                self.interfaces = Ipv6Pim.Active.DefaultContext.Interfaces()
                self.interfaces.parent = self
                self._children_name_map["interfaces"] = "interfaces"

                self.net_io_tunnels = Ipv6Pim.Active.DefaultContext.NetIoTunnels()
                self.net_io_tunnels.parent = self
                self._children_name_map["net_io_tunnels"] = "net-io-tunnels"

                self.bidir_df_states = Ipv6Pim.Active.DefaultContext.BidirDfStates()
                self.bidir_df_states.parent = self
                self._children_name_map["bidir_df_states"] = "bidir-df-states"

                self.topologies = Ipv6Pim.Active.DefaultContext.Topologies()
                self.topologies.parent = self
                self._children_name_map["topologies"] = "topologies"

                self.bgp_afs = Ipv6Pim.Active.DefaultContext.BgpAfs()
                self.bgp_afs.parent = self
                self._children_name_map["bgp_afs"] = "bgp-afs"

                self.auto_rp = Ipv6Pim.Active.DefaultContext.AutoRp()
                self.auto_rp.parent = self
                self._children_name_map["auto_rp"] = "auto-rp"

                self.topology_interface_flag_route_counts = Ipv6Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts()
                self.topology_interface_flag_route_counts.parent = self
                self._children_name_map["topology_interface_flag_route_counts"] = "topology-interface-flag-route-counts"

                self.group_map_sources = Ipv6Pim.Active.DefaultContext.GroupMapSources()
                self.group_map_sources.parent = self
                self._children_name_map["group_map_sources"] = "group-map-sources"

                self.traffic_counters = Ipv6Pim.Active.DefaultContext.TrafficCounters()
                self.traffic_counters.parent = self
                self._children_name_map["traffic_counters"] = "traffic-counters"

                self.group_map_rpfs = Ipv6Pim.Active.DefaultContext.GroupMapRpfs()
                self.group_map_rpfs.parent = self
                self._children_name_map["group_map_rpfs"] = "group-map-rpfs"

                self.summary = Ipv6Pim.Active.DefaultContext.Summary()
                self.summary.parent = self
                self._children_name_map["summary"] = "summary"

                self.gre = Ipv6Pim.Active.DefaultContext.Gre()
                self.gre.parent = self
                self._children_name_map["gre"] = "gre"

                self.bidir_df_winners = Ipv6Pim.Active.DefaultContext.BidirDfWinners()
                self.bidir_df_winners.parent = self
                self._children_name_map["bidir_df_winners"] = "bidir-df-winners"

                self.table_contexts = Ipv6Pim.Active.DefaultContext.TableContexts()
                self.table_contexts.parent = self
                self._children_name_map["table_contexts"] = "table-contexts"

                self.neighbor_summaries = Ipv6Pim.Active.DefaultContext.NeighborSummaries()
                self.neighbor_summaries.parent = self
                self._children_name_map["neighbor_summaries"] = "neighbor-summaries"

                self.context = Ipv6Pim.Active.DefaultContext.Context()
                self.context.parent = self
                self._children_name_map["context"] = "context"

                self.topology_entry_flag_route_counts = Ipv6Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts()
                self.topology_entry_flag_route_counts.parent = self
                self._children_name_map["topology_entry_flag_route_counts"] = "topology-entry-flag-route-counts"

                self.rpf_redirect = Ipv6Pim.Active.DefaultContext.RpfRedirect()
                self.rpf_redirect.parent = self
                self._children_name_map["rpf_redirect"] = "rpf-redirect"

                self.tunnels = Ipv6Pim.Active.DefaultContext.Tunnels()
                self.tunnels.parent = self
                self._children_name_map["tunnels"] = "tunnels"

                self.multicast_static_routes = Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes()
                self.multicast_static_routes.parent = self
                self._children_name_map["multicast_static_routes"] = "multicast-static-routes"

                self.neighbors = Ipv6Pim.Active.DefaultContext.Neighbors()
                self.neighbors.parent = self
                self._children_name_map["neighbors"] = "neighbors"
                self._segment_path = lambda: "default-context"
                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Ipv6Pim.Active.DefaultContext, [], name, value)


            class GlobalInterfaces(Entity):
                """
                PIM global interface table
                
                .. attribute:: global_interface
                
                	PIM interface name
                	**type**\: list of  		 :py:class:`GlobalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.GlobalInterfaces, self).__init__()

                    self.yang_name = "global-interfaces"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("global-interface", ("global_interface", Ipv6Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface))])
                    self._leafs = OrderedDict()

                    self.global_interface = YList(self)
                    self._segment_path = lambda: "global-interfaces"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.GlobalInterfaces, [], name, value)


                class GlobalInterface(Entity):
                    """
                    PIM interface name
                    
                    .. attribute:: interface_name  (key)
                    
                    	Interface name
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: dr_address
                    
                    	PIM Designated Router
                    	**type**\:  :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress>`
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identfier
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: interface_address_mask
                    
                    	Interface IP Address Mask
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: is_enabled
                    
                    	Is PIM enabled on this IF ?
                    	**type**\: bool
                    
                    .. attribute:: neighbor_count
                    
                    	No. of neighbors on this IF
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: external_neighbor_count
                    
                    	No. of external neighbors on this IF
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: hello_interval
                    
                    	Hello Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dr_priority
                    
                    	DR Priority
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_expiry
                    
                    	Hello Timer Expiry
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: are_we_dr
                    
                    	Are we the DR on this IF ?
                    	**type**\: bool
                    
                    .. attribute:: bfd_enabled
                    
                    	BFD state
                    	**type**\: bool
                    
                    .. attribute:: bfd_interval
                    
                    	BFD Interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bfd_multiplier
                    
                    	BFD Multiplier
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_interface
                    
                    	 is this a Virtual Interfaces ?
                    	**type**\: bool
                    
                    .. attribute:: passive_interface
                    
                    	Passive PIM interface
                    	**type**\: bool
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\: str
                    
                    .. attribute:: join_prune_interval
                    
                    	Join\-Prune Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: prune_delay_enabled
                    
                    	Prune Delay Enabled
                    	**type**\: bool
                    
                    .. attribute:: configured_propagation_delay
                    
                    	Configured Propagation Delay
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_override_interval
                    
                    	Configured Override Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: generation_id
                    
                    	Generation Identifier
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Bidir Capable
                    	**type**\: bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Proxy Capable
                    	**type**\: bool
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Batch Asserts Capable
                    	**type**\: bool
                    
                    .. attribute:: idb_oor_enabled
                    
                    	Interface oor enabled
                    	**type**\: bool
                    
                    .. attribute:: idb_acl_provided
                    
                    	ACL name provided
                    	**type**\: bool
                    
                    .. attribute:: idb_max_count
                    
                    	Interface ole max count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_threshold_count
                    
                    	Interface ole threshold count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_current_count
                    
                    	Interface ole current count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_acl_name
                    
                    	Interface ole ACL Name
                    	**type**\: str
                    
                    	**length:** 0..64
                    
                    .. attribute:: interface_address
                    
                    	List of Interface IP Addresses
                    	**type**\: list of  		 :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.InterfaceAddress>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface, self).__init__()

                        self.yang_name = "global-interface"
                        self.yang_parent_name = "global-interfaces"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['interface_name']
                        self._child_classes = OrderedDict([("dr-address", ("dr_address", Ipv6Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress)), ("interface-address", ("interface_address", Ipv6Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.InterfaceAddress))])
                        self._leafs = OrderedDict([
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                            ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                            ('interface_address_mask', (YLeaf(YType.uint8, 'interface-address-mask'), ['int'])),
                            ('is_enabled', (YLeaf(YType.boolean, 'is-enabled'), ['bool'])),
                            ('neighbor_count', (YLeaf(YType.uint16, 'neighbor-count'), ['int'])),
                            ('external_neighbor_count', (YLeaf(YType.uint16, 'external-neighbor-count'), ['int'])),
                            ('hello_interval', (YLeaf(YType.uint16, 'hello-interval'), ['int'])),
                            ('dr_priority', (YLeaf(YType.uint32, 'dr-priority'), ['int'])),
                            ('hello_expiry', (YLeaf(YType.uint64, 'hello-expiry'), ['int'])),
                            ('are_we_dr', (YLeaf(YType.boolean, 'are-we-dr'), ['bool'])),
                            ('bfd_enabled', (YLeaf(YType.boolean, 'bfd-enabled'), ['bool'])),
                            ('bfd_interval', (YLeaf(YType.uint32, 'bfd-interval'), ['int'])),
                            ('bfd_multiplier', (YLeaf(YType.uint32, 'bfd-multiplier'), ['int'])),
                            ('virtual_interface', (YLeaf(YType.boolean, 'virtual-interface'), ['bool'])),
                            ('passive_interface', (YLeaf(YType.boolean, 'passive-interface'), ['bool'])),
                            ('neighbor_filter_name', (YLeaf(YType.str, 'neighbor-filter-name'), ['str'])),
                            ('join_prune_interval', (YLeaf(YType.uint16, 'join-prune-interval'), ['int'])),
                            ('prune_delay_enabled', (YLeaf(YType.boolean, 'prune-delay-enabled'), ['bool'])),
                            ('configured_propagation_delay', (YLeaf(YType.uint16, 'configured-propagation-delay'), ['int'])),
                            ('propagation_delay', (YLeaf(YType.uint16, 'propagation-delay'), ['int'])),
                            ('configured_override_interval', (YLeaf(YType.uint16, 'configured-override-interval'), ['int'])),
                            ('override_interval', (YLeaf(YType.uint16, 'override-interval'), ['int'])),
                            ('generation_id', (YLeaf(YType.uint32, 'generation-id'), ['int'])),
                            ('is_bidirectional_capable', (YLeaf(YType.boolean, 'is-bidirectional-capable'), ['bool'])),
                            ('is_proxy_capable', (YLeaf(YType.boolean, 'is-proxy-capable'), ['bool'])),
                            ('is_batch_asserts_capable', (YLeaf(YType.boolean, 'is-batch-asserts-capable'), ['bool'])),
                            ('idb_oor_enabled', (YLeaf(YType.boolean, 'idb-oor-enabled'), ['bool'])),
                            ('idb_acl_provided', (YLeaf(YType.boolean, 'idb-acl-provided'), ['bool'])),
                            ('idb_max_count', (YLeaf(YType.uint32, 'idb-max-count'), ['int'])),
                            ('idb_threshold_count', (YLeaf(YType.uint32, 'idb-threshold-count'), ['int'])),
                            ('idb_current_count', (YLeaf(YType.uint32, 'idb-current-count'), ['int'])),
                            ('idb_acl_name', (YLeaf(YType.str, 'idb-acl-name'), ['str'])),
                        ])
                        self.interface_name = None
                        self.interface_name_xr = None
                        self.interface_address_mask = None
                        self.is_enabled = None
                        self.neighbor_count = None
                        self.external_neighbor_count = None
                        self.hello_interval = None
                        self.dr_priority = None
                        self.hello_expiry = None
                        self.are_we_dr = None
                        self.bfd_enabled = None
                        self.bfd_interval = None
                        self.bfd_multiplier = None
                        self.virtual_interface = None
                        self.passive_interface = None
                        self.neighbor_filter_name = None
                        self.join_prune_interval = None
                        self.prune_delay_enabled = None
                        self.configured_propagation_delay = None
                        self.propagation_delay = None
                        self.configured_override_interval = None
                        self.override_interval = None
                        self.generation_id = None
                        self.is_bidirectional_capable = None
                        self.is_proxy_capable = None
                        self.is_batch_asserts_capable = None
                        self.idb_oor_enabled = None
                        self.idb_acl_provided = None
                        self.idb_max_count = None
                        self.idb_threshold_count = None
                        self.idb_current_count = None
                        self.idb_acl_name = None

                        self.dr_address = Ipv6Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress()
                        self.dr_address.parent = self
                        self._children_name_map["dr_address"] = "dr-address"

                        self.interface_address = YList(self)
                        self._segment_path = lambda: "global-interface" + "[interface-name='" + str(self.interface_name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/global-interfaces/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface, ['interface_name', 'interface_name_xr', 'interface_address_mask', 'is_enabled', 'neighbor_count', 'external_neighbor_count', 'hello_interval', 'dr_priority', 'hello_expiry', 'are_we_dr', 'bfd_enabled', 'bfd_interval', 'bfd_multiplier', 'virtual_interface', 'passive_interface', 'neighbor_filter_name', 'join_prune_interval', 'prune_delay_enabled', 'configured_propagation_delay', 'propagation_delay', 'configured_override_interval', 'override_interval', 'generation_id', 'is_bidirectional_capable', 'is_proxy_capable', 'is_batch_asserts_capable', 'idb_oor_enabled', 'idb_acl_provided', 'idb_max_count', 'idb_threshold_count', 'idb_current_count', 'idb_acl_name'], name, value)


                    class DrAddress(Entity):
                        """
                        PIM Designated Router
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress, self).__init__()

                            self.yang_name = "dr-address"
                            self.yang_parent_name = "global-interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "dr-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class InterfaceAddress(Entity):
                        """
                        List of Interface IP Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.InterfaceAddress, self).__init__()

                            self.yang_name = "interface-address"
                            self.yang_parent_name = "global-interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "interface-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.InterfaceAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class IfrsInterfaces(Entity):
                """
                PIM interfaces in forward reference store table
                
                .. attribute:: ifrs_interface
                
                	PIM IFRS interface information
                	**type**\: list of  		 :py:class:`IfrsInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.IfrsInterfaces, self).__init__()

                    self.yang_name = "ifrs-interfaces"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ifrs-interface", ("ifrs_interface", Ipv6Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface))])
                    self._leafs = OrderedDict()

                    self.ifrs_interface = YList(self)
                    self._segment_path = lambda: "ifrs-interfaces"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.IfrsInterfaces, [], name, value)


                class IfrsInterface(Entity):
                    """
                    PIM IFRS interface information
                    
                    .. attribute:: interface_name  (key)
                    
                    	Interface name
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: dr_address
                    
                    	PIM Designated Router
                    	**type**\:  :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress>`
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identfier
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: interface_address_mask
                    
                    	Interface IP Address Mask
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: is_enabled
                    
                    	Is PIM enabled on this IF ?
                    	**type**\: bool
                    
                    .. attribute:: neighbor_count
                    
                    	No. of neighbors on this IF
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: external_neighbor_count
                    
                    	No. of external neighbors on this IF
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: hello_interval
                    
                    	Hello Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dr_priority
                    
                    	DR Priority
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_expiry
                    
                    	Hello Timer Expiry
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: are_we_dr
                    
                    	Are we the DR on this IF ?
                    	**type**\: bool
                    
                    .. attribute:: bfd_enabled
                    
                    	BFD state
                    	**type**\: bool
                    
                    .. attribute:: bfd_interval
                    
                    	BFD Interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bfd_multiplier
                    
                    	BFD Multiplier
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_interface
                    
                    	 is this a Virtual Interfaces ?
                    	**type**\: bool
                    
                    .. attribute:: passive_interface
                    
                    	Passive PIM interface
                    	**type**\: bool
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\: str
                    
                    .. attribute:: join_prune_interval
                    
                    	Join\-Prune Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: prune_delay_enabled
                    
                    	Prune Delay Enabled
                    	**type**\: bool
                    
                    .. attribute:: configured_propagation_delay
                    
                    	Configured Propagation Delay
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_override_interval
                    
                    	Configured Override Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: generation_id
                    
                    	Generation Identifier
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Bidir Capable
                    	**type**\: bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Proxy Capable
                    	**type**\: bool
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Batch Asserts Capable
                    	**type**\: bool
                    
                    .. attribute:: idb_oor_enabled
                    
                    	Interface oor enabled
                    	**type**\: bool
                    
                    .. attribute:: idb_acl_provided
                    
                    	ACL name provided
                    	**type**\: bool
                    
                    .. attribute:: idb_max_count
                    
                    	Interface ole max count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_threshold_count
                    
                    	Interface ole threshold count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_current_count
                    
                    	Interface ole current count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_acl_name
                    
                    	Interface ole ACL Name
                    	**type**\: str
                    
                    	**length:** 0..64
                    
                    .. attribute:: interface_address
                    
                    	List of Interface IP Addresses
                    	**type**\: list of  		 :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.InterfaceAddress>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface, self).__init__()

                        self.yang_name = "ifrs-interface"
                        self.yang_parent_name = "ifrs-interfaces"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['interface_name']
                        self._child_classes = OrderedDict([("dr-address", ("dr_address", Ipv6Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress)), ("interface-address", ("interface_address", Ipv6Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.InterfaceAddress))])
                        self._leafs = OrderedDict([
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                            ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                            ('interface_address_mask', (YLeaf(YType.uint8, 'interface-address-mask'), ['int'])),
                            ('is_enabled', (YLeaf(YType.boolean, 'is-enabled'), ['bool'])),
                            ('neighbor_count', (YLeaf(YType.uint16, 'neighbor-count'), ['int'])),
                            ('external_neighbor_count', (YLeaf(YType.uint16, 'external-neighbor-count'), ['int'])),
                            ('hello_interval', (YLeaf(YType.uint16, 'hello-interval'), ['int'])),
                            ('dr_priority', (YLeaf(YType.uint32, 'dr-priority'), ['int'])),
                            ('hello_expiry', (YLeaf(YType.uint64, 'hello-expiry'), ['int'])),
                            ('are_we_dr', (YLeaf(YType.boolean, 'are-we-dr'), ['bool'])),
                            ('bfd_enabled', (YLeaf(YType.boolean, 'bfd-enabled'), ['bool'])),
                            ('bfd_interval', (YLeaf(YType.uint32, 'bfd-interval'), ['int'])),
                            ('bfd_multiplier', (YLeaf(YType.uint32, 'bfd-multiplier'), ['int'])),
                            ('virtual_interface', (YLeaf(YType.boolean, 'virtual-interface'), ['bool'])),
                            ('passive_interface', (YLeaf(YType.boolean, 'passive-interface'), ['bool'])),
                            ('neighbor_filter_name', (YLeaf(YType.str, 'neighbor-filter-name'), ['str'])),
                            ('join_prune_interval', (YLeaf(YType.uint16, 'join-prune-interval'), ['int'])),
                            ('prune_delay_enabled', (YLeaf(YType.boolean, 'prune-delay-enabled'), ['bool'])),
                            ('configured_propagation_delay', (YLeaf(YType.uint16, 'configured-propagation-delay'), ['int'])),
                            ('propagation_delay', (YLeaf(YType.uint16, 'propagation-delay'), ['int'])),
                            ('configured_override_interval', (YLeaf(YType.uint16, 'configured-override-interval'), ['int'])),
                            ('override_interval', (YLeaf(YType.uint16, 'override-interval'), ['int'])),
                            ('generation_id', (YLeaf(YType.uint32, 'generation-id'), ['int'])),
                            ('is_bidirectional_capable', (YLeaf(YType.boolean, 'is-bidirectional-capable'), ['bool'])),
                            ('is_proxy_capable', (YLeaf(YType.boolean, 'is-proxy-capable'), ['bool'])),
                            ('is_batch_asserts_capable', (YLeaf(YType.boolean, 'is-batch-asserts-capable'), ['bool'])),
                            ('idb_oor_enabled', (YLeaf(YType.boolean, 'idb-oor-enabled'), ['bool'])),
                            ('idb_acl_provided', (YLeaf(YType.boolean, 'idb-acl-provided'), ['bool'])),
                            ('idb_max_count', (YLeaf(YType.uint32, 'idb-max-count'), ['int'])),
                            ('idb_threshold_count', (YLeaf(YType.uint32, 'idb-threshold-count'), ['int'])),
                            ('idb_current_count', (YLeaf(YType.uint32, 'idb-current-count'), ['int'])),
                            ('idb_acl_name', (YLeaf(YType.str, 'idb-acl-name'), ['str'])),
                        ])
                        self.interface_name = None
                        self.interface_name_xr = None
                        self.interface_address_mask = None
                        self.is_enabled = None
                        self.neighbor_count = None
                        self.external_neighbor_count = None
                        self.hello_interval = None
                        self.dr_priority = None
                        self.hello_expiry = None
                        self.are_we_dr = None
                        self.bfd_enabled = None
                        self.bfd_interval = None
                        self.bfd_multiplier = None
                        self.virtual_interface = None
                        self.passive_interface = None
                        self.neighbor_filter_name = None
                        self.join_prune_interval = None
                        self.prune_delay_enabled = None
                        self.configured_propagation_delay = None
                        self.propagation_delay = None
                        self.configured_override_interval = None
                        self.override_interval = None
                        self.generation_id = None
                        self.is_bidirectional_capable = None
                        self.is_proxy_capable = None
                        self.is_batch_asserts_capable = None
                        self.idb_oor_enabled = None
                        self.idb_acl_provided = None
                        self.idb_max_count = None
                        self.idb_threshold_count = None
                        self.idb_current_count = None
                        self.idb_acl_name = None

                        self.dr_address = Ipv6Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress()
                        self.dr_address.parent = self
                        self._children_name_map["dr_address"] = "dr-address"

                        self.interface_address = YList(self)
                        self._segment_path = lambda: "ifrs-interface" + "[interface-name='" + str(self.interface_name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/ifrs-interfaces/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface, ['interface_name', 'interface_name_xr', 'interface_address_mask', 'is_enabled', 'neighbor_count', 'external_neighbor_count', 'hello_interval', 'dr_priority', 'hello_expiry', 'are_we_dr', 'bfd_enabled', 'bfd_interval', 'bfd_multiplier', 'virtual_interface', 'passive_interface', 'neighbor_filter_name', 'join_prune_interval', 'prune_delay_enabled', 'configured_propagation_delay', 'propagation_delay', 'configured_override_interval', 'override_interval', 'generation_id', 'is_bidirectional_capable', 'is_proxy_capable', 'is_batch_asserts_capable', 'idb_oor_enabled', 'idb_acl_provided', 'idb_max_count', 'idb_threshold_count', 'idb_current_count', 'idb_acl_name'], name, value)


                    class DrAddress(Entity):
                        """
                        PIM Designated Router
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress, self).__init__()

                            self.yang_name = "dr-address"
                            self.yang_parent_name = "ifrs-interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "dr-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class InterfaceAddress(Entity):
                        """
                        List of Interface IP Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.InterfaceAddress, self).__init__()

                            self.yang_name = "interface-address"
                            self.yang_parent_name = "ifrs-interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "interface-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.InterfaceAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class Safs(Entity):
                """
                SAFI table and type
                
                .. attribute:: saf
                
                	SAF name 
                	**type**\: list of  		 :py:class:`Saf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Safs.Saf>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.Safs, self).__init__()

                    self.yang_name = "safs"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("saf", ("saf", Ipv6Pim.Active.DefaultContext.Safs.Saf))])
                    self._leafs = OrderedDict()

                    self.saf = YList(self)
                    self._segment_path = lambda: "safs"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.Safs, [], name, value)


                class Saf(Entity):
                    """
                    SAF name 
                    
                    .. attribute:: rpf_hash_source_groups
                    
                    	PIM RPF multipath hash outcome
                    	**type**\:  :py:class:`RpfHashSourceGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups>`
                    
                    .. attribute:: rpf_hash_sources
                    
                    	PIM RPF multipath hash outcome
                    	**type**\:  :py:class:`RpfHashSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources>`
                    
                    .. attribute:: rpfs
                    
                    	PIM RPF information table
                    	**type**\:  :py:class:`Rpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs>`
                    
                    .. attribute:: saf_name
                    
                    	SAF name 
                    	**type**\:  :py:class:`PimSafi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimSafi>`
                    
                    .. attribute:: topology_name
                    
                    	Topology name 
                    	**type**\: str
                    
                    	**length:** 1..32
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.Safs.Saf, self).__init__()

                        self.yang_name = "saf"
                        self.yang_parent_name = "safs"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("rpf-hash-source-groups", ("rpf_hash_source_groups", Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups)), ("rpf-hash-sources", ("rpf_hash_sources", Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources)), ("rpfs", ("rpfs", Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs))])
                        self._leafs = OrderedDict([
                            ('saf_name', (YLeaf(YType.enumeration, 'saf-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimSafi', '')])),
                            ('topology_name', (YLeaf(YType.str, 'topology-name'), ['str'])),
                        ])
                        self.saf_name = None
                        self.topology_name = None

                        self.rpf_hash_source_groups = Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups()
                        self.rpf_hash_source_groups.parent = self
                        self._children_name_map["rpf_hash_source_groups"] = "rpf-hash-source-groups"

                        self.rpf_hash_sources = Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources()
                        self.rpf_hash_sources.parent = self
                        self._children_name_map["rpf_hash_sources"] = "rpf-hash-sources"

                        self.rpfs = Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs()
                        self.rpfs.parent = self
                        self._children_name_map["rpfs"] = "rpfs"
                        self._segment_path = lambda: "saf"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/safs/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.Safs.Saf, ['saf_name', 'topology_name'], name, value)


                    class RpfHashSourceGroups(Entity):
                        """
                        PIM RPF multipath hash outcome
                        
                        .. attribute:: rpf_hash_source_group
                        
                        	PIM RPF hash outcome for S,G
                        	**type**\: list of  		 :py:class:`RpfHashSourceGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups, self).__init__()

                            self.yang_name = "rpf-hash-source-groups"
                            self.yang_parent_name = "saf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rpf-hash-source-group", ("rpf_hash_source_group", Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup))])
                            self._leafs = OrderedDict()

                            self.rpf_hash_source_group = YList(self)
                            self._segment_path = lambda: "rpf-hash-source-groups"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/safs/saf/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups, [], name, value)


                        class RpfHashSourceGroup(Entity):
                            """
                            PIM RPF hash outcome for S,G
                            
                            .. attribute:: source_address
                            
                            	Source address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: group_address
                            
                            	Group address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: mask_length
                            
                            	Hash mask length
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mofrr
                            
                            	MOFRR
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: next_hop_address
                            
                            	Next hop neighbor address
                            	**type**\:  :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress>`
                            
                            .. attribute:: secondary_next_hop_address
                            
                            	Secondary Next hop neighbor address
                            	**type**\:  :py:class:`SecondaryNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress>`
                            
                            .. attribute:: next_hop_multipath_enabled
                            
                            	Next hop multipath enabled?
                            	**type**\: bool
                            
                            .. attribute:: next_hop_interface
                            
                            	Next hop neighbor interface
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: secondary_next_hop_interface
                            
                            	Secondary Next hop neighbor interface
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup, self).__init__()

                                self.yang_name = "rpf-hash-source-group"
                                self.yang_parent_name = "rpf-hash-source-groups"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("next-hop-address", ("next_hop_address", Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress)), ("secondary-next-hop-address", ("secondary_next_hop_address", Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress))])
                                self._leafs = OrderedDict([
                                    ('source_address', (YLeaf(YType.str, 'source-address'), ['str','str'])),
                                    ('group_address', (YLeaf(YType.str, 'group-address'), ['str','str'])),
                                    ('mask_length', (YLeaf(YType.uint32, 'mask-length'), ['int'])),
                                    ('mofrr', (YLeaf(YType.uint32, 'mofrr'), ['int'])),
                                    ('next_hop_multipath_enabled', (YLeaf(YType.boolean, 'next-hop-multipath-enabled'), ['bool'])),
                                    ('next_hop_interface', (YLeaf(YType.str, 'next-hop-interface'), ['str'])),
                                    ('secondary_next_hop_interface', (YLeaf(YType.str, 'secondary-next-hop-interface'), ['str'])),
                                ])
                                self.source_address = None
                                self.group_address = None
                                self.mask_length = None
                                self.mofrr = None
                                self.next_hop_multipath_enabled = None
                                self.next_hop_interface = None
                                self.secondary_next_hop_interface = None

                                self.next_hop_address = Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress()
                                self.next_hop_address.parent = self
                                self._children_name_map["next_hop_address"] = "next-hop-address"

                                self.secondary_next_hop_address = Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress()
                                self.secondary_next_hop_address.parent = self
                                self._children_name_map["secondary_next_hop_address"] = "secondary-next-hop-address"
                                self._segment_path = lambda: "rpf-hash-source-group"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/safs/saf/rpf-hash-source-groups/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup, ['source_address', 'group_address', 'mask_length', 'mofrr', 'next_hop_multipath_enabled', 'next_hop_interface', 'secondary_next_hop_interface'], name, value)


                            class NextHopAddress(Entity):
                                """
                                Next hop neighbor address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress, self).__init__()

                                    self.yang_name = "next-hop-address"
                                    self.yang_parent_name = "rpf-hash-source-group"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "next-hop-address"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/safs/saf/rpf-hash-source-groups/rpf-hash-source-group/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                            class SecondaryNextHopAddress(Entity):
                                """
                                Secondary Next hop neighbor address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress, self).__init__()

                                    self.yang_name = "secondary-next-hop-address"
                                    self.yang_parent_name = "rpf-hash-source-group"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "secondary-next-hop-address"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/safs/saf/rpf-hash-source-groups/rpf-hash-source-group/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class RpfHashSources(Entity):
                        """
                        PIM RPF multipath hash outcome
                        
                        .. attribute:: rpf_hash_source
                        
                        	PIM RPF hash outcome for S,G
                        	**type**\: list of  		 :py:class:`RpfHashSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources, self).__init__()

                            self.yang_name = "rpf-hash-sources"
                            self.yang_parent_name = "saf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rpf-hash-source", ("rpf_hash_source", Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource))])
                            self._leafs = OrderedDict()

                            self.rpf_hash_source = YList(self)
                            self._segment_path = lambda: "rpf-hash-sources"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/safs/saf/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources, [], name, value)


                        class RpfHashSource(Entity):
                            """
                            PIM RPF hash outcome for S,G
                            
                            .. attribute:: source_address
                            
                            	Source address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: mofrr
                            
                            	MOFRR
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: next_hop_address
                            
                            	Next hop neighbor address
                            	**type**\:  :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress>`
                            
                            .. attribute:: secondary_next_hop_address
                            
                            	Secondary Next hop neighbor address
                            	**type**\:  :py:class:`SecondaryNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress>`
                            
                            .. attribute:: next_hop_multipath_enabled
                            
                            	Next hop multipath enabled?
                            	**type**\: bool
                            
                            .. attribute:: next_hop_interface
                            
                            	Next hop neighbor interface
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: secondary_next_hop_interface
                            
                            	Secondary Next hop neighbor interface
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource, self).__init__()

                                self.yang_name = "rpf-hash-source"
                                self.yang_parent_name = "rpf-hash-sources"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("next-hop-address", ("next_hop_address", Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress)), ("secondary-next-hop-address", ("secondary_next_hop_address", Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress))])
                                self._leafs = OrderedDict([
                                    ('source_address', (YLeaf(YType.str, 'source-address'), ['str','str'])),
                                    ('mofrr', (YLeaf(YType.uint32, 'mofrr'), ['int'])),
                                    ('next_hop_multipath_enabled', (YLeaf(YType.boolean, 'next-hop-multipath-enabled'), ['bool'])),
                                    ('next_hop_interface', (YLeaf(YType.str, 'next-hop-interface'), ['str'])),
                                    ('secondary_next_hop_interface', (YLeaf(YType.str, 'secondary-next-hop-interface'), ['str'])),
                                ])
                                self.source_address = None
                                self.mofrr = None
                                self.next_hop_multipath_enabled = None
                                self.next_hop_interface = None
                                self.secondary_next_hop_interface = None

                                self.next_hop_address = Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress()
                                self.next_hop_address.parent = self
                                self._children_name_map["next_hop_address"] = "next-hop-address"

                                self.secondary_next_hop_address = Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress()
                                self.secondary_next_hop_address.parent = self
                                self._children_name_map["secondary_next_hop_address"] = "secondary-next-hop-address"
                                self._segment_path = lambda: "rpf-hash-source"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/safs/saf/rpf-hash-sources/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource, ['source_address', 'mofrr', 'next_hop_multipath_enabled', 'next_hop_interface', 'secondary_next_hop_interface'], name, value)


                            class NextHopAddress(Entity):
                                """
                                Next hop neighbor address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress, self).__init__()

                                    self.yang_name = "next-hop-address"
                                    self.yang_parent_name = "rpf-hash-source"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "next-hop-address"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/safs/saf/rpf-hash-sources/rpf-hash-source/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                            class SecondaryNextHopAddress(Entity):
                                """
                                Secondary Next hop neighbor address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress, self).__init__()

                                    self.yang_name = "secondary-next-hop-address"
                                    self.yang_parent_name = "rpf-hash-source"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "secondary-next-hop-address"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/safs/saf/rpf-hash-sources/rpf-hash-source/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class Rpfs(Entity):
                        """
                        PIM RPF information table
                        
                        .. attribute:: rpf
                        
                        	PIM RPF information
                        	**type**\: list of  		 :py:class:`Rpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs, self).__init__()

                            self.yang_name = "rpfs"
                            self.yang_parent_name = "saf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rpf", ("rpf", Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf))])
                            self._leafs = OrderedDict()

                            self.rpf = YList(self)
                            self._segment_path = lambda: "rpfs"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/safs/saf/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs, [], name, value)


                        class Rpf(Entity):
                            """
                            PIM RPF information
                            
                            .. attribute:: registered_address  (key)
                            
                            	Address for which RPF lookup
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: registered_address_xr
                            
                            	Address registered
                            	**type**\:  :py:class:`RegisteredAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr>`
                            
                            .. attribute:: metric
                            
                            	Metric
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_preference
                            
                            	Metric preference
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_connected
                            
                            	Are we connected ?
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: is_rpf_bgp_route
                            
                            	Is RPF through BGP route
                            	**type**\: bool
                            
                            .. attribute:: rpf_path
                            
                            	RPF Paths list
                            	**type**\: list of  		 :py:class:`RpfPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf, self).__init__()

                                self.yang_name = "rpf"
                                self.yang_parent_name = "rpfs"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['registered_address']
                                self._child_classes = OrderedDict([("registered-address-xr", ("registered_address_xr", Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr)), ("rpf-path", ("rpf_path", Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath))])
                                self._leafs = OrderedDict([
                                    ('registered_address', (YLeaf(YType.str, 'registered-address'), ['str','str'])),
                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                    ('metric_preference', (YLeaf(YType.uint32, 'metric-preference'), ['int'])),
                                    ('is_connected', (YLeaf(YType.uint8, 'is-connected'), ['int'])),
                                    ('is_rpf_bgp_route', (YLeaf(YType.boolean, 'is-rpf-bgp-route'), ['bool'])),
                                ])
                                self.registered_address = None
                                self.metric = None
                                self.metric_preference = None
                                self.is_connected = None
                                self.is_rpf_bgp_route = None

                                self.registered_address_xr = Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr()
                                self.registered_address_xr.parent = self
                                self._children_name_map["registered_address_xr"] = "registered-address-xr"

                                self.rpf_path = YList(self)
                                self._segment_path = lambda: "rpf" + "[registered-address='" + str(self.registered_address) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/safs/saf/rpfs/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf, ['registered_address', 'metric', 'metric_preference', 'is_connected', 'is_rpf_bgp_route'], name, value)


                            class RegisteredAddressXr(Entity):
                                """
                                Address registered
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr, self).__init__()

                                    self.yang_name = "registered-address-xr"
                                    self.yang_parent_name = "rpf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "registered-address-xr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                            class RpfPath(Entity):
                                """
                                RPF Paths list
                                
                                .. attribute:: rpf_neighbor
                                
                                	RPF neighbor
                                	**type**\:  :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor>`
                                
                                .. attribute:: rpf_nexthop
                                
                                	RPF nexthop
                                	**type**\:  :py:class:`RpfNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop>`
                                
                                .. attribute:: rpf_interface_name
                                
                                	RPF Interface
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                .. attribute:: is_rpf_interface_disabled
                                
                                	Is the rpf interface disabled ?
                                	**type**\: bool
                                
                                .. attribute:: is_via_lsm
                                
                                	Via LSM
                                	**type**\: bool
                                
                                .. attribute:: is_via_mlsm
                                
                                	Via Mstatic LSM
                                	**type**\: bool
                                
                                .. attribute:: is_connector_attribute_present
                                
                                	Connector attribute present
                                	**type**\: bool
                                
                                .. attribute:: connector
                                
                                	Connector Attribute
                                	**type**\: str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                .. attribute:: extranet_vrf_name
                                
                                	Extranet VRF name
                                	**type**\: str
                                
                                	**length:** 0..33
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath, self).__init__()

                                    self.yang_name = "rpf-path"
                                    self.yang_parent_name = "rpf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("rpf-neighbor", ("rpf_neighbor", Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor)), ("rpf-nexthop", ("rpf_nexthop", Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop))])
                                    self._leafs = OrderedDict([
                                        ('rpf_interface_name', (YLeaf(YType.str, 'rpf-interface-name'), ['str'])),
                                        ('is_rpf_interface_disabled', (YLeaf(YType.boolean, 'is-rpf-interface-disabled'), ['bool'])),
                                        ('is_via_lsm', (YLeaf(YType.boolean, 'is-via-lsm'), ['bool'])),
                                        ('is_via_mlsm', (YLeaf(YType.boolean, 'is-via-mlsm'), ['bool'])),
                                        ('is_connector_attribute_present', (YLeaf(YType.boolean, 'is-connector-attribute-present'), ['bool'])),
                                        ('connector', (YLeaf(YType.str, 'connector'), ['str'])),
                                        ('extranet_vrf_name', (YLeaf(YType.str, 'extranet-vrf-name'), ['str'])),
                                    ])
                                    self.rpf_interface_name = None
                                    self.is_rpf_interface_disabled = None
                                    self.is_via_lsm = None
                                    self.is_via_mlsm = None
                                    self.is_connector_attribute_present = None
                                    self.connector = None
                                    self.extranet_vrf_name = None

                                    self.rpf_neighbor = Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor()
                                    self.rpf_neighbor.parent = self
                                    self._children_name_map["rpf_neighbor"] = "rpf-neighbor"

                                    self.rpf_nexthop = Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop()
                                    self.rpf_nexthop.parent = self
                                    self._children_name_map["rpf_nexthop"] = "rpf-nexthop"
                                    self._segment_path = lambda: "rpf-path"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath, ['rpf_interface_name', 'is_rpf_interface_disabled', 'is_via_lsm', 'is_via_mlsm', 'is_connector_attribute_present', 'connector', 'extranet_vrf_name'], name, value)


                                class RpfNeighbor(Entity):
                                    """
                                    RPF neighbor
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor, self).__init__()

                                        self.yang_name = "rpf-neighbor"
                                        self.yang_parent_name = "rpf-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ])
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None
                                        self._segment_path = lambda: "rpf-neighbor"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                                class RpfNexthop(Entity):
                                    """
                                    RPF nexthop
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop, self).__init__()

                                        self.yang_name = "rpf-nexthop"
                                        self.yang_parent_name = "rpf-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ])
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None
                                        self._segment_path = lambda: "rpf-nexthop"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class InterfaceStatistics(Entity):
                """
                PIM interface statistics
                
                .. attribute:: interface_statistic
                
                	PIM interface statistics
                	**type**\: list of  		 :py:class:`InterfaceStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.InterfaceStatistics.InterfaceStatistic>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.InterfaceStatistics, self).__init__()

                    self.yang_name = "interface-statistics"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("interface-statistic", ("interface_statistic", Ipv6Pim.Active.DefaultContext.InterfaceStatistics.InterfaceStatistic))])
                    self._leafs = OrderedDict()

                    self.interface_statistic = YList(self)
                    self._segment_path = lambda: "interface-statistics"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.InterfaceStatistics, [], name, value)


                class InterfaceStatistic(Entity):
                    """
                    PIM interface statistics
                    
                    .. attribute:: interface_name  (key)
                    
                    	Interface name
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: input_hello
                    
                    	Hello packets in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_hello
                    
                    	Hello packets out
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_register
                    
                    	Register packets in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_register
                    
                    	Register packets out
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_register_stop
                    
                    	Register Stop packets in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_register_stop
                    
                    	Register Stop packets out
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_jp
                    
                    	Join Prune packets in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_jp
                    
                    	Join Prune packets out
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_bsr_message
                    
                    	Input BSR Messages
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_bsr_message
                    
                    	Output BSR Messages
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_assert
                    
                    	Assert packets in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_assert
                    
                    	Assert packets out
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_graft_message
                    
                    	Input Graft Messages
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_graft_message
                    
                    	Output Graft Messages
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_graft_ack_message
                    
                    	Input Graft Ack Messages
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_graft_ack_message
                    
                    	Output Graft Ack Messages
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_candidate_rp_advertisement
                    
                    	Input Candidate\-RP Advertisment
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_candidate_rp_advertisement
                    
                    	Output Candidate\-RP Advertisment
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_df_election
                    
                    	DF Election packets in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_df_election
                    
                    	DF Election packets out
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_miscellaneous
                    
                    	Miscellaneous packet in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.InterfaceStatistics.InterfaceStatistic, self).__init__()

                        self.yang_name = "interface-statistic"
                        self.yang_parent_name = "interface-statistics"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['interface_name']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                            ('input_hello', (YLeaf(YType.uint32, 'input-hello'), ['int'])),
                            ('output_hello', (YLeaf(YType.uint32, 'output-hello'), ['int'])),
                            ('input_register', (YLeaf(YType.uint32, 'input-register'), ['int'])),
                            ('output_register', (YLeaf(YType.uint32, 'output-register'), ['int'])),
                            ('input_register_stop', (YLeaf(YType.uint32, 'input-register-stop'), ['int'])),
                            ('output_register_stop', (YLeaf(YType.uint32, 'output-register-stop'), ['int'])),
                            ('input_jp', (YLeaf(YType.uint32, 'input-jp'), ['int'])),
                            ('output_jp', (YLeaf(YType.uint32, 'output-jp'), ['int'])),
                            ('input_bsr_message', (YLeaf(YType.uint32, 'input-bsr-message'), ['int'])),
                            ('output_bsr_message', (YLeaf(YType.uint32, 'output-bsr-message'), ['int'])),
                            ('input_assert', (YLeaf(YType.uint32, 'input-assert'), ['int'])),
                            ('output_assert', (YLeaf(YType.uint32, 'output-assert'), ['int'])),
                            ('input_graft_message', (YLeaf(YType.uint32, 'input-graft-message'), ['int'])),
                            ('output_graft_message', (YLeaf(YType.uint32, 'output-graft-message'), ['int'])),
                            ('input_graft_ack_message', (YLeaf(YType.uint32, 'input-graft-ack-message'), ['int'])),
                            ('output_graft_ack_message', (YLeaf(YType.uint32, 'output-graft-ack-message'), ['int'])),
                            ('input_candidate_rp_advertisement', (YLeaf(YType.uint32, 'input-candidate-rp-advertisement'), ['int'])),
                            ('output_candidate_rp_advertisement', (YLeaf(YType.uint32, 'output-candidate-rp-advertisement'), ['int'])),
                            ('input_df_election', (YLeaf(YType.uint32, 'input-df-election'), ['int'])),
                            ('output_df_election', (YLeaf(YType.uint32, 'output-df-election'), ['int'])),
                            ('input_miscellaneous', (YLeaf(YType.uint32, 'input-miscellaneous'), ['int'])),
                        ])
                        self.interface_name = None
                        self.input_hello = None
                        self.output_hello = None
                        self.input_register = None
                        self.output_register = None
                        self.input_register_stop = None
                        self.output_register_stop = None
                        self.input_jp = None
                        self.output_jp = None
                        self.input_bsr_message = None
                        self.output_bsr_message = None
                        self.input_assert = None
                        self.output_assert = None
                        self.input_graft_message = None
                        self.output_graft_message = None
                        self.input_graft_ack_message = None
                        self.output_graft_ack_message = None
                        self.input_candidate_rp_advertisement = None
                        self.output_candidate_rp_advertisement = None
                        self.input_df_election = None
                        self.output_df_election = None
                        self.input_miscellaneous = None
                        self._segment_path = lambda: "interface-statistic" + "[interface-name='" + str(self.interface_name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/interface-statistics/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.InterfaceStatistics.InterfaceStatistic, ['interface_name', 'input_hello', 'output_hello', 'input_register', 'output_register', 'input_register_stop', 'output_register_stop', 'input_jp', 'output_jp', 'input_bsr_message', 'output_bsr_message', 'input_assert', 'output_assert', 'input_graft_message', 'output_graft_message', 'input_graft_ack_message', 'output_graft_ack_message', 'input_candidate_rp_advertisement', 'output_candidate_rp_advertisement', 'input_df_election', 'output_df_election', 'input_miscellaneous'], name, value)


            class TopologyRouteCount(Entity):
                """
                Topology route count information from PIM
                topology table
                
                .. attribute:: group_ranges
                
                	No. of (\*,G/M) routes
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: active_group_ranges
                
                	No. of (\*,G/M) routes active in mrib
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: groute_count
                
                	No. of (\*,G) routes
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: sg_route_count
                
                	No. of (S,G) routes
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: sgr_route_count
                
                	No. of (S,G)RPT routes
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_node_low_memory
                
                	Is node in low memory condition
                	**type**\: bool
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.TopologyRouteCount, self).__init__()

                    self.yang_name = "topology-route-count"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('group_ranges', (YLeaf(YType.uint32, 'group-ranges'), ['int'])),
                        ('active_group_ranges', (YLeaf(YType.uint32, 'active-group-ranges'), ['int'])),
                        ('groute_count', (YLeaf(YType.uint32, 'groute-count'), ['int'])),
                        ('sg_route_count', (YLeaf(YType.uint32, 'sg-route-count'), ['int'])),
                        ('sgr_route_count', (YLeaf(YType.uint32, 'sgr-route-count'), ['int'])),
                        ('is_node_low_memory', (YLeaf(YType.boolean, 'is-node-low-memory'), ['bool'])),
                    ])
                    self.group_ranges = None
                    self.active_group_ranges = None
                    self.groute_count = None
                    self.sg_route_count = None
                    self.sgr_route_count = None
                    self.is_node_low_memory = None
                    self._segment_path = lambda: "topology-route-count"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.TopologyRouteCount, ['group_ranges', 'active_group_ranges', 'groute_count', 'sg_route_count', 'sgr_route_count', 'is_node_low_memory'], name, value)


            class JpStatistics(Entity):
                """
                PIM join prune statistics table
                
                .. attribute:: jp_statistic
                
                	PIM Join Prune Statistics
                	**type**\: list of  		 :py:class:`JpStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.JpStatistics.JpStatistic>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.JpStatistics, self).__init__()

                    self.yang_name = "jp-statistics"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("jp-statistic", ("jp_statistic", Ipv6Pim.Active.DefaultContext.JpStatistics.JpStatistic))])
                    self._leafs = OrderedDict()

                    self.jp_statistic = YList(self)
                    self._segment_path = lambda: "jp-statistics"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.JpStatistics, [], name, value)


                class JpStatistic(Entity):
                    """
                    PIM Join Prune Statistics
                    
                    .. attribute:: interface_name  (key)
                    
                    	Interface name
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identifier
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: mtu
                    
                    	Interface MTU
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: transmitted
                    
                    	Transmitted
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: transmitted100
                    
                    	Transmitted 100 average
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: transmitted_1k
                    
                    	Transmitted 1K average
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: transmitted_10k
                    
                    	Transmitted 10K average
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: transmitted_50k
                    
                    	Deprecated by Transmitted100
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: received
                    
                    	Received
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: received100
                    
                    	Received 100 average
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: received_1k
                    
                    	Received 1K average
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: received_10k
                    
                    	Received 10K average
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: received_50k
                    
                    	Deprecated by Received100
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.JpStatistics.JpStatistic, self).__init__()

                        self.yang_name = "jp-statistic"
                        self.yang_parent_name = "jp-statistics"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['interface_name']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                            ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                            ('mtu', (YLeaf(YType.uint32, 'mtu'), ['int'])),
                            ('transmitted', (YLeaf(YType.uint32, 'transmitted'), ['int'])),
                            ('transmitted100', (YLeaf(YType.uint16, 'transmitted100'), ['int'])),
                            ('transmitted_1k', (YLeaf(YType.uint16, 'transmitted-1k'), ['int'])),
                            ('transmitted_10k', (YLeaf(YType.uint16, 'transmitted-10k'), ['int'])),
                            ('transmitted_50k', (YLeaf(YType.uint16, 'transmitted-50k'), ['int'])),
                            ('received', (YLeaf(YType.uint32, 'received'), ['int'])),
                            ('received100', (YLeaf(YType.uint16, 'received100'), ['int'])),
                            ('received_1k', (YLeaf(YType.uint16, 'received-1k'), ['int'])),
                            ('received_10k', (YLeaf(YType.uint16, 'received-10k'), ['int'])),
                            ('received_50k', (YLeaf(YType.uint16, 'received-50k'), ['int'])),
                        ])
                        self.interface_name = None
                        self.interface_name_xr = None
                        self.mtu = None
                        self.transmitted = None
                        self.transmitted100 = None
                        self.transmitted_1k = None
                        self.transmitted_10k = None
                        self.transmitted_50k = None
                        self.received = None
                        self.received100 = None
                        self.received_1k = None
                        self.received_10k = None
                        self.received_50k = None
                        self._segment_path = lambda: "jp-statistic" + "[interface-name='" + str(self.interface_name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/jp-statistics/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.JpStatistics.JpStatistic, ['interface_name', 'interface_name_xr', 'mtu', 'transmitted', 'transmitted100', 'transmitted_1k', 'transmitted_10k', 'transmitted_50k', 'received', 'received100', 'received_1k', 'received_10k', 'received_50k'], name, value)


            class MibDatabases(Entity):
                """
                PIM group database for mroute mibs table
                
                .. attribute:: mib_database
                
                	PIM multicast static route information
                	**type**\: list of  		 :py:class:`MibDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.MibDatabases, self).__init__()

                    self.yang_name = "mib-databases"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("mib-database", ("mib_database", Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase))])
                    self._leafs = OrderedDict()

                    self.mib_database = YList(self)
                    self._segment_path = lambda: "mib-databases"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.MibDatabases, [], name, value)


                class MibDatabase(Entity):
                    """
                    PIM multicast static route information
                    
                    .. attribute:: source_address
                    
                    	Multicast static route source address
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: group_address
                    
                    	Multicast satic route group address
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: source_netmask
                    
                    	Source mask
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: source_address_xr
                    
                    	Source Address
                    	**type**\:  :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr>`
                    
                    .. attribute:: group_address_xr
                    
                    	Group Address
                    	**type**\:  :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr>`
                    
                    .. attribute:: rpf_neighbor
                    
                    	The RPF Neighbor
                    	**type**\:  :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor>`
                    
                    .. attribute:: rpf_root
                    
                    	Root of this mcast tree
                    	**type**\:  :py:class:`RpfRoot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfRoot>`
                    
                    .. attribute:: upstream_assert_timer
                    
                    	Upstream Assert Timer
                    	**type**\: int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: assert_metric
                    
                    	Assert Metric
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: assert_metric_preference
                    
                    	Assert Metric Preference
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: assert_rpt_bit
                    
                    	Assert RPT Bit
                    	**type**\: bool
                    
                    .. attribute:: spt_bit
                    
                    	Is SPT bit set ?
                    	**type**\: bool
                    
                    .. attribute:: rpf_mask
                    
                    	Mask of the multicast root
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rpf_safi
                    
                    	Unicast or mcast
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: rpf_table_name
                    
                    	RPF Table name
                    	**type**\: str
                    
                    .. attribute:: rpf_drop
                    
                    	RPF route\-policy drop
                    	**type**\: bool
                    
                    .. attribute:: rpf_extranet
                    
                    	Extranet RPF route\-policy
                    	**type**\: bool
                    
                    .. attribute:: rpf_interface_name
                    
                    	RPF interface name 
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: rpf_vrf_name
                    
                    	RPF VRF Name
                    	**type**\: str
                    
                    	**length:** 0..33
                    
                    .. attribute:: bidirectional_route
                    
                    	Is this Bidir ?
                    	**type**\: bool
                    
                    .. attribute:: uptime
                    
                    	Uptime of route
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: protocol
                    
                    	The PIM protocol
                    	**type**\:  :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase, self).__init__()

                        self.yang_name = "mib-database"
                        self.yang_parent_name = "mib-databases"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("source-address-xr", ("source_address_xr", Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr)), ("group-address-xr", ("group_address_xr", Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr)), ("rpf-neighbor", ("rpf_neighbor", Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor)), ("rpf-root", ("rpf_root", Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfRoot))])
                        self._leafs = OrderedDict([
                            ('source_address', (YLeaf(YType.str, 'source-address'), ['str','str'])),
                            ('group_address', (YLeaf(YType.str, 'group-address'), ['str','str'])),
                            ('source_netmask', (YLeaf(YType.uint32, 'source-netmask'), ['int'])),
                            ('upstream_assert_timer', (YLeaf(YType.int32, 'upstream-assert-timer'), ['int'])),
                            ('assert_metric', (YLeaf(YType.uint32, 'assert-metric'), ['int'])),
                            ('assert_metric_preference', (YLeaf(YType.uint32, 'assert-metric-preference'), ['int'])),
                            ('assert_rpt_bit', (YLeaf(YType.boolean, 'assert-rpt-bit'), ['bool'])),
                            ('spt_bit', (YLeaf(YType.boolean, 'spt-bit'), ['bool'])),
                            ('rpf_mask', (YLeaf(YType.uint32, 'rpf-mask'), ['int'])),
                            ('rpf_safi', (YLeaf(YType.uint8, 'rpf-safi'), ['int'])),
                            ('rpf_table_name', (YLeaf(YType.str, 'rpf-table-name'), ['str'])),
                            ('rpf_drop', (YLeaf(YType.boolean, 'rpf-drop'), ['bool'])),
                            ('rpf_extranet', (YLeaf(YType.boolean, 'rpf-extranet'), ['bool'])),
                            ('rpf_interface_name', (YLeaf(YType.str, 'rpf-interface-name'), ['str'])),
                            ('rpf_vrf_name', (YLeaf(YType.str, 'rpf-vrf-name'), ['str'])),
                            ('bidirectional_route', (YLeaf(YType.boolean, 'bidirectional-route'), ['bool'])),
                            ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                            ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowProtocol', '')])),
                        ])
                        self.source_address = None
                        self.group_address = None
                        self.source_netmask = None
                        self.upstream_assert_timer = None
                        self.assert_metric = None
                        self.assert_metric_preference = None
                        self.assert_rpt_bit = None
                        self.spt_bit = None
                        self.rpf_mask = None
                        self.rpf_safi = None
                        self.rpf_table_name = None
                        self.rpf_drop = None
                        self.rpf_extranet = None
                        self.rpf_interface_name = None
                        self.rpf_vrf_name = None
                        self.bidirectional_route = None
                        self.uptime = None
                        self.protocol = None

                        self.source_address_xr = Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr()
                        self.source_address_xr.parent = self
                        self._children_name_map["source_address_xr"] = "source-address-xr"

                        self.group_address_xr = Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr()
                        self.group_address_xr.parent = self
                        self._children_name_map["group_address_xr"] = "group-address-xr"

                        self.rpf_neighbor = Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor()
                        self.rpf_neighbor.parent = self
                        self._children_name_map["rpf_neighbor"] = "rpf-neighbor"

                        self.rpf_root = Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfRoot()
                        self.rpf_root.parent = self
                        self._children_name_map["rpf_root"] = "rpf-root"
                        self._segment_path = lambda: "mib-database"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/mib-databases/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase, ['source_address', 'group_address', 'source_netmask', 'upstream_assert_timer', 'assert_metric', 'assert_metric_preference', 'assert_rpt_bit', 'spt_bit', 'rpf_mask', 'rpf_safi', 'rpf_table_name', 'rpf_drop', 'rpf_extranet', 'rpf_interface_name', 'rpf_vrf_name', 'bidirectional_route', 'uptime', 'protocol'], name, value)


                    class SourceAddressXr(Entity):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr, self).__init__()

                            self.yang_name = "source-address-xr"
                            self.yang_parent_name = "mib-database"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "source-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/mib-databases/mib-database/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class GroupAddressXr(Entity):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr, self).__init__()

                            self.yang_name = "group-address-xr"
                            self.yang_parent_name = "mib-database"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "group-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/mib-databases/mib-database/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class RpfNeighbor(Entity):
                        """
                        The RPF Neighbor
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor, self).__init__()

                            self.yang_name = "rpf-neighbor"
                            self.yang_parent_name = "mib-database"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "rpf-neighbor"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/mib-databases/mib-database/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class RpfRoot(Entity):
                        """
                        Root of this mcast tree
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfRoot, self).__init__()

                            self.yang_name = "rpf-root"
                            self.yang_parent_name = "mib-database"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "rpf-root"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/mib-databases/mib-database/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfRoot, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class NeighborOldFormats(Entity):
                """
                PIM neighbor table old format
                
                .. attribute:: neighbor_old_format
                
                	PIM neighbor information
                	**type**\: list of  		 :py:class:`NeighborOldFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.NeighborOldFormats.NeighborOldFormat>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.NeighborOldFormats, self).__init__()

                    self.yang_name = "neighbor-old-formats"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("neighbor-old-format", ("neighbor_old_format", Ipv6Pim.Active.DefaultContext.NeighborOldFormats.NeighborOldFormat))])
                    self._leafs = OrderedDict()

                    self.neighbor_old_format = YList(self)
                    self._segment_path = lambda: "neighbor-old-formats"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.NeighborOldFormats, [], name, value)


                class NeighborOldFormat(Entity):
                    """
                    PIM neighbor information
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: neighbor_address
                    
                    	Neighbor address
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identifier
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: expires
                    
                    	Neighbor expiry in seconds
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: expiry_timer
                    
                    	Expiry timer in seconds
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: is_this_neighbor_us
                    
                    	Is this neighbor us ?
                    	**type**\: bool
                    
                    .. attribute:: is_this_neighbor_dr
                    
                    	Is this neighbor the DR
                    	**type**\: bool
                    
                    .. attribute:: is_dr_priority_capable
                    
                    	Is this neighbor DR priority capable ?
                    	**type**\: bool
                    
                    .. attribute:: dr_priority
                    
                    	DR priority
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Is this neighbor bidir capable ?
                    	**type**\: bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Is this neighbor proxy capable?
                    	**type**\: bool
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Is this neighbor capable of batching asserts?
                    	**type**\: bool
                    
                    .. attribute:: is_ecmp_redirect_capable
                    
                    	Is this neighbor capable of Ecmp Redirect?
                    	**type**\: bool
                    
                    .. attribute:: is_bfd_state
                    
                    	Is the neighbor bfd session created
                    	**type**\: bool
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_address_xr
                    
                    	List of Neighbor Addresses
                    	**type**\: list of  		 :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.NeighborOldFormats.NeighborOldFormat, self).__init__()

                        self.yang_name = "neighbor-old-format"
                        self.yang_parent_name = "neighbor-old-formats"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("neighbor-address-xr", ("neighbor_address_xr", Ipv6Pim.Active.DefaultContext.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr))])
                        self._leafs = OrderedDict([
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                            ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                            ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                            ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                            ('expires', (YLeaf(YType.uint64, 'expires'), ['int'])),
                            ('expiry_timer', (YLeaf(YType.uint64, 'expiry-timer'), ['int'])),
                            ('is_this_neighbor_us', (YLeaf(YType.boolean, 'is-this-neighbor-us'), ['bool'])),
                            ('is_this_neighbor_dr', (YLeaf(YType.boolean, 'is-this-neighbor-dr'), ['bool'])),
                            ('is_dr_priority_capable', (YLeaf(YType.boolean, 'is-dr-priority-capable'), ['bool'])),
                            ('dr_priority', (YLeaf(YType.uint32, 'dr-priority'), ['int'])),
                            ('is_bidirectional_capable', (YLeaf(YType.boolean, 'is-bidirectional-capable'), ['bool'])),
                            ('is_proxy_capable', (YLeaf(YType.boolean, 'is-proxy-capable'), ['bool'])),
                            ('is_batch_asserts_capable', (YLeaf(YType.boolean, 'is-batch-asserts-capable'), ['bool'])),
                            ('is_ecmp_redirect_capable', (YLeaf(YType.boolean, 'is-ecmp-redirect-capable'), ['bool'])),
                            ('is_bfd_state', (YLeaf(YType.boolean, 'is-bfd-state'), ['bool'])),
                            ('propagation_delay', (YLeaf(YType.uint16, 'propagation-delay'), ['int'])),
                            ('override_interval', (YLeaf(YType.uint16, 'override-interval'), ['int'])),
                        ])
                        self.interface_name = None
                        self.neighbor_address = None
                        self.interface_name_xr = None
                        self.uptime = None
                        self.expires = None
                        self.expiry_timer = None
                        self.is_this_neighbor_us = None
                        self.is_this_neighbor_dr = None
                        self.is_dr_priority_capable = None
                        self.dr_priority = None
                        self.is_bidirectional_capable = None
                        self.is_proxy_capable = None
                        self.is_batch_asserts_capable = None
                        self.is_ecmp_redirect_capable = None
                        self.is_bfd_state = None
                        self.propagation_delay = None
                        self.override_interval = None

                        self.neighbor_address_xr = YList(self)
                        self._segment_path = lambda: "neighbor-old-format"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/neighbor-old-formats/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.NeighborOldFormats.NeighborOldFormat, ['interface_name', 'neighbor_address', 'interface_name_xr', 'uptime', 'expires', 'expiry_timer', 'is_this_neighbor_us', 'is_this_neighbor_dr', 'is_dr_priority_capable', 'dr_priority', 'is_bidirectional_capable', 'is_proxy_capable', 'is_batch_asserts_capable', 'is_ecmp_redirect_capable', 'is_bfd_state', 'propagation_delay', 'override_interval'], name, value)


                    class NeighborAddressXr(Entity):
                        """
                        List of Neighbor Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr, self).__init__()

                            self.yang_name = "neighbor-address-xr"
                            self.yang_parent_name = "neighbor-old-format"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "neighbor-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/neighbor-old-formats/neighbor-old-format/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class IfrsSummary(Entity):
                """
                PIM interfaces in forward reference store
                summary
                
                .. attribute:: interface_count
                
                	Number of interfaces
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: configuration_count
                
                	Configuration counts
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.IfrsSummary, self).__init__()

                    self.yang_name = "ifrs-summary"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('interface_count', (YLeaf(YType.uint32, 'interface-count'), ['int'])),
                        ('configuration_count', (YLeaf(YType.uint32, 'configuration-count'), ['int'])),
                    ])
                    self.interface_count = None
                    self.configuration_count = None
                    self._segment_path = lambda: "ifrs-summary"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.IfrsSummary, ['interface_count', 'configuration_count'], name, value)


            class Ranges(Entity):
                """
                PIM range list information
                
                .. attribute:: range
                
                	PIM range list information
                	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Ranges.Range>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.Ranges, self).__init__()

                    self.yang_name = "ranges"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("range", ("range", Ipv6Pim.Active.DefaultContext.Ranges.Range))])
                    self._leafs = OrderedDict()

                    self.range = YList(self)
                    self._segment_path = lambda: "ranges"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.Ranges, [], name, value)


                class Range(Entity):
                    """
                    PIM range list information
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: client
                    
                    	Client
                    	**type**\:  :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                    
                    .. attribute:: rp_address_xr
                    
                    	Rendezvous point address
                    	**type**\:  :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Ranges.Range.RpAddressXr>`
                    
                    .. attribute:: source_of_information
                    
                    	Source of information
                    	**type**\:  :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Ranges.Range.SourceOfInformation>`
                    
                    .. attribute:: protocol
                    
                    	PIM protocol
                    	**type**\:  :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                    
                    .. attribute:: client_xr
                    
                    	Client mapping learnt via
                    	**type**\:  :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                    
                    .. attribute:: expires
                    
                    	When mapping expires
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: group_range
                    
                    	List of group ranges
                    	**type**\: list of  		 :py:class:`GroupRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Ranges.Range.GroupRange>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.Ranges.Range, self).__init__()

                        self.yang_name = "range"
                        self.yang_parent_name = "ranges"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("rp-address-xr", ("rp_address_xr", Ipv6Pim.Active.DefaultContext.Ranges.Range.RpAddressXr)), ("source-of-information", ("source_of_information", Ipv6Pim.Active.DefaultContext.Ranges.Range.SourceOfInformation)), ("group-range", ("group_range", Ipv6Pim.Active.DefaultContext.Ranges.Range.GroupRange))])
                        self._leafs = OrderedDict([
                            ('rp_address', (YLeaf(YType.str, 'rp-address'), ['str','str'])),
                            ('client', (YLeaf(YType.enumeration, 'client'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimClient', '')])),
                            ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowProtocol', '')])),
                            ('client_xr', (YLeaf(YType.enumeration, 'client-xr'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowRangeClient', '')])),
                            ('expires', (YLeaf(YType.uint64, 'expires'), ['int'])),
                        ])
                        self.rp_address = None
                        self.client = None
                        self.protocol = None
                        self.client_xr = None
                        self.expires = None

                        self.rp_address_xr = Ipv6Pim.Active.DefaultContext.Ranges.Range.RpAddressXr()
                        self.rp_address_xr.parent = self
                        self._children_name_map["rp_address_xr"] = "rp-address-xr"

                        self.source_of_information = Ipv6Pim.Active.DefaultContext.Ranges.Range.SourceOfInformation()
                        self.source_of_information.parent = self
                        self._children_name_map["source_of_information"] = "source-of-information"

                        self.group_range = YList(self)
                        self._segment_path = lambda: "range"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/ranges/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.Ranges.Range, ['rp_address', 'client', 'protocol', 'client_xr', 'expires'], name, value)


                    class RpAddressXr(Entity):
                        """
                        Rendezvous point address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Ranges.Range.RpAddressXr, self).__init__()

                            self.yang_name = "rp-address-xr"
                            self.yang_parent_name = "range"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "rp-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/ranges/range/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.Ranges.Range.RpAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class SourceOfInformation(Entity):
                        """
                        Source of information
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Ranges.Range.SourceOfInformation, self).__init__()

                            self.yang_name = "source-of-information"
                            self.yang_parent_name = "range"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "source-of-information"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/ranges/range/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.Ranges.Range.SourceOfInformation, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class GroupRange(Entity):
                        """
                        List of group ranges
                        
                        .. attribute:: prefix
                        
                        	Group range prefix
                        	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Ranges.Range.GroupRange.Prefix>`
                        
                        .. attribute:: source_of_information
                        
                        	Source of information
                        	**type**\:  :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation>`
                        
                        .. attribute:: prefix_length
                        
                        	Group range prefix length
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: expires
                        
                        	When mapping expires
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Ranges.Range.GroupRange, self).__init__()

                            self.yang_name = "group-range"
                            self.yang_parent_name = "range"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("prefix", ("prefix", Ipv6Pim.Active.DefaultContext.Ranges.Range.GroupRange.Prefix)), ("source-of-information", ("source_of_information", Ipv6Pim.Active.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation))])
                            self._leafs = OrderedDict([
                                ('prefix_length', (YLeaf(YType.int32, 'prefix-length'), ['int'])),
                                ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                                ('expires', (YLeaf(YType.uint64, 'expires'), ['int'])),
                            ])
                            self.prefix_length = None
                            self.uptime = None
                            self.expires = None

                            self.prefix = Ipv6Pim.Active.DefaultContext.Ranges.Range.GroupRange.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"

                            self.source_of_information = Ipv6Pim.Active.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation()
                            self.source_of_information.parent = self
                            self._children_name_map["source_of_information"] = "source-of-information"
                            self._segment_path = lambda: "group-range"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/ranges/range/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.Ranges.Range.GroupRange, ['prefix_length', 'uptime', 'expires'], name, value)


                        class Prefix(Entity):
                            """
                            Group range prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.Ranges.Range.GroupRange.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "group-range"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "prefix"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/ranges/range/group-range/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.DefaultContext.Ranges.Range.GroupRange.Prefix, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class SourceOfInformation(Entity):
                            """
                            Source of information
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation, self).__init__()

                                self.yang_name = "source-of-information"
                                self.yang_parent_name = "group-range"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "source-of-information"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/ranges/range/group-range/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class InterfaceOldFormats(Entity):
                """
                PIM interfaces in old format
                
                .. attribute:: interface_old_format
                
                	PIM interface name
                	**type**\: list of  		 :py:class:`InterfaceOldFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.InterfaceOldFormats, self).__init__()

                    self.yang_name = "interface-old-formats"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("interface-old-format", ("interface_old_format", Ipv6Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat))])
                    self._leafs = OrderedDict()

                    self.interface_old_format = YList(self)
                    self._segment_path = lambda: "interface-old-formats"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.InterfaceOldFormats, [], name, value)


                class InterfaceOldFormat(Entity):
                    """
                    PIM interface name
                    
                    .. attribute:: interface_name  (key)
                    
                    	Interface name
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: dr_address
                    
                    	PIM Designated Router
                    	**type**\:  :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress>`
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identfier
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: interface_address_mask
                    
                    	Interface IP Address Mask
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: is_enabled
                    
                    	Is PIM enabled on this IF ?
                    	**type**\: bool
                    
                    .. attribute:: neighbor_count
                    
                    	No. of neighbors on this IF
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: external_neighbor_count
                    
                    	No. of external neighbors on this IF
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: hello_interval
                    
                    	Hello Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dr_priority
                    
                    	DR Priority
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_expiry
                    
                    	Hello Timer Expiry
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: are_we_dr
                    
                    	Are we the DR on this IF ?
                    	**type**\: bool
                    
                    .. attribute:: bfd_enabled
                    
                    	BFD state
                    	**type**\: bool
                    
                    .. attribute:: bfd_interval
                    
                    	BFD Interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bfd_multiplier
                    
                    	BFD Multiplier
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_interface
                    
                    	 is this a Virtual Interfaces ?
                    	**type**\: bool
                    
                    .. attribute:: passive_interface
                    
                    	Passive PIM interface
                    	**type**\: bool
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\: str
                    
                    .. attribute:: join_prune_interval
                    
                    	Join\-Prune Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: prune_delay_enabled
                    
                    	Prune Delay Enabled
                    	**type**\: bool
                    
                    .. attribute:: configured_propagation_delay
                    
                    	Configured Propagation Delay
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_override_interval
                    
                    	Configured Override Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: generation_id
                    
                    	Generation Identifier
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Bidir Capable
                    	**type**\: bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Proxy Capable
                    	**type**\: bool
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Batch Asserts Capable
                    	**type**\: bool
                    
                    .. attribute:: idb_oor_enabled
                    
                    	Interface oor enabled
                    	**type**\: bool
                    
                    .. attribute:: idb_acl_provided
                    
                    	ACL name provided
                    	**type**\: bool
                    
                    .. attribute:: idb_max_count
                    
                    	Interface ole max count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_threshold_count
                    
                    	Interface ole threshold count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_current_count
                    
                    	Interface ole current count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_acl_name
                    
                    	Interface ole ACL Name
                    	**type**\: str
                    
                    	**length:** 0..64
                    
                    .. attribute:: interface_address
                    
                    	List of Interface IP Addresses
                    	**type**\: list of  		 :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat, self).__init__()

                        self.yang_name = "interface-old-format"
                        self.yang_parent_name = "interface-old-formats"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['interface_name']
                        self._child_classes = OrderedDict([("dr-address", ("dr_address", Ipv6Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress)), ("interface-address", ("interface_address", Ipv6Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress))])
                        self._leafs = OrderedDict([
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                            ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                            ('interface_address_mask', (YLeaf(YType.uint8, 'interface-address-mask'), ['int'])),
                            ('is_enabled', (YLeaf(YType.boolean, 'is-enabled'), ['bool'])),
                            ('neighbor_count', (YLeaf(YType.uint16, 'neighbor-count'), ['int'])),
                            ('external_neighbor_count', (YLeaf(YType.uint16, 'external-neighbor-count'), ['int'])),
                            ('hello_interval', (YLeaf(YType.uint16, 'hello-interval'), ['int'])),
                            ('dr_priority', (YLeaf(YType.uint32, 'dr-priority'), ['int'])),
                            ('hello_expiry', (YLeaf(YType.uint64, 'hello-expiry'), ['int'])),
                            ('are_we_dr', (YLeaf(YType.boolean, 'are-we-dr'), ['bool'])),
                            ('bfd_enabled', (YLeaf(YType.boolean, 'bfd-enabled'), ['bool'])),
                            ('bfd_interval', (YLeaf(YType.uint32, 'bfd-interval'), ['int'])),
                            ('bfd_multiplier', (YLeaf(YType.uint32, 'bfd-multiplier'), ['int'])),
                            ('virtual_interface', (YLeaf(YType.boolean, 'virtual-interface'), ['bool'])),
                            ('passive_interface', (YLeaf(YType.boolean, 'passive-interface'), ['bool'])),
                            ('neighbor_filter_name', (YLeaf(YType.str, 'neighbor-filter-name'), ['str'])),
                            ('join_prune_interval', (YLeaf(YType.uint16, 'join-prune-interval'), ['int'])),
                            ('prune_delay_enabled', (YLeaf(YType.boolean, 'prune-delay-enabled'), ['bool'])),
                            ('configured_propagation_delay', (YLeaf(YType.uint16, 'configured-propagation-delay'), ['int'])),
                            ('propagation_delay', (YLeaf(YType.uint16, 'propagation-delay'), ['int'])),
                            ('configured_override_interval', (YLeaf(YType.uint16, 'configured-override-interval'), ['int'])),
                            ('override_interval', (YLeaf(YType.uint16, 'override-interval'), ['int'])),
                            ('generation_id', (YLeaf(YType.uint32, 'generation-id'), ['int'])),
                            ('is_bidirectional_capable', (YLeaf(YType.boolean, 'is-bidirectional-capable'), ['bool'])),
                            ('is_proxy_capable', (YLeaf(YType.boolean, 'is-proxy-capable'), ['bool'])),
                            ('is_batch_asserts_capable', (YLeaf(YType.boolean, 'is-batch-asserts-capable'), ['bool'])),
                            ('idb_oor_enabled', (YLeaf(YType.boolean, 'idb-oor-enabled'), ['bool'])),
                            ('idb_acl_provided', (YLeaf(YType.boolean, 'idb-acl-provided'), ['bool'])),
                            ('idb_max_count', (YLeaf(YType.uint32, 'idb-max-count'), ['int'])),
                            ('idb_threshold_count', (YLeaf(YType.uint32, 'idb-threshold-count'), ['int'])),
                            ('idb_current_count', (YLeaf(YType.uint32, 'idb-current-count'), ['int'])),
                            ('idb_acl_name', (YLeaf(YType.str, 'idb-acl-name'), ['str'])),
                        ])
                        self.interface_name = None
                        self.interface_name_xr = None
                        self.interface_address_mask = None
                        self.is_enabled = None
                        self.neighbor_count = None
                        self.external_neighbor_count = None
                        self.hello_interval = None
                        self.dr_priority = None
                        self.hello_expiry = None
                        self.are_we_dr = None
                        self.bfd_enabled = None
                        self.bfd_interval = None
                        self.bfd_multiplier = None
                        self.virtual_interface = None
                        self.passive_interface = None
                        self.neighbor_filter_name = None
                        self.join_prune_interval = None
                        self.prune_delay_enabled = None
                        self.configured_propagation_delay = None
                        self.propagation_delay = None
                        self.configured_override_interval = None
                        self.override_interval = None
                        self.generation_id = None
                        self.is_bidirectional_capable = None
                        self.is_proxy_capable = None
                        self.is_batch_asserts_capable = None
                        self.idb_oor_enabled = None
                        self.idb_acl_provided = None
                        self.idb_max_count = None
                        self.idb_threshold_count = None
                        self.idb_current_count = None
                        self.idb_acl_name = None

                        self.dr_address = Ipv6Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress()
                        self.dr_address.parent = self
                        self._children_name_map["dr_address"] = "dr-address"

                        self.interface_address = YList(self)
                        self._segment_path = lambda: "interface-old-format" + "[interface-name='" + str(self.interface_name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/interface-old-formats/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat, ['interface_name', 'interface_name_xr', 'interface_address_mask', 'is_enabled', 'neighbor_count', 'external_neighbor_count', 'hello_interval', 'dr_priority', 'hello_expiry', 'are_we_dr', 'bfd_enabled', 'bfd_interval', 'bfd_multiplier', 'virtual_interface', 'passive_interface', 'neighbor_filter_name', 'join_prune_interval', 'prune_delay_enabled', 'configured_propagation_delay', 'propagation_delay', 'configured_override_interval', 'override_interval', 'generation_id', 'is_bidirectional_capable', 'is_proxy_capable', 'is_batch_asserts_capable', 'idb_oor_enabled', 'idb_acl_provided', 'idb_max_count', 'idb_threshold_count', 'idb_current_count', 'idb_acl_name'], name, value)


                    class DrAddress(Entity):
                        """
                        PIM Designated Router
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress, self).__init__()

                            self.yang_name = "dr-address"
                            self.yang_parent_name = "interface-old-format"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "dr-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class InterfaceAddress(Entity):
                        """
                        List of Interface IP Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress, self).__init__()

                            self.yang_name = "interface-address"
                            self.yang_parent_name = "interface-old-format"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "interface-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class Bsr(Entity):
                """
                PIM BSR information
                
                .. attribute:: rp_caches
                
                	PIM BSR RP cache table
                	**type**\:  :py:class:`RpCaches <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Bsr.RpCaches>`
                
                .. attribute:: candidate_rps
                
                	PIM candidate\-RP
                	**type**\:  :py:class:`CandidateRps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps>`
                
                .. attribute:: bsr_elections
                
                	PIM BSR election state
                	**type**\:  :py:class:`BsrElections <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Bsr.BsrElections>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.Bsr, self).__init__()

                    self.yang_name = "bsr"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("rp-caches", ("rp_caches", Ipv6Pim.Active.DefaultContext.Bsr.RpCaches)), ("candidate-rps", ("candidate_rps", Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps)), ("bsr-elections", ("bsr_elections", Ipv6Pim.Active.DefaultContext.Bsr.BsrElections))])
                    self._leafs = OrderedDict()

                    self.rp_caches = Ipv6Pim.Active.DefaultContext.Bsr.RpCaches()
                    self.rp_caches.parent = self
                    self._children_name_map["rp_caches"] = "rp-caches"

                    self.candidate_rps = Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps()
                    self.candidate_rps.parent = self
                    self._children_name_map["candidate_rps"] = "candidate-rps"

                    self.bsr_elections = Ipv6Pim.Active.DefaultContext.Bsr.BsrElections()
                    self.bsr_elections.parent = self
                    self._children_name_map["bsr_elections"] = "bsr-elections"
                    self._segment_path = lambda: "bsr"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.Bsr, [], name, value)


                class RpCaches(Entity):
                    """
                    PIM BSR RP cache table
                    
                    .. attribute:: rp_cache
                    
                    	PIM BSR RP cache
                    	**type**\: list of  		 :py:class:`RpCache <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.Bsr.RpCaches, self).__init__()

                        self.yang_name = "rp-caches"
                        self.yang_parent_name = "bsr"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("rp-cache", ("rp_cache", Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache))])
                        self._leafs = OrderedDict()

                        self.rp_cache = YList(self)
                        self._segment_path = lambda: "rp-caches"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/bsr/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.Bsr.RpCaches, [], name, value)


                    class RpCache(Entity):
                        """
                        PIM BSR RP cache
                        
                        .. attribute:: group_prefix  (key)
                        
                        	Group prefix
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: group_prefix_xr
                        
                        	Group Prefix
                        	**type**\:  :py:class:`GroupPrefixXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr>`
                        
                        .. attribute:: candidate_rp_list
                        
                        	C\-RP list for this prefix
                        	**type**\:  :py:class:`CandidateRpList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList>`
                        
                        .. attribute:: group_prefix_length
                        
                        	Group Prefix Length
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: candidate_rp_group_count
                        
                        	C\-RP count for this Prefix
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache, self).__init__()

                            self.yang_name = "rp-cache"
                            self.yang_parent_name = "rp-caches"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['group_prefix']
                            self._child_classes = OrderedDict([("group-prefix-xr", ("group_prefix_xr", Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr)), ("candidate-rp-list", ("candidate_rp_list", Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList))])
                            self._leafs = OrderedDict([
                                ('group_prefix', (YLeaf(YType.str, 'group-prefix'), ['str','str'])),
                                ('group_prefix_length', (YLeaf(YType.uint32, 'group-prefix-length'), ['int'])),
                                ('candidate_rp_group_count', (YLeaf(YType.uint32, 'candidate-rp-group-count'), ['int'])),
                            ])
                            self.group_prefix = None
                            self.group_prefix_length = None
                            self.candidate_rp_group_count = None

                            self.group_prefix_xr = Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr()
                            self.group_prefix_xr.parent = self
                            self._children_name_map["group_prefix_xr"] = "group-prefix-xr"

                            self.candidate_rp_list = Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList()
                            self.candidate_rp_list.parent = self
                            self._children_name_map["candidate_rp_list"] = "candidate-rp-list"
                            self._segment_path = lambda: "rp-cache" + "[group-prefix='" + str(self.group_prefix) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/bsr/rp-caches/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache, ['group_prefix', 'group_prefix_length', 'candidate_rp_group_count'], name, value)


                        class GroupPrefixXr(Entity):
                            """
                            Group Prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr, self).__init__()

                                self.yang_name = "group-prefix-xr"
                                self.yang_parent_name = "rp-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "group-prefix-xr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class CandidateRpList(Entity):
                            """
                            C\-RP list for this prefix
                            
                            .. attribute:: pim_bsr_crp_bag
                            
                            	pim bsr crp bag
                            	**type**\: list of  		 :py:class:`PimBsrCrpBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList, self).__init__()

                                self.yang_name = "candidate-rp-list"
                                self.yang_parent_name = "rp-cache"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("pim-bsr-crp-bag", ("pim_bsr_crp_bag", Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag))])
                                self._leafs = OrderedDict()

                                self.pim_bsr_crp_bag = YList(self)
                                self._segment_path = lambda: "candidate-rp-list"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList, [], name, value)


                            class PimBsrCrpBag(Entity):
                                """
                                pim bsr crp bag
                                
                                .. attribute:: candidate_rp_address
                                
                                	C\-RP address
                                	**type**\:  :py:class:`CandidateRpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress>`
                                
                                .. attribute:: candidate_rp_holdtime
                                
                                	C\-RP Holdtime
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: candidate_rp_priority
                                
                                	C\-RP Priority
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: candidate_rp_up_time
                                
                                	C\-RP Uptime
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: candidate_rp_expires
                                
                                	C\-RP Expires
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: protocol
                                
                                	PIM Protocol
                                	**type**\:  :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag, self).__init__()

                                    self.yang_name = "pim-bsr-crp-bag"
                                    self.yang_parent_name = "candidate-rp-list"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("candidate-rp-address", ("candidate_rp_address", Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress))])
                                    self._leafs = OrderedDict([
                                        ('candidate_rp_holdtime', (YLeaf(YType.uint16, 'candidate-rp-holdtime'), ['int'])),
                                        ('candidate_rp_priority', (YLeaf(YType.uint8, 'candidate-rp-priority'), ['int'])),
                                        ('candidate_rp_up_time', (YLeaf(YType.uint16, 'candidate-rp-up-time'), ['int'])),
                                        ('candidate_rp_expires', (YLeaf(YType.uint16, 'candidate-rp-expires'), ['int'])),
                                        ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowProtocol', '')])),
                                    ])
                                    self.candidate_rp_holdtime = None
                                    self.candidate_rp_priority = None
                                    self.candidate_rp_up_time = None
                                    self.candidate_rp_expires = None
                                    self.protocol = None

                                    self.candidate_rp_address = Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress()
                                    self.candidate_rp_address.parent = self
                                    self._children_name_map["candidate_rp_address"] = "candidate-rp-address"
                                    self._segment_path = lambda: "pim-bsr-crp-bag"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag, ['candidate_rp_holdtime', 'candidate_rp_priority', 'candidate_rp_up_time', 'candidate_rp_expires', 'protocol'], name, value)


                                class CandidateRpAddress(Entity):
                                    """
                                    C\-RP address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress, self).__init__()

                                        self.yang_name = "candidate-rp-address"
                                        self.yang_parent_name = "pim-bsr-crp-bag"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ])
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None
                                        self._segment_path = lambda: "candidate-rp-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class CandidateRps(Entity):
                    """
                    PIM candidate\-RP
                    
                    .. attribute:: candidate_rp
                    
                    	PIM BSR candidate RP information
                    	**type**\: list of  		 :py:class:`CandidateRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps, self).__init__()

                        self.yang_name = "candidate-rps"
                        self.yang_parent_name = "bsr"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("candidate-rp", ("candidate_rp", Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp))])
                        self._leafs = OrderedDict()

                        self.candidate_rp = YList(self)
                        self._segment_path = lambda: "candidate-rps"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/bsr/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps, [], name, value)


                    class CandidateRp(Entity):
                        """
                        PIM BSR candidate RP information
                        
                        .. attribute:: rp_address  (key)
                        
                        	Candidate\-RP address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: candidate_rp
                        
                        	Cand\-RP Address
                        	**type**\:  :py:class:`CandidateRp_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp_>`
                        
                        .. attribute:: candidate_rp_mode
                        
                        	Cand\-RP Mode
                        	**type**\:  :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: candidate_rp_scope
                        
                        	Cand\-RP Scope
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: crp_priority
                        
                        	Cand\-RP Priority
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: crp_holdtime
                        
                        	Cand\-RP Holdtime
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: candidate_rp_advance_interval
                        
                        	Cand\-RP Adv Interval in seconds
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        	**units**\: second
                        
                        .. attribute:: candidate_rp_uptime
                        
                        	Cand\-RP uptime
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: acl_name
                        
                        	Group Access\-List Name
                        	**type**\: str
                        
                        	**length:** 0..33
                        
                        .. attribute:: crp_access
                        
                        	Group Ranges Using this Cand\-RP
                        	**type**\: list of  		 :py:class:`CrpAccess <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CrpAccess>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp, self).__init__()

                            self.yang_name = "candidate-rp"
                            self.yang_parent_name = "candidate-rps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['rp_address']
                            self._child_classes = OrderedDict([("candidate-rp", ("candidate_rp", Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp_)), ("crp-access", ("crp_access", Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CrpAccess))])
                            self._leafs = OrderedDict([
                                ('rp_address', (YLeaf(YType.str, 'rp-address'), ['str','str'])),
                                ('candidate_rp_mode', (YLeaf(YType.enumeration, 'candidate-rp-mode'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowProtocol', '')])),
                                ('candidate_rp_scope', (YLeaf(YType.int32, 'candidate-rp-scope'), ['int'])),
                                ('crp_priority', (YLeaf(YType.uint8, 'crp-priority'), ['int'])),
                                ('crp_holdtime', (YLeaf(YType.uint16, 'crp-holdtime'), ['int'])),
                                ('candidate_rp_advance_interval', (YLeaf(YType.uint16, 'candidate-rp-advance-interval'), ['int'])),
                                ('candidate_rp_uptime', (YLeaf(YType.uint16, 'candidate-rp-uptime'), ['int'])),
                                ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                            ])
                            self.rp_address = None
                            self.candidate_rp_mode = None
                            self.candidate_rp_scope = None
                            self.crp_priority = None
                            self.crp_holdtime = None
                            self.candidate_rp_advance_interval = None
                            self.candidate_rp_uptime = None
                            self.acl_name = None

                            self.candidate_rp = Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp_()
                            self.candidate_rp.parent = self
                            self._children_name_map["candidate_rp"] = "candidate-rp"

                            self.crp_access = YList(self)
                            self._segment_path = lambda: "candidate-rp" + "[rp-address='" + str(self.rp_address) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/bsr/candidate-rps/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp, ['rp_address', 'candidate_rp_mode', 'candidate_rp_scope', 'crp_priority', 'crp_holdtime', 'candidate_rp_advance_interval', 'candidate_rp_uptime', 'acl_name'], name, value)


                        class CandidateRp_(Entity):
                            """
                            Cand\-RP Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp_, self).__init__()

                                self.yang_name = "candidate-rp"
                                self.yang_parent_name = "candidate-rp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "candidate-rp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp_, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class CrpAccess(Entity):
                            """
                            Group Ranges Using this Cand\-RP
                            
                            .. attribute:: candidate_rp_mode
                            
                            	Cand\-RP Mode
                            	**type**\:  :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                            
                            .. attribute:: acl_name
                            
                            	Group Access\-List Name
                            	**type**\: str
                            
                            	**length:** 0..33
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CrpAccess, self).__init__()

                                self.yang_name = "crp-access"
                                self.yang_parent_name = "candidate-rp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('candidate_rp_mode', (YLeaf(YType.enumeration, 'candidate-rp-mode'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowProtocol', '')])),
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                                ])
                                self.candidate_rp_mode = None
                                self.acl_name = None
                                self._segment_path = lambda: "crp-access"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CrpAccess, ['candidate_rp_mode', 'acl_name'], name, value)


                class BsrElections(Entity):
                    """
                    PIM BSR election state
                    
                    .. attribute:: bsr_election
                    
                    	PIM BSR information
                    	**type**\: list of  		 :py:class:`BsrElection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.Bsr.BsrElections, self).__init__()

                        self.yang_name = "bsr-elections"
                        self.yang_parent_name = "bsr"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("bsr-election", ("bsr_election", Ipv6Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection))])
                        self._leafs = OrderedDict()

                        self.bsr_election = YList(self)
                        self._segment_path = lambda: "bsr-elections"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/bsr/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.Bsr.BsrElections, [], name, value)


                    class BsrElection(Entity):
                        """
                        PIM BSR information
                        
                        .. attribute:: pim_scope  (key)
                        
                        	BSR information
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bsr_address
                        
                        	BSR address
                        	**type**\:  :py:class:`BsrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress>`
                        
                        .. attribute:: candidate_bsr_address
                        
                        	C\-BSR address
                        	**type**\:  :py:class:`CandidateBsrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress>`
                        
                        .. attribute:: bsr_priority
                        
                        	BSR Priority
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: bsr_mask_length
                        
                        	Hash Function Mask Length
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: bsr_up_time
                        
                        	BSR Uptime
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: bootstrap_timeout
                        
                        	Bootstrap Timeout
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: candidate_bsr_state
                        
                        	BSR Candidate State
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bsr_election_state
                        
                        	BSR Election State
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bsr_scope
                        
                        	BSR Scope
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: candidate_bsr_flag
                        
                        	BSR Candidate Config Flag
                        	**type**\: bool
                        
                        .. attribute:: candidate_bsr_priority
                        
                        	C\-BSR Priority
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: candidate_bsr_mask_length
                        
                        	C\-BSR Hash Func. Mask Len
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection, self).__init__()

                            self.yang_name = "bsr-election"
                            self.yang_parent_name = "bsr-elections"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['pim_scope']
                            self._child_classes = OrderedDict([("bsr-address", ("bsr_address", Ipv6Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress)), ("candidate-bsr-address", ("candidate_bsr_address", Ipv6Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress))])
                            self._leafs = OrderedDict([
                                ('pim_scope', (YLeaf(YType.uint32, 'pim-scope'), ['int'])),
                                ('bsr_priority', (YLeaf(YType.uint8, 'bsr-priority'), ['int'])),
                                ('bsr_mask_length', (YLeaf(YType.uint8, 'bsr-mask-length'), ['int'])),
                                ('bsr_up_time', (YLeaf(YType.uint16, 'bsr-up-time'), ['int'])),
                                ('bootstrap_timeout', (YLeaf(YType.uint16, 'bootstrap-timeout'), ['int'])),
                                ('candidate_bsr_state', (YLeaf(YType.uint32, 'candidate-bsr-state'), ['int'])),
                                ('bsr_election_state', (YLeaf(YType.uint32, 'bsr-election-state'), ['int'])),
                                ('bsr_scope', (YLeaf(YType.uint16, 'bsr-scope'), ['int'])),
                                ('candidate_bsr_flag', (YLeaf(YType.boolean, 'candidate-bsr-flag'), ['bool'])),
                                ('candidate_bsr_priority', (YLeaf(YType.uint8, 'candidate-bsr-priority'), ['int'])),
                                ('candidate_bsr_mask_length', (YLeaf(YType.uint8, 'candidate-bsr-mask-length'), ['int'])),
                            ])
                            self.pim_scope = None
                            self.bsr_priority = None
                            self.bsr_mask_length = None
                            self.bsr_up_time = None
                            self.bootstrap_timeout = None
                            self.candidate_bsr_state = None
                            self.bsr_election_state = None
                            self.bsr_scope = None
                            self.candidate_bsr_flag = None
                            self.candidate_bsr_priority = None
                            self.candidate_bsr_mask_length = None

                            self.bsr_address = Ipv6Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress()
                            self.bsr_address.parent = self
                            self._children_name_map["bsr_address"] = "bsr-address"

                            self.candidate_bsr_address = Ipv6Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress()
                            self.candidate_bsr_address.parent = self
                            self._children_name_map["candidate_bsr_address"] = "candidate-bsr-address"
                            self._segment_path = lambda: "bsr-election" + "[pim-scope='" + str(self.pim_scope) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/bsr/bsr-elections/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection, ['pim_scope', 'bsr_priority', 'bsr_mask_length', 'bsr_up_time', 'bootstrap_timeout', 'candidate_bsr_state', 'bsr_election_state', 'bsr_scope', 'candidate_bsr_flag', 'candidate_bsr_priority', 'candidate_bsr_mask_length'], name, value)


                        class BsrAddress(Entity):
                            """
                            BSR address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress, self).__init__()

                                self.yang_name = "bsr-address"
                                self.yang_parent_name = "bsr-election"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "bsr-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class CandidateBsrAddress(Entity):
                            """
                            C\-BSR address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress, self).__init__()

                                self.yang_name = "candidate-bsr-address"
                                self.yang_parent_name = "bsr-election"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "candidate-bsr-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class RoutePolicy(Entity):
                """
                PIM route policy
                
                .. attribute:: route_policy_statistics
                
                	PIM route policy statistics
                	**type**\:  :py:class:`RoutePolicyStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyStatistics>`
                
                .. attribute:: route_policy_tests
                
                	PIM route policy test run table
                	**type**\:  :py:class:`RoutePolicyTests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.RoutePolicy, self).__init__()

                    self.yang_name = "route-policy"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("route-policy-statistics", ("route_policy_statistics", Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyStatistics)), ("route-policy-tests", ("route_policy_tests", Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests))])
                    self._leafs = OrderedDict()

                    self.route_policy_statistics = Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyStatistics()
                    self.route_policy_statistics.parent = self
                    self._children_name_map["route_policy_statistics"] = "route-policy-statistics"

                    self.route_policy_tests = Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests()
                    self.route_policy_tests.parent = self
                    self._children_name_map["route_policy_tests"] = "route-policy-tests"
                    self._segment_path = lambda: "route-policy"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.RoutePolicy, [], name, value)


                class RoutePolicyStatistics(Entity):
                    """
                    PIM route policy statistics
                    
                    .. attribute:: policy_name
                    
                    	RPF policy name
                    	**type**\: str
                    
                    .. attribute:: requests
                    
                    	Number of RPF lookup requests
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pass_
                    
                    	Number of RPF pass
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: drop
                    
                    	Number of RPF drops
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: default_table
                    
                    	Number of RPF lookup in default\-only Table
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: any_table
                    
                    	Number of RPF lookup in any Table
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyStatistics, self).__init__()

                        self.yang_name = "route-policy-statistics"
                        self.yang_parent_name = "route-policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('policy_name', (YLeaf(YType.str, 'policy-name'), ['str'])),
                            ('requests', (YLeaf(YType.uint32, 'requests'), ['int'])),
                            ('pass_', (YLeaf(YType.uint32, 'pass'), ['int'])),
                            ('drop', (YLeaf(YType.uint32, 'drop'), ['int'])),
                            ('default_table', (YLeaf(YType.uint32, 'default-table'), ['int'])),
                            ('any_table', (YLeaf(YType.uint32, 'any-table'), ['int'])),
                        ])
                        self.policy_name = None
                        self.requests = None
                        self.pass_ = None
                        self.drop = None
                        self.default_table = None
                        self.any_table = None
                        self._segment_path = lambda: "route-policy-statistics"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/route-policy/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyStatistics, ['policy_name', 'requests', 'pass_', 'drop', 'default_table', 'any_table'], name, value)


                class RoutePolicyTests(Entity):
                    """
                    PIM route policy test run table
                    
                    .. attribute:: route_policy_test
                    
                    	PIM route policy test run
                    	**type**\: list of  		 :py:class:`RoutePolicyTest <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests, self).__init__()

                        self.yang_name = "route-policy-tests"
                        self.yang_parent_name = "route-policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("route-policy-test", ("route_policy_test", Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest))])
                        self._leafs = OrderedDict()

                        self.route_policy_test = YList(self)
                        self._segment_path = lambda: "route-policy-tests"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/route-policy/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests, [], name, value)


                    class RoutePolicyTest(Entity):
                        """
                        PIM route policy test run
                        
                        .. attribute:: source_address
                        
                        	Source IP address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: group_address
                        
                        	Group IP address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ext_comm
                        
                        	Extended Community
                        	**type**\: str
                        
                        	**length:** 1..8
                        
                        .. attribute:: source_address_xr
                        
                        	Source address
                        	**type**\:  :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr>`
                        
                        .. attribute:: group_address_xr
                        
                        	Source address
                        	**type**\:  :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr>`
                        
                        .. attribute:: policy_name
                        
                        	RPF policy name
                        	**type**\: str
                        
                        .. attribute:: extended_community_rt
                        
                        	Route Target
                        	**type**\: str
                        
                        	**length:** 0..33
                        
                        .. attribute:: pass_
                        
                        	Pass
                        	**type**\: bool
                        
                        .. attribute:: default_table
                        
                        	Default table selected
                        	**type**\: bool
                        
                        .. attribute:: vrf_name
                        
                        	VRF name
                        	**type**\: str
                        
                        	**length:** 0..33
                        
                        .. attribute:: afi
                        
                        	AFI
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: safi
                        
                        	SAFI
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_name
                        
                        	Table name
                        	**type**\: str
                        
                        .. attribute:: table_exists
                        
                        	Table exists
                        	**type**\: bool
                        
                        .. attribute:: table_active
                        
                        	Table active
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest, self).__init__()

                            self.yang_name = "route-policy-test"
                            self.yang_parent_name = "route-policy-tests"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("source-address-xr", ("source_address_xr", Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr)), ("group-address-xr", ("group_address_xr", Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr))])
                            self._leafs = OrderedDict([
                                ('source_address', (YLeaf(YType.str, 'source-address'), ['str','str'])),
                                ('group_address', (YLeaf(YType.str, 'group-address'), ['str','str'])),
                                ('ext_comm', (YLeaf(YType.str, 'ext-comm'), ['str'])),
                                ('policy_name', (YLeaf(YType.str, 'policy-name'), ['str'])),
                                ('extended_community_rt', (YLeaf(YType.str, 'extended-community-rt'), ['str'])),
                                ('pass_', (YLeaf(YType.boolean, 'pass'), ['bool'])),
                                ('default_table', (YLeaf(YType.boolean, 'default-table'), ['bool'])),
                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                ('afi', (YLeaf(YType.uint32, 'afi'), ['int'])),
                                ('safi', (YLeaf(YType.uint32, 'safi'), ['int'])),
                                ('table_name', (YLeaf(YType.str, 'table-name'), ['str'])),
                                ('table_exists', (YLeaf(YType.boolean, 'table-exists'), ['bool'])),
                                ('table_active', (YLeaf(YType.boolean, 'table-active'), ['bool'])),
                            ])
                            self.source_address = None
                            self.group_address = None
                            self.ext_comm = None
                            self.policy_name = None
                            self.extended_community_rt = None
                            self.pass_ = None
                            self.default_table = None
                            self.vrf_name = None
                            self.afi = None
                            self.safi = None
                            self.table_name = None
                            self.table_exists = None
                            self.table_active = None

                            self.source_address_xr = Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr()
                            self.source_address_xr.parent = self
                            self._children_name_map["source_address_xr"] = "source-address-xr"

                            self.group_address_xr = Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._segment_path = lambda: "route-policy-test"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/route-policy/route-policy-tests/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest, ['source_address', 'group_address', 'ext_comm', 'policy_name', 'extended_community_rt', 'pass_', 'default_table', 'vrf_name', 'afi', 'safi', 'table_name', 'table_exists', 'table_active'], name, value)


                        class SourceAddressXr(Entity):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr, self).__init__()

                                self.yang_name = "source-address-xr"
                                self.yang_parent_name = "route-policy-test"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "source-address-xr"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/route-policy/route-policy-tests/route-policy-test/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class GroupAddressXr(Entity):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "route-policy-test"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "group-address-xr"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/route-policy/route-policy-tests/route-policy-test/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class RpfSummary(Entity):
                """
                PIM RPF registration summary
                
                .. attribute:: default_safi
                
                	Default RPF Table SAFI
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: default_table_name
                
                	Default RPF Table Name
                	**type**\: str
                
                .. attribute:: is_mbgp_configured
                
                	Is MBGP configured?
                	**type**\: bool
                
                .. attribute:: is_ospf_te_configured
                
                	Is OSPF TE configured?
                	**type**\: bool
                
                .. attribute:: is_isis_te_configured
                
                	Is ISIS TE configured?
                	**type**\: bool
                
                .. attribute:: is_isis_mtr_configured
                
                	Is ISIS MTR configured?
                	**type**\: bool
                
                .. attribute:: mo_frr_configured
                
                	Is MoFRR configured?
                	**type**\: bool
                
                .. attribute:: rib_mo_frr_configured
                
                	Is MoFRR RIB configured?
                	**type**\: bool
                
                .. attribute:: rump_enabled
                
                	Is RUMP MuRIB enabled?
                	**type**\: bool
                
                .. attribute:: rib_convergence_timeout
                
                	RIB convergence timeout in seconds
                	**type**\: int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: rib_convergence_time_left
                
                	RIB convergence time left in seconds
                	**type**\: int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: is_multipath_enabled
                
                	Is Multipath Enabled ?
                	**type**\: bool
                
                .. attribute:: is_multipath_interface_hash_enabled
                
                	Is Multipath Interface Hash Extension Enabled ?
                	**type**\: bool
                
                .. attribute:: is_multipath_source_hash_enabled
                
                	Is Multipath Source based Hash Enabled ?
                	**type**\: bool
                
                .. attribute:: is_multipath_source_next_hop_hash_enabled
                
                	Is Multipath Source\-Nexthop Hash Enabled ?
                	**type**\: bool
                
                .. attribute:: rpf_registrations
                
                	RPF Registration count
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_rib_convergence
                
                	RIB Convergence status
                	**type**\: bool
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.RpfSummary, self).__init__()

                    self.yang_name = "rpf-summary"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('default_safi', (YLeaf(YType.uint32, 'default-safi'), ['int'])),
                        ('default_table_name', (YLeaf(YType.str, 'default-table-name'), ['str'])),
                        ('is_mbgp_configured', (YLeaf(YType.boolean, 'is-mbgp-configured'), ['bool'])),
                        ('is_ospf_te_configured', (YLeaf(YType.boolean, 'is-ospf-te-configured'), ['bool'])),
                        ('is_isis_te_configured', (YLeaf(YType.boolean, 'is-isis-te-configured'), ['bool'])),
                        ('is_isis_mtr_configured', (YLeaf(YType.boolean, 'is-isis-mtr-configured'), ['bool'])),
                        ('mo_frr_configured', (YLeaf(YType.boolean, 'mo-frr-configured'), ['bool'])),
                        ('rib_mo_frr_configured', (YLeaf(YType.boolean, 'rib-mo-frr-configured'), ['bool'])),
                        ('rump_enabled', (YLeaf(YType.boolean, 'rump-enabled'), ['bool'])),
                        ('rib_convergence_timeout', (YLeaf(YType.uint32, 'rib-convergence-timeout'), ['int'])),
                        ('rib_convergence_time_left', (YLeaf(YType.uint32, 'rib-convergence-time-left'), ['int'])),
                        ('is_multipath_enabled', (YLeaf(YType.boolean, 'is-multipath-enabled'), ['bool'])),
                        ('is_multipath_interface_hash_enabled', (YLeaf(YType.boolean, 'is-multipath-interface-hash-enabled'), ['bool'])),
                        ('is_multipath_source_hash_enabled', (YLeaf(YType.boolean, 'is-multipath-source-hash-enabled'), ['bool'])),
                        ('is_multipath_source_next_hop_hash_enabled', (YLeaf(YType.boolean, 'is-multipath-source-next-hop-hash-enabled'), ['bool'])),
                        ('rpf_registrations', (YLeaf(YType.uint32, 'rpf-registrations'), ['int'])),
                        ('is_rib_convergence', (YLeaf(YType.boolean, 'is-rib-convergence'), ['bool'])),
                    ])
                    self.default_safi = None
                    self.default_table_name = None
                    self.is_mbgp_configured = None
                    self.is_ospf_te_configured = None
                    self.is_isis_te_configured = None
                    self.is_isis_mtr_configured = None
                    self.mo_frr_configured = None
                    self.rib_mo_frr_configured = None
                    self.rump_enabled = None
                    self.rib_convergence_timeout = None
                    self.rib_convergence_time_left = None
                    self.is_multipath_enabled = None
                    self.is_multipath_interface_hash_enabled = None
                    self.is_multipath_source_hash_enabled = None
                    self.is_multipath_source_next_hop_hash_enabled = None
                    self.rpf_registrations = None
                    self.is_rib_convergence = None
                    self._segment_path = lambda: "rpf-summary"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.RpfSummary, ['default_safi', 'default_table_name', 'is_mbgp_configured', 'is_ospf_te_configured', 'is_isis_te_configured', 'is_isis_mtr_configured', 'mo_frr_configured', 'rib_mo_frr_configured', 'rump_enabled', 'rib_convergence_timeout', 'rib_convergence_time_left', 'is_multipath_enabled', 'is_multipath_interface_hash_enabled', 'is_multipath_source_hash_enabled', 'is_multipath_source_next_hop_hash_enabled', 'rpf_registrations', 'is_rib_convergence'], name, value)


            class Interfaces(Entity):
                """
                PIM interfaces
                
                .. attribute:: interface
                
                	PIM interface name
                	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Interfaces.Interface>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.Interfaces, self).__init__()

                    self.yang_name = "interfaces"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("interface", ("interface", Ipv6Pim.Active.DefaultContext.Interfaces.Interface))])
                    self._leafs = OrderedDict()

                    self.interface = YList(self)
                    self._segment_path = lambda: "interfaces"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.Interfaces, [], name, value)


                class Interface(Entity):
                    """
                    PIM interface name
                    
                    .. attribute:: interface_name  (key)
                    
                    	Interface name
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: dr_address
                    
                    	PIM Designated Router
                    	**type**\:  :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Interfaces.Interface.DrAddress>`
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identfier
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: interface_address_mask
                    
                    	Interface IP Address Mask
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: is_enabled
                    
                    	Is PIM enabled on this IF ?
                    	**type**\: bool
                    
                    .. attribute:: neighbor_count
                    
                    	No. of neighbors on this IF
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: external_neighbor_count
                    
                    	No. of external neighbors on this IF
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: hello_interval
                    
                    	Hello Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dr_priority
                    
                    	DR Priority
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_expiry
                    
                    	Hello Timer Expiry
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: are_we_dr
                    
                    	Are we the DR on this IF ?
                    	**type**\: bool
                    
                    .. attribute:: bfd_enabled
                    
                    	BFD state
                    	**type**\: bool
                    
                    .. attribute:: bfd_interval
                    
                    	BFD Interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bfd_multiplier
                    
                    	BFD Multiplier
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_interface
                    
                    	 is this a Virtual Interfaces ?
                    	**type**\: bool
                    
                    .. attribute:: passive_interface
                    
                    	Passive PIM interface
                    	**type**\: bool
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\: str
                    
                    .. attribute:: join_prune_interval
                    
                    	Join\-Prune Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: prune_delay_enabled
                    
                    	Prune Delay Enabled
                    	**type**\: bool
                    
                    .. attribute:: configured_propagation_delay
                    
                    	Configured Propagation Delay
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_override_interval
                    
                    	Configured Override Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: generation_id
                    
                    	Generation Identifier
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Bidir Capable
                    	**type**\: bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Proxy Capable
                    	**type**\: bool
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Batch Asserts Capable
                    	**type**\: bool
                    
                    .. attribute:: idb_oor_enabled
                    
                    	Interface oor enabled
                    	**type**\: bool
                    
                    .. attribute:: idb_acl_provided
                    
                    	ACL name provided
                    	**type**\: bool
                    
                    .. attribute:: idb_max_count
                    
                    	Interface ole max count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_threshold_count
                    
                    	Interface ole threshold count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_current_count
                    
                    	Interface ole current count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_acl_name
                    
                    	Interface ole ACL Name
                    	**type**\: str
                    
                    	**length:** 0..64
                    
                    .. attribute:: interface_address
                    
                    	List of Interface IP Addresses
                    	**type**\: list of  		 :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Interfaces.Interface.InterfaceAddress>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.Interfaces.Interface, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "interfaces"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['interface_name']
                        self._child_classes = OrderedDict([("dr-address", ("dr_address", Ipv6Pim.Active.DefaultContext.Interfaces.Interface.DrAddress)), ("interface-address", ("interface_address", Ipv6Pim.Active.DefaultContext.Interfaces.Interface.InterfaceAddress))])
                        self._leafs = OrderedDict([
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                            ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                            ('interface_address_mask', (YLeaf(YType.uint8, 'interface-address-mask'), ['int'])),
                            ('is_enabled', (YLeaf(YType.boolean, 'is-enabled'), ['bool'])),
                            ('neighbor_count', (YLeaf(YType.uint16, 'neighbor-count'), ['int'])),
                            ('external_neighbor_count', (YLeaf(YType.uint16, 'external-neighbor-count'), ['int'])),
                            ('hello_interval', (YLeaf(YType.uint16, 'hello-interval'), ['int'])),
                            ('dr_priority', (YLeaf(YType.uint32, 'dr-priority'), ['int'])),
                            ('hello_expiry', (YLeaf(YType.uint64, 'hello-expiry'), ['int'])),
                            ('are_we_dr', (YLeaf(YType.boolean, 'are-we-dr'), ['bool'])),
                            ('bfd_enabled', (YLeaf(YType.boolean, 'bfd-enabled'), ['bool'])),
                            ('bfd_interval', (YLeaf(YType.uint32, 'bfd-interval'), ['int'])),
                            ('bfd_multiplier', (YLeaf(YType.uint32, 'bfd-multiplier'), ['int'])),
                            ('virtual_interface', (YLeaf(YType.boolean, 'virtual-interface'), ['bool'])),
                            ('passive_interface', (YLeaf(YType.boolean, 'passive-interface'), ['bool'])),
                            ('neighbor_filter_name', (YLeaf(YType.str, 'neighbor-filter-name'), ['str'])),
                            ('join_prune_interval', (YLeaf(YType.uint16, 'join-prune-interval'), ['int'])),
                            ('prune_delay_enabled', (YLeaf(YType.boolean, 'prune-delay-enabled'), ['bool'])),
                            ('configured_propagation_delay', (YLeaf(YType.uint16, 'configured-propagation-delay'), ['int'])),
                            ('propagation_delay', (YLeaf(YType.uint16, 'propagation-delay'), ['int'])),
                            ('configured_override_interval', (YLeaf(YType.uint16, 'configured-override-interval'), ['int'])),
                            ('override_interval', (YLeaf(YType.uint16, 'override-interval'), ['int'])),
                            ('generation_id', (YLeaf(YType.uint32, 'generation-id'), ['int'])),
                            ('is_bidirectional_capable', (YLeaf(YType.boolean, 'is-bidirectional-capable'), ['bool'])),
                            ('is_proxy_capable', (YLeaf(YType.boolean, 'is-proxy-capable'), ['bool'])),
                            ('is_batch_asserts_capable', (YLeaf(YType.boolean, 'is-batch-asserts-capable'), ['bool'])),
                            ('idb_oor_enabled', (YLeaf(YType.boolean, 'idb-oor-enabled'), ['bool'])),
                            ('idb_acl_provided', (YLeaf(YType.boolean, 'idb-acl-provided'), ['bool'])),
                            ('idb_max_count', (YLeaf(YType.uint32, 'idb-max-count'), ['int'])),
                            ('idb_threshold_count', (YLeaf(YType.uint32, 'idb-threshold-count'), ['int'])),
                            ('idb_current_count', (YLeaf(YType.uint32, 'idb-current-count'), ['int'])),
                            ('idb_acl_name', (YLeaf(YType.str, 'idb-acl-name'), ['str'])),
                        ])
                        self.interface_name = None
                        self.interface_name_xr = None
                        self.interface_address_mask = None
                        self.is_enabled = None
                        self.neighbor_count = None
                        self.external_neighbor_count = None
                        self.hello_interval = None
                        self.dr_priority = None
                        self.hello_expiry = None
                        self.are_we_dr = None
                        self.bfd_enabled = None
                        self.bfd_interval = None
                        self.bfd_multiplier = None
                        self.virtual_interface = None
                        self.passive_interface = None
                        self.neighbor_filter_name = None
                        self.join_prune_interval = None
                        self.prune_delay_enabled = None
                        self.configured_propagation_delay = None
                        self.propagation_delay = None
                        self.configured_override_interval = None
                        self.override_interval = None
                        self.generation_id = None
                        self.is_bidirectional_capable = None
                        self.is_proxy_capable = None
                        self.is_batch_asserts_capable = None
                        self.idb_oor_enabled = None
                        self.idb_acl_provided = None
                        self.idb_max_count = None
                        self.idb_threshold_count = None
                        self.idb_current_count = None
                        self.idb_acl_name = None

                        self.dr_address = Ipv6Pim.Active.DefaultContext.Interfaces.Interface.DrAddress()
                        self.dr_address.parent = self
                        self._children_name_map["dr_address"] = "dr-address"

                        self.interface_address = YList(self)
                        self._segment_path = lambda: "interface" + "[interface-name='" + str(self.interface_name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/interfaces/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.Interfaces.Interface, ['interface_name', 'interface_name_xr', 'interface_address_mask', 'is_enabled', 'neighbor_count', 'external_neighbor_count', 'hello_interval', 'dr_priority', 'hello_expiry', 'are_we_dr', 'bfd_enabled', 'bfd_interval', 'bfd_multiplier', 'virtual_interface', 'passive_interface', 'neighbor_filter_name', 'join_prune_interval', 'prune_delay_enabled', 'configured_propagation_delay', 'propagation_delay', 'configured_override_interval', 'override_interval', 'generation_id', 'is_bidirectional_capable', 'is_proxy_capable', 'is_batch_asserts_capable', 'idb_oor_enabled', 'idb_acl_provided', 'idb_max_count', 'idb_threshold_count', 'idb_current_count', 'idb_acl_name'], name, value)


                    class DrAddress(Entity):
                        """
                        PIM Designated Router
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Interfaces.Interface.DrAddress, self).__init__()

                            self.yang_name = "dr-address"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "dr-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.Interfaces.Interface.DrAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class InterfaceAddress(Entity):
                        """
                        List of Interface IP Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Interfaces.Interface.InterfaceAddress, self).__init__()

                            self.yang_name = "interface-address"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "interface-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.Interfaces.Interface.InterfaceAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class NetIoTunnels(Entity):
                """
                Tunnel information that NETIO has 
                
                .. attribute:: net_io_tunnel
                
                	PIM netio tunnel information
                	**type**\: list of  		 :py:class:`NetIoTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.NetIoTunnels, self).__init__()

                    self.yang_name = "net-io-tunnels"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("net-io-tunnel", ("net_io_tunnel", Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel))])
                    self._leafs = OrderedDict()

                    self.net_io_tunnel = YList(self)
                    self._segment_path = lambda: "net-io-tunnels"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.NetIoTunnels, [], name, value)


                class NetIoTunnel(Entity):
                    """
                    PIM netio tunnel information
                    
                    .. attribute:: tunnel_name  (key)
                    
                    	Tunnel name
                    	**type**\: str
                    
                    	**length:** 1..64
                    
                    .. attribute:: source_address
                    
                    	Source addr known to PIM
                    	**type**\:  :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress>`
                    
                    .. attribute:: rp_address
                    
                    	RP addr known to PIM
                    	**type**\:  :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress>`
                    
                    .. attribute:: source_address_netio
                    
                    	Source addr from netio
                    	**type**\:  :py:class:`SourceAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio>`
                    
                    .. attribute:: group_address_netio
                    
                    	Group addr from netio
                    	**type**\:  :py:class:`GroupAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio>`
                    
                    .. attribute:: vrf_name
                    
                    	VRF Name
                    	**type**\: str
                    
                    	**length:** 0..33
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel, self).__init__()

                        self.yang_name = "net-io-tunnel"
                        self.yang_parent_name = "net-io-tunnels"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['tunnel_name']
                        self._child_classes = OrderedDict([("source-address", ("source_address", Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress)), ("rp-address", ("rp_address", Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress)), ("source-address-netio", ("source_address_netio", Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio)), ("group-address-netio", ("group_address_netio", Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio))])
                        self._leafs = OrderedDict([
                            ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                        ])
                        self.tunnel_name = None
                        self.vrf_name = None

                        self.source_address = Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress()
                        self.source_address.parent = self
                        self._children_name_map["source_address"] = "source-address"

                        self.rp_address = Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress()
                        self.rp_address.parent = self
                        self._children_name_map["rp_address"] = "rp-address"

                        self.source_address_netio = Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio()
                        self.source_address_netio.parent = self
                        self._children_name_map["source_address_netio"] = "source-address-netio"

                        self.group_address_netio = Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio()
                        self.group_address_netio.parent = self
                        self._children_name_map["group_address_netio"] = "group-address-netio"
                        self._segment_path = lambda: "net-io-tunnel" + "[tunnel-name='" + str(self.tunnel_name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/net-io-tunnels/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel, ['tunnel_name', 'vrf_name'], name, value)


                    class SourceAddress(Entity):
                        """
                        Source addr known to PIM
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress, self).__init__()

                            self.yang_name = "source-address"
                            self.yang_parent_name = "net-io-tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "source-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class RpAddress(Entity):
                        """
                        RP addr known to PIM
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress, self).__init__()

                            self.yang_name = "rp-address"
                            self.yang_parent_name = "net-io-tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "rp-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class SourceAddressNetio(Entity):
                        """
                        Source addr from netio
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio, self).__init__()

                            self.yang_name = "source-address-netio"
                            self.yang_parent_name = "net-io-tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "source-address-netio"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class GroupAddressNetio(Entity):
                        """
                        Group addr from netio
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio, self).__init__()

                            self.yang_name = "group-address-netio"
                            self.yang_parent_name = "net-io-tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "group-address-netio"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class BidirDfStates(Entity):
                """
                Bidirectional PIM DF election state table
                
                .. attribute:: bidir_df_state
                
                	Bidirectional PIM DF Election Table Entry
                	**type**\: list of  		 :py:class:`BidirDfState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.BidirDfStates.BidirDfState>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.BidirDfStates, self).__init__()

                    self.yang_name = "bidir-df-states"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("bidir-df-state", ("bidir_df_state", Ipv6Pim.Active.DefaultContext.BidirDfStates.BidirDfState))])
                    self._leafs = OrderedDict()

                    self.bidir_df_state = YList(self)
                    self._segment_path = lambda: "bidir-df-states"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.BidirDfStates, [], name, value)


                class BidirDfState(Entity):
                    """
                    Bidirectional PIM DF Election Table Entry
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: rp_address_xr
                    
                    	RP Address
                    	**type**\:  :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr>`
                    
                    .. attribute:: pim_interface_name
                    
                    	Interface Name
                    	**type**\: str
                    
                    .. attribute:: election_state
                    
                    	DF Election State
                    	**type**\: str
                    
                    .. attribute:: time_seconds
                    
                    	Timer expires (seconds)
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: time_nano_seconds
                    
                    	Timer expires (nseconds)
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: nanosecond
                    
                    .. attribute:: our_metric
                    
                    	Metric
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: our_metric_preference
                    
                    	MetricPreference
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.BidirDfStates.BidirDfState, self).__init__()

                        self.yang_name = "bidir-df-state"
                        self.yang_parent_name = "bidir-df-states"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("rp-address-xr", ("rp_address_xr", Ipv6Pim.Active.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr))])
                        self._leafs = OrderedDict([
                            ('rp_address', (YLeaf(YType.str, 'rp-address'), ['str','str'])),
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                            ('pim_interface_name', (YLeaf(YType.str, 'pim-interface-name'), ['str'])),
                            ('election_state', (YLeaf(YType.str, 'election-state'), ['str'])),
                            ('time_seconds', (YLeaf(YType.uint64, 'time-seconds'), ['int'])),
                            ('time_nano_seconds', (YLeaf(YType.uint64, 'time-nano-seconds'), ['int'])),
                            ('our_metric', (YLeaf(YType.uint32, 'our-metric'), ['int'])),
                            ('our_metric_preference', (YLeaf(YType.uint32, 'our-metric-preference'), ['int'])),
                        ])
                        self.rp_address = None
                        self.interface_name = None
                        self.pim_interface_name = None
                        self.election_state = None
                        self.time_seconds = None
                        self.time_nano_seconds = None
                        self.our_metric = None
                        self.our_metric_preference = None

                        self.rp_address_xr = Ipv6Pim.Active.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr()
                        self.rp_address_xr.parent = self
                        self._children_name_map["rp_address_xr"] = "rp-address-xr"
                        self._segment_path = lambda: "bidir-df-state"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/bidir-df-states/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.BidirDfStates.BidirDfState, ['rp_address', 'interface_name', 'pim_interface_name', 'election_state', 'time_seconds', 'time_nano_seconds', 'our_metric', 'our_metric_preference'], name, value)


                    class RpAddressXr(Entity):
                        """
                        RP Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr, self).__init__()

                            self.yang_name = "rp-address-xr"
                            self.yang_parent_name = "bidir-df-state"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "rp-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/bidir-df-states/bidir-df-state/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class Topologies(Entity):
                """
                PIM topology table
                
                .. attribute:: topology
                
                	PIM topology information
                	**type**\: list of  		 :py:class:`Topology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Topologies.Topology>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.Topologies, self).__init__()

                    self.yang_name = "topologies"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("topology", ("topology", Ipv6Pim.Active.DefaultContext.Topologies.Topology))])
                    self._leafs = OrderedDict()

                    self.topology = YList(self)
                    self._segment_path = lambda: "topologies"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.Topologies, [], name, value)


                class Topology(Entity):
                    """
                    PIM topology information
                    
                    .. attribute:: source_address
                    
                    	Source address
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: group_address
                    
                    	Group address
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: rpt
                    
                    	RPT bit
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_address_xr
                    
                    	Group Address
                    	**type**\:  :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Topologies.Topology.GroupAddressXr>`
                    
                    .. attribute:: source_address_xr
                    
                    	Source Address
                    	**type**\:  :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Topologies.Topology.SourceAddressXr>`
                    
                    .. attribute:: rp_address
                    
                    	RP Address (If rpt)
                    	**type**\:  :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Topologies.Topology.RpAddress>`
                    
                    .. attribute:: rpf_neighbor
                    
                    	RPF Neighbor
                    	**type**\:  :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Topologies.Topology.RpfNeighbor>`
                    
                    .. attribute:: secondary_rpf_neighbor
                    
                    	Secondary RPF Neighbor
                    	**type**\:  :py:class:`SecondaryRpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor>`
                    
                    .. attribute:: rpf_root
                    
                    	Root of this mcast tree
                    	**type**\:  :py:class:`RpfRoot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Topologies.Topology.RpfRoot>`
                    
                    .. attribute:: proxy_address
                    
                    	RPF Proxy address
                    	**type**\:  :py:class:`ProxyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Topologies.Topology.ProxyAddress>`
                    
                    .. attribute:: orig_src_address
                    
                    	Orig Src Address
                    	**type**\:  :py:class:`OrigSrcAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Topologies.Topology.OrigSrcAddress>`
                    
                    .. attribute:: limit_reached
                    
                    	Have we throttled the creation of routes or interfaces ?
                    	**type**\: bool
                    
                    .. attribute:: low_memory
                    
                    	Node is running low on memory
                    	**type**\: bool
                    
                    .. attribute:: protocol
                    
                    	The PIM protocol
                    	**type**\:  :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                    
                    .. attribute:: wildcard
                    
                    	WC \-Wildcard
                    	**type**\: bool
                    
                    .. attribute:: rpt_xr
                    
                    	Is this on the RPT ?
                    	**type**\: bool
                    
                    .. attribute:: spt
                    
                    	Is this on the SPT ?
                    	**type**\: bool
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: expiry
                    
                    	When this entry expires
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: alive
                    
                    	Alive time in seconds (\-1 if never)
                    	**type**\: int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    .. attribute:: register_received_timer
                    
                    	Register Received Timer in seconds (\-1 if never)
                    	**type**\: int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    .. attribute:: remote_source
                    
                    	MSDP told us
                    	**type**\: bool
                    
                    .. attribute:: crossed_threshold
                    
                    	Incoming traffic crossed threshold. MT flag set
                    	**type**\: bool
                    
                    .. attribute:: data_mdt_addr_assigned
                    
                    	PIM has assigned a Data MDT Address
                    	**type**\: bool
                    
                    .. attribute:: rpf_interface_name
                    
                    	Interface Identifier
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: rpf_vrf_name
                    
                    	RPF VRF Name
                    	**type**\: str
                    
                    	**length:** 0..33
                    
                    .. attribute:: rpf_safi
                    
                    	Unicast or mcast
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: rpf_table_name
                    
                    	RPF Table name
                    	**type**\: str
                    
                    .. attribute:: rpf_drop
                    
                    	RPF route\-policy drop
                    	**type**\: bool
                    
                    .. attribute:: rpf_extranet
                    
                    	Extranet RPF route\-policy
                    	**type**\: bool
                    
                    .. attribute:: is_via_lsm
                    
                    	Via LSM
                    	**type**\: bool
                    
                    .. attribute:: secondary_rpf_interface_name
                    
                    	Secondary Interface Identifier
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: connected
                    
                    	Is Connected ?
                    	**type**\: bool
                    
                    .. attribute:: proxy
                    
                    	Is the RPF target a proxy?
                    	**type**\: bool
                    
                    .. attribute:: rpf_proxy_enabled
                    
                    	Is rpf if proxy enabled?
                    	**type**\: bool
                    
                    .. attribute:: mofrr_enabled
                    
                    	Is this SG MoFRR enabled?
                    	**type**\: bool
                    
                    .. attribute:: rib_mo_frr_enabled
                    
                    	Is this SG MoFRR enabled?
                    	**type**\: bool
                    
                    .. attribute:: jp_timer
                    
                    	Join\-Prune Timer
                    	**type**\: int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: jp_status
                    
                    	Join\-Prune Status
                    	**type**\: int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: suppress_registers
                    
                    	When the Null register probe expires
                    	**type**\: int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: assume_alive
                    
                    	The Assume Alive Bit
                    	**type**\: bool
                    
                    .. attribute:: probe_alive
                    
                    	The Probe Alive Bit
                    	**type**\: bool
                    
                    .. attribute:: really_alive
                    
                    	The Really Alive Bit
                    	**type**\: bool
                    
                    .. attribute:: inherit_alive
                    
                    	The Inherit Alive Bit
                    	**type**\: bool
                    
                    .. attribute:: inherit_spt
                    
                    	The Inherit SPT Bit
                    	**type**\: bool
                    
                    .. attribute:: signal_sources
                    
                    	Signal Sources on route?
                    	**type**\: bool
                    
                    .. attribute:: dont_check_connected
                    
                    	Do we need to make the connected check on this route ?
                    	**type**\: bool
                    
                    .. attribute:: register_received
                    
                    	Have registers been received for this source ?
                    	**type**\: bool
                    
                    .. attribute:: last_hop
                    
                    	Are we last hop ?
                    	**type**\: bool
                    
                    .. attribute:: sending_registers
                    
                    	Are we sending registers for this route ?
                    	**type**\: bool
                    
                    .. attribute:: sending_null_registers
                    
                    	Are we sending null registers for this route ?
                    	**type**\: bool
                    
                    .. attribute:: sa_sent
                    
                    	BGP SA sent
                    	**type**\: bool
                    
                    .. attribute:: sa_received
                    
                    	BGP SA received
                    	**type**\: bool
                    
                    .. attribute:: sa_joined
                    
                    	BGP SA join
                    	**type**\: bool
                    
                    .. attribute:: anycast_rp_match
                    
                    	Group matches Anycast\-RP policy
                    	**type**\: bool
                    
                    .. attribute:: anycast_rp_route_target
                    
                    	Anycast\-RP RT
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: bgp_join
                    
                    	BGP C JOIN
                    	**type**\: bool
                    
                    .. attribute:: bgp_jp_time
                    
                    	BGP C JP Time
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: customer_routing_type
                    
                    	Type of Customer Routing in the MVPN
                    	**type**\: int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: extranet_route
                    
                    	Is a Extranet route ?
                    	**type**\: bool
                    
                    .. attribute:: mofrr_active
                    
                    	Is MoFRR Active?
                    	**type**\: bool
                    
                    .. attribute:: mofrr_primary
                    
                    	Is this Mofrr Primary?
                    	**type**\: bool
                    
                    .. attribute:: mofrr_backup
                    
                    	Is this Mofrr Backup?
                    	**type**\: bool
                    
                    .. attribute:: vxlan
                    
                    	Is this VXLAN?
                    	**type**\: bool
                    
                    .. attribute:: kat_state
                    
                    	Keep Alive Timer State
                    	**type**\: bool
                    
                    .. attribute:: outgoing_interface
                    
                    	Outgoing interface list
                    	**type**\: list of  		 :py:class:`OutgoingInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.Topologies.Topology, self).__init__()

                        self.yang_name = "topology"
                        self.yang_parent_name = "topologies"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("group-address-xr", ("group_address_xr", Ipv6Pim.Active.DefaultContext.Topologies.Topology.GroupAddressXr)), ("source-address-xr", ("source_address_xr", Ipv6Pim.Active.DefaultContext.Topologies.Topology.SourceAddressXr)), ("rp-address", ("rp_address", Ipv6Pim.Active.DefaultContext.Topologies.Topology.RpAddress)), ("rpf-neighbor", ("rpf_neighbor", Ipv6Pim.Active.DefaultContext.Topologies.Topology.RpfNeighbor)), ("secondary-rpf-neighbor", ("secondary_rpf_neighbor", Ipv6Pim.Active.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor)), ("rpf-root", ("rpf_root", Ipv6Pim.Active.DefaultContext.Topologies.Topology.RpfRoot)), ("proxy-address", ("proxy_address", Ipv6Pim.Active.DefaultContext.Topologies.Topology.ProxyAddress)), ("orig-src-address", ("orig_src_address", Ipv6Pim.Active.DefaultContext.Topologies.Topology.OrigSrcAddress)), ("outgoing-interface", ("outgoing_interface", Ipv6Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface))])
                        self._leafs = OrderedDict([
                            ('source_address', (YLeaf(YType.str, 'source-address'), ['str','str'])),
                            ('group_address', (YLeaf(YType.str, 'group-address'), ['str','str'])),
                            ('rpt', (YLeaf(YType.uint32, 'rpt'), ['int'])),
                            ('limit_reached', (YLeaf(YType.boolean, 'limit-reached'), ['bool'])),
                            ('low_memory', (YLeaf(YType.boolean, 'low-memory'), ['bool'])),
                            ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowProtocol', '')])),
                            ('wildcard', (YLeaf(YType.boolean, 'wildcard'), ['bool'])),
                            ('rpt_xr', (YLeaf(YType.boolean, 'rpt-xr'), ['bool'])),
                            ('spt', (YLeaf(YType.boolean, 'spt'), ['bool'])),
                            ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                            ('expiry', (YLeaf(YType.uint64, 'expiry'), ['int'])),
                            ('alive', (YLeaf(YType.int32, 'alive'), ['int'])),
                            ('register_received_timer', (YLeaf(YType.int32, 'register-received-timer'), ['int'])),
                            ('remote_source', (YLeaf(YType.boolean, 'remote-source'), ['bool'])),
                            ('crossed_threshold', (YLeaf(YType.boolean, 'crossed-threshold'), ['bool'])),
                            ('data_mdt_addr_assigned', (YLeaf(YType.boolean, 'data-mdt-addr-assigned'), ['bool'])),
                            ('rpf_interface_name', (YLeaf(YType.str, 'rpf-interface-name'), ['str'])),
                            ('rpf_vrf_name', (YLeaf(YType.str, 'rpf-vrf-name'), ['str'])),
                            ('rpf_safi', (YLeaf(YType.uint8, 'rpf-safi'), ['int'])),
                            ('rpf_table_name', (YLeaf(YType.str, 'rpf-table-name'), ['str'])),
                            ('rpf_drop', (YLeaf(YType.boolean, 'rpf-drop'), ['bool'])),
                            ('rpf_extranet', (YLeaf(YType.boolean, 'rpf-extranet'), ['bool'])),
                            ('is_via_lsm', (YLeaf(YType.boolean, 'is-via-lsm'), ['bool'])),
                            ('secondary_rpf_interface_name', (YLeaf(YType.str, 'secondary-rpf-interface-name'), ['str'])),
                            ('connected', (YLeaf(YType.boolean, 'connected'), ['bool'])),
                            ('proxy', (YLeaf(YType.boolean, 'proxy'), ['bool'])),
                            ('rpf_proxy_enabled', (YLeaf(YType.boolean, 'rpf-proxy-enabled'), ['bool'])),
                            ('mofrr_enabled', (YLeaf(YType.boolean, 'mofrr-enabled'), ['bool'])),
                            ('rib_mo_frr_enabled', (YLeaf(YType.boolean, 'rib-mo-frr-enabled'), ['bool'])),
                            ('jp_timer', (YLeaf(YType.int32, 'jp-timer'), ['int'])),
                            ('jp_status', (YLeaf(YType.int32, 'jp-status'), ['int'])),
                            ('suppress_registers', (YLeaf(YType.int32, 'suppress-registers'), ['int'])),
                            ('assume_alive', (YLeaf(YType.boolean, 'assume-alive'), ['bool'])),
                            ('probe_alive', (YLeaf(YType.boolean, 'probe-alive'), ['bool'])),
                            ('really_alive', (YLeaf(YType.boolean, 'really-alive'), ['bool'])),
                            ('inherit_alive', (YLeaf(YType.boolean, 'inherit-alive'), ['bool'])),
                            ('inherit_spt', (YLeaf(YType.boolean, 'inherit-spt'), ['bool'])),
                            ('signal_sources', (YLeaf(YType.boolean, 'signal-sources'), ['bool'])),
                            ('dont_check_connected', (YLeaf(YType.boolean, 'dont-check-connected'), ['bool'])),
                            ('register_received', (YLeaf(YType.boolean, 'register-received'), ['bool'])),
                            ('last_hop', (YLeaf(YType.boolean, 'last-hop'), ['bool'])),
                            ('sending_registers', (YLeaf(YType.boolean, 'sending-registers'), ['bool'])),
                            ('sending_null_registers', (YLeaf(YType.boolean, 'sending-null-registers'), ['bool'])),
                            ('sa_sent', (YLeaf(YType.boolean, 'sa-sent'), ['bool'])),
                            ('sa_received', (YLeaf(YType.boolean, 'sa-received'), ['bool'])),
                            ('sa_joined', (YLeaf(YType.boolean, 'sa-joined'), ['bool'])),
                            ('anycast_rp_match', (YLeaf(YType.boolean, 'anycast-rp-match'), ['bool'])),
                            ('anycast_rp_route_target', (YLeaf(YType.str, 'anycast-rp-route-target'), ['str'])),
                            ('bgp_join', (YLeaf(YType.boolean, 'bgp-join'), ['bool'])),
                            ('bgp_jp_time', (YLeaf(YType.uint64, 'bgp-jp-time'), ['int'])),
                            ('customer_routing_type', (YLeaf(YType.int32, 'customer-routing-type'), ['int'])),
                            ('extranet_route', (YLeaf(YType.boolean, 'extranet-route'), ['bool'])),
                            ('mofrr_active', (YLeaf(YType.boolean, 'mofrr-active'), ['bool'])),
                            ('mofrr_primary', (YLeaf(YType.boolean, 'mofrr-primary'), ['bool'])),
                            ('mofrr_backup', (YLeaf(YType.boolean, 'mofrr-backup'), ['bool'])),
                            ('vxlan', (YLeaf(YType.boolean, 'vxlan'), ['bool'])),
                            ('kat_state', (YLeaf(YType.boolean, 'kat-state'), ['bool'])),
                        ])
                        self.source_address = None
                        self.group_address = None
                        self.rpt = None
                        self.limit_reached = None
                        self.low_memory = None
                        self.protocol = None
                        self.wildcard = None
                        self.rpt_xr = None
                        self.spt = None
                        self.uptime = None
                        self.expiry = None
                        self.alive = None
                        self.register_received_timer = None
                        self.remote_source = None
                        self.crossed_threshold = None
                        self.data_mdt_addr_assigned = None
                        self.rpf_interface_name = None
                        self.rpf_vrf_name = None
                        self.rpf_safi = None
                        self.rpf_table_name = None
                        self.rpf_drop = None
                        self.rpf_extranet = None
                        self.is_via_lsm = None
                        self.secondary_rpf_interface_name = None
                        self.connected = None
                        self.proxy = None
                        self.rpf_proxy_enabled = None
                        self.mofrr_enabled = None
                        self.rib_mo_frr_enabled = None
                        self.jp_timer = None
                        self.jp_status = None
                        self.suppress_registers = None
                        self.assume_alive = None
                        self.probe_alive = None
                        self.really_alive = None
                        self.inherit_alive = None
                        self.inherit_spt = None
                        self.signal_sources = None
                        self.dont_check_connected = None
                        self.register_received = None
                        self.last_hop = None
                        self.sending_registers = None
                        self.sending_null_registers = None
                        self.sa_sent = None
                        self.sa_received = None
                        self.sa_joined = None
                        self.anycast_rp_match = None
                        self.anycast_rp_route_target = None
                        self.bgp_join = None
                        self.bgp_jp_time = None
                        self.customer_routing_type = None
                        self.extranet_route = None
                        self.mofrr_active = None
                        self.mofrr_primary = None
                        self.mofrr_backup = None
                        self.vxlan = None
                        self.kat_state = None

                        self.group_address_xr = Ipv6Pim.Active.DefaultContext.Topologies.Topology.GroupAddressXr()
                        self.group_address_xr.parent = self
                        self._children_name_map["group_address_xr"] = "group-address-xr"

                        self.source_address_xr = Ipv6Pim.Active.DefaultContext.Topologies.Topology.SourceAddressXr()
                        self.source_address_xr.parent = self
                        self._children_name_map["source_address_xr"] = "source-address-xr"

                        self.rp_address = Ipv6Pim.Active.DefaultContext.Topologies.Topology.RpAddress()
                        self.rp_address.parent = self
                        self._children_name_map["rp_address"] = "rp-address"

                        self.rpf_neighbor = Ipv6Pim.Active.DefaultContext.Topologies.Topology.RpfNeighbor()
                        self.rpf_neighbor.parent = self
                        self._children_name_map["rpf_neighbor"] = "rpf-neighbor"

                        self.secondary_rpf_neighbor = Ipv6Pim.Active.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor()
                        self.secondary_rpf_neighbor.parent = self
                        self._children_name_map["secondary_rpf_neighbor"] = "secondary-rpf-neighbor"

                        self.rpf_root = Ipv6Pim.Active.DefaultContext.Topologies.Topology.RpfRoot()
                        self.rpf_root.parent = self
                        self._children_name_map["rpf_root"] = "rpf-root"

                        self.proxy_address = Ipv6Pim.Active.DefaultContext.Topologies.Topology.ProxyAddress()
                        self.proxy_address.parent = self
                        self._children_name_map["proxy_address"] = "proxy-address"

                        self.orig_src_address = Ipv6Pim.Active.DefaultContext.Topologies.Topology.OrigSrcAddress()
                        self.orig_src_address.parent = self
                        self._children_name_map["orig_src_address"] = "orig-src-address"

                        self.outgoing_interface = YList(self)
                        self._segment_path = lambda: "topology"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/topologies/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.Topologies.Topology, ['source_address', 'group_address', 'rpt', 'limit_reached', 'low_memory', 'protocol', 'wildcard', 'rpt_xr', 'spt', 'uptime', 'expiry', 'alive', 'register_received_timer', 'remote_source', 'crossed_threshold', 'data_mdt_addr_assigned', 'rpf_interface_name', 'rpf_vrf_name', 'rpf_safi', 'rpf_table_name', 'rpf_drop', 'rpf_extranet', 'is_via_lsm', 'secondary_rpf_interface_name', 'connected', 'proxy', 'rpf_proxy_enabled', 'mofrr_enabled', 'rib_mo_frr_enabled', 'jp_timer', 'jp_status', 'suppress_registers', 'assume_alive', 'probe_alive', 'really_alive', 'inherit_alive', 'inherit_spt', 'signal_sources', 'dont_check_connected', 'register_received', 'last_hop', 'sending_registers', 'sending_null_registers', 'sa_sent', 'sa_received', 'sa_joined', 'anycast_rp_match', 'anycast_rp_route_target', 'bgp_join', 'bgp_jp_time', 'customer_routing_type', 'extranet_route', 'mofrr_active', 'mofrr_primary', 'mofrr_backup', 'vxlan', 'kat_state'], name, value)


                    class GroupAddressXr(Entity):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Topologies.Topology.GroupAddressXr, self).__init__()

                            self.yang_name = "group-address-xr"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "group-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/topologies/topology/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.Topologies.Topology.GroupAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class SourceAddressXr(Entity):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Topologies.Topology.SourceAddressXr, self).__init__()

                            self.yang_name = "source-address-xr"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "source-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/topologies/topology/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.Topologies.Topology.SourceAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class RpAddress(Entity):
                        """
                        RP Address (If rpt)
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Topologies.Topology.RpAddress, self).__init__()

                            self.yang_name = "rp-address"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "rp-address"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/topologies/topology/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.Topologies.Topology.RpAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class RpfNeighbor(Entity):
                        """
                        RPF Neighbor
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Topologies.Topology.RpfNeighbor, self).__init__()

                            self.yang_name = "rpf-neighbor"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "rpf-neighbor"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/topologies/topology/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.Topologies.Topology.RpfNeighbor, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class SecondaryRpfNeighbor(Entity):
                        """
                        Secondary RPF Neighbor
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor, self).__init__()

                            self.yang_name = "secondary-rpf-neighbor"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "secondary-rpf-neighbor"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/topologies/topology/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class RpfRoot(Entity):
                        """
                        Root of this mcast tree
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Topologies.Topology.RpfRoot, self).__init__()

                            self.yang_name = "rpf-root"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "rpf-root"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/topologies/topology/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.Topologies.Topology.RpfRoot, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class ProxyAddress(Entity):
                        """
                        RPF Proxy address.
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Topologies.Topology.ProxyAddress, self).__init__()

                            self.yang_name = "proxy-address"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "proxy-address"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/topologies/topology/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.Topologies.Topology.ProxyAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class OrigSrcAddress(Entity):
                        """
                        Orig Src Address.
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Topologies.Topology.OrigSrcAddress, self).__init__()

                            self.yang_name = "orig-src-address"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "orig-src-address"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/topologies/topology/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.Topologies.Topology.OrigSrcAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class OutgoingInterface(Entity):
                        """
                        Outgoing interface list
                        
                        .. attribute:: assert_winner
                        
                        	Assert Winner
                        	**type**\:  :py:class:`AssertWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner>`
                        
                        .. attribute:: interface_name
                        
                        	Interface Identifier
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: expiry
                        
                        	Expiry in seconds
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: bgp_c_mcast_prune_delay_timer
                        
                        	BGP C\-MCAST Prune Suppression in seconds
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: jp_timer
                        
                        	Join\-Prune Timer (secs)
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: jp_state
                        
                        	Join\-Prune State
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: assert_timer
                        
                        	Assert Timer in seconds
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: local_members
                        
                        	Local Information. Deprecated \- use 'local\-members\-information' instead
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: internal_interest_info
                        
                        	Internal Interest. Deprecated \- use 'internal\-interest\-information' instead
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: forwarding_state
                        
                        	Forward or Prune
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: immediate_state
                        
                        	Immediate fwding state
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: last_hop
                        
                        	Are we last hop ?
                        	**type**\: bool
                        
                        .. attribute:: mldp_inband_mdt
                        
                        	MLDP Inband MDT interface
                        	**type**\: bool
                        
                        .. attribute:: mldp_stale
                        
                        	OLE is stale
                        	**type**\: bool
                        
                        .. attribute:: sa_prune
                        
                        	BGP SA Prune state
                        	**type**\: bool
                        
                        .. attribute:: admin_boundary
                        
                        	Is this an administrative boundary ?
                        	**type**\: bool
                        
                        .. attribute:: igmp_membership
                        
                        	IGMP membership
                        	**type**\: bool
                        
                        .. attribute:: mdt_safi_join
                        
                        	MDT Safi join
                        	**type**\: bool
                        
                        .. attribute:: mvpn_safi_join
                        
                        	MVPN Safi join
                        	**type**\: bool
                        
                        .. attribute:: local_mdt_join
                        
                        	Default MDT Join
                        	**type**\: bool
                        
                        .. attribute:: data_mdt_join
                        
                        	Data MDT join
                        	**type**\: bool
                        
                        .. attribute:: mvpnv6_safi_join
                        
                        	MVPN IPv6 Safi join
                        	**type**\: bool
                        
                        .. attribute:: bgp_c_mcast_join
                        
                        	BGP C\-Mcast join
                        	**type**\: bool
                        
                        .. attribute:: vrf_name
                        
                        	VRF which physically owns
                        	**type**\: str
                        
                        	**length:** 0..33
                        
                        .. attribute:: extranet_interface
                        
                        	Is this an Extranet Interface ?
                        	**type**\: bool
                        
                        .. attribute:: internal_interest_information
                        
                        	Internal Interest. Replaces internal\-interest\-info
                        	**type**\:  :py:class:`PimInternalInterestInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimInternalInterestInfo>`
                        
                        .. attribute:: local_members_information
                        
                        	Local Information. Replaces local\-members
                        	**type**\:  :py:class:`PimShowLocalInterest <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowLocalInterest>`
                        
                        .. attribute:: assert_state
                        
                        	Assert State
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface, self).__init__()

                            self.yang_name = "outgoing-interface"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("assert-winner", ("assert_winner", Ipv6Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner))])
                            self._leafs = OrderedDict([
                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                                ('expiry', (YLeaf(YType.uint64, 'expiry'), ['int'])),
                                ('bgp_c_mcast_prune_delay_timer', (YLeaf(YType.uint64, 'bgp-c-mcast-prune-delay-timer'), ['int'])),
                                ('jp_timer', (YLeaf(YType.int32, 'jp-timer'), ['int'])),
                                ('jp_state', (YLeaf(YType.int32, 'jp-state'), ['int'])),
                                ('assert_timer', (YLeaf(YType.int32, 'assert-timer'), ['int'])),
                                ('local_members', (YLeaf(YType.int32, 'local-members'), ['int'])),
                                ('internal_interest_info', (YLeaf(YType.int32, 'internal-interest-info'), ['int'])),
                                ('forwarding_state', (YLeaf(YType.int32, 'forwarding-state'), ['int'])),
                                ('immediate_state', (YLeaf(YType.int32, 'immediate-state'), ['int'])),
                                ('last_hop', (YLeaf(YType.boolean, 'last-hop'), ['bool'])),
                                ('mldp_inband_mdt', (YLeaf(YType.boolean, 'mldp-inband-mdt'), ['bool'])),
                                ('mldp_stale', (YLeaf(YType.boolean, 'mldp-stale'), ['bool'])),
                                ('sa_prune', (YLeaf(YType.boolean, 'sa-prune'), ['bool'])),
                                ('admin_boundary', (YLeaf(YType.boolean, 'admin-boundary'), ['bool'])),
                                ('igmp_membership', (YLeaf(YType.boolean, 'igmp-membership'), ['bool'])),
                                ('mdt_safi_join', (YLeaf(YType.boolean, 'mdt-safi-join'), ['bool'])),
                                ('mvpn_safi_join', (YLeaf(YType.boolean, 'mvpn-safi-join'), ['bool'])),
                                ('local_mdt_join', (YLeaf(YType.boolean, 'local-mdt-join'), ['bool'])),
                                ('data_mdt_join', (YLeaf(YType.boolean, 'data-mdt-join'), ['bool'])),
                                ('mvpnv6_safi_join', (YLeaf(YType.boolean, 'mvpnv6-safi-join'), ['bool'])),
                                ('bgp_c_mcast_join', (YLeaf(YType.boolean, 'bgp-c-mcast-join'), ['bool'])),
                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                ('extranet_interface', (YLeaf(YType.boolean, 'extranet-interface'), ['bool'])),
                                ('internal_interest_information', (YLeaf(YType.enumeration, 'internal-interest-information'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimInternalInterestInfo', '')])),
                                ('local_members_information', (YLeaf(YType.enumeration, 'local-members-information'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowLocalInterest', '')])),
                                ('assert_state', (YLeaf(YType.boolean, 'assert-state'), ['bool'])),
                            ])
                            self.interface_name = None
                            self.uptime = None
                            self.expiry = None
                            self.bgp_c_mcast_prune_delay_timer = None
                            self.jp_timer = None
                            self.jp_state = None
                            self.assert_timer = None
                            self.local_members = None
                            self.internal_interest_info = None
                            self.forwarding_state = None
                            self.immediate_state = None
                            self.last_hop = None
                            self.mldp_inband_mdt = None
                            self.mldp_stale = None
                            self.sa_prune = None
                            self.admin_boundary = None
                            self.igmp_membership = None
                            self.mdt_safi_join = None
                            self.mvpn_safi_join = None
                            self.local_mdt_join = None
                            self.data_mdt_join = None
                            self.mvpnv6_safi_join = None
                            self.bgp_c_mcast_join = None
                            self.vrf_name = None
                            self.extranet_interface = None
                            self.internal_interest_information = None
                            self.local_members_information = None
                            self.assert_state = None

                            self.assert_winner = Ipv6Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner()
                            self.assert_winner.parent = self
                            self._children_name_map["assert_winner"] = "assert-winner"
                            self._segment_path = lambda: "outgoing-interface"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/topologies/topology/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface, ['interface_name', 'uptime', 'expiry', 'bgp_c_mcast_prune_delay_timer', 'jp_timer', 'jp_state', 'assert_timer', 'local_members', 'internal_interest_info', 'forwarding_state', 'immediate_state', 'last_hop', 'mldp_inband_mdt', 'mldp_stale', 'sa_prune', 'admin_boundary', 'igmp_membership', 'mdt_safi_join', 'mvpn_safi_join', 'local_mdt_join', 'data_mdt_join', 'mvpnv6_safi_join', 'bgp_c_mcast_join', 'vrf_name', 'extranet_interface', 'internal_interest_information', 'local_members_information', 'assert_state'], name, value)


                        class AssertWinner(Entity):
                            """
                            Assert Winner
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner, self).__init__()

                                self.yang_name = "assert-winner"
                                self.yang_parent_name = "outgoing-interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "assert-winner"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/topologies/topology/outgoing-interface/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class BgpAfs(Entity):
                """
                PIM BGP SAFI table
                
                .. attribute:: bgp_af
                
                	PIM BGP SAFI information
                	**type**\: list of  		 :py:class:`BgpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.BgpAfs, self).__init__()

                    self.yang_name = "bgp-afs"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("bgp-af", ("bgp_af", Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf))])
                    self._leafs = OrderedDict()

                    self.bgp_af = YList(self)
                    self._segment_path = lambda: "bgp-afs"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.BgpAfs, [], name, value)


                class BgpAf(Entity):
                    """
                    PIM BGP SAFI information
                    
                    .. attribute:: source_address
                    
                    	Source IP address
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: group_address
                    
                    	Group IP address
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: source
                    
                    	Source address
                    	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf.Source>`
                    
                    .. attribute:: group
                    
                    	Group address
                    	**type**\:  :py:class:`Group <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf.Group>`
                    
                    .. attribute:: next_hop
                    
                    	Next hop address
                    	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf.NextHop>`
                    
                    .. attribute:: route_distinguisher
                    
                    	Router ID
                    	**type**\: str
                    
                    	**length:** 0..256
                    
                    .. attribute:: extranet_path_count
                    
                    	Count of dependent extranet paths
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_bgp_added
                    
                    	SAFI learnt from BGP
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf, self).__init__()

                        self.yang_name = "bgp-af"
                        self.yang_parent_name = "bgp-afs"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("source", ("source", Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf.Source)), ("group", ("group", Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf.Group)), ("next-hop", ("next_hop", Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf.NextHop))])
                        self._leafs = OrderedDict([
                            ('source_address', (YLeaf(YType.str, 'source-address'), ['str','str'])),
                            ('group_address', (YLeaf(YType.str, 'group-address'), ['str','str'])),
                            ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                            ('extranet_path_count', (YLeaf(YType.uint32, 'extranet-path-count'), ['int'])),
                            ('is_bgp_added', (YLeaf(YType.boolean, 'is-bgp-added'), ['bool'])),
                        ])
                        self.source_address = None
                        self.group_address = None
                        self.route_distinguisher = None
                        self.extranet_path_count = None
                        self.is_bgp_added = None

                        self.source = Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf.Source()
                        self.source.parent = self
                        self._children_name_map["source"] = "source"

                        self.group = Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf.Group()
                        self.group.parent = self
                        self._children_name_map["group"] = "group"

                        self.next_hop = Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf.NextHop()
                        self.next_hop.parent = self
                        self._children_name_map["next_hop"] = "next-hop"
                        self._segment_path = lambda: "bgp-af"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/bgp-afs/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf, ['source_address', 'group_address', 'route_distinguisher', 'extranet_path_count', 'is_bgp_added'], name, value)


                    class Source(Entity):
                        """
                        Source address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf.Source, self).__init__()

                            self.yang_name = "source"
                            self.yang_parent_name = "bgp-af"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "source"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/bgp-afs/bgp-af/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf.Source, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class Group(Entity):
                        """
                        Group address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf.Group, self).__init__()

                            self.yang_name = "group"
                            self.yang_parent_name = "bgp-af"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "group"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/bgp-afs/bgp-af/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf.Group, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class NextHop(Entity):
                        """
                        Next hop address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf.NextHop, self).__init__()

                            self.yang_name = "next-hop"
                            self.yang_parent_name = "bgp-af"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "next-hop"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/bgp-afs/bgp-af/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf.NextHop, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class AutoRp(Entity):
                """
                PIM Auto\-RP information
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.AutoRp, self).__init__()

                    self.yang_name = "auto-rp"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict()
                    self._segment_path = lambda: "auto-rp"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True


            class TopologyInterfaceFlagRouteCounts(Entity):
                """
                Route count for topology with interface flag set
                
                .. attribute:: topology_interface_flag_route_count
                
                	Route count for topology with interface flag set
                	**type**\: list of  		 :py:class:`TopologyInterfaceFlagRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts, self).__init__()

                    self.yang_name = "topology-interface-flag-route-counts"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("topology-interface-flag-route-count", ("topology_interface_flag_route_count", Ipv6Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount))])
                    self._leafs = OrderedDict()

                    self.topology_interface_flag_route_count = YList(self)
                    self._segment_path = lambda: "topology-interface-flag-route-counts"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts, [], name, value)


                class TopologyInterfaceFlagRouteCount(Entity):
                    """
                    Route count for topology with interface flag
                    set
                    
                    .. attribute:: interface_flag  (key)
                    
                    	Interface flag
                    	**type**\:  :py:class:`PimTopologyInterfaceFlag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimTopologyInterfaceFlag>`
                    
                    .. attribute:: group_ranges
                    
                    	No. of (\*,G/M) routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: active_group_ranges
                    
                    	No. of (\*,G/M) routes active in mrib
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: groute_count
                    
                    	No. of (\*,G) routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sg_route_count
                    
                    	No. of (S,G) routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sgr_route_count
                    
                    	No. of (S,G)RPT routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount, self).__init__()

                        self.yang_name = "topology-interface-flag-route-count"
                        self.yang_parent_name = "topology-interface-flag-route-counts"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['interface_flag']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('interface_flag', (YLeaf(YType.enumeration, 'interface-flag'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimTopologyInterfaceFlag', '')])),
                            ('group_ranges', (YLeaf(YType.uint32, 'group-ranges'), ['int'])),
                            ('active_group_ranges', (YLeaf(YType.uint32, 'active-group-ranges'), ['int'])),
                            ('groute_count', (YLeaf(YType.uint32, 'groute-count'), ['int'])),
                            ('sg_route_count', (YLeaf(YType.uint32, 'sg-route-count'), ['int'])),
                            ('sgr_route_count', (YLeaf(YType.uint32, 'sgr-route-count'), ['int'])),
                            ('is_node_low_memory', (YLeaf(YType.boolean, 'is-node-low-memory'), ['bool'])),
                        ])
                        self.interface_flag = None
                        self.group_ranges = None
                        self.active_group_ranges = None
                        self.groute_count = None
                        self.sg_route_count = None
                        self.sgr_route_count = None
                        self.is_node_low_memory = None
                        self._segment_path = lambda: "topology-interface-flag-route-count" + "[interface-flag='" + str(self.interface_flag) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/topology-interface-flag-route-counts/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount, ['interface_flag', 'group_ranges', 'active_group_ranges', 'groute_count', 'sg_route_count', 'sgr_route_count', 'is_node_low_memory'], name, value)


            class GroupMapSources(Entity):
                """
                PIM group\-mapping with source information
                
                .. attribute:: group_map_source
                
                	PIM Group Mapping Entry with source information
                	**type**\: list of  		 :py:class:`GroupMapSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.GroupMapSources, self).__init__()

                    self.yang_name = "group-map-sources"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("group-map-source", ("group_map_source", Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource))])
                    self._leafs = OrderedDict()

                    self.group_map_source = YList(self)
                    self._segment_path = lambda: "group-map-sources"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.GroupMapSources, [], name, value)


                class GroupMapSource(Entity):
                    """
                    PIM Group Mapping Entry with source information
                    
                    .. attribute:: prefix
                    
                    	Prefix
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: client
                    
                    	Client
                    	**type**\:  :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                    
                    .. attribute:: protocol
                    
                    	Protocol
                    	**type**\:  :py:class:`PimProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimProtocol>`
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: priority
                    
                    	RP Priority
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: source_of_information
                    
                    	The source of information
                    	**type**\:  :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation>`
                    
                    .. attribute:: group_map_information
                    
                    	Group Mapping information
                    	**type**\:  :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation>`
                    
                    .. attribute:: holdtime
                    
                    	Holdtime in seconds
                    	**type**\: int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    .. attribute:: expires
                    
                    	Mapping expiry time in seconds
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: uptime
                    
                    	Mapping uptime in seconds
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource, self).__init__()

                        self.yang_name = "group-map-source"
                        self.yang_parent_name = "group-map-sources"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("source-of-information", ("source_of_information", Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation)), ("group-map-information", ("group_map_information", Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation))])
                        self._leafs = OrderedDict([
                            ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                            ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                            ('client', (YLeaf(YType.enumeration, 'client'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimClient', '')])),
                            ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimProtocol', '')])),
                            ('rp_address', (YLeaf(YType.str, 'rp-address'), ['str','str'])),
                            ('priority', (YLeaf(YType.uint32, 'priority'), ['int'])),
                            ('holdtime', (YLeaf(YType.int32, 'holdtime'), ['int'])),
                            ('expires', (YLeaf(YType.uint64, 'expires'), ['int'])),
                            ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                        ])
                        self.prefix = None
                        self.prefix_length = None
                        self.client = None
                        self.protocol = None
                        self.rp_address = None
                        self.priority = None
                        self.holdtime = None
                        self.expires = None
                        self.uptime = None

                        self.source_of_information = Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation()
                        self.source_of_information.parent = self
                        self._children_name_map["source_of_information"] = "source-of-information"

                        self.group_map_information = Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation()
                        self.group_map_information.parent = self
                        self._children_name_map["group_map_information"] = "group-map-information"
                        self._segment_path = lambda: "group-map-source"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/group-map-sources/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource, ['prefix', 'prefix_length', 'client', 'protocol', 'rp_address', 'priority', 'holdtime', 'expires', 'uptime'], name, value)


                    class SourceOfInformation(Entity):
                        """
                        The source of information
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation, self).__init__()

                            self.yang_name = "source-of-information"
                            self.yang_parent_name = "group-map-source"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "source-of-information"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/group-map-sources/group-map-source/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class GroupMapInformation(Entity):
                        """
                        Group Mapping information
                        
                        .. attribute:: prefix
                        
                        	Group range prefix
                        	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix>`
                        
                        .. attribute:: rp_address
                        
                        	Rendezvous Point Address
                        	**type**\:  :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress>`
                        
                        .. attribute:: prefix_length
                        
                        	Group range prefix length
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: client
                        
                        	Client mapping learnt from
                        	**type**\:  :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                        
                        .. attribute:: protocol
                        
                        	Protocol mode of the range
                        	**type**\:  :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: group_count
                        
                        	No. of groups in this range
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_used
                        
                        	Is this mapping being used?
                        	**type**\: bool
                        
                        .. attribute:: mrib_active
                        
                        	Is this mapping active in MRIB?
                        	**type**\: bool
                        
                        .. attribute:: is_override
                        
                        	Is this the override range?
                        	**type**\: bool
                        
                        .. attribute:: priority
                        
                        	Bootstrap priority
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation, self).__init__()

                            self.yang_name = "group-map-information"
                            self.yang_parent_name = "group-map-source"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("prefix", ("prefix", Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix)), ("rp-address", ("rp_address", Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress))])
                            self._leafs = OrderedDict([
                                ('prefix_length', (YLeaf(YType.int32, 'prefix-length'), ['int'])),
                                ('client', (YLeaf(YType.enumeration, 'client'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowRangeClient', '')])),
                                ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowProtocol', '')])),
                                ('group_count', (YLeaf(YType.uint32, 'group-count'), ['int'])),
                                ('is_used', (YLeaf(YType.boolean, 'is-used'), ['bool'])),
                                ('mrib_active', (YLeaf(YType.boolean, 'mrib-active'), ['bool'])),
                                ('is_override', (YLeaf(YType.boolean, 'is-override'), ['bool'])),
                                ('priority', (YLeaf(YType.uint32, 'priority'), ['int'])),
                            ])
                            self.prefix_length = None
                            self.client = None
                            self.protocol = None
                            self.group_count = None
                            self.is_used = None
                            self.mrib_active = None
                            self.is_override = None
                            self.priority = None

                            self.prefix = Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"

                            self.rp_address = Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"
                            self._segment_path = lambda: "group-map-information"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/group-map-sources/group-map-source/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation, ['prefix_length', 'client', 'protocol', 'group_count', 'is_used', 'mrib_active', 'is_override', 'priority'], name, value)


                        class Prefix(Entity):
                            """
                            Group range prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "group-map-information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "prefix"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/group-map-sources/group-map-source/group-map-information/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class RpAddress(Entity):
                            """
                            Rendezvous Point Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "group-map-information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "rp-address"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/group-map-sources/group-map-source/group-map-information/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class TrafficCounters(Entity):
                """
                PIM message traffic counters
                
                .. attribute:: elapsed_time
                
                	Running time for counters in seconds
                	**type**\: int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: inputs
                
                	Packets in
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: outputs
                
                	Packets out
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: format_error
                
                	Malformed packets in
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: pakman_error
                
                	Pakman packets dropped
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: standby_packets_error
                
                	Packets received in standby state
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: checksum_error
                
                	Checksum errors
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: socket_error
                
                	Socket errors
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: send_queue_full
                
                	Packets dropped since send queue was full
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: boundary_acl_rx_drop
                
                	Inc. JP dropped since boundary ACL confg
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: boundary_acl_tx_drop
                
                	Out JP dropped since boundary ACL confg
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: no_socket_connection
                
                	Packets dropped since no socket connection
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: no_source_address
                
                	Packets dropped since no source address
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_hello
                
                	Hello packets in
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_hello
                
                	Hello packets out
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_jp
                
                	Join Prune packets in
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_jp
                
                	Join Prune packets out
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_data_register
                
                	Data Register packets in
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_null_register
                
                	Null Register packets in
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_null_register
                
                	Null Register packets out
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_register_stop
                
                	Register Stop packets in
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_register_stop
                
                	Register Stop packets out
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_assert
                
                	Assert packets in
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_assert_batched
                
                	Batched Assert packets in
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_assert
                
                	Assert packets out
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_assert_batched
                
                	Batched Assert packets out
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_df_election
                
                	DF Election packets in
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_df_election
                
                	DF Election packets out
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_bsr_message
                
                	Input BSR Messages
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_bsr_message
                
                	Output BSR Messages
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_candidate_rp_advertisement
                
                	Input Candidate\-RP Advertisment
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_candidate_rp_advertisement
                
                	Output Candidate\-RP Advertisment
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_ecmp_redirect
                
                	Input Ecmp Redirect
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_ecmp_redirect
                
                	Output Ecmp Redirect
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_loop_error
                
                	Output on loopback error
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_invalid_lsm_identifier
                
                	 Invalid LSM ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_idb_error
                
                	No IDB for intf error
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_vrf_error
                
                	No VRF for idb error
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_pim_error
                
                	PIM Disabled on intf error
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_pim_version_error
                
                	Invalid PIM version error
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_join_group
                
                	Output Join Groups
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_prune_group
                
                	Output Prune Groups
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_join_prune_bytes
                
                	Output JP Bytes
                	**type**\: int
                
                	**range:** 0..4294967295
                
                	**units**\: byte
                
                .. attribute:: output_hello_bytes
                
                	Output Hello Bytes
                	**type**\: int
                
                	**range:** 0..4294967295
                
                	**units**\: byte
                
                .. attribute:: non_supported_packets
                
                	PIM non supported pckets
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: invalid_registers
                
                	PIM invalid registers received
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: invalid_join_prunes
                
                	PIM invalid Join/Prunes received
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_packman_error
                
                	Packets Dropped due to Pakman Error
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_read_socket_error
                
                	Packet Read Socket Error
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_queue_last_clear
                
                	Time in seconds since the last clear of all packet queues stats
                	**type**\: int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: packets_standby
                
                	Packets Dropped due to Standby Error
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: no_mdt_socket_connection
                
                	Packets dropped since no mdt socket connection
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_send_queue_full
                
                	Packets dropped since mdt send queue was full
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_socket_error
                
                	MDT Socket errors
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_join_tlv_sent
                
                	Data MDT Join Msgs sent
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_join_tlv_received
                
                	Data MDT Join Msgs received
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_join_bad_type
                
                	Data MDT TLV bad type
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_drop_local_source_address
                
                	Data MDT Join msgs dropped due to local source addr
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_drop_null_local_address
                
                	Data MDT Join msgs dropped due to null local addr
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_drop_no_idb
                
                	Data MDT Join msgs dropped due to idb missing
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_drop_no_vrf
                
                	Data MDT Join msgs dropped due to vrf missing
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: invalid_destination_packets
                
                	Control Packets with Invalid Destination
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_joins_drop_multiple_encapsulation
                
                	MDT Join msgs dropped due to multiple Encap limitation
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: truncated_pim_packets
                
                	Packets dropped due to truncated Joins or Prunes
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: invalid_source_encodings
                
                	Number of invalid source encodings received
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: invalid_hello_options
                
                	Number of invalid hello options received
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_queue
                
                	Packet queue state and statistics
                	**type**\: list of  		 :py:class:`PacketQueue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.TrafficCounters.PacketQueue>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.TrafficCounters, self).__init__()

                    self.yang_name = "traffic-counters"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("packet-queue", ("packet_queue", Ipv6Pim.Active.DefaultContext.TrafficCounters.PacketQueue))])
                    self._leafs = OrderedDict([
                        ('elapsed_time', (YLeaf(YType.uint32, 'elapsed-time'), ['int'])),
                        ('inputs', (YLeaf(YType.uint32, 'inputs'), ['int'])),
                        ('outputs', (YLeaf(YType.uint32, 'outputs'), ['int'])),
                        ('format_error', (YLeaf(YType.uint32, 'format-error'), ['int'])),
                        ('pakman_error', (YLeaf(YType.uint32, 'pakman-error'), ['int'])),
                        ('standby_packets_error', (YLeaf(YType.uint32, 'standby-packets-error'), ['int'])),
                        ('checksum_error', (YLeaf(YType.uint32, 'checksum-error'), ['int'])),
                        ('socket_error', (YLeaf(YType.uint32, 'socket-error'), ['int'])),
                        ('send_queue_full', (YLeaf(YType.uint32, 'send-queue-full'), ['int'])),
                        ('boundary_acl_rx_drop', (YLeaf(YType.uint32, 'boundary-acl-rx-drop'), ['int'])),
                        ('boundary_acl_tx_drop', (YLeaf(YType.uint32, 'boundary-acl-tx-drop'), ['int'])),
                        ('no_socket_connection', (YLeaf(YType.uint32, 'no-socket-connection'), ['int'])),
                        ('no_source_address', (YLeaf(YType.uint32, 'no-source-address'), ['int'])),
                        ('input_hello', (YLeaf(YType.uint32, 'input-hello'), ['int'])),
                        ('output_hello', (YLeaf(YType.uint32, 'output-hello'), ['int'])),
                        ('input_jp', (YLeaf(YType.uint32, 'input-jp'), ['int'])),
                        ('output_jp', (YLeaf(YType.uint32, 'output-jp'), ['int'])),
                        ('input_data_register', (YLeaf(YType.uint32, 'input-data-register'), ['int'])),
                        ('input_null_register', (YLeaf(YType.uint32, 'input-null-register'), ['int'])),
                        ('output_null_register', (YLeaf(YType.uint32, 'output-null-register'), ['int'])),
                        ('input_register_stop', (YLeaf(YType.uint32, 'input-register-stop'), ['int'])),
                        ('output_register_stop', (YLeaf(YType.uint32, 'output-register-stop'), ['int'])),
                        ('input_assert', (YLeaf(YType.uint32, 'input-assert'), ['int'])),
                        ('input_assert_batched', (YLeaf(YType.uint32, 'input-assert-batched'), ['int'])),
                        ('output_assert', (YLeaf(YType.uint32, 'output-assert'), ['int'])),
                        ('output_assert_batched', (YLeaf(YType.uint32, 'output-assert-batched'), ['int'])),
                        ('input_df_election', (YLeaf(YType.uint32, 'input-df-election'), ['int'])),
                        ('output_df_election', (YLeaf(YType.uint32, 'output-df-election'), ['int'])),
                        ('input_bsr_message', (YLeaf(YType.uint32, 'input-bsr-message'), ['int'])),
                        ('output_bsr_message', (YLeaf(YType.uint32, 'output-bsr-message'), ['int'])),
                        ('input_candidate_rp_advertisement', (YLeaf(YType.uint32, 'input-candidate-rp-advertisement'), ['int'])),
                        ('output_candidate_rp_advertisement', (YLeaf(YType.uint32, 'output-candidate-rp-advertisement'), ['int'])),
                        ('input_ecmp_redirect', (YLeaf(YType.uint32, 'input-ecmp-redirect'), ['int'])),
                        ('output_ecmp_redirect', (YLeaf(YType.uint32, 'output-ecmp-redirect'), ['int'])),
                        ('output_loop_error', (YLeaf(YType.uint32, 'output-loop-error'), ['int'])),
                        ('mldp_mdt_invalid_lsm_identifier', (YLeaf(YType.uint32, 'mldp-mdt-invalid-lsm-identifier'), ['int'])),
                        ('input_no_idb_error', (YLeaf(YType.uint32, 'input-no-idb-error'), ['int'])),
                        ('input_no_vrf_error', (YLeaf(YType.uint32, 'input-no-vrf-error'), ['int'])),
                        ('input_no_pim_error', (YLeaf(YType.uint32, 'input-no-pim-error'), ['int'])),
                        ('input_pim_version_error', (YLeaf(YType.uint32, 'input-pim-version-error'), ['int'])),
                        ('output_join_group', (YLeaf(YType.uint32, 'output-join-group'), ['int'])),
                        ('output_prune_group', (YLeaf(YType.uint32, 'output-prune-group'), ['int'])),
                        ('output_join_prune_bytes', (YLeaf(YType.uint32, 'output-join-prune-bytes'), ['int'])),
                        ('output_hello_bytes', (YLeaf(YType.uint32, 'output-hello-bytes'), ['int'])),
                        ('non_supported_packets', (YLeaf(YType.uint32, 'non-supported-packets'), ['int'])),
                        ('invalid_registers', (YLeaf(YType.uint32, 'invalid-registers'), ['int'])),
                        ('invalid_join_prunes', (YLeaf(YType.uint32, 'invalid-join-prunes'), ['int'])),
                        ('packet_packman_error', (YLeaf(YType.uint32, 'packet-packman-error'), ['int'])),
                        ('packet_read_socket_error', (YLeaf(YType.uint32, 'packet-read-socket-error'), ['int'])),
                        ('packet_queue_last_clear', (YLeaf(YType.uint32, 'packet-queue-last-clear'), ['int'])),
                        ('packets_standby', (YLeaf(YType.uint32, 'packets-standby'), ['int'])),
                        ('no_mdt_socket_connection', (YLeaf(YType.uint32, 'no-mdt-socket-connection'), ['int'])),
                        ('mdt_send_queue_full', (YLeaf(YType.uint32, 'mdt-send-queue-full'), ['int'])),
                        ('mdt_socket_error', (YLeaf(YType.uint32, 'mdt-socket-error'), ['int'])),
                        ('mdt_join_tlv_sent', (YLeaf(YType.uint32, 'mdt-join-tlv-sent'), ['int'])),
                        ('mdt_join_tlv_received', (YLeaf(YType.uint32, 'mdt-join-tlv-received'), ['int'])),
                        ('mdt_join_bad_type', (YLeaf(YType.uint32, 'mdt-join-bad-type'), ['int'])),
                        ('mdt_drop_local_source_address', (YLeaf(YType.uint32, 'mdt-drop-local-source-address'), ['int'])),
                        ('mdt_drop_null_local_address', (YLeaf(YType.uint32, 'mdt-drop-null-local-address'), ['int'])),
                        ('mdt_drop_no_idb', (YLeaf(YType.uint32, 'mdt-drop-no-idb'), ['int'])),
                        ('mdt_drop_no_vrf', (YLeaf(YType.uint32, 'mdt-drop-no-vrf'), ['int'])),
                        ('invalid_destination_packets', (YLeaf(YType.uint32, 'invalid-destination-packets'), ['int'])),
                        ('mdt_joins_drop_multiple_encapsulation', (YLeaf(YType.uint32, 'mdt-joins-drop-multiple-encapsulation'), ['int'])),
                        ('truncated_pim_packets', (YLeaf(YType.uint32, 'truncated-pim-packets'), ['int'])),
                        ('invalid_source_encodings', (YLeaf(YType.uint32, 'invalid-source-encodings'), ['int'])),
                        ('invalid_hello_options', (YLeaf(YType.uint32, 'invalid-hello-options'), ['int'])),
                    ])
                    self.elapsed_time = None
                    self.inputs = None
                    self.outputs = None
                    self.format_error = None
                    self.pakman_error = None
                    self.standby_packets_error = None
                    self.checksum_error = None
                    self.socket_error = None
                    self.send_queue_full = None
                    self.boundary_acl_rx_drop = None
                    self.boundary_acl_tx_drop = None
                    self.no_socket_connection = None
                    self.no_source_address = None
                    self.input_hello = None
                    self.output_hello = None
                    self.input_jp = None
                    self.output_jp = None
                    self.input_data_register = None
                    self.input_null_register = None
                    self.output_null_register = None
                    self.input_register_stop = None
                    self.output_register_stop = None
                    self.input_assert = None
                    self.input_assert_batched = None
                    self.output_assert = None
                    self.output_assert_batched = None
                    self.input_df_election = None
                    self.output_df_election = None
                    self.input_bsr_message = None
                    self.output_bsr_message = None
                    self.input_candidate_rp_advertisement = None
                    self.output_candidate_rp_advertisement = None
                    self.input_ecmp_redirect = None
                    self.output_ecmp_redirect = None
                    self.output_loop_error = None
                    self.mldp_mdt_invalid_lsm_identifier = None
                    self.input_no_idb_error = None
                    self.input_no_vrf_error = None
                    self.input_no_pim_error = None
                    self.input_pim_version_error = None
                    self.output_join_group = None
                    self.output_prune_group = None
                    self.output_join_prune_bytes = None
                    self.output_hello_bytes = None
                    self.non_supported_packets = None
                    self.invalid_registers = None
                    self.invalid_join_prunes = None
                    self.packet_packman_error = None
                    self.packet_read_socket_error = None
                    self.packet_queue_last_clear = None
                    self.packets_standby = None
                    self.no_mdt_socket_connection = None
                    self.mdt_send_queue_full = None
                    self.mdt_socket_error = None
                    self.mdt_join_tlv_sent = None
                    self.mdt_join_tlv_received = None
                    self.mdt_join_bad_type = None
                    self.mdt_drop_local_source_address = None
                    self.mdt_drop_null_local_address = None
                    self.mdt_drop_no_idb = None
                    self.mdt_drop_no_vrf = None
                    self.invalid_destination_packets = None
                    self.mdt_joins_drop_multiple_encapsulation = None
                    self.truncated_pim_packets = None
                    self.invalid_source_encodings = None
                    self.invalid_hello_options = None

                    self.packet_queue = YList(self)
                    self._segment_path = lambda: "traffic-counters"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.TrafficCounters, ['elapsed_time', 'inputs', 'outputs', 'format_error', 'pakman_error', 'standby_packets_error', 'checksum_error', 'socket_error', 'send_queue_full', 'boundary_acl_rx_drop', 'boundary_acl_tx_drop', 'no_socket_connection', 'no_source_address', 'input_hello', 'output_hello', 'input_jp', 'output_jp', 'input_data_register', 'input_null_register', 'output_null_register', 'input_register_stop', 'output_register_stop', 'input_assert', 'input_assert_batched', 'output_assert', 'output_assert_batched', 'input_df_election', 'output_df_election', 'input_bsr_message', 'output_bsr_message', 'input_candidate_rp_advertisement', 'output_candidate_rp_advertisement', 'input_ecmp_redirect', 'output_ecmp_redirect', 'output_loop_error', 'mldp_mdt_invalid_lsm_identifier', 'input_no_idb_error', 'input_no_vrf_error', 'input_no_pim_error', 'input_pim_version_error', 'output_join_group', 'output_prune_group', 'output_join_prune_bytes', 'output_hello_bytes', 'non_supported_packets', 'invalid_registers', 'invalid_join_prunes', 'packet_packman_error', 'packet_read_socket_error', 'packet_queue_last_clear', 'packets_standby', 'no_mdt_socket_connection', 'mdt_send_queue_full', 'mdt_socket_error', 'mdt_join_tlv_sent', 'mdt_join_tlv_received', 'mdt_join_bad_type', 'mdt_drop_local_source_address', 'mdt_drop_null_local_address', 'mdt_drop_no_idb', 'mdt_drop_no_vrf', 'invalid_destination_packets', 'mdt_joins_drop_multiple_encapsulation', 'truncated_pim_packets', 'invalid_source_encodings', 'invalid_hello_options'], name, value)


                class PacketQueue(Entity):
                    """
                    Packet queue state and statistics
                    
                    .. attribute:: packet_queue_state
                    
                    	State of the queue
                    	**type**\:  :py:class:`PacketQueueState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState>`
                    
                    .. attribute:: packet_queue_stats
                    
                    	Statistics about the queue
                    	**type**\:  :py:class:`PacketQueueStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats>`
                    
                    .. attribute:: packet_queue_priority
                    
                    	Priority of this packet queue
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.TrafficCounters.PacketQueue, self).__init__()

                        self.yang_name = "packet-queue"
                        self.yang_parent_name = "traffic-counters"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("packet-queue-state", ("packet_queue_state", Ipv6Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState)), ("packet-queue-stats", ("packet_queue_stats", Ipv6Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats))])
                        self._leafs = OrderedDict([
                            ('packet_queue_priority', (YLeaf(YType.uint32, 'packet-queue-priority'), ['int'])),
                        ])
                        self.packet_queue_priority = None

                        self.packet_queue_state = Ipv6Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState()
                        self.packet_queue_state.parent = self
                        self._children_name_map["packet_queue_state"] = "packet-queue-state"

                        self.packet_queue_stats = Ipv6Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats()
                        self.packet_queue_stats.parent = self
                        self._children_name_map["packet_queue_stats"] = "packet-queue-stats"
                        self._segment_path = lambda: "packet-queue"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/traffic-counters/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.TrafficCounters.PacketQueue, ['packet_queue_priority'], name, value)


                    class PacketQueueState(Entity):
                        """
                        State of the queue
                        
                        .. attribute:: max_queue_size
                        
                        	Maximum size of queue in bytes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: byte
                        
                        .. attribute:: queue_size_bytes
                        
                        	Size of queue in bytes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: byte
                        
                        .. attribute:: queue_size_packets
                        
                        	Size of queue in number of packets
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState, self).__init__()

                            self.yang_name = "packet-queue-state"
                            self.yang_parent_name = "packet-queue"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('max_queue_size', (YLeaf(YType.uint32, 'max-queue-size'), ['int'])),
                                ('queue_size_bytes', (YLeaf(YType.uint32, 'queue-size-bytes'), ['int'])),
                                ('queue_size_packets', (YLeaf(YType.uint32, 'queue-size-packets'), ['int'])),
                            ])
                            self.max_queue_size = None
                            self.queue_size_bytes = None
                            self.queue_size_packets = None
                            self._segment_path = lambda: "packet-queue-state"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/traffic-counters/packet-queue/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState, ['max_queue_size', 'queue_size_bytes', 'queue_size_packets'], name, value)


                    class PacketQueueStats(Entity):
                        """
                        Statistics about the queue
                        
                        .. attribute:: enqueued_packets
                        
                        	Total number of packets enqueued to this queue
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: dequeued_packets
                        
                        	Total number of packets dequeued from this queue
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: high_water_mark_packets
                        
                        	Highest number of packets enqueued in this queue
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: high_water_mark_bytes
                        
                        	Highest number of bytes enqueued in this queue
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: byte
                        
                        .. attribute:: tail_drops
                        
                        	Number packets dropped from this queue due to max size
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats, self).__init__()

                            self.yang_name = "packet-queue-stats"
                            self.yang_parent_name = "packet-queue"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('enqueued_packets', (YLeaf(YType.uint32, 'enqueued-packets'), ['int'])),
                                ('dequeued_packets', (YLeaf(YType.uint32, 'dequeued-packets'), ['int'])),
                                ('high_water_mark_packets', (YLeaf(YType.uint32, 'high-water-mark-packets'), ['int'])),
                                ('high_water_mark_bytes', (YLeaf(YType.uint32, 'high-water-mark-bytes'), ['int'])),
                                ('tail_drops', (YLeaf(YType.uint32, 'tail-drops'), ['int'])),
                            ])
                            self.enqueued_packets = None
                            self.dequeued_packets = None
                            self.high_water_mark_packets = None
                            self.high_water_mark_bytes = None
                            self.tail_drops = None
                            self._segment_path = lambda: "packet-queue-stats"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/traffic-counters/packet-queue/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats, ['enqueued_packets', 'dequeued_packets', 'high_water_mark_packets', 'high_water_mark_bytes', 'tail_drops'], name, value)


            class GroupMapRpfs(Entity):
                """
                PIM group mapping information
                
                .. attribute:: group_map_rpf
                
                	PIM group mapping entry
                	**type**\: list of  		 :py:class:`GroupMapRpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.GroupMapRpfs, self).__init__()

                    self.yang_name = "group-map-rpfs"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("group-map-rpf", ("group_map_rpf", Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf))])
                    self._leafs = OrderedDict()

                    self.group_map_rpf = YList(self)
                    self._segment_path = lambda: "group-map-rpfs"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.GroupMapRpfs, [], name, value)


                class GroupMapRpf(Entity):
                    """
                    PIM group mapping entry
                    
                    .. attribute:: prefix
                    
                    	Prefix
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: client
                    
                    	Client
                    	**type**\:  :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                    
                    .. attribute:: protocol
                    
                    	Protocol
                    	**type**\:  :py:class:`PimProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimProtocol>`
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: rp_priority
                    
                    	RP priority
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rpf_neighbor
                    
                    	RPF neighbor to the RP
                    	**type**\:  :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor>`
                    
                    .. attribute:: group_map_information
                    
                    	Group Mapping information
                    	**type**\:  :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation>`
                    
                    .. attribute:: are_we_rp
                    
                    	Are we the RP?
                    	**type**\: bool
                    
                    .. attribute:: rpf_interface_name
                    
                    	RPF interface to the RP
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: rpf_vrf_name
                    
                    	RPF VRF Name
                    	**type**\: str
                    
                    	**length:** 0..33
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf, self).__init__()

                        self.yang_name = "group-map-rpf"
                        self.yang_parent_name = "group-map-rpfs"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("rpf-neighbor", ("rpf_neighbor", Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor)), ("group-map-information", ("group_map_information", Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation))])
                        self._leafs = OrderedDict([
                            ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                            ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                            ('client', (YLeaf(YType.enumeration, 'client'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimClient', '')])),
                            ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimProtocol', '')])),
                            ('rp_address', (YLeaf(YType.str, 'rp-address'), ['str','str'])),
                            ('rp_priority', (YLeaf(YType.uint32, 'rp-priority'), ['int'])),
                            ('are_we_rp', (YLeaf(YType.boolean, 'are-we-rp'), ['bool'])),
                            ('rpf_interface_name', (YLeaf(YType.str, 'rpf-interface-name'), ['str'])),
                            ('rpf_vrf_name', (YLeaf(YType.str, 'rpf-vrf-name'), ['str'])),
                        ])
                        self.prefix = None
                        self.prefix_length = None
                        self.client = None
                        self.protocol = None
                        self.rp_address = None
                        self.rp_priority = None
                        self.are_we_rp = None
                        self.rpf_interface_name = None
                        self.rpf_vrf_name = None

                        self.rpf_neighbor = Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor()
                        self.rpf_neighbor.parent = self
                        self._children_name_map["rpf_neighbor"] = "rpf-neighbor"

                        self.group_map_information = Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation()
                        self.group_map_information.parent = self
                        self._children_name_map["group_map_information"] = "group-map-information"
                        self._segment_path = lambda: "group-map-rpf"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/group-map-rpfs/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf, ['prefix', 'prefix_length', 'client', 'protocol', 'rp_address', 'rp_priority', 'are_we_rp', 'rpf_interface_name', 'rpf_vrf_name'], name, value)


                    class RpfNeighbor(Entity):
                        """
                        RPF neighbor to the RP
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor, self).__init__()

                            self.yang_name = "rpf-neighbor"
                            self.yang_parent_name = "group-map-rpf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "rpf-neighbor"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/group-map-rpfs/group-map-rpf/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class GroupMapInformation(Entity):
                        """
                        Group Mapping information
                        
                        .. attribute:: prefix
                        
                        	Group range prefix
                        	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix>`
                        
                        .. attribute:: rp_address
                        
                        	Rendezvous Point Address
                        	**type**\:  :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress>`
                        
                        .. attribute:: prefix_length
                        
                        	Group range prefix length
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: client
                        
                        	Client mapping learnt from
                        	**type**\:  :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                        
                        .. attribute:: protocol
                        
                        	Protocol mode of the range
                        	**type**\:  :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: group_count
                        
                        	No. of groups in this range
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_used
                        
                        	Is this mapping being used?
                        	**type**\: bool
                        
                        .. attribute:: mrib_active
                        
                        	Is this mapping active in MRIB?
                        	**type**\: bool
                        
                        .. attribute:: is_override
                        
                        	Is this the override range?
                        	**type**\: bool
                        
                        .. attribute:: priority
                        
                        	Bootstrap priority
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation, self).__init__()

                            self.yang_name = "group-map-information"
                            self.yang_parent_name = "group-map-rpf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("prefix", ("prefix", Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix)), ("rp-address", ("rp_address", Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress))])
                            self._leafs = OrderedDict([
                                ('prefix_length', (YLeaf(YType.int32, 'prefix-length'), ['int'])),
                                ('client', (YLeaf(YType.enumeration, 'client'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowRangeClient', '')])),
                                ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowProtocol', '')])),
                                ('group_count', (YLeaf(YType.uint32, 'group-count'), ['int'])),
                                ('is_used', (YLeaf(YType.boolean, 'is-used'), ['bool'])),
                                ('mrib_active', (YLeaf(YType.boolean, 'mrib-active'), ['bool'])),
                                ('is_override', (YLeaf(YType.boolean, 'is-override'), ['bool'])),
                                ('priority', (YLeaf(YType.uint32, 'priority'), ['int'])),
                            ])
                            self.prefix_length = None
                            self.client = None
                            self.protocol = None
                            self.group_count = None
                            self.is_used = None
                            self.mrib_active = None
                            self.is_override = None
                            self.priority = None

                            self.prefix = Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"

                            self.rp_address = Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"
                            self._segment_path = lambda: "group-map-information"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/group-map-rpfs/group-map-rpf/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation, ['prefix_length', 'client', 'protocol', 'group_count', 'is_used', 'mrib_active', 'is_override', 'priority'], name, value)


                        class Prefix(Entity):
                            """
                            Group range prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "group-map-information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "prefix"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/group-map-rpfs/group-map-rpf/group-map-information/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class RpAddress(Entity):
                            """
                            Rendezvous Point Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "group-map-information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "rp-address"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/group-map-rpfs/group-map-rpf/group-map-information/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class Summary(Entity):
                """
                PIM summary
                
                .. attribute:: route_limit
                
                	Maximum routes
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_count
                
                	Current routes
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_low_water_mark
                
                	The number of routes below which the throttle on route creation will be lifted
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_route_limit_reached
                
                	Is route creation throttled
                	**type**\: bool
                
                .. attribute:: topology_interface_state_limit
                
                	Maximum Topology Interface State count
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_count
                
                	Current Topology Interface State count
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: rxi_low_water_mark
                
                	The rxi below which the throttle on interface creation will be lifted
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: rxi_limit_reached
                
                	Is interface creation throttled
                	**type**\: bool
                
                .. attribute:: register_limit
                
                	Maximum registers
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_count
                
                	Current registers
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_limit_reached
                
                	Is PIM SM register handling throttled
                	**type**\: bool
                
                .. attribute:: ranges_limit
                
                	Maximum group ranges from Autorp
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: ranges_count
                
                	Current group ranges from Autorp
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: ranges_threshold
                
                	OOR theshold of grange ranges from AutoRP
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_ranges_limit_reached
                
                	Is Auto\-RP group\-to\-RP mapping range creation throttled
                	**type**\: bool
                
                .. attribute:: bsr_ranges_limit
                
                	Maximum group ranges from BSR
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_ranges_count
                
                	Current group ranges from BSR
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_range_threshold
                
                	Threshold group range from BSR
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_bsr_ranges_threshold_reached
                
                	Is VRF\-specific BSR group\-to\-RP mapping range creation throttled
                	**type**\: bool
                
                .. attribute:: bsr_candidate_rp_set_limit
                
                	Maximum crp\-set from BSR
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_candidate_rp_set_count
                
                	Current crp\-set count from BSR
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_candidate_rp_set_threshold
                
                	Threshold crp\-set from BSR
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_maximum_enforcement_disabled
                
                	Is maximum enforcement disabled
                	**type**\: bool
                
                .. attribute:: is_node_low_memory
                
                	Is node in low memory condition
                	**type**\: bool
                
                .. attribute:: route_threshold
                
                	Threshold routes
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_auto_rp_ranges_limit
                
                	Global Auto\-RP maximum group ranges
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_global_auto_rp_ranges_limit_reached
                
                	Is global AutoRP group\-to\-RP mapping range creation throttled
                	**type**\: bool
                
                .. attribute:: global_bsr_ranges_limit
                
                	Global BSR maximum group ranges
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_count
                
                	Global BSR current group ranges
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_threshold
                
                	Global BSR Threshold group ranges
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_global_bsr_ranges_limit_reached
                
                	Is global BSR group\-to\-RP mapping range creation throttled
                	**type**\: bool
                
                .. attribute:: global_bsr_candidate_rp_set_limit
                
                	Global BSR maximum crp\-set
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_count
                
                	Global BSR current crp\-set count
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_threshold
                
                	Global BSR Threshold crp\-set
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_global_route_limit_reached
                
                	Is global route creation throttled
                	**type**\: bool
                
                .. attribute:: topology_interface_state_threshold
                
                	Topology Interface State threshold
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_global_rxi_limit_reached
                
                	Is global interface creation throttled
                	**type**\: bool
                
                .. attribute:: register_threshold
                
                	Threshold registers
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_register_limit
                
                	Maximum global registers
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_global_register_limit_reached
                
                	Is global PIM SM register handling throttled
                	**type**\: bool
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.Summary, self).__init__()

                    self.yang_name = "summary"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('route_limit', (YLeaf(YType.uint32, 'route-limit'), ['int'])),
                        ('route_count', (YLeaf(YType.uint32, 'route-count'), ['int'])),
                        ('route_low_water_mark', (YLeaf(YType.uint32, 'route-low-water-mark'), ['int'])),
                        ('is_route_limit_reached', (YLeaf(YType.boolean, 'is-route-limit-reached'), ['bool'])),
                        ('topology_interface_state_limit', (YLeaf(YType.uint32, 'topology-interface-state-limit'), ['int'])),
                        ('topology_interface_state_count', (YLeaf(YType.uint32, 'topology-interface-state-count'), ['int'])),
                        ('rxi_low_water_mark', (YLeaf(YType.uint32, 'rxi-low-water-mark'), ['int'])),
                        ('rxi_limit_reached', (YLeaf(YType.boolean, 'rxi-limit-reached'), ['bool'])),
                        ('register_limit', (YLeaf(YType.uint32, 'register-limit'), ['int'])),
                        ('register_count', (YLeaf(YType.uint32, 'register-count'), ['int'])),
                        ('register_limit_reached', (YLeaf(YType.boolean, 'register-limit-reached'), ['bool'])),
                        ('ranges_limit', (YLeaf(YType.uint32, 'ranges-limit'), ['int'])),
                        ('ranges_count', (YLeaf(YType.uint32, 'ranges-count'), ['int'])),
                        ('ranges_threshold', (YLeaf(YType.uint32, 'ranges-threshold'), ['int'])),
                        ('is_ranges_limit_reached', (YLeaf(YType.boolean, 'is-ranges-limit-reached'), ['bool'])),
                        ('bsr_ranges_limit', (YLeaf(YType.uint32, 'bsr-ranges-limit'), ['int'])),
                        ('bsr_ranges_count', (YLeaf(YType.uint32, 'bsr-ranges-count'), ['int'])),
                        ('bsr_range_threshold', (YLeaf(YType.uint32, 'bsr-range-threshold'), ['int'])),
                        ('is_bsr_ranges_threshold_reached', (YLeaf(YType.boolean, 'is-bsr-ranges-threshold-reached'), ['bool'])),
                        ('bsr_candidate_rp_set_limit', (YLeaf(YType.uint32, 'bsr-candidate-rp-set-limit'), ['int'])),
                        ('bsr_candidate_rp_set_count', (YLeaf(YType.uint32, 'bsr-candidate-rp-set-count'), ['int'])),
                        ('bsr_candidate_rp_set_threshold', (YLeaf(YType.uint32, 'bsr-candidate-rp-set-threshold'), ['int'])),
                        ('is_maximum_enforcement_disabled', (YLeaf(YType.boolean, 'is-maximum-enforcement-disabled'), ['bool'])),
                        ('is_node_low_memory', (YLeaf(YType.boolean, 'is-node-low-memory'), ['bool'])),
                        ('route_threshold', (YLeaf(YType.uint32, 'route-threshold'), ['int'])),
                        ('global_auto_rp_ranges_limit', (YLeaf(YType.uint32, 'global-auto-rp-ranges-limit'), ['int'])),
                        ('is_global_auto_rp_ranges_limit_reached', (YLeaf(YType.boolean, 'is-global-auto-rp-ranges-limit-reached'), ['bool'])),
                        ('global_bsr_ranges_limit', (YLeaf(YType.uint32, 'global-bsr-ranges-limit'), ['int'])),
                        ('global_bsr_ranges_count', (YLeaf(YType.uint32, 'global-bsr-ranges-count'), ['int'])),
                        ('global_bsr_ranges_threshold', (YLeaf(YType.uint32, 'global-bsr-ranges-threshold'), ['int'])),
                        ('is_global_bsr_ranges_limit_reached', (YLeaf(YType.boolean, 'is-global-bsr-ranges-limit-reached'), ['bool'])),
                        ('global_bsr_candidate_rp_set_limit', (YLeaf(YType.uint32, 'global-bsr-candidate-rp-set-limit'), ['int'])),
                        ('global_bsr_candidate_rp_set_count', (YLeaf(YType.uint32, 'global-bsr-candidate-rp-set-count'), ['int'])),
                        ('global_bsr_candidate_rp_set_threshold', (YLeaf(YType.uint32, 'global-bsr-candidate-rp-set-threshold'), ['int'])),
                        ('is_global_route_limit_reached', (YLeaf(YType.boolean, 'is-global-route-limit-reached'), ['bool'])),
                        ('topology_interface_state_threshold', (YLeaf(YType.uint32, 'topology-interface-state-threshold'), ['int'])),
                        ('is_global_rxi_limit_reached', (YLeaf(YType.boolean, 'is-global-rxi-limit-reached'), ['bool'])),
                        ('register_threshold', (YLeaf(YType.uint32, 'register-threshold'), ['int'])),
                        ('global_register_limit', (YLeaf(YType.uint32, 'global-register-limit'), ['int'])),
                        ('is_global_register_limit_reached', (YLeaf(YType.boolean, 'is-global-register-limit-reached'), ['bool'])),
                    ])
                    self.route_limit = None
                    self.route_count = None
                    self.route_low_water_mark = None
                    self.is_route_limit_reached = None
                    self.topology_interface_state_limit = None
                    self.topology_interface_state_count = None
                    self.rxi_low_water_mark = None
                    self.rxi_limit_reached = None
                    self.register_limit = None
                    self.register_count = None
                    self.register_limit_reached = None
                    self.ranges_limit = None
                    self.ranges_count = None
                    self.ranges_threshold = None
                    self.is_ranges_limit_reached = None
                    self.bsr_ranges_limit = None
                    self.bsr_ranges_count = None
                    self.bsr_range_threshold = None
                    self.is_bsr_ranges_threshold_reached = None
                    self.bsr_candidate_rp_set_limit = None
                    self.bsr_candidate_rp_set_count = None
                    self.bsr_candidate_rp_set_threshold = None
                    self.is_maximum_enforcement_disabled = None
                    self.is_node_low_memory = None
                    self.route_threshold = None
                    self.global_auto_rp_ranges_limit = None
                    self.is_global_auto_rp_ranges_limit_reached = None
                    self.global_bsr_ranges_limit = None
                    self.global_bsr_ranges_count = None
                    self.global_bsr_ranges_threshold = None
                    self.is_global_bsr_ranges_limit_reached = None
                    self.global_bsr_candidate_rp_set_limit = None
                    self.global_bsr_candidate_rp_set_count = None
                    self.global_bsr_candidate_rp_set_threshold = None
                    self.is_global_route_limit_reached = None
                    self.topology_interface_state_threshold = None
                    self.is_global_rxi_limit_reached = None
                    self.register_threshold = None
                    self.global_register_limit = None
                    self.is_global_register_limit_reached = None
                    self._segment_path = lambda: "summary"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.Summary, ['route_limit', 'route_count', 'route_low_water_mark', 'is_route_limit_reached', 'topology_interface_state_limit', 'topology_interface_state_count', 'rxi_low_water_mark', 'rxi_limit_reached', 'register_limit', 'register_count', 'register_limit_reached', 'ranges_limit', 'ranges_count', 'ranges_threshold', 'is_ranges_limit_reached', 'bsr_ranges_limit', 'bsr_ranges_count', 'bsr_range_threshold', 'is_bsr_ranges_threshold_reached', 'bsr_candidate_rp_set_limit', 'bsr_candidate_rp_set_count', 'bsr_candidate_rp_set_threshold', 'is_maximum_enforcement_disabled', 'is_node_low_memory', 'route_threshold', 'global_auto_rp_ranges_limit', 'is_global_auto_rp_ranges_limit_reached', 'global_bsr_ranges_limit', 'global_bsr_ranges_count', 'global_bsr_ranges_threshold', 'is_global_bsr_ranges_limit_reached', 'global_bsr_candidate_rp_set_limit', 'global_bsr_candidate_rp_set_count', 'global_bsr_candidate_rp_set_threshold', 'is_global_route_limit_reached', 'topology_interface_state_threshold', 'is_global_rxi_limit_reached', 'register_threshold', 'global_register_limit', 'is_global_register_limit_reached'], name, value)


            class Gre(Entity):
                """
                GRE information
                
                .. attribute:: gre_hashes
                
                	GRE hash
                	**type**\:  :py:class:`GreHashes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Gre.GreHashes>`
                
                .. attribute:: gre_next_hops
                
                	GRE destination neighbor table
                	**type**\:  :py:class:`GreNextHops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Gre.GreNextHops>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.Gre, self).__init__()

                    self.yang_name = "gre"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("gre-hashes", ("gre_hashes", Ipv6Pim.Active.DefaultContext.Gre.GreHashes)), ("gre-next-hops", ("gre_next_hops", Ipv6Pim.Active.DefaultContext.Gre.GreNextHops))])
                    self._leafs = OrderedDict()

                    self.gre_hashes = Ipv6Pim.Active.DefaultContext.Gre.GreHashes()
                    self.gre_hashes.parent = self
                    self._children_name_map["gre_hashes"] = "gre-hashes"

                    self.gre_next_hops = Ipv6Pim.Active.DefaultContext.Gre.GreNextHops()
                    self.gre_next_hops.parent = self
                    self._children_name_map["gre_next_hops"] = "gre-next-hops"
                    self._segment_path = lambda: "gre"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.Gre, [], name, value)


                class GreHashes(Entity):
                    """
                    GRE hash
                    
                    .. attribute:: gre_hash
                    
                    	PIM GRE Hashed Underlying Interface
                    	**type**\: list of  		 :py:class:`GreHash <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Gre.GreHashes.GreHash>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.Gre.GreHashes, self).__init__()

                        self.yang_name = "gre-hashes"
                        self.yang_parent_name = "gre"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("gre-hash", ("gre_hash", Ipv6Pim.Active.DefaultContext.Gre.GreHashes.GreHash))])
                        self._leafs = OrderedDict()

                        self.gre_hash = YList(self)
                        self._segment_path = lambda: "gre-hashes"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/gre/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.Gre.GreHashes, [], name, value)


                    class GreHash(Entity):
                        """
                        PIM GRE Hashed Underlying Interface
                        
                        .. attribute:: source_address  (key)
                        
                        	Source address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: destination_address  (key)
                        
                        	Destination address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ifname  (key)
                        
                        	GRE Tunnel Interface
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: next_hop_interface
                        
                        	Next hop neighbor interface
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Gre.GreHashes.GreHash, self).__init__()

                            self.yang_name = "gre-hash"
                            self.yang_parent_name = "gre-hashes"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['source_address','destination_address','ifname']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('source_address', (YLeaf(YType.str, 'source-address'), ['str','str'])),
                                ('destination_address', (YLeaf(YType.str, 'destination-address'), ['str','str'])),
                                ('ifname', (YLeaf(YType.str, 'ifname'), ['str'])),
                                ('next_hop_interface', (YLeaf(YType.str, 'next-hop-interface'), ['str'])),
                            ])
                            self.source_address = None
                            self.destination_address = None
                            self.ifname = None
                            self.next_hop_interface = None
                            self._segment_path = lambda: "gre-hash" + "[source-address='" + str(self.source_address) + "']" + "[destination-address='" + str(self.destination_address) + "']" + "[ifname='" + str(self.ifname) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/gre/gre-hashes/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.Gre.GreHashes.GreHash, ['source_address', 'destination_address', 'ifname', 'next_hop_interface'], name, value)


                class GreNextHops(Entity):
                    """
                    GRE destination neighbor table
                    
                    .. attribute:: gre_next_hop
                    
                    	PIM GRE address next\-hop information
                    	**type**\: list of  		 :py:class:`GreNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.Gre.GreNextHops, self).__init__()

                        self.yang_name = "gre-next-hops"
                        self.yang_parent_name = "gre"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("gre-next-hop", ("gre_next_hop", Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop))])
                        self._leafs = OrderedDict()

                        self.gre_next_hop = YList(self)
                        self._segment_path = lambda: "gre-next-hops"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/gre/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.Gre.GreNextHops, [], name, value)


                    class GreNextHop(Entity):
                        """
                        PIM GRE address next\-hop information
                        
                        .. attribute:: destination_address  (key)
                        
                        	GRE destination address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: registered_address
                        
                        	Address registered
                        	**type**\:  :py:class:`RegisteredAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress>`
                        
                        .. attribute:: metric
                        
                        	Metric
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: metric_preference
                        
                        	Metric preference
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_connected
                        
                        	Are we connected ?
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: gre_path
                        
                        	GRE Paths list
                        	**type**\: list of  		 :py:class:`GrePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop, self).__init__()

                            self.yang_name = "gre-next-hop"
                            self.yang_parent_name = "gre-next-hops"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['destination_address']
                            self._child_classes = OrderedDict([("registered-address", ("registered_address", Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress)), ("gre-path", ("gre_path", Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath))])
                            self._leafs = OrderedDict([
                                ('destination_address', (YLeaf(YType.str, 'destination-address'), ['str','str'])),
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                ('metric_preference', (YLeaf(YType.uint32, 'metric-preference'), ['int'])),
                                ('is_connected', (YLeaf(YType.uint8, 'is-connected'), ['int'])),
                            ])
                            self.destination_address = None
                            self.metric = None
                            self.metric_preference = None
                            self.is_connected = None

                            self.registered_address = Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress()
                            self.registered_address.parent = self
                            self._children_name_map["registered_address"] = "registered-address"

                            self.gre_path = YList(self)
                            self._segment_path = lambda: "gre-next-hop" + "[destination-address='" + str(self.destination_address) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/gre/gre-next-hops/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop, ['destination_address', 'metric', 'metric_preference', 'is_connected'], name, value)


                        class RegisteredAddress(Entity):
                            """
                            Address registered
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress, self).__init__()

                                self.yang_name = "registered-address"
                                self.yang_parent_name = "gre-next-hop"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "registered-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class GrePath(Entity):
                            """
                            GRE Paths list
                            
                            .. attribute:: gre_neighbor
                            
                            	GRE neighbor
                            	**type**\:  :py:class:`GreNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor>`
                            
                            .. attribute:: gre_next_hop
                            
                            	GRE nexthop
                            	**type**\:  :py:class:`GreNextHop_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop_>`
                            
                            .. attribute:: gre_interface_name
                            
                            	GRE Interface
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: is_gre_interface_disabled
                            
                            	Is the gre interface disabled ?
                            	**type**\: bool
                            
                            .. attribute:: is_via_lsm
                            
                            	Via LSM
                            	**type**\: bool
                            
                            .. attribute:: is_connector_attribute_present
                            
                            	Connector attribute present
                            	**type**\: bool
                            
                            .. attribute:: extranet_vrf_name
                            
                            	Extranet VRF name
                            	**type**\: str
                            
                            	**length:** 0..33
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath, self).__init__()

                                self.yang_name = "gre-path"
                                self.yang_parent_name = "gre-next-hop"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("gre-neighbor", ("gre_neighbor", Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor)), ("gre-next-hop", ("gre_next_hop", Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop_))])
                                self._leafs = OrderedDict([
                                    ('gre_interface_name', (YLeaf(YType.str, 'gre-interface-name'), ['str'])),
                                    ('is_gre_interface_disabled', (YLeaf(YType.boolean, 'is-gre-interface-disabled'), ['bool'])),
                                    ('is_via_lsm', (YLeaf(YType.boolean, 'is-via-lsm'), ['bool'])),
                                    ('is_connector_attribute_present', (YLeaf(YType.boolean, 'is-connector-attribute-present'), ['bool'])),
                                    ('extranet_vrf_name', (YLeaf(YType.str, 'extranet-vrf-name'), ['str'])),
                                ])
                                self.gre_interface_name = None
                                self.is_gre_interface_disabled = None
                                self.is_via_lsm = None
                                self.is_connector_attribute_present = None
                                self.extranet_vrf_name = None

                                self.gre_neighbor = Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor()
                                self.gre_neighbor.parent = self
                                self._children_name_map["gre_neighbor"] = "gre-neighbor"

                                self.gre_next_hop = Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop_()
                                self.gre_next_hop.parent = self
                                self._children_name_map["gre_next_hop"] = "gre-next-hop"
                                self._segment_path = lambda: "gre-path"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath, ['gre_interface_name', 'is_gre_interface_disabled', 'is_via_lsm', 'is_connector_attribute_present', 'extranet_vrf_name'], name, value)


                            class GreNeighbor(Entity):
                                """
                                GRE neighbor
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor, self).__init__()

                                    self.yang_name = "gre-neighbor"
                                    self.yang_parent_name = "gre-path"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "gre-neighbor"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                            class GreNextHop_(Entity):
                                """
                                GRE nexthop
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop_, self).__init__()

                                    self.yang_name = "gre-next-hop"
                                    self.yang_parent_name = "gre-path"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "gre-next-hop"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop_, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class BidirDfWinners(Entity):
                """
                Bidirectional PIM DF election winner table
                
                .. attribute:: bidir_df_winner
                
                	Bidirectional PIM DF election table entry
                	**type**\: list of  		 :py:class:`BidirDfWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.BidirDfWinners, self).__init__()

                    self.yang_name = "bidir-df-winners"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("bidir-df-winner", ("bidir_df_winner", Ipv6Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner))])
                    self._leafs = OrderedDict()

                    self.bidir_df_winner = YList(self)
                    self._segment_path = lambda: "bidir-df-winners"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.BidirDfWinners, [], name, value)


                class BidirDfWinner(Entity):
                    """
                    Bidirectional PIM DF election table entry
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: rp_address_xr
                    
                    	RP Address
                    	**type**\:  :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr>`
                    
                    .. attribute:: df_winner
                    
                    	DF Winner
                    	**type**\:  :py:class:`DfWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner>`
                    
                    .. attribute:: pim_interface_name
                    
                    	Interface Name
                    	**type**\: str
                    
                    .. attribute:: are_we_df
                    
                    	Are we DF
                    	**type**\: bool
                    
                    .. attribute:: rp_lan
                    
                    	Is this the RP LAN
                    	**type**\: bool
                    
                    .. attribute:: metric
                    
                    	Metric
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: metric_preference
                    
                    	Metric Preference
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner, self).__init__()

                        self.yang_name = "bidir-df-winner"
                        self.yang_parent_name = "bidir-df-winners"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("rp-address-xr", ("rp_address_xr", Ipv6Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr)), ("df-winner", ("df_winner", Ipv6Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner))])
                        self._leafs = OrderedDict([
                            ('rp_address', (YLeaf(YType.str, 'rp-address'), ['str','str'])),
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                            ('pim_interface_name', (YLeaf(YType.str, 'pim-interface-name'), ['str'])),
                            ('are_we_df', (YLeaf(YType.boolean, 'are-we-df'), ['bool'])),
                            ('rp_lan', (YLeaf(YType.boolean, 'rp-lan'), ['bool'])),
                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                            ('metric_preference', (YLeaf(YType.uint32, 'metric-preference'), ['int'])),
                            ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                        ])
                        self.rp_address = None
                        self.interface_name = None
                        self.pim_interface_name = None
                        self.are_we_df = None
                        self.rp_lan = None
                        self.metric = None
                        self.metric_preference = None
                        self.uptime = None

                        self.rp_address_xr = Ipv6Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr()
                        self.rp_address_xr.parent = self
                        self._children_name_map["rp_address_xr"] = "rp-address-xr"

                        self.df_winner = Ipv6Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner()
                        self.df_winner.parent = self
                        self._children_name_map["df_winner"] = "df-winner"
                        self._segment_path = lambda: "bidir-df-winner"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/bidir-df-winners/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner, ['rp_address', 'interface_name', 'pim_interface_name', 'are_we_df', 'rp_lan', 'metric', 'metric_preference', 'uptime'], name, value)


                    class RpAddressXr(Entity):
                        """
                        RP Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr, self).__init__()

                            self.yang_name = "rp-address-xr"
                            self.yang_parent_name = "bidir-df-winner"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "rp-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/bidir-df-winners/bidir-df-winner/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class DfWinner(Entity):
                        """
                        DF Winner
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner, self).__init__()

                            self.yang_name = "df-winner"
                            self.yang_parent_name = "bidir-df-winner"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "df-winner"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/bidir-df-winners/bidir-df-winner/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class TableContexts(Entity):
                """
                PIM table context list
                
                .. attribute:: table_context
                
                	PIM table context information
                	**type**\: list of  		 :py:class:`TableContext <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.TableContexts.TableContext>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.TableContexts, self).__init__()

                    self.yang_name = "table-contexts"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("table-context", ("table_context", Ipv6Pim.Active.DefaultContext.TableContexts.TableContext))])
                    self._leafs = OrderedDict()

                    self.table_context = YList(self)
                    self._segment_path = lambda: "table-contexts"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.TableContexts, [], name, value)


                class TableContext(Entity):
                    """
                    PIM table context information
                    
                    .. attribute:: saf_name
                    
                    	SAF name
                    	**type**\:  :py:class:`PimSafi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimSafi>`
                    
                    .. attribute:: topology_name
                    
                    	Topology name
                    	**type**\: str
                    
                    	**length:** 1..32
                    
                    .. attribute:: afi
                    
                    	AFI
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: safi
                    
                    	SAFI
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_name
                    
                    	Table name
                    	**type**\: str
                    
                    .. attribute:: vrf_id
                    
                    	VRF ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_id
                    
                    	Table ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_active
                    
                    	Active status
                    	**type**\: bool
                    
                    .. attribute:: is_ital_registration_done
                    
                    	ITAL reg status
                    	**type**\: bool
                    
                    .. attribute:: is_rib_registration_done
                    
                    	RIB reg status
                    	**type**\: bool
                    
                    .. attribute:: is_rib_convergence_received
                    
                    	RIB Convergence receive status
                    	**type**\: bool
                    
                    .. attribute:: is_rib_convergence
                    
                    	RIB Convergence status
                    	**type**\: bool
                    
                    .. attribute:: rpf_registrations
                    
                    	RPF Registration count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.TableContexts.TableContext, self).__init__()

                        self.yang_name = "table-context"
                        self.yang_parent_name = "table-contexts"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('saf_name', (YLeaf(YType.enumeration, 'saf-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimSafi', '')])),
                            ('topology_name', (YLeaf(YType.str, 'topology-name'), ['str'])),
                            ('afi', (YLeaf(YType.uint32, 'afi'), ['int'])),
                            ('safi', (YLeaf(YType.uint32, 'safi'), ['int'])),
                            ('table_name', (YLeaf(YType.str, 'table-name'), ['str'])),
                            ('vrf_id', (YLeaf(YType.uint32, 'vrf-id'), ['int'])),
                            ('table_id', (YLeaf(YType.uint32, 'table-id'), ['int'])),
                            ('is_active', (YLeaf(YType.boolean, 'is-active'), ['bool'])),
                            ('is_ital_registration_done', (YLeaf(YType.boolean, 'is-ital-registration-done'), ['bool'])),
                            ('is_rib_registration_done', (YLeaf(YType.boolean, 'is-rib-registration-done'), ['bool'])),
                            ('is_rib_convergence_received', (YLeaf(YType.boolean, 'is-rib-convergence-received'), ['bool'])),
                            ('is_rib_convergence', (YLeaf(YType.boolean, 'is-rib-convergence'), ['bool'])),
                            ('rpf_registrations', (YLeaf(YType.uint32, 'rpf-registrations'), ['int'])),
                        ])
                        self.saf_name = None
                        self.topology_name = None
                        self.afi = None
                        self.safi = None
                        self.table_name = None
                        self.vrf_id = None
                        self.table_id = None
                        self.is_active = None
                        self.is_ital_registration_done = None
                        self.is_rib_registration_done = None
                        self.is_rib_convergence_received = None
                        self.is_rib_convergence = None
                        self.rpf_registrations = None
                        self._segment_path = lambda: "table-context"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/table-contexts/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.TableContexts.TableContext, ['saf_name', 'topology_name', 'afi', 'safi', 'table_name', 'vrf_id', 'table_id', 'is_active', 'is_ital_registration_done', 'is_rib_registration_done', 'is_rib_convergence_received', 'is_rib_convergence', 'rpf_registrations'], name, value)


            class NeighborSummaries(Entity):
                """
                PIM neighbor summary table
                
                .. attribute:: neighbor_summary
                
                	PIM neighbor summary information
                	**type**\: list of  		 :py:class:`NeighborSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.NeighborSummaries.NeighborSummary>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.NeighborSummaries, self).__init__()

                    self.yang_name = "neighbor-summaries"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("neighbor-summary", ("neighbor_summary", Ipv6Pim.Active.DefaultContext.NeighborSummaries.NeighborSummary))])
                    self._leafs = OrderedDict()

                    self.neighbor_summary = YList(self)
                    self._segment_path = lambda: "neighbor-summaries"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.NeighborSummaries, [], name, value)


                class NeighborSummary(Entity):
                    """
                    PIM neighbor summary information
                    
                    .. attribute:: interface_name  (key)
                    
                    	Interface name
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: number_of_neighbors
                    
                    	Number of neighbors
                    	**type**\: int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: number_of_external_neighbors
                    
                    	Number of external neighbors
                    	**type**\: int
                    
                    	**range:** \-2147483648..2147483647
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.NeighborSummaries.NeighborSummary, self).__init__()

                        self.yang_name = "neighbor-summary"
                        self.yang_parent_name = "neighbor-summaries"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['interface_name']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                            ('number_of_neighbors', (YLeaf(YType.int32, 'number-of-neighbors'), ['int'])),
                            ('number_of_external_neighbors', (YLeaf(YType.int32, 'number-of-external-neighbors'), ['int'])),
                        ])
                        self.interface_name = None
                        self.number_of_neighbors = None
                        self.number_of_external_neighbors = None
                        self._segment_path = lambda: "neighbor-summary" + "[interface-name='" + str(self.interface_name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/neighbor-summaries/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.NeighborSummaries.NeighborSummary, ['interface_name', 'number_of_neighbors', 'number_of_external_neighbors'], name, value)


            class Context(Entity):
                """
                PIM context information
                
                .. attribute:: remote_default_group
                
                	Remote Default Group
                	**type**\:  :py:class:`RemoteDefaultGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Context.RemoteDefaultGroup>`
                
                .. attribute:: rpf_default_table
                
                	RPF Default Table
                	**type**\:  :py:class:`RpfDefaultTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Context.RpfDefaultTable>`
                
                .. attribute:: vrf_id
                
                	VRF ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: table_id
                
                	Table ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: murib_id
                
                	MURIB ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: rpf_id
                
                	RPF ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: remote_table_id
                
                	Remote Table ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_default_group
                
                	MDT Default group
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: mdt_source
                
                	MDT source
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: mdt_source_interface
                
                	MDT Source Interface Name
                	**type**\: str
                
                .. attribute:: mdt_interface
                
                	MDT handle
                	**type**\: str
                
                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                
                .. attribute:: mdt_gre_rpf_identifier
                
                	GRE\-MDT RPF Identifier
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_gre_remote_rpf_identifier
                
                	GRE\-MDT Remote RPF Identifier
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_unicast_rib_registration
                
                	Ucast RIB Registration
                	**type**\: bool
                
                .. attribute:: is_multicast_rib_registration
                
                	Mcast RIB Registration
                	**type**\: bool
                
                .. attribute:: is_active
                
                	Active
                	**type**\: bool
                
                .. attribute:: is_active_ital
                
                	Active ITAL
                	**type**\: bool
                
                .. attribute:: is_mrib_register
                
                	MRIB Register
                	**type**\: bool
                
                .. attribute:: is_mdt_owner
                
                	MDT Owner
                	**type**\: bool
                
                .. attribute:: is_routing_enabled
                
                	Routing Enabled
                	**type**\: bool
                
                .. attribute:: is_socket_add_required
                
                	VRF required on Socket
                	**type**\: bool
                
                .. attribute:: is_socket_added
                
                	VRF added on Socket
                	**type**\: bool
                
                .. attribute:: is_lpts_socket_add_required
                
                	VRF LPTS filter required on Socket
                	**type**\: bool
                
                .. attribute:: is_lpts_socket_added
                
                	VRF LPTS filter added on Socket
                	**type**\: bool
                
                .. attribute:: is_udp_socket_add_required
                
                	VRF added on UDP Socket
                	**type**\: bool
                
                .. attribute:: is_udp_socket_added
                
                	VRF added on UDP Socket
                	**type**\: bool
                
                .. attribute:: is_udp_socket_bind_required
                
                	VRF bind required on UDP Socket
                	**type**\: bool
                
                .. attribute:: is_udp_socket_bind
                
                	VRF bound on UDP Socket
                	**type**\: bool
                
                .. attribute:: is_register_injection_socket_add_required
                
                	VRF required on Register Injection Socket
                	**type**\: bool
                
                .. attribute:: is_register_injection_socket_added
                
                	VRF added on Register Injection Socket
                	**type**\: bool
                
                .. attribute:: is_register_injection_lpts_socket_add_required
                
                	VRF LPTS filter required on Register Injection Socket
                	**type**\: bool
                
                .. attribute:: is_register_injection_lpts_socket_added
                
                	VRF LPTS filter added on Register Injection Socket
                	**type**\: bool
                
                .. attribute:: is_m_host_publish_pending
                
                	Publish pending for MHost Default interface
                	**type**\: bool
                
                .. attribute:: mhost_interface
                
                	MHost handle
                	**type**\: str
                
                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                
                .. attribute:: mhost_default_interface_config
                
                	Configured Mhost Defint
                	**type**\: str
                
                .. attribute:: mdt_mtu
                
                	MDT MTU
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: maximum_mdt_aggregation
                
                	MDT max aggregation
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_data_switchover_interval
                
                	Data MDT Switchover interval
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_data_announce_interval
                
                	Data MDT Announce interval
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: non_default_vrf_count_on_socket
                
                	Count of non\-default vrfs on raw socket
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: neighbor_filter_name
                
                	Neighbor Filter Name
                	**type**\: str
                
                .. attribute:: mdt_neighbor_filter_name
                
                	MDT Neighbor Filter Name
                	**type**\: str
                
                .. attribute:: allow_rp_configured
                
                	Allow RP Configured
                	**type**\: bool
                
                .. attribute:: allow_rp_group_list
                
                	Allow RP Group\-List ACL Name
                	**type**\: str
                
                	**length:** 0..64
                
                .. attribute:: allow_rp_rp_list
                
                	Allow RP RP\-list ACL Name
                	**type**\: str
                
                	**length:** 0..64
                
                .. attribute:: sg_expiry_timer_configured
                
                	S,G Expiry Timer Configured
                	**type**\: bool
                
                .. attribute:: sg_expiry_time
                
                	S,G Expiry Time Configured, in seconds
                	**type**\: int
                
                	**range:** 0..65535
                
                	**units**\: second
                
                .. attribute:: sg_expiry_timer_sg_list
                
                	S,G expiry timer ACL name
                	**type**\: str
                
                	**length:** 0..64
                
                .. attribute:: mldp_mdt_name
                
                	MLDP MDT Name
                	**type**\: str
                
                .. attribute:: mldp_mdt_interface
                
                	MLDP MDT handle
                	**type**\: str
                
                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                
                .. attribute:: mldp_mdt_mtu
                
                	MLDP MDT MTU
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_maximum_mdt_aggregation
                
                	MLDP MDT max aggregation
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_data_switchover_interval
                
                	MLDP Data MDT Switchover interval
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_data_announce_interval
                
                	MLDP Data MDT Announce interval
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_rpf_identifier
                
                	MLDP RPF\-ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_remote_rpf_identifier
                
                	MLDP Remote RPF\-ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_create_mldp_mdt_interface
                
                	Create MLDP MDT interface
                	**type**\: bool
                
                .. attribute:: is_mldp_mdt_owner
                
                	MLDP MDT Owner
                	**type**\: bool
                
                .. attribute:: mldp_root_count
                
                	MLDP Root count
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_head_lsm_identifier
                
                	MLDP Head LSM\-ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_remote_head_lsm_identifier
                
                	MLDP Remote Head LSM\-ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: organization_unique_identifier
                
                	OUI for VPN\-ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: vpn_index
                
                	VPN Index
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_partitioned_mdt_configured
                
                	MLDP Partitioned MDT
                	**type**\: bool
                
                .. attribute:: mldp_remote_partitioned_mdt_configured
                
                	MLDP Remote Partitioned MDT
                	**type**\: bool
                
                .. attribute:: mldp_partioned_mp2m_ptree
                
                	MP2MP Partitioned MDT tree
                	**type**\: bool
                
                .. attribute:: mldp_partitioned_head_lsm_identifier
                
                	Partitioned MDT Head LSM\-ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_head_local_label
                
                	Partitioned MDT Head local label
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_partitioned_mdt_identifier
                
                	MLDP Partitioned MDT Identifier
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: bgp_auto_discovery_configured
                
                	BGP Auto\-Discovery configured
                	**type**\: bool
                
                .. attribute:: suppress_pim_data_mdt_tlv
                
                	Suppress PIM Data\-MDT TLV Announcements
                	**type**\: bool
                
                .. attribute:: inter_autonomous_system_enabled
                
                	Inter\-AS Enabled
                	**type**\: bool
                
                .. attribute:: bgp_source_active_announce
                
                	Send BGP Source\-Active Announcements
                	**type**\: bool
                
                .. attribute:: bgp_i_pmsi_added
                
                	BGP I\-PMSI Added
                	**type**\: bool
                
                .. attribute:: mldp_bsr_control_tree_added
                
                	MLDP BSR Control tree added
                	**type**\: bool
                
                .. attribute:: mldp_auto_rp_discovery_tree_added
                
                	MLDP Autorp Discovery Control tree added
                	**type**\: bool
                
                .. attribute:: mldp_auto_rp_announce_tree_added
                
                	MLDP Autorp Announce Control tree added
                	**type**\: bool
                
                .. attribute:: bgp_auto_discovery_type
                
                	BGP Auto Discovery Type
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_partitioned_mdt_control_identifier
                
                	Partitioned MDT Control Identifier
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_partitioned_ir_control_identifier
                
                	Partitioned IR MDT Control Identifier
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_control_head_lsm_identifier
                
                	MLDP MVPN Identifier
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: umh
                
                	Join UMH Core\-Tree
                	**type**\: bool
                
                .. attribute:: suppress_shared_tree_join
                
                	Suppress Shared\-Tree Joins
                	**type**\: bool
                
                .. attribute:: rsvp_te_mdt_name
                
                	RSVP\-TE MDT Name
                	**type**\: str
                
                .. attribute:: rsvp_te_mdt_interface
                
                	RSVP\-TEMDT handle
                	**type**\: str
                
                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                
                .. attribute:: rsvp_te_mdt_mtu
                
                	RSVP\-TEMDT MTU
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_maximum_mdt_aggregation
                
                	RSVP\-TE MDT max aggregation
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_data_switchover_interval
                
                	RSVP\-TE Data MDT Switchover interval
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_data_announce_interval
                
                	RSVP\-TE Data MDT Announce interval
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_rpf_identifier
                
                	RSVP\-TE RPF\-ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_create_rsvp_te_mdt_interface
                
                	Create RSVP\-TE MDT interface
                	**type**\: bool
                
                .. attribute:: is_rsvp_te_mdt_owner
                
                	RSVP\-TE MDT Owner
                	**type**\: bool
                
                .. attribute:: rsvp_te_mdt_static_p2mp_count
                
                	Number of Static P2MP\-TE MDT
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: p2mpte_li_drop
                
                	Route LI updates dropped for P2MP
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_name
                
                	IR MDT Name
                	**type**\: str
                
                .. attribute:: ir_mdt_interface
                
                	IRMDT handle
                	**type**\: str
                
                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                
                .. attribute:: ir_mdt_mtu
                
                	IRMDT MTU
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_maximum_mdt_aggregation
                
                	IR MDT max aggregation
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_data_switchover_interval
                
                	IR Data MDT Switchover interval
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_data_announce_interval
                
                	IR Data MDT Announce interval
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_rpf_identifier
                
                	IR RPF\-ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_tail_label
                
                	IR Tail Label
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_create_ir_mdt_interface
                
                	Create IR MDT interface
                	**type**\: bool
                
                .. attribute:: is_ir_mdt_owner
                
                	IR MDT Owner
                	**type**\: bool
                
                .. attribute:: in_b_and_mdt_name
                
                	Inband MDT Name
                	**type**\: str
                
                .. attribute:: in_b_and_mdt_interface
                
                	Inband MDT handle
                	**type**\: str
                
                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                
                .. attribute:: in_b_and_mdt_mtu
                
                	Inband MDT MTU
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_band_maximum_mdt_aggregation
                
                	Inband MDT max aggregation
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_b_and_mdt_data_switchover_interval
                
                	Inband Data MDT Switchover interval
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_b_and_mdt_data_announce_interval
                
                	Inband Data MDT Announce interval
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_b_and_mdt_rpf_identifier
                
                	Inband RPF\-ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_create_in_b_and_mdt_interface
                
                	Create Inband MDT interface
                	**type**\: bool
                
                .. attribute:: is_in_b_and_mdt_owner
                
                	Inband MDT Owner
                	**type**\: bool
                
                .. attribute:: in_band_signaling_local_enabled
                
                	Inband signaling Local enabled
                	**type**\: bool
                
                .. attribute:: in_band_signaling_remote_enabled
                
                	Inband signaling Remote enabled
                	**type**\: bool
                
                .. attribute:: valid_rd_present
                
                	RD is valid
                	**type**\: bool
                
                .. attribute:: stale_rd_present
                
                	RD is stale
                	**type**\: bool
                
                .. attribute:: route_distinguisher
                
                	RD value
                	**type**\: str
                
                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                
                .. attribute:: gin_b_and_mdt_name
                
                	Inband MDT Name
                	**type**\: str
                
                .. attribute:: gin_b_and_mdt_interface
                
                	Inband MDT handle
                	**type**\: str
                
                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                
                .. attribute:: gin_b_and_mdt_mtu
                
                	Inband MDT MTU
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: gin_band_maximum_mdt_aggregation
                
                	Inband MDT max aggregation
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: gin_b_and_mdt_data_switchover_interval
                
                	Inband Data MDT Switchover interval
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: gin_b_and_mdt_data_announce_interval
                
                	Inband Data MDT Announce interval
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: gin_b_and_mdt_rpf_identifier
                
                	Inband RPF\-ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_create_gin_b_and_mdt_interface
                
                	Create Inband MDT interface
                	**type**\: bool
                
                .. attribute:: is_gin_b_and_mdt_owner
                
                	Inband MDT Owner
                	**type**\: bool
                
                .. attribute:: is_pim_nsf_rib_converged
                
                	PIM NSF RIB converged
                	**type**\: bool
                
                .. attribute:: is_pim_nsf_rib_converge_received
                
                	PIM NSF RIB converge received
                	**type**\: bool
                
                .. attribute:: is_rib_multipath_enabled
                
                	PIM RIB multiplath enabled
                	**type**\: bool
                
                .. attribute:: is_rib_multipath_interface_hash
                
                	PIM RIB multipath interface hash
                	**type**\: bool
                
                .. attribute:: is_rib_multipath_source_hash
                
                	PIM RIB multipath source based hash
                	**type**\: bool
                
                .. attribute:: is_rib_multipath_source_next_hop_hash
                
                	PIM RIB multipath source\-nexthop hash
                	**type**\: bool
                
                .. attribute:: rump_enabled
                
                	PIM is using MuRIB
                	**type**\: bool
                
                .. attribute:: is_create_mdt_interface
                
                	Create MDT interface
                	**type**\: bool
                
                .. attribute:: is_auto_rp_listen_enabled
                
                	Auto RP Listen Enabled
                	**type**\: bool
                
                .. attribute:: is_all_interface_disable_operation
                
                	PIM all interface disable operation
                	**type**\: bool
                
                .. attribute:: is_default_granges
                
                	Default granges
                	**type**\: bool
                
                .. attribute:: is_auto_rp_listen_sock_add
                
                	Auto RP listen sock add
                	**type**\: bool
                
                .. attribute:: is_redistribution_reset
                
                	Pending redist reset
                	**type**\: bool
                
                .. attribute:: redistribution_reset_count
                
                	Redist reset count
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: rpf_policy_name
                
                	RPF topology selection route\-policy name
                	**type**\: str
                
                .. attribute:: table_count
                
                	Number of configured Tables
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: active_table_count
                
                	Number of active Tables
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: anycast_rp_policy_name
                
                	Anycast\-RP Policy Name
                	**type**\: str
                
                .. attribute:: anycast_rp_configured
                
                	Anycast\-RP config
                	**type**\: bool
                
                .. attribute:: bgp_remote_on
                
                	BGP remote interface status
                	**type**\: bool
                
                .. attribute:: bgp_remote_interface_name
                
                	BGP remote interface name
                	**type**\: str
                
                .. attribute:: bgp_remote_interface
                
                	BGP remote interface handle
                	**type**\: str
                
                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                
                .. attribute:: bgp_remote_address
                
                	BGP remote interface address
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: bgp_remote_state
                
                	BGP remote interface state
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: physical_interface_count
                
                	Enabled Physical Interface Count
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: virtual_interface_count
                
                	Enabled Virtual Interface Count
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: virtual_mlc_interface_name
                
                	Virtual master line card Interface
                	**type**\: str
                
                .. attribute:: mdt_immediate_switch
                
                	MDT Immediate Switch
                	**type**\: bool
                
                .. attribute:: mldp_root_address
                
                	MLDP Root addresses
                	**type**\: list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: export_route_target
                
                	Export Route Targets
                	**type**\: list of  		 :py:class:`ExportRouteTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Context.ExportRouteTarget>`
                
                .. attribute:: import_route_target
                
                	Import Route Targets
                	**type**\: list of  		 :py:class:`ImportRouteTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Context.ImportRouteTarget>`
                
                .. attribute:: anycast_rp_range
                
                	Anycast\-RP Ranges
                	**type**\: list of  		 :py:class:`AnycastRpRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Context.AnycastRpRange>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.Context, self).__init__()

                    self.yang_name = "context"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("remote-default-group", ("remote_default_group", Ipv6Pim.Active.DefaultContext.Context.RemoteDefaultGroup)), ("rpf-default-table", ("rpf_default_table", Ipv6Pim.Active.DefaultContext.Context.RpfDefaultTable)), ("export-route-target", ("export_route_target", Ipv6Pim.Active.DefaultContext.Context.ExportRouteTarget)), ("import-route-target", ("import_route_target", Ipv6Pim.Active.DefaultContext.Context.ImportRouteTarget)), ("anycast-rp-range", ("anycast_rp_range", Ipv6Pim.Active.DefaultContext.Context.AnycastRpRange))])
                    self._leafs = OrderedDict([
                        ('vrf_id', (YLeaf(YType.uint32, 'vrf-id'), ['int'])),
                        ('table_id', (YLeaf(YType.uint32, 'table-id'), ['int'])),
                        ('murib_id', (YLeaf(YType.uint32, 'murib-id'), ['int'])),
                        ('rpf_id', (YLeaf(YType.uint32, 'rpf-id'), ['int'])),
                        ('remote_table_id', (YLeaf(YType.uint32, 'remote-table-id'), ['int'])),
                        ('mdt_default_group', (YLeaf(YType.str, 'mdt-default-group'), ['str'])),
                        ('mdt_source', (YLeaf(YType.str, 'mdt-source'), ['str'])),
                        ('mdt_source_interface', (YLeaf(YType.str, 'mdt-source-interface'), ['str'])),
                        ('mdt_interface', (YLeaf(YType.str, 'mdt-interface'), ['str'])),
                        ('mdt_gre_rpf_identifier', (YLeaf(YType.uint32, 'mdt-gre-rpf-identifier'), ['int'])),
                        ('mdt_gre_remote_rpf_identifier', (YLeaf(YType.uint32, 'mdt-gre-remote-rpf-identifier'), ['int'])),
                        ('is_unicast_rib_registration', (YLeaf(YType.boolean, 'is-unicast-rib-registration'), ['bool'])),
                        ('is_multicast_rib_registration', (YLeaf(YType.boolean, 'is-multicast-rib-registration'), ['bool'])),
                        ('is_active', (YLeaf(YType.boolean, 'is-active'), ['bool'])),
                        ('is_active_ital', (YLeaf(YType.boolean, 'is-active-ital'), ['bool'])),
                        ('is_mrib_register', (YLeaf(YType.boolean, 'is-mrib-register'), ['bool'])),
                        ('is_mdt_owner', (YLeaf(YType.boolean, 'is-mdt-owner'), ['bool'])),
                        ('is_routing_enabled', (YLeaf(YType.boolean, 'is-routing-enabled'), ['bool'])),
                        ('is_socket_add_required', (YLeaf(YType.boolean, 'is-socket-add-required'), ['bool'])),
                        ('is_socket_added', (YLeaf(YType.boolean, 'is-socket-added'), ['bool'])),
                        ('is_lpts_socket_add_required', (YLeaf(YType.boolean, 'is-lpts-socket-add-required'), ['bool'])),
                        ('is_lpts_socket_added', (YLeaf(YType.boolean, 'is-lpts-socket-added'), ['bool'])),
                        ('is_udp_socket_add_required', (YLeaf(YType.boolean, 'is-udp-socket-add-required'), ['bool'])),
                        ('is_udp_socket_added', (YLeaf(YType.boolean, 'is-udp-socket-added'), ['bool'])),
                        ('is_udp_socket_bind_required', (YLeaf(YType.boolean, 'is-udp-socket-bind-required'), ['bool'])),
                        ('is_udp_socket_bind', (YLeaf(YType.boolean, 'is-udp-socket-bind'), ['bool'])),
                        ('is_register_injection_socket_add_required', (YLeaf(YType.boolean, 'is-register-injection-socket-add-required'), ['bool'])),
                        ('is_register_injection_socket_added', (YLeaf(YType.boolean, 'is-register-injection-socket-added'), ['bool'])),
                        ('is_register_injection_lpts_socket_add_required', (YLeaf(YType.boolean, 'is-register-injection-lpts-socket-add-required'), ['bool'])),
                        ('is_register_injection_lpts_socket_added', (YLeaf(YType.boolean, 'is-register-injection-lpts-socket-added'), ['bool'])),
                        ('is_m_host_publish_pending', (YLeaf(YType.boolean, 'is-m-host-publish-pending'), ['bool'])),
                        ('mhost_interface', (YLeaf(YType.str, 'mhost-interface'), ['str'])),
                        ('mhost_default_interface_config', (YLeaf(YType.str, 'mhost-default-interface-config'), ['str'])),
                        ('mdt_mtu', (YLeaf(YType.uint32, 'mdt-mtu'), ['int'])),
                        ('maximum_mdt_aggregation', (YLeaf(YType.uint32, 'maximum-mdt-aggregation'), ['int'])),
                        ('mdt_data_switchover_interval', (YLeaf(YType.uint32, 'mdt-data-switchover-interval'), ['int'])),
                        ('mdt_data_announce_interval', (YLeaf(YType.uint32, 'mdt-data-announce-interval'), ['int'])),
                        ('non_default_vrf_count_on_socket', (YLeaf(YType.uint32, 'non-default-vrf-count-on-socket'), ['int'])),
                        ('neighbor_filter_name', (YLeaf(YType.str, 'neighbor-filter-name'), ['str'])),
                        ('mdt_neighbor_filter_name', (YLeaf(YType.str, 'mdt-neighbor-filter-name'), ['str'])),
                        ('allow_rp_configured', (YLeaf(YType.boolean, 'allow-rp-configured'), ['bool'])),
                        ('allow_rp_group_list', (YLeaf(YType.str, 'allow-rp-group-list'), ['str'])),
                        ('allow_rp_rp_list', (YLeaf(YType.str, 'allow-rp-rp-list'), ['str'])),
                        ('sg_expiry_timer_configured', (YLeaf(YType.boolean, 'sg-expiry-timer-configured'), ['bool'])),
                        ('sg_expiry_time', (YLeaf(YType.uint16, 'sg-expiry-time'), ['int'])),
                        ('sg_expiry_timer_sg_list', (YLeaf(YType.str, 'sg-expiry-timer-sg-list'), ['str'])),
                        ('mldp_mdt_name', (YLeaf(YType.str, 'mldp-mdt-name'), ['str'])),
                        ('mldp_mdt_interface', (YLeaf(YType.str, 'mldp-mdt-interface'), ['str'])),
                        ('mldp_mdt_mtu', (YLeaf(YType.uint32, 'mldp-mdt-mtu'), ['int'])),
                        ('mldp_maximum_mdt_aggregation', (YLeaf(YType.uint32, 'mldp-maximum-mdt-aggregation'), ['int'])),
                        ('mldp_mdt_data_switchover_interval', (YLeaf(YType.uint32, 'mldp-mdt-data-switchover-interval'), ['int'])),
                        ('mldp_mdt_data_announce_interval', (YLeaf(YType.uint32, 'mldp-mdt-data-announce-interval'), ['int'])),
                        ('mldp_mdt_rpf_identifier', (YLeaf(YType.uint32, 'mldp-mdt-rpf-identifier'), ['int'])),
                        ('mldp_mdt_remote_rpf_identifier', (YLeaf(YType.uint32, 'mldp-mdt-remote-rpf-identifier'), ['int'])),
                        ('is_create_mldp_mdt_interface', (YLeaf(YType.boolean, 'is-create-mldp-mdt-interface'), ['bool'])),
                        ('is_mldp_mdt_owner', (YLeaf(YType.boolean, 'is-mldp-mdt-owner'), ['bool'])),
                        ('mldp_root_count', (YLeaf(YType.uint32, 'mldp-root-count'), ['int'])),
                        ('mldp_head_lsm_identifier', (YLeaf(YType.uint32, 'mldp-head-lsm-identifier'), ['int'])),
                        ('mldp_remote_head_lsm_identifier', (YLeaf(YType.uint32, 'mldp-remote-head-lsm-identifier'), ['int'])),
                        ('organization_unique_identifier', (YLeaf(YType.uint32, 'organization-unique-identifier'), ['int'])),
                        ('vpn_index', (YLeaf(YType.uint32, 'vpn-index'), ['int'])),
                        ('mldp_partitioned_mdt_configured', (YLeaf(YType.boolean, 'mldp-partitioned-mdt-configured'), ['bool'])),
                        ('mldp_remote_partitioned_mdt_configured', (YLeaf(YType.boolean, 'mldp-remote-partitioned-mdt-configured'), ['bool'])),
                        ('mldp_partioned_mp2m_ptree', (YLeaf(YType.boolean, 'mldp-partioned-mp2m-ptree'), ['bool'])),
                        ('mldp_partitioned_head_lsm_identifier', (YLeaf(YType.uint32, 'mldp-partitioned-head-lsm-identifier'), ['int'])),
                        ('mldp_head_local_label', (YLeaf(YType.uint32, 'mldp-head-local-label'), ['int'])),
                        ('mldp_partitioned_mdt_identifier', (YLeaf(YType.uint32, 'mldp-partitioned-mdt-identifier'), ['int'])),
                        ('bgp_auto_discovery_configured', (YLeaf(YType.boolean, 'bgp-auto-discovery-configured'), ['bool'])),
                        ('suppress_pim_data_mdt_tlv', (YLeaf(YType.boolean, 'suppress-pim-data-mdt-tlv'), ['bool'])),
                        ('inter_autonomous_system_enabled', (YLeaf(YType.boolean, 'inter-autonomous-system-enabled'), ['bool'])),
                        ('bgp_source_active_announce', (YLeaf(YType.boolean, 'bgp-source-active-announce'), ['bool'])),
                        ('bgp_i_pmsi_added', (YLeaf(YType.boolean, 'bgp-i-pmsi-added'), ['bool'])),
                        ('mldp_bsr_control_tree_added', (YLeaf(YType.boolean, 'mldp-bsr-control-tree-added'), ['bool'])),
                        ('mldp_auto_rp_discovery_tree_added', (YLeaf(YType.boolean, 'mldp-auto-rp-discovery-tree-added'), ['bool'])),
                        ('mldp_auto_rp_announce_tree_added', (YLeaf(YType.boolean, 'mldp-auto-rp-announce-tree-added'), ['bool'])),
                        ('bgp_auto_discovery_type', (YLeaf(YType.uint32, 'bgp-auto-discovery-type'), ['int'])),
                        ('mdt_partitioned_mdt_control_identifier', (YLeaf(YType.uint32, 'mdt-partitioned-mdt-control-identifier'), ['int'])),
                        ('mdt_partitioned_ir_control_identifier', (YLeaf(YType.uint32, 'mdt-partitioned-ir-control-identifier'), ['int'])),
                        ('mldp_control_head_lsm_identifier', (YLeaf(YType.uint32, 'mldp-control-head-lsm-identifier'), ['int'])),
                        ('umh', (YLeaf(YType.boolean, 'umh'), ['bool'])),
                        ('suppress_shared_tree_join', (YLeaf(YType.boolean, 'suppress-shared-tree-join'), ['bool'])),
                        ('rsvp_te_mdt_name', (YLeaf(YType.str, 'rsvp-te-mdt-name'), ['str'])),
                        ('rsvp_te_mdt_interface', (YLeaf(YType.str, 'rsvp-te-mdt-interface'), ['str'])),
                        ('rsvp_te_mdt_mtu', (YLeaf(YType.uint32, 'rsvp-te-mdt-mtu'), ['int'])),
                        ('rsvp_te_maximum_mdt_aggregation', (YLeaf(YType.uint32, 'rsvp-te-maximum-mdt-aggregation'), ['int'])),
                        ('rsvp_te_mdt_data_switchover_interval', (YLeaf(YType.uint32, 'rsvp-te-mdt-data-switchover-interval'), ['int'])),
                        ('rsvp_te_mdt_data_announce_interval', (YLeaf(YType.uint32, 'rsvp-te-mdt-data-announce-interval'), ['int'])),
                        ('rsvp_te_mdt_rpf_identifier', (YLeaf(YType.uint32, 'rsvp-te-mdt-rpf-identifier'), ['int'])),
                        ('is_create_rsvp_te_mdt_interface', (YLeaf(YType.boolean, 'is-create-rsvp-te-mdt-interface'), ['bool'])),
                        ('is_rsvp_te_mdt_owner', (YLeaf(YType.boolean, 'is-rsvp-te-mdt-owner'), ['bool'])),
                        ('rsvp_te_mdt_static_p2mp_count', (YLeaf(YType.uint32, 'rsvp-te-mdt-static-p2mp-count'), ['int'])),
                        ('p2mpte_li_drop', (YLeaf(YType.uint32, 'p2mpte-li-drop'), ['int'])),
                        ('ir_mdt_name', (YLeaf(YType.str, 'ir-mdt-name'), ['str'])),
                        ('ir_mdt_interface', (YLeaf(YType.str, 'ir-mdt-interface'), ['str'])),
                        ('ir_mdt_mtu', (YLeaf(YType.uint32, 'ir-mdt-mtu'), ['int'])),
                        ('ir_maximum_mdt_aggregation', (YLeaf(YType.uint32, 'ir-maximum-mdt-aggregation'), ['int'])),
                        ('ir_mdt_data_switchover_interval', (YLeaf(YType.uint32, 'ir-mdt-data-switchover-interval'), ['int'])),
                        ('ir_mdt_data_announce_interval', (YLeaf(YType.uint32, 'ir-mdt-data-announce-interval'), ['int'])),
                        ('ir_mdt_rpf_identifier', (YLeaf(YType.uint32, 'ir-mdt-rpf-identifier'), ['int'])),
                        ('ir_mdt_tail_label', (YLeaf(YType.uint32, 'ir-mdt-tail-label'), ['int'])),
                        ('is_create_ir_mdt_interface', (YLeaf(YType.boolean, 'is-create-ir-mdt-interface'), ['bool'])),
                        ('is_ir_mdt_owner', (YLeaf(YType.boolean, 'is-ir-mdt-owner'), ['bool'])),
                        ('in_b_and_mdt_name', (YLeaf(YType.str, 'in-b-and-mdt-name'), ['str'])),
                        ('in_b_and_mdt_interface', (YLeaf(YType.str, 'in-b-and-mdt-interface'), ['str'])),
                        ('in_b_and_mdt_mtu', (YLeaf(YType.uint32, 'in-b-and-mdt-mtu'), ['int'])),
                        ('in_band_maximum_mdt_aggregation', (YLeaf(YType.uint32, 'in-band-maximum-mdt-aggregation'), ['int'])),
                        ('in_b_and_mdt_data_switchover_interval', (YLeaf(YType.uint32, 'in-b-and-mdt-data-switchover-interval'), ['int'])),
                        ('in_b_and_mdt_data_announce_interval', (YLeaf(YType.uint32, 'in-b-and-mdt-data-announce-interval'), ['int'])),
                        ('in_b_and_mdt_rpf_identifier', (YLeaf(YType.uint32, 'in-b-and-mdt-rpf-identifier'), ['int'])),
                        ('is_create_in_b_and_mdt_interface', (YLeaf(YType.boolean, 'is-create-in-b-and-mdt-interface'), ['bool'])),
                        ('is_in_b_and_mdt_owner', (YLeaf(YType.boolean, 'is-in-b-and-mdt-owner'), ['bool'])),
                        ('in_band_signaling_local_enabled', (YLeaf(YType.boolean, 'in-band-signaling-local-enabled'), ['bool'])),
                        ('in_band_signaling_remote_enabled', (YLeaf(YType.boolean, 'in-band-signaling-remote-enabled'), ['bool'])),
                        ('valid_rd_present', (YLeaf(YType.boolean, 'valid-rd-present'), ['bool'])),
                        ('stale_rd_present', (YLeaf(YType.boolean, 'stale-rd-present'), ['bool'])),
                        ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                        ('gin_b_and_mdt_name', (YLeaf(YType.str, 'gin-b-and-mdt-name'), ['str'])),
                        ('gin_b_and_mdt_interface', (YLeaf(YType.str, 'gin-b-and-mdt-interface'), ['str'])),
                        ('gin_b_and_mdt_mtu', (YLeaf(YType.uint32, 'gin-b-and-mdt-mtu'), ['int'])),
                        ('gin_band_maximum_mdt_aggregation', (YLeaf(YType.uint32, 'gin-band-maximum-mdt-aggregation'), ['int'])),
                        ('gin_b_and_mdt_data_switchover_interval', (YLeaf(YType.uint32, 'gin-b-and-mdt-data-switchover-interval'), ['int'])),
                        ('gin_b_and_mdt_data_announce_interval', (YLeaf(YType.uint32, 'gin-b-and-mdt-data-announce-interval'), ['int'])),
                        ('gin_b_and_mdt_rpf_identifier', (YLeaf(YType.uint32, 'gin-b-and-mdt-rpf-identifier'), ['int'])),
                        ('is_create_gin_b_and_mdt_interface', (YLeaf(YType.boolean, 'is-create-gin-b-and-mdt-interface'), ['bool'])),
                        ('is_gin_b_and_mdt_owner', (YLeaf(YType.boolean, 'is-gin-b-and-mdt-owner'), ['bool'])),
                        ('is_pim_nsf_rib_converged', (YLeaf(YType.boolean, 'is-pim-nsf-rib-converged'), ['bool'])),
                        ('is_pim_nsf_rib_converge_received', (YLeaf(YType.boolean, 'is-pim-nsf-rib-converge-received'), ['bool'])),
                        ('is_rib_multipath_enabled', (YLeaf(YType.boolean, 'is-rib-multipath-enabled'), ['bool'])),
                        ('is_rib_multipath_interface_hash', (YLeaf(YType.boolean, 'is-rib-multipath-interface-hash'), ['bool'])),
                        ('is_rib_multipath_source_hash', (YLeaf(YType.boolean, 'is-rib-multipath-source-hash'), ['bool'])),
                        ('is_rib_multipath_source_next_hop_hash', (YLeaf(YType.boolean, 'is-rib-multipath-source-next-hop-hash'), ['bool'])),
                        ('rump_enabled', (YLeaf(YType.boolean, 'rump-enabled'), ['bool'])),
                        ('is_create_mdt_interface', (YLeaf(YType.boolean, 'is-create-mdt-interface'), ['bool'])),
                        ('is_auto_rp_listen_enabled', (YLeaf(YType.boolean, 'is-auto-rp-listen-enabled'), ['bool'])),
                        ('is_all_interface_disable_operation', (YLeaf(YType.boolean, 'is-all-interface-disable-operation'), ['bool'])),
                        ('is_default_granges', (YLeaf(YType.boolean, 'is-default-granges'), ['bool'])),
                        ('is_auto_rp_listen_sock_add', (YLeaf(YType.boolean, 'is-auto-rp-listen-sock-add'), ['bool'])),
                        ('is_redistribution_reset', (YLeaf(YType.boolean, 'is-redistribution-reset'), ['bool'])),
                        ('redistribution_reset_count', (YLeaf(YType.uint32, 'redistribution-reset-count'), ['int'])),
                        ('rpf_policy_name', (YLeaf(YType.str, 'rpf-policy-name'), ['str'])),
                        ('table_count', (YLeaf(YType.uint32, 'table-count'), ['int'])),
                        ('active_table_count', (YLeaf(YType.uint32, 'active-table-count'), ['int'])),
                        ('anycast_rp_policy_name', (YLeaf(YType.str, 'anycast-rp-policy-name'), ['str'])),
                        ('anycast_rp_configured', (YLeaf(YType.boolean, 'anycast-rp-configured'), ['bool'])),
                        ('bgp_remote_on', (YLeaf(YType.boolean, 'bgp-remote-on'), ['bool'])),
                        ('bgp_remote_interface_name', (YLeaf(YType.str, 'bgp-remote-interface-name'), ['str'])),
                        ('bgp_remote_interface', (YLeaf(YType.str, 'bgp-remote-interface'), ['str'])),
                        ('bgp_remote_address', (YLeaf(YType.str, 'bgp-remote-address'), ['str'])),
                        ('bgp_remote_state', (YLeaf(YType.uint32, 'bgp-remote-state'), ['int'])),
                        ('physical_interface_count', (YLeaf(YType.uint64, 'physical-interface-count'), ['int'])),
                        ('virtual_interface_count', (YLeaf(YType.uint64, 'virtual-interface-count'), ['int'])),
                        ('virtual_mlc_interface_name', (YLeaf(YType.str, 'virtual-mlc-interface-name'), ['str'])),
                        ('mdt_immediate_switch', (YLeaf(YType.boolean, 'mdt-immediate-switch'), ['bool'])),
                        ('mldp_root_address', (YLeafList(YType.uint32, 'mldp-root-address'), ['int'])),
                    ])
                    self.vrf_id = None
                    self.table_id = None
                    self.murib_id = None
                    self.rpf_id = None
                    self.remote_table_id = None
                    self.mdt_default_group = None
                    self.mdt_source = None
                    self.mdt_source_interface = None
                    self.mdt_interface = None
                    self.mdt_gre_rpf_identifier = None
                    self.mdt_gre_remote_rpf_identifier = None
                    self.is_unicast_rib_registration = None
                    self.is_multicast_rib_registration = None
                    self.is_active = None
                    self.is_active_ital = None
                    self.is_mrib_register = None
                    self.is_mdt_owner = None
                    self.is_routing_enabled = None
                    self.is_socket_add_required = None
                    self.is_socket_added = None
                    self.is_lpts_socket_add_required = None
                    self.is_lpts_socket_added = None
                    self.is_udp_socket_add_required = None
                    self.is_udp_socket_added = None
                    self.is_udp_socket_bind_required = None
                    self.is_udp_socket_bind = None
                    self.is_register_injection_socket_add_required = None
                    self.is_register_injection_socket_added = None
                    self.is_register_injection_lpts_socket_add_required = None
                    self.is_register_injection_lpts_socket_added = None
                    self.is_m_host_publish_pending = None
                    self.mhost_interface = None
                    self.mhost_default_interface_config = None
                    self.mdt_mtu = None
                    self.maximum_mdt_aggregation = None
                    self.mdt_data_switchover_interval = None
                    self.mdt_data_announce_interval = None
                    self.non_default_vrf_count_on_socket = None
                    self.neighbor_filter_name = None
                    self.mdt_neighbor_filter_name = None
                    self.allow_rp_configured = None
                    self.allow_rp_group_list = None
                    self.allow_rp_rp_list = None
                    self.sg_expiry_timer_configured = None
                    self.sg_expiry_time = None
                    self.sg_expiry_timer_sg_list = None
                    self.mldp_mdt_name = None
                    self.mldp_mdt_interface = None
                    self.mldp_mdt_mtu = None
                    self.mldp_maximum_mdt_aggregation = None
                    self.mldp_mdt_data_switchover_interval = None
                    self.mldp_mdt_data_announce_interval = None
                    self.mldp_mdt_rpf_identifier = None
                    self.mldp_mdt_remote_rpf_identifier = None
                    self.is_create_mldp_mdt_interface = None
                    self.is_mldp_mdt_owner = None
                    self.mldp_root_count = None
                    self.mldp_head_lsm_identifier = None
                    self.mldp_remote_head_lsm_identifier = None
                    self.organization_unique_identifier = None
                    self.vpn_index = None
                    self.mldp_partitioned_mdt_configured = None
                    self.mldp_remote_partitioned_mdt_configured = None
                    self.mldp_partioned_mp2m_ptree = None
                    self.mldp_partitioned_head_lsm_identifier = None
                    self.mldp_head_local_label = None
                    self.mldp_partitioned_mdt_identifier = None
                    self.bgp_auto_discovery_configured = None
                    self.suppress_pim_data_mdt_tlv = None
                    self.inter_autonomous_system_enabled = None
                    self.bgp_source_active_announce = None
                    self.bgp_i_pmsi_added = None
                    self.mldp_bsr_control_tree_added = None
                    self.mldp_auto_rp_discovery_tree_added = None
                    self.mldp_auto_rp_announce_tree_added = None
                    self.bgp_auto_discovery_type = None
                    self.mdt_partitioned_mdt_control_identifier = None
                    self.mdt_partitioned_ir_control_identifier = None
                    self.mldp_control_head_lsm_identifier = None
                    self.umh = None
                    self.suppress_shared_tree_join = None
                    self.rsvp_te_mdt_name = None
                    self.rsvp_te_mdt_interface = None
                    self.rsvp_te_mdt_mtu = None
                    self.rsvp_te_maximum_mdt_aggregation = None
                    self.rsvp_te_mdt_data_switchover_interval = None
                    self.rsvp_te_mdt_data_announce_interval = None
                    self.rsvp_te_mdt_rpf_identifier = None
                    self.is_create_rsvp_te_mdt_interface = None
                    self.is_rsvp_te_mdt_owner = None
                    self.rsvp_te_mdt_static_p2mp_count = None
                    self.p2mpte_li_drop = None
                    self.ir_mdt_name = None
                    self.ir_mdt_interface = None
                    self.ir_mdt_mtu = None
                    self.ir_maximum_mdt_aggregation = None
                    self.ir_mdt_data_switchover_interval = None
                    self.ir_mdt_data_announce_interval = None
                    self.ir_mdt_rpf_identifier = None
                    self.ir_mdt_tail_label = None
                    self.is_create_ir_mdt_interface = None
                    self.is_ir_mdt_owner = None
                    self.in_b_and_mdt_name = None
                    self.in_b_and_mdt_interface = None
                    self.in_b_and_mdt_mtu = None
                    self.in_band_maximum_mdt_aggregation = None
                    self.in_b_and_mdt_data_switchover_interval = None
                    self.in_b_and_mdt_data_announce_interval = None
                    self.in_b_and_mdt_rpf_identifier = None
                    self.is_create_in_b_and_mdt_interface = None
                    self.is_in_b_and_mdt_owner = None
                    self.in_band_signaling_local_enabled = None
                    self.in_band_signaling_remote_enabled = None
                    self.valid_rd_present = None
                    self.stale_rd_present = None
                    self.route_distinguisher = None
                    self.gin_b_and_mdt_name = None
                    self.gin_b_and_mdt_interface = None
                    self.gin_b_and_mdt_mtu = None
                    self.gin_band_maximum_mdt_aggregation = None
                    self.gin_b_and_mdt_data_switchover_interval = None
                    self.gin_b_and_mdt_data_announce_interval = None
                    self.gin_b_and_mdt_rpf_identifier = None
                    self.is_create_gin_b_and_mdt_interface = None
                    self.is_gin_b_and_mdt_owner = None
                    self.is_pim_nsf_rib_converged = None
                    self.is_pim_nsf_rib_converge_received = None
                    self.is_rib_multipath_enabled = None
                    self.is_rib_multipath_interface_hash = None
                    self.is_rib_multipath_source_hash = None
                    self.is_rib_multipath_source_next_hop_hash = None
                    self.rump_enabled = None
                    self.is_create_mdt_interface = None
                    self.is_auto_rp_listen_enabled = None
                    self.is_all_interface_disable_operation = None
                    self.is_default_granges = None
                    self.is_auto_rp_listen_sock_add = None
                    self.is_redistribution_reset = None
                    self.redistribution_reset_count = None
                    self.rpf_policy_name = None
                    self.table_count = None
                    self.active_table_count = None
                    self.anycast_rp_policy_name = None
                    self.anycast_rp_configured = None
                    self.bgp_remote_on = None
                    self.bgp_remote_interface_name = None
                    self.bgp_remote_interface = None
                    self.bgp_remote_address = None
                    self.bgp_remote_state = None
                    self.physical_interface_count = None
                    self.virtual_interface_count = None
                    self.virtual_mlc_interface_name = None
                    self.mdt_immediate_switch = None
                    self.mldp_root_address = []

                    self.remote_default_group = Ipv6Pim.Active.DefaultContext.Context.RemoteDefaultGroup()
                    self.remote_default_group.parent = self
                    self._children_name_map["remote_default_group"] = "remote-default-group"

                    self.rpf_default_table = Ipv6Pim.Active.DefaultContext.Context.RpfDefaultTable()
                    self.rpf_default_table.parent = self
                    self._children_name_map["rpf_default_table"] = "rpf-default-table"

                    self.export_route_target = YList(self)
                    self.import_route_target = YList(self)
                    self.anycast_rp_range = YList(self)
                    self._segment_path = lambda: "context"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.Context, ['vrf_id', 'table_id', 'murib_id', 'rpf_id', 'remote_table_id', 'mdt_default_group', 'mdt_source', 'mdt_source_interface', 'mdt_interface', 'mdt_gre_rpf_identifier', 'mdt_gre_remote_rpf_identifier', 'is_unicast_rib_registration', 'is_multicast_rib_registration', 'is_active', 'is_active_ital', 'is_mrib_register', 'is_mdt_owner', 'is_routing_enabled', 'is_socket_add_required', 'is_socket_added', 'is_lpts_socket_add_required', 'is_lpts_socket_added', 'is_udp_socket_add_required', 'is_udp_socket_added', 'is_udp_socket_bind_required', 'is_udp_socket_bind', 'is_register_injection_socket_add_required', 'is_register_injection_socket_added', 'is_register_injection_lpts_socket_add_required', 'is_register_injection_lpts_socket_added', 'is_m_host_publish_pending', 'mhost_interface', 'mhost_default_interface_config', 'mdt_mtu', 'maximum_mdt_aggregation', 'mdt_data_switchover_interval', 'mdt_data_announce_interval', 'non_default_vrf_count_on_socket', 'neighbor_filter_name', 'mdt_neighbor_filter_name', 'allow_rp_configured', 'allow_rp_group_list', 'allow_rp_rp_list', 'sg_expiry_timer_configured', 'sg_expiry_time', 'sg_expiry_timer_sg_list', 'mldp_mdt_name', 'mldp_mdt_interface', 'mldp_mdt_mtu', 'mldp_maximum_mdt_aggregation', 'mldp_mdt_data_switchover_interval', 'mldp_mdt_data_announce_interval', 'mldp_mdt_rpf_identifier', 'mldp_mdt_remote_rpf_identifier', 'is_create_mldp_mdt_interface', 'is_mldp_mdt_owner', 'mldp_root_count', 'mldp_head_lsm_identifier', 'mldp_remote_head_lsm_identifier', 'organization_unique_identifier', 'vpn_index', 'mldp_partitioned_mdt_configured', 'mldp_remote_partitioned_mdt_configured', 'mldp_partioned_mp2m_ptree', 'mldp_partitioned_head_lsm_identifier', 'mldp_head_local_label', 'mldp_partitioned_mdt_identifier', 'bgp_auto_discovery_configured', 'suppress_pim_data_mdt_tlv', 'inter_autonomous_system_enabled', 'bgp_source_active_announce', 'bgp_i_pmsi_added', 'mldp_bsr_control_tree_added', 'mldp_auto_rp_discovery_tree_added', 'mldp_auto_rp_announce_tree_added', 'bgp_auto_discovery_type', 'mdt_partitioned_mdt_control_identifier', 'mdt_partitioned_ir_control_identifier', 'mldp_control_head_lsm_identifier', 'umh', 'suppress_shared_tree_join', 'rsvp_te_mdt_name', 'rsvp_te_mdt_interface', 'rsvp_te_mdt_mtu', 'rsvp_te_maximum_mdt_aggregation', 'rsvp_te_mdt_data_switchover_interval', 'rsvp_te_mdt_data_announce_interval', 'rsvp_te_mdt_rpf_identifier', 'is_create_rsvp_te_mdt_interface', 'is_rsvp_te_mdt_owner', 'rsvp_te_mdt_static_p2mp_count', 'p2mpte_li_drop', 'ir_mdt_name', 'ir_mdt_interface', 'ir_mdt_mtu', 'ir_maximum_mdt_aggregation', 'ir_mdt_data_switchover_interval', 'ir_mdt_data_announce_interval', 'ir_mdt_rpf_identifier', 'ir_mdt_tail_label', 'is_create_ir_mdt_interface', 'is_ir_mdt_owner', 'in_b_and_mdt_name', 'in_b_and_mdt_interface', 'in_b_and_mdt_mtu', 'in_band_maximum_mdt_aggregation', 'in_b_and_mdt_data_switchover_interval', 'in_b_and_mdt_data_announce_interval', 'in_b_and_mdt_rpf_identifier', 'is_create_in_b_and_mdt_interface', 'is_in_b_and_mdt_owner', 'in_band_signaling_local_enabled', 'in_band_signaling_remote_enabled', 'valid_rd_present', 'stale_rd_present', 'route_distinguisher', 'gin_b_and_mdt_name', 'gin_b_and_mdt_interface', 'gin_b_and_mdt_mtu', 'gin_band_maximum_mdt_aggregation', 'gin_b_and_mdt_data_switchover_interval', 'gin_b_and_mdt_data_announce_interval', 'gin_b_and_mdt_rpf_identifier', 'is_create_gin_b_and_mdt_interface', 'is_gin_b_and_mdt_owner', 'is_pim_nsf_rib_converged', 'is_pim_nsf_rib_converge_received', 'is_rib_multipath_enabled', 'is_rib_multipath_interface_hash', 'is_rib_multipath_source_hash', 'is_rib_multipath_source_next_hop_hash', 'rump_enabled', 'is_create_mdt_interface', 'is_auto_rp_listen_enabled', 'is_all_interface_disable_operation', 'is_default_granges', 'is_auto_rp_listen_sock_add', 'is_redistribution_reset', 'redistribution_reset_count', 'rpf_policy_name', 'table_count', 'active_table_count', 'anycast_rp_policy_name', 'anycast_rp_configured', 'bgp_remote_on', 'bgp_remote_interface_name', 'bgp_remote_interface', 'bgp_remote_address', 'bgp_remote_state', 'physical_interface_count', 'virtual_interface_count', 'virtual_mlc_interface_name', 'mdt_immediate_switch', 'mldp_root_address'], name, value)


                class RemoteDefaultGroup(Entity):
                    """
                    Remote Default Group
                    
                    .. attribute:: af_name
                    
                    	AFName
                    	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                    
                    .. attribute:: ipv4_address
                    
                    	IPv4 Address
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: ipv6_address
                    
                    	IPV6 Address
                    	**type**\: str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.Context.RemoteDefaultGroup, self).__init__()

                        self.yang_name = "remote-default-group"
                        self.yang_parent_name = "context"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                        ])
                        self.af_name = None
                        self.ipv4_address = None
                        self.ipv6_address = None
                        self._segment_path = lambda: "remote-default-group"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/context/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.Context.RemoteDefaultGroup, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class RpfDefaultTable(Entity):
                    """
                    RPF Default Table
                    
                    .. attribute:: afi
                    
                    	AFI
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: safi
                    
                    	SAFI
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_name
                    
                    	Table name
                    	**type**\: str
                    
                    .. attribute:: vrf_id
                    
                    	VRF ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_id
                    
                    	Table ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_active
                    
                    	Active status
                    	**type**\: bool
                    
                    .. attribute:: is_ital_registration_done
                    
                    	ITAL reg status
                    	**type**\: bool
                    
                    .. attribute:: is_rib_registration_done
                    
                    	RIB reg status
                    	**type**\: bool
                    
                    .. attribute:: is_rib_convergence_received
                    
                    	RIB Convergence receive status
                    	**type**\: bool
                    
                    .. attribute:: is_rib_convergence
                    
                    	RIB Convergence status
                    	**type**\: bool
                    
                    .. attribute:: rpf_registrations
                    
                    	RPF Registration count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.Context.RpfDefaultTable, self).__init__()

                        self.yang_name = "rpf-default-table"
                        self.yang_parent_name = "context"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('afi', (YLeaf(YType.uint32, 'afi'), ['int'])),
                            ('safi', (YLeaf(YType.uint32, 'safi'), ['int'])),
                            ('table_name', (YLeaf(YType.str, 'table-name'), ['str'])),
                            ('vrf_id', (YLeaf(YType.uint32, 'vrf-id'), ['int'])),
                            ('table_id', (YLeaf(YType.uint32, 'table-id'), ['int'])),
                            ('is_active', (YLeaf(YType.boolean, 'is-active'), ['bool'])),
                            ('is_ital_registration_done', (YLeaf(YType.boolean, 'is-ital-registration-done'), ['bool'])),
                            ('is_rib_registration_done', (YLeaf(YType.boolean, 'is-rib-registration-done'), ['bool'])),
                            ('is_rib_convergence_received', (YLeaf(YType.boolean, 'is-rib-convergence-received'), ['bool'])),
                            ('is_rib_convergence', (YLeaf(YType.boolean, 'is-rib-convergence'), ['bool'])),
                            ('rpf_registrations', (YLeaf(YType.uint32, 'rpf-registrations'), ['int'])),
                        ])
                        self.afi = None
                        self.safi = None
                        self.table_name = None
                        self.vrf_id = None
                        self.table_id = None
                        self.is_active = None
                        self.is_ital_registration_done = None
                        self.is_rib_registration_done = None
                        self.is_rib_convergence_received = None
                        self.is_rib_convergence = None
                        self.rpf_registrations = None
                        self._segment_path = lambda: "rpf-default-table"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/context/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.Context.RpfDefaultTable, ['afi', 'safi', 'table_name', 'vrf_id', 'table_id', 'is_active', 'is_ital_registration_done', 'is_rib_registration_done', 'is_rib_convergence_received', 'is_rib_convergence', 'rpf_registrations'], name, value)


                class ExportRouteTarget(Entity):
                    """
                    Export Route Targets
                    
                    .. attribute:: route_target
                    
                    	Route Target Extended community value
                    	**type**\: str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: configured
                    
                    	Configured Route Target
                    	**type**\: bool
                    
                    .. attribute:: anycast_rp
                    
                    	Anycast\-RP Group
                    	**type**\: bool
                    
                    .. attribute:: anycast_rp_marked
                    
                    	Anycast\-RP Group marked
                    	**type**\: bool
                    
                    .. attribute:: update_pending
                    
                    	Update Pending to BGP
                    	**type**\: bool
                    
                    .. attribute:: bgp_auto_discovery
                    
                    	BGP Auto Discovery
                    	**type**\: bool
                    
                    .. attribute:: segment_border
                    
                    	Segment Border
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.Context.ExportRouteTarget, self).__init__()

                        self.yang_name = "export-route-target"
                        self.yang_parent_name = "context"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_target', (YLeaf(YType.str, 'route-target'), ['str'])),
                            ('configured', (YLeaf(YType.boolean, 'configured'), ['bool'])),
                            ('anycast_rp', (YLeaf(YType.boolean, 'anycast-rp'), ['bool'])),
                            ('anycast_rp_marked', (YLeaf(YType.boolean, 'anycast-rp-marked'), ['bool'])),
                            ('update_pending', (YLeaf(YType.boolean, 'update-pending'), ['bool'])),
                            ('bgp_auto_discovery', (YLeaf(YType.boolean, 'bgp-auto-discovery'), ['bool'])),
                            ('segment_border', (YLeaf(YType.boolean, 'segment-border'), ['bool'])),
                        ])
                        self.route_target = None
                        self.configured = None
                        self.anycast_rp = None
                        self.anycast_rp_marked = None
                        self.update_pending = None
                        self.bgp_auto_discovery = None
                        self.segment_border = None
                        self._segment_path = lambda: "export-route-target"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/context/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.Context.ExportRouteTarget, ['route_target', 'configured', 'anycast_rp', 'anycast_rp_marked', 'update_pending', 'bgp_auto_discovery', 'segment_border'], name, value)


                class ImportRouteTarget(Entity):
                    """
                    Import Route Targets
                    
                    .. attribute:: route_target
                    
                    	Route Target Extended community value
                    	**type**\: str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: configured
                    
                    	Configured Route Target
                    	**type**\: bool
                    
                    .. attribute:: anycast_rp
                    
                    	Anycast\-RP Group
                    	**type**\: bool
                    
                    .. attribute:: anycast_rp_marked
                    
                    	Anycast\-RP Group marked
                    	**type**\: bool
                    
                    .. attribute:: update_pending
                    
                    	Update Pending to BGP
                    	**type**\: bool
                    
                    .. attribute:: bgp_auto_discovery
                    
                    	BGP Auto Discovery
                    	**type**\: bool
                    
                    .. attribute:: segment_border
                    
                    	Segment Border
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.Context.ImportRouteTarget, self).__init__()

                        self.yang_name = "import-route-target"
                        self.yang_parent_name = "context"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_target', (YLeaf(YType.str, 'route-target'), ['str'])),
                            ('configured', (YLeaf(YType.boolean, 'configured'), ['bool'])),
                            ('anycast_rp', (YLeaf(YType.boolean, 'anycast-rp'), ['bool'])),
                            ('anycast_rp_marked', (YLeaf(YType.boolean, 'anycast-rp-marked'), ['bool'])),
                            ('update_pending', (YLeaf(YType.boolean, 'update-pending'), ['bool'])),
                            ('bgp_auto_discovery', (YLeaf(YType.boolean, 'bgp-auto-discovery'), ['bool'])),
                            ('segment_border', (YLeaf(YType.boolean, 'segment-border'), ['bool'])),
                        ])
                        self.route_target = None
                        self.configured = None
                        self.anycast_rp = None
                        self.anycast_rp_marked = None
                        self.update_pending = None
                        self.bgp_auto_discovery = None
                        self.segment_border = None
                        self._segment_path = lambda: "import-route-target"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/context/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.Context.ImportRouteTarget, ['route_target', 'configured', 'anycast_rp', 'anycast_rp_marked', 'update_pending', 'bgp_auto_discovery', 'segment_border'], name, value)


                class AnycastRpRange(Entity):
                    """
                    Anycast\-RP Ranges
                    
                    .. attribute:: prefix
                    
                    	Anycast\-RP Range Prefix
                    	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Context.AnycastRpRange.Prefix>`
                    
                    .. attribute:: prefix_length
                    
                    	Anycast\-RP Range Prefix Length
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: ancast_rp_marked
                    
                    	Anycast\-RP Range marked
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.Context.AnycastRpRange, self).__init__()

                        self.yang_name = "anycast-rp-range"
                        self.yang_parent_name = "context"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("prefix", ("prefix", Ipv6Pim.Active.DefaultContext.Context.AnycastRpRange.Prefix))])
                        self._leafs = OrderedDict([
                            ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                            ('ancast_rp_marked', (YLeaf(YType.boolean, 'ancast-rp-marked'), ['bool'])),
                        ])
                        self.prefix_length = None
                        self.ancast_rp_marked = None

                        self.prefix = Ipv6Pim.Active.DefaultContext.Context.AnycastRpRange.Prefix()
                        self.prefix.parent = self
                        self._children_name_map["prefix"] = "prefix"
                        self._segment_path = lambda: "anycast-rp-range"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/context/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.Context.AnycastRpRange, ['prefix_length', 'ancast_rp_marked'], name, value)


                    class Prefix(Entity):
                        """
                        Anycast\-RP Range Prefix
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Context.AnycastRpRange.Prefix, self).__init__()

                            self.yang_name = "prefix"
                            self.yang_parent_name = "anycast-rp-range"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "prefix"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/context/anycast-rp-range/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.Context.AnycastRpRange.Prefix, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class TopologyEntryFlagRouteCounts(Entity):
                """
                Route count for topology with entry flag set
                
                .. attribute:: topology_entry_flag_route_count
                
                	Route count for topology with entry flag set
                	**type**\: list of  		 :py:class:`TopologyEntryFlagRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts, self).__init__()

                    self.yang_name = "topology-entry-flag-route-counts"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("topology-entry-flag-route-count", ("topology_entry_flag_route_count", Ipv6Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount))])
                    self._leafs = OrderedDict()

                    self.topology_entry_flag_route_count = YList(self)
                    self._segment_path = lambda: "topology-entry-flag-route-counts"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts, [], name, value)


                class TopologyEntryFlagRouteCount(Entity):
                    """
                    Route count for topology with entry flag set
                    
                    .. attribute:: entry_flag  (key)
                    
                    	entry flag
                    	**type**\:  :py:class:`PimTopologyEntryFlag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimTopologyEntryFlag>`
                    
                    .. attribute:: group_ranges
                    
                    	No. of (\*,G/M) routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: active_group_ranges
                    
                    	No. of (\*,G/M) routes active in mrib
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: groute_count
                    
                    	No. of (\*,G) routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sg_route_count
                    
                    	No. of (S,G) routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sgr_route_count
                    
                    	No. of (S,G)RPT routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount, self).__init__()

                        self.yang_name = "topology-entry-flag-route-count"
                        self.yang_parent_name = "topology-entry-flag-route-counts"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['entry_flag']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('entry_flag', (YLeaf(YType.enumeration, 'entry-flag'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimTopologyEntryFlag', '')])),
                            ('group_ranges', (YLeaf(YType.uint32, 'group-ranges'), ['int'])),
                            ('active_group_ranges', (YLeaf(YType.uint32, 'active-group-ranges'), ['int'])),
                            ('groute_count', (YLeaf(YType.uint32, 'groute-count'), ['int'])),
                            ('sg_route_count', (YLeaf(YType.uint32, 'sg-route-count'), ['int'])),
                            ('sgr_route_count', (YLeaf(YType.uint32, 'sgr-route-count'), ['int'])),
                            ('is_node_low_memory', (YLeaf(YType.boolean, 'is-node-low-memory'), ['bool'])),
                        ])
                        self.entry_flag = None
                        self.group_ranges = None
                        self.active_group_ranges = None
                        self.groute_count = None
                        self.sg_route_count = None
                        self.sgr_route_count = None
                        self.is_node_low_memory = None
                        self._segment_path = lambda: "topology-entry-flag-route-count" + "[entry-flag='" + str(self.entry_flag) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/topology-entry-flag-route-counts/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount, ['entry_flag', 'group_ranges', 'active_group_ranges', 'groute_count', 'sg_route_count', 'sgr_route_count', 'is_node_low_memory'], name, value)


            class RpfRedirect(Entity):
                """
                PIM ECMP RPF\-redirect bundle
                
                .. attribute:: redirect_route_databases
                
                	PIM ECMP RPF\-redirect route database
                	**type**\:  :py:class:`RedirectRouteDatabases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases>`
                
                .. attribute:: bundle_interfaces
                
                	PIM ECMP RPF\-redirect bundle information
                	**type**\:  :py:class:`BundleInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.RpfRedirect, self).__init__()

                    self.yang_name = "rpf-redirect"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("redirect-route-databases", ("redirect_route_databases", Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases)), ("bundle-interfaces", ("bundle_interfaces", Ipv6Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces))])
                    self._leafs = OrderedDict()

                    self.redirect_route_databases = Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases()
                    self.redirect_route_databases.parent = self
                    self._children_name_map["redirect_route_databases"] = "redirect-route-databases"

                    self.bundle_interfaces = Ipv6Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces()
                    self.bundle_interfaces.parent = self
                    self._children_name_map["bundle_interfaces"] = "bundle-interfaces"
                    self._segment_path = lambda: "rpf-redirect"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.RpfRedirect, [], name, value)


                class RedirectRouteDatabases(Entity):
                    """
                    PIM ECMP RPF\-redirect route database
                    
                    .. attribute:: redirect_route_database
                    
                    	PIM ECMP RPF\-redirect route information
                    	**type**\: list of  		 :py:class:`RedirectRouteDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases, self).__init__()

                        self.yang_name = "redirect-route-databases"
                        self.yang_parent_name = "rpf-redirect"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("redirect-route-database", ("redirect_route_database", Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase))])
                        self._leafs = OrderedDict()

                        self.redirect_route_database = YList(self)
                        self._segment_path = lambda: "redirect-route-databases"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/rpf-redirect/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases, [], name, value)


                    class RedirectRouteDatabase(Entity):
                        """
                        PIM ECMP RPF\-redirect route information
                        
                        .. attribute:: source_address
                        
                        	Source address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: group_address
                        
                        	Group address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: group_address_xr
                        
                        	Group ddress
                        	**type**\:  :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr>`
                        
                        .. attribute:: source_address_xr
                        
                        	Source address
                        	**type**\:  :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr>`
                        
                        .. attribute:: bandwidth
                        
                        	Bandwidth in Kbps
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: interface
                        
                        	Outgoing interface list
                        	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase, self).__init__()

                            self.yang_name = "redirect-route-database"
                            self.yang_parent_name = "redirect-route-databases"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("group-address-xr", ("group_address_xr", Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr)), ("source-address-xr", ("source_address_xr", Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr)), ("interface", ("interface", Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface))])
                            self._leafs = OrderedDict([
                                ('source_address', (YLeaf(YType.str, 'source-address'), ['str','str'])),
                                ('group_address', (YLeaf(YType.str, 'group-address'), ['str','str'])),
                                ('bandwidth', (YLeaf(YType.uint32, 'bandwidth'), ['int'])),
                                ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                            ])
                            self.source_address = None
                            self.group_address = None
                            self.bandwidth = None
                            self.uptime = None

                            self.group_address_xr = Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"

                            self.source_address_xr = Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr()
                            self.source_address_xr.parent = self
                            self._children_name_map["source_address_xr"] = "source-address-xr"

                            self.interface = YList(self)
                            self._segment_path = lambda: "redirect-route-database"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/rpf-redirect/redirect-route-databases/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase, ['source_address', 'group_address', 'bandwidth', 'uptime'], name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group ddress
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "redirect-route-database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "group-address-xr"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/rpf-redirect/redirect-route-databases/redirect-route-database/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class SourceAddressXr(Entity):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr, self).__init__()

                                self.yang_name = "source-address-xr"
                                self.yang_parent_name = "redirect-route-database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "source-address-xr"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/rpf-redirect/redirect-route-databases/redirect-route-database/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class Interface(Entity):
                            """
                            Outgoing interface list
                            
                            .. attribute:: rpf_address
                            
                            	RPF Address
                            	**type**\:  :py:class:`RpfAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress>`
                            
                            .. attribute:: interface_name
                            
                            	Interface name
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: expiry
                            
                            	Expiry in seconds
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: is_rpf_interface
                            
                            	Is RPF Interface
                            	**type**\: bool
                            
                            .. attribute:: is_outgoing_interface
                            
                            	Is outgoing Interface
                            	**type**\: bool
                            
                            .. attribute:: is_snoop_interface
                            
                            	Is snooping Interface
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface, self).__init__()

                                self.yang_name = "interface"
                                self.yang_parent_name = "redirect-route-database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("rpf-address", ("rpf_address", Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress))])
                                self._leafs = OrderedDict([
                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                    ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                                    ('expiry', (YLeaf(YType.uint64, 'expiry'), ['int'])),
                                    ('is_rpf_interface', (YLeaf(YType.boolean, 'is-rpf-interface'), ['bool'])),
                                    ('is_outgoing_interface', (YLeaf(YType.boolean, 'is-outgoing-interface'), ['bool'])),
                                    ('is_snoop_interface', (YLeaf(YType.boolean, 'is-snoop-interface'), ['bool'])),
                                ])
                                self.interface_name = None
                                self.uptime = None
                                self.expiry = None
                                self.is_rpf_interface = None
                                self.is_outgoing_interface = None
                                self.is_snoop_interface = None

                                self.rpf_address = Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress()
                                self.rpf_address.parent = self
                                self._children_name_map["rpf_address"] = "rpf-address"
                                self._segment_path = lambda: "interface"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/rpf-redirect/redirect-route-databases/redirect-route-database/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface, ['interface_name', 'uptime', 'expiry', 'is_rpf_interface', 'is_outgoing_interface', 'is_snoop_interface'], name, value)


                            class RpfAddress(Entity):
                                """
                                RPF Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress, self).__init__()

                                    self.yang_name = "rpf-address"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "rpf-address"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/rpf-redirect/redirect-route-databases/redirect-route-database/interface/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class BundleInterfaces(Entity):
                    """
                    PIM ECMP RPF\-redirect bundle information
                    
                    .. attribute:: bundle_interface
                    
                    	PIM ECMP RPF\-redirect bundle interface information
                    	**type**\: list of  		 :py:class:`BundleInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces.BundleInterface>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces, self).__init__()

                        self.yang_name = "bundle-interfaces"
                        self.yang_parent_name = "rpf-redirect"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("bundle-interface", ("bundle_interface", Ipv6Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces.BundleInterface))])
                        self._leafs = OrderedDict()

                        self.bundle_interface = YList(self)
                        self._segment_path = lambda: "bundle-interfaces"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/rpf-redirect/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces, [], name, value)


                    class BundleInterface(Entity):
                        """
                        PIM ECMP RPF\-redirect bundle interface
                        information
                        
                        .. attribute:: bundle_name
                        
                        	Bundle name
                        	**type**\: str
                        
                        	**length:** 1..32
                        
                        .. attribute:: interface_name
                        
                        	Bundle interface name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: rpf_redirect_bundle_name
                        
                        	RPF redirect bundle name
                        	**type**\: str
                        
                        	**length:** 0..33
                        
                        .. attribute:: rpf_redirect_interface_name
                        
                        	RPF redirect interface name
                        	**type**\: str
                        
                        	**length:** 0..33
                        
                        .. attribute:: available_bandwidth
                        
                        	Bandwidth available in Kbps
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: allocated_bandwidth
                        
                        	Bandwidth allocated in Kbps
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: total_bandwidth
                        
                        	Total bandwidth used in Kbps
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: topology_bandwidth_used
                        
                        	Bandwidth used by topology in Kbps
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: snooping_bandwidth_used
                        
                        	Bandwidth used by snooped entries in Kbps
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: allocated_threshold_bandwidth
                        
                        	Configured threshold in Kbps
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: available_threshold_bandwidth
                        
                        	Available threshold in Kbps
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces.BundleInterface, self).__init__()

                            self.yang_name = "bundle-interface"
                            self.yang_parent_name = "bundle-interfaces"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('bundle_name', (YLeaf(YType.str, 'bundle-name'), ['str'])),
                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ('rpf_redirect_bundle_name', (YLeaf(YType.str, 'rpf-redirect-bundle-name'), ['str'])),
                                ('rpf_redirect_interface_name', (YLeaf(YType.str, 'rpf-redirect-interface-name'), ['str'])),
                                ('available_bandwidth', (YLeaf(YType.int32, 'available-bandwidth'), ['int'])),
                                ('allocated_bandwidth', (YLeaf(YType.int32, 'allocated-bandwidth'), ['int'])),
                                ('total_bandwidth', (YLeaf(YType.int32, 'total-bandwidth'), ['int'])),
                                ('topology_bandwidth_used', (YLeaf(YType.int32, 'topology-bandwidth-used'), ['int'])),
                                ('snooping_bandwidth_used', (YLeaf(YType.int32, 'snooping-bandwidth-used'), ['int'])),
                                ('allocated_threshold_bandwidth', (YLeaf(YType.int32, 'allocated-threshold-bandwidth'), ['int'])),
                                ('available_threshold_bandwidth', (YLeaf(YType.int32, 'available-threshold-bandwidth'), ['int'])),
                            ])
                            self.bundle_name = None
                            self.interface_name = None
                            self.rpf_redirect_bundle_name = None
                            self.rpf_redirect_interface_name = None
                            self.available_bandwidth = None
                            self.allocated_bandwidth = None
                            self.total_bandwidth = None
                            self.topology_bandwidth_used = None
                            self.snooping_bandwidth_used = None
                            self.allocated_threshold_bandwidth = None
                            self.available_threshold_bandwidth = None
                            self._segment_path = lambda: "bundle-interface"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/rpf-redirect/bundle-interfaces/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces.BundleInterface, ['bundle_name', 'interface_name', 'rpf_redirect_bundle_name', 'rpf_redirect_interface_name', 'available_bandwidth', 'allocated_bandwidth', 'total_bandwidth', 'topology_bandwidth_used', 'snooping_bandwidth_used', 'allocated_threshold_bandwidth', 'available_threshold_bandwidth'], name, value)


            class Tunnels(Entity):
                """
                Tunnels information that PIM has
                
                .. attribute:: tunnel
                
                	PIM tunnel information
                	**type**\: list of  		 :py:class:`Tunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.Tunnels, self).__init__()

                    self.yang_name = "tunnels"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("tunnel", ("tunnel", Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel))])
                    self._leafs = OrderedDict()

                    self.tunnel = YList(self)
                    self._segment_path = lambda: "tunnels"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.Tunnels, [], name, value)


                class Tunnel(Entity):
                    """
                    PIM tunnel information
                    
                    .. attribute:: tunnel_name  (key)
                    
                    	Tunnel name
                    	**type**\: str
                    
                    	**length:** 1..64
                    
                    .. attribute:: source_address
                    
                    	Source addr known to PIM
                    	**type**\:  :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddress>`
                    
                    .. attribute:: rp_address
                    
                    	RP addr known to PIM
                    	**type**\:  :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.RpAddress>`
                    
                    .. attribute:: source_address_netio
                    
                    	Source addr from netio
                    	**type**\:  :py:class:`SourceAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddressNetio>`
                    
                    .. attribute:: group_address_netio
                    
                    	Group addr from netio
                    	**type**\:  :py:class:`GroupAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.GroupAddressNetio>`
                    
                    .. attribute:: vrf_name
                    
                    	VRF Name
                    	**type**\: str
                    
                    	**length:** 0..33
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel, self).__init__()

                        self.yang_name = "tunnel"
                        self.yang_parent_name = "tunnels"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['tunnel_name']
                        self._child_classes = OrderedDict([("source-address", ("source_address", Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddress)), ("rp-address", ("rp_address", Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.RpAddress)), ("source-address-netio", ("source_address_netio", Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddressNetio)), ("group-address-netio", ("group_address_netio", Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.GroupAddressNetio))])
                        self._leafs = OrderedDict([
                            ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                        ])
                        self.tunnel_name = None
                        self.vrf_name = None

                        self.source_address = Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddress()
                        self.source_address.parent = self
                        self._children_name_map["source_address"] = "source-address"

                        self.rp_address = Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.RpAddress()
                        self.rp_address.parent = self
                        self._children_name_map["rp_address"] = "rp-address"

                        self.source_address_netio = Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddressNetio()
                        self.source_address_netio.parent = self
                        self._children_name_map["source_address_netio"] = "source-address-netio"

                        self.group_address_netio = Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.GroupAddressNetio()
                        self.group_address_netio.parent = self
                        self._children_name_map["group_address_netio"] = "group-address-netio"
                        self._segment_path = lambda: "tunnel" + "[tunnel-name='" + str(self.tunnel_name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/tunnels/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel, ['tunnel_name', 'vrf_name'], name, value)


                    class SourceAddress(Entity):
                        """
                        Source addr known to PIM
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddress, self).__init__()

                            self.yang_name = "source-address"
                            self.yang_parent_name = "tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "source-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class RpAddress(Entity):
                        """
                        RP addr known to PIM
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.RpAddress, self).__init__()

                            self.yang_name = "rp-address"
                            self.yang_parent_name = "tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "rp-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.RpAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class SourceAddressNetio(Entity):
                        """
                        Source addr from netio
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddressNetio, self).__init__()

                            self.yang_name = "source-address-netio"
                            self.yang_parent_name = "tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "source-address-netio"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddressNetio, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class GroupAddressNetio(Entity):
                        """
                        Group addr from netio
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.GroupAddressNetio, self).__init__()

                            self.yang_name = "group-address-netio"
                            self.yang_parent_name = "tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "group-address-netio"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.GroupAddressNetio, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class MulticastStaticRoutes(Entity):
                """
                PIM multicast static route table
                
                .. attribute:: multicast_static_route
                
                	PIM multicast static route information
                	**type**\: list of  		 :py:class:`MulticastStaticRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes, self).__init__()

                    self.yang_name = "multicast-static-routes"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("multicast-static-route", ("multicast_static_route", Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute))])
                    self._leafs = OrderedDict()

                    self.multicast_static_route = YList(self)
                    self._segment_path = lambda: "multicast-static-routes"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes, [], name, value)


                class MulticastStaticRoute(Entity):
                    """
                    PIM multicast static route information
                    
                    .. attribute:: address
                    
                    	Network address
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: prefix
                    
                    	Prefix
                    	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix>`
                    
                    .. attribute:: nexthop
                    
                    	Next Hop
                    	**type**\:  :py:class:`Nexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop>`
                    
                    .. attribute:: interface_name
                    
                    	Interface Handle
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: distance
                    
                    	Distance
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: prefix_length_xr
                    
                    	Prefix Length
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: is_via_lsm
                    
                    	LSM flag
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute, self).__init__()

                        self.yang_name = "multicast-static-route"
                        self.yang_parent_name = "multicast-static-routes"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("prefix", ("prefix", Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix)), ("nexthop", ("nexthop", Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop))])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str','str'])),
                            ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                            ('distance', (YLeaf(YType.uint32, 'distance'), ['int'])),
                            ('prefix_length_xr', (YLeaf(YType.uint8, 'prefix-length-xr'), ['int'])),
                            ('is_via_lsm', (YLeaf(YType.boolean, 'is-via-lsm'), ['bool'])),
                        ])
                        self.address = None
                        self.prefix_length = None
                        self.interface_name = None
                        self.distance = None
                        self.prefix_length_xr = None
                        self.is_via_lsm = None

                        self.prefix = Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix()
                        self.prefix.parent = self
                        self._children_name_map["prefix"] = "prefix"

                        self.nexthop = Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop()
                        self.nexthop.parent = self
                        self._children_name_map["nexthop"] = "nexthop"
                        self._segment_path = lambda: "multicast-static-route"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/multicast-static-routes/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute, ['address', 'prefix_length', 'interface_name', 'distance', 'prefix_length_xr', 'is_via_lsm'], name, value)


                    class Prefix(Entity):
                        """
                        Prefix
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix, self).__init__()

                            self.yang_name = "prefix"
                            self.yang_parent_name = "multicast-static-route"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "prefix"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/multicast-static-routes/multicast-static-route/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class Nexthop(Entity):
                        """
                        Next Hop
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop, self).__init__()

                            self.yang_name = "nexthop"
                            self.yang_parent_name = "multicast-static-route"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "nexthop"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/multicast-static-routes/multicast-static-route/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class Neighbors(Entity):
                """
                PIM neighbor table
                
                .. attribute:: neighbor
                
                	PIM neighbor information
                	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Neighbors.Neighbor>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.Neighbors, self).__init__()

                    self.yang_name = "neighbors"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("neighbor", ("neighbor", Ipv6Pim.Active.DefaultContext.Neighbors.Neighbor))])
                    self._leafs = OrderedDict()

                    self.neighbor = YList(self)
                    self._segment_path = lambda: "neighbors"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.DefaultContext.Neighbors, [], name, value)


                class Neighbor(Entity):
                    """
                    PIM neighbor information
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: neighbor_address
                    
                    	Neighbor address
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identifier
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: expires
                    
                    	Neighbor expiry in seconds
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: expiry_timer
                    
                    	Expiry timer in seconds
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: is_this_neighbor_us
                    
                    	Is this neighbor us ?
                    	**type**\: bool
                    
                    .. attribute:: is_this_neighbor_dr
                    
                    	Is this neighbor the DR
                    	**type**\: bool
                    
                    .. attribute:: is_dr_priority_capable
                    
                    	Is this neighbor DR priority capable ?
                    	**type**\: bool
                    
                    .. attribute:: dr_priority
                    
                    	DR priority
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Is this neighbor bidir capable ?
                    	**type**\: bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Is this neighbor proxy capable?
                    	**type**\: bool
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Is this neighbor capable of batching asserts?
                    	**type**\: bool
                    
                    .. attribute:: is_ecmp_redirect_capable
                    
                    	Is this neighbor capable of Ecmp Redirect?
                    	**type**\: bool
                    
                    .. attribute:: is_bfd_state
                    
                    	Is the neighbor bfd session created
                    	**type**\: bool
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_address_xr
                    
                    	List of Neighbor Addresses
                    	**type**\: list of  		 :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Neighbors.Neighbor.NeighborAddressXr>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.Neighbors.Neighbor, self).__init__()

                        self.yang_name = "neighbor"
                        self.yang_parent_name = "neighbors"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("neighbor-address-xr", ("neighbor_address_xr", Ipv6Pim.Active.DefaultContext.Neighbors.Neighbor.NeighborAddressXr))])
                        self._leafs = OrderedDict([
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                            ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                            ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                            ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                            ('expires', (YLeaf(YType.uint64, 'expires'), ['int'])),
                            ('expiry_timer', (YLeaf(YType.uint64, 'expiry-timer'), ['int'])),
                            ('is_this_neighbor_us', (YLeaf(YType.boolean, 'is-this-neighbor-us'), ['bool'])),
                            ('is_this_neighbor_dr', (YLeaf(YType.boolean, 'is-this-neighbor-dr'), ['bool'])),
                            ('is_dr_priority_capable', (YLeaf(YType.boolean, 'is-dr-priority-capable'), ['bool'])),
                            ('dr_priority', (YLeaf(YType.uint32, 'dr-priority'), ['int'])),
                            ('is_bidirectional_capable', (YLeaf(YType.boolean, 'is-bidirectional-capable'), ['bool'])),
                            ('is_proxy_capable', (YLeaf(YType.boolean, 'is-proxy-capable'), ['bool'])),
                            ('is_batch_asserts_capable', (YLeaf(YType.boolean, 'is-batch-asserts-capable'), ['bool'])),
                            ('is_ecmp_redirect_capable', (YLeaf(YType.boolean, 'is-ecmp-redirect-capable'), ['bool'])),
                            ('is_bfd_state', (YLeaf(YType.boolean, 'is-bfd-state'), ['bool'])),
                            ('propagation_delay', (YLeaf(YType.uint16, 'propagation-delay'), ['int'])),
                            ('override_interval', (YLeaf(YType.uint16, 'override-interval'), ['int'])),
                        ])
                        self.interface_name = None
                        self.neighbor_address = None
                        self.interface_name_xr = None
                        self.uptime = None
                        self.expires = None
                        self.expiry_timer = None
                        self.is_this_neighbor_us = None
                        self.is_this_neighbor_dr = None
                        self.is_dr_priority_capable = None
                        self.dr_priority = None
                        self.is_bidirectional_capable = None
                        self.is_proxy_capable = None
                        self.is_batch_asserts_capable = None
                        self.is_ecmp_redirect_capable = None
                        self.is_bfd_state = None
                        self.propagation_delay = None
                        self.override_interval = None

                        self.neighbor_address_xr = YList(self)
                        self._segment_path = lambda: "neighbor"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/neighbors/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.DefaultContext.Neighbors.Neighbor, ['interface_name', 'neighbor_address', 'interface_name_xr', 'uptime', 'expires', 'expiry_timer', 'is_this_neighbor_us', 'is_this_neighbor_dr', 'is_dr_priority_capable', 'dr_priority', 'is_bidirectional_capable', 'is_proxy_capable', 'is_batch_asserts_capable', 'is_ecmp_redirect_capable', 'is_bfd_state', 'propagation_delay', 'override_interval'], name, value)


                    class NeighborAddressXr(Entity):
                        """
                        List of Neighbor Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Neighbors.Neighbor.NeighborAddressXr, self).__init__()

                            self.yang_name = "neighbor-address-xr"
                            self.yang_parent_name = "neighbor"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "neighbor-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/neighbors/neighbor/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.DefaultContext.Neighbors.Neighbor.NeighborAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


        class Process(Entity):
            """
            Process
            
            .. attribute:: nsr
            
            	NSR Information
            	**type**\:  :py:class:`Nsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Process.Nsr>`
            
            .. attribute:: summary
            
            	PIM Global Summary
            	**type**\:  :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Process.Summary>`
            
            .. attribute:: nsf
            
            	PIM NSF information
            	**type**\:  :py:class:`Nsf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Process.Nsf>`
            
            .. attribute:: issu
            
            	ISSU Information
            	**type**\:  :py:class:`Issu <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Process.Issu>`
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(Ipv6Pim.Active.Process, self).__init__()

                self.yang_name = "process"
                self.yang_parent_name = "active"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("nsr", ("nsr", Ipv6Pim.Active.Process.Nsr)), ("summary", ("summary", Ipv6Pim.Active.Process.Summary)), ("nsf", ("nsf", Ipv6Pim.Active.Process.Nsf)), ("issu", ("issu", Ipv6Pim.Active.Process.Issu))])
                self._leafs = OrderedDict()

                self.nsr = Ipv6Pim.Active.Process.Nsr()
                self.nsr.parent = self
                self._children_name_map["nsr"] = "nsr"

                self.summary = Ipv6Pim.Active.Process.Summary()
                self.summary.parent = self
                self._children_name_map["summary"] = "summary"

                self.nsf = Ipv6Pim.Active.Process.Nsf()
                self.nsf.parent = self
                self._children_name_map["nsf"] = "nsf"

                self.issu = Ipv6Pim.Active.Process.Issu()
                self.issu.parent = self
                self._children_name_map["issu"] = "issu"
                self._segment_path = lambda: "process"
                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Ipv6Pim.Active.Process, [], name, value)


            class Nsr(Entity):
                """
                NSR Information
                
                .. attribute:: state
                
                	NSR state
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: partner_connected
                
                	Partner process connected
                	**type**\: bool
                
                .. attribute:: rmf_notification_done
                
                	RMF Notification done
                	**type**\: bool
                
                .. attribute:: rmf_timer_valid
                
                	Is RMF timer running ?
                	**type**\: bool
                
                .. attribute:: rmf_timer_expiry
                
                	Time for RMF timer to expire
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_connection_up
                
                	Time when connection went up
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_connection_dn
                
                	Time when connection went down
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_rmf_ready
                
                	Time when RMF Rdy notif was sent
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_rmf_not_ready
                
                	Time when RMF Not\-Rdy notif was sent
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: count_connection_up
                
                	No. of times connection went up
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_connection_dn
                
                	No. of times connection went down
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_rmf_ready
                
                	No. of times RMF Ready notif was sent
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_rmf_not_ready
                
                	No. of times RMF Not Ready notif was sent
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Active.Process.Nsr, self).__init__()

                    self.yang_name = "nsr"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('state', (YLeaf(YType.uint8, 'state'), ['int'])),
                        ('partner_connected', (YLeaf(YType.boolean, 'partner-connected'), ['bool'])),
                        ('rmf_notification_done', (YLeaf(YType.boolean, 'rmf-notification-done'), ['bool'])),
                        ('rmf_timer_valid', (YLeaf(YType.boolean, 'rmf-timer-valid'), ['bool'])),
                        ('rmf_timer_expiry', (YLeaf(YType.uint64, 'rmf-timer-expiry'), ['int'])),
                        ('last_connection_up', (YLeaf(YType.uint64, 'last-connection-up'), ['int'])),
                        ('last_connection_dn', (YLeaf(YType.uint64, 'last-connection-dn'), ['int'])),
                        ('last_rmf_ready', (YLeaf(YType.uint64, 'last-rmf-ready'), ['int'])),
                        ('last_rmf_not_ready', (YLeaf(YType.uint64, 'last-rmf-not-ready'), ['int'])),
                        ('count_connection_up', (YLeaf(YType.uint32, 'count-connection-up'), ['int'])),
                        ('count_connection_dn', (YLeaf(YType.uint32, 'count-connection-dn'), ['int'])),
                        ('count_rmf_ready', (YLeaf(YType.uint32, 'count-rmf-ready'), ['int'])),
                        ('count_rmf_not_ready', (YLeaf(YType.uint32, 'count-rmf-not-ready'), ['int'])),
                    ])
                    self.state = None
                    self.partner_connected = None
                    self.rmf_notification_done = None
                    self.rmf_timer_valid = None
                    self.rmf_timer_expiry = None
                    self.last_connection_up = None
                    self.last_connection_dn = None
                    self.last_rmf_ready = None
                    self.last_rmf_not_ready = None
                    self.count_connection_up = None
                    self.count_connection_dn = None
                    self.count_rmf_ready = None
                    self.count_rmf_not_ready = None
                    self._segment_path = lambda: "nsr"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/process/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.Process.Nsr, ['state', 'partner_connected', 'rmf_notification_done', 'rmf_timer_valid', 'rmf_timer_expiry', 'last_connection_up', 'last_connection_dn', 'last_rmf_ready', 'last_rmf_not_ready', 'count_connection_up', 'count_connection_dn', 'count_rmf_ready', 'count_rmf_not_ready'], name, value)


            class Summary(Entity):
                """
                PIM Global Summary
                
                .. attribute:: route_limit
                
                	Maximum routes
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_count
                
                	Current routes
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_low_water_mark
                
                	The number of routes below which the throttle on route creation will be lifted
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_route_limit_reached
                
                	Is route creation throttled
                	**type**\: bool
                
                .. attribute:: topology_interface_state_limit
                
                	Maximum Topology Interface State count
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_count
                
                	Current Topology Interface State count
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: rxi_low_water_mark
                
                	The rxi below which the throttle on interface creation will be lifted
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: rxi_limit_reached
                
                	Is interface creation throttled
                	**type**\: bool
                
                .. attribute:: register_limit
                
                	Maximum registers
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_count
                
                	Current registers
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_limit_reached
                
                	Is PIM SM register handling throttled
                	**type**\: bool
                
                .. attribute:: ranges_limit
                
                	Maximum group ranges from Autorp
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: ranges_count
                
                	Current group ranges from Autorp
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: ranges_threshold
                
                	OOR theshold of grange ranges from AutoRP
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_ranges_limit_reached
                
                	Is Auto\-RP group\-to\-RP mapping range creation throttled
                	**type**\: bool
                
                .. attribute:: bsr_ranges_limit
                
                	Maximum group ranges from BSR
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_ranges_count
                
                	Current group ranges from BSR
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_range_threshold
                
                	Threshold group range from BSR
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_bsr_ranges_threshold_reached
                
                	Is VRF\-specific BSR group\-to\-RP mapping range creation throttled
                	**type**\: bool
                
                .. attribute:: bsr_candidate_rp_set_limit
                
                	Maximum crp\-set from BSR
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_candidate_rp_set_count
                
                	Current crp\-set count from BSR
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_candidate_rp_set_threshold
                
                	Threshold crp\-set from BSR
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_maximum_enforcement_disabled
                
                	Is maximum enforcement disabled
                	**type**\: bool
                
                .. attribute:: is_node_low_memory
                
                	Is node in low memory condition
                	**type**\: bool
                
                .. attribute:: route_threshold
                
                	Threshold routes
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_auto_rp_ranges_limit
                
                	Global Auto\-RP maximum group ranges
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_global_auto_rp_ranges_limit_reached
                
                	Is global AutoRP group\-to\-RP mapping range creation throttled
                	**type**\: bool
                
                .. attribute:: global_bsr_ranges_limit
                
                	Global BSR maximum group ranges
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_count
                
                	Global BSR current group ranges
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_threshold
                
                	Global BSR Threshold group ranges
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_global_bsr_ranges_limit_reached
                
                	Is global BSR group\-to\-RP mapping range creation throttled
                	**type**\: bool
                
                .. attribute:: global_bsr_candidate_rp_set_limit
                
                	Global BSR maximum crp\-set
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_count
                
                	Global BSR current crp\-set count
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_threshold
                
                	Global BSR Threshold crp\-set
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_global_route_limit_reached
                
                	Is global route creation throttled
                	**type**\: bool
                
                .. attribute:: topology_interface_state_threshold
                
                	Topology Interface State threshold
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_global_rxi_limit_reached
                
                	Is global interface creation throttled
                	**type**\: bool
                
                .. attribute:: register_threshold
                
                	Threshold registers
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_register_limit
                
                	Maximum global registers
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_global_register_limit_reached
                
                	Is global PIM SM register handling throttled
                	**type**\: bool
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Active.Process.Summary, self).__init__()

                    self.yang_name = "summary"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('route_limit', (YLeaf(YType.uint32, 'route-limit'), ['int'])),
                        ('route_count', (YLeaf(YType.uint32, 'route-count'), ['int'])),
                        ('route_low_water_mark', (YLeaf(YType.uint32, 'route-low-water-mark'), ['int'])),
                        ('is_route_limit_reached', (YLeaf(YType.boolean, 'is-route-limit-reached'), ['bool'])),
                        ('topology_interface_state_limit', (YLeaf(YType.uint32, 'topology-interface-state-limit'), ['int'])),
                        ('topology_interface_state_count', (YLeaf(YType.uint32, 'topology-interface-state-count'), ['int'])),
                        ('rxi_low_water_mark', (YLeaf(YType.uint32, 'rxi-low-water-mark'), ['int'])),
                        ('rxi_limit_reached', (YLeaf(YType.boolean, 'rxi-limit-reached'), ['bool'])),
                        ('register_limit', (YLeaf(YType.uint32, 'register-limit'), ['int'])),
                        ('register_count', (YLeaf(YType.uint32, 'register-count'), ['int'])),
                        ('register_limit_reached', (YLeaf(YType.boolean, 'register-limit-reached'), ['bool'])),
                        ('ranges_limit', (YLeaf(YType.uint32, 'ranges-limit'), ['int'])),
                        ('ranges_count', (YLeaf(YType.uint32, 'ranges-count'), ['int'])),
                        ('ranges_threshold', (YLeaf(YType.uint32, 'ranges-threshold'), ['int'])),
                        ('is_ranges_limit_reached', (YLeaf(YType.boolean, 'is-ranges-limit-reached'), ['bool'])),
                        ('bsr_ranges_limit', (YLeaf(YType.uint32, 'bsr-ranges-limit'), ['int'])),
                        ('bsr_ranges_count', (YLeaf(YType.uint32, 'bsr-ranges-count'), ['int'])),
                        ('bsr_range_threshold', (YLeaf(YType.uint32, 'bsr-range-threshold'), ['int'])),
                        ('is_bsr_ranges_threshold_reached', (YLeaf(YType.boolean, 'is-bsr-ranges-threshold-reached'), ['bool'])),
                        ('bsr_candidate_rp_set_limit', (YLeaf(YType.uint32, 'bsr-candidate-rp-set-limit'), ['int'])),
                        ('bsr_candidate_rp_set_count', (YLeaf(YType.uint32, 'bsr-candidate-rp-set-count'), ['int'])),
                        ('bsr_candidate_rp_set_threshold', (YLeaf(YType.uint32, 'bsr-candidate-rp-set-threshold'), ['int'])),
                        ('is_maximum_enforcement_disabled', (YLeaf(YType.boolean, 'is-maximum-enforcement-disabled'), ['bool'])),
                        ('is_node_low_memory', (YLeaf(YType.boolean, 'is-node-low-memory'), ['bool'])),
                        ('route_threshold', (YLeaf(YType.uint32, 'route-threshold'), ['int'])),
                        ('global_auto_rp_ranges_limit', (YLeaf(YType.uint32, 'global-auto-rp-ranges-limit'), ['int'])),
                        ('is_global_auto_rp_ranges_limit_reached', (YLeaf(YType.boolean, 'is-global-auto-rp-ranges-limit-reached'), ['bool'])),
                        ('global_bsr_ranges_limit', (YLeaf(YType.uint32, 'global-bsr-ranges-limit'), ['int'])),
                        ('global_bsr_ranges_count', (YLeaf(YType.uint32, 'global-bsr-ranges-count'), ['int'])),
                        ('global_bsr_ranges_threshold', (YLeaf(YType.uint32, 'global-bsr-ranges-threshold'), ['int'])),
                        ('is_global_bsr_ranges_limit_reached', (YLeaf(YType.boolean, 'is-global-bsr-ranges-limit-reached'), ['bool'])),
                        ('global_bsr_candidate_rp_set_limit', (YLeaf(YType.uint32, 'global-bsr-candidate-rp-set-limit'), ['int'])),
                        ('global_bsr_candidate_rp_set_count', (YLeaf(YType.uint32, 'global-bsr-candidate-rp-set-count'), ['int'])),
                        ('global_bsr_candidate_rp_set_threshold', (YLeaf(YType.uint32, 'global-bsr-candidate-rp-set-threshold'), ['int'])),
                        ('is_global_route_limit_reached', (YLeaf(YType.boolean, 'is-global-route-limit-reached'), ['bool'])),
                        ('topology_interface_state_threshold', (YLeaf(YType.uint32, 'topology-interface-state-threshold'), ['int'])),
                        ('is_global_rxi_limit_reached', (YLeaf(YType.boolean, 'is-global-rxi-limit-reached'), ['bool'])),
                        ('register_threshold', (YLeaf(YType.uint32, 'register-threshold'), ['int'])),
                        ('global_register_limit', (YLeaf(YType.uint32, 'global-register-limit'), ['int'])),
                        ('is_global_register_limit_reached', (YLeaf(YType.boolean, 'is-global-register-limit-reached'), ['bool'])),
                    ])
                    self.route_limit = None
                    self.route_count = None
                    self.route_low_water_mark = None
                    self.is_route_limit_reached = None
                    self.topology_interface_state_limit = None
                    self.topology_interface_state_count = None
                    self.rxi_low_water_mark = None
                    self.rxi_limit_reached = None
                    self.register_limit = None
                    self.register_count = None
                    self.register_limit_reached = None
                    self.ranges_limit = None
                    self.ranges_count = None
                    self.ranges_threshold = None
                    self.is_ranges_limit_reached = None
                    self.bsr_ranges_limit = None
                    self.bsr_ranges_count = None
                    self.bsr_range_threshold = None
                    self.is_bsr_ranges_threshold_reached = None
                    self.bsr_candidate_rp_set_limit = None
                    self.bsr_candidate_rp_set_count = None
                    self.bsr_candidate_rp_set_threshold = None
                    self.is_maximum_enforcement_disabled = None
                    self.is_node_low_memory = None
                    self.route_threshold = None
                    self.global_auto_rp_ranges_limit = None
                    self.is_global_auto_rp_ranges_limit_reached = None
                    self.global_bsr_ranges_limit = None
                    self.global_bsr_ranges_count = None
                    self.global_bsr_ranges_threshold = None
                    self.is_global_bsr_ranges_limit_reached = None
                    self.global_bsr_candidate_rp_set_limit = None
                    self.global_bsr_candidate_rp_set_count = None
                    self.global_bsr_candidate_rp_set_threshold = None
                    self.is_global_route_limit_reached = None
                    self.topology_interface_state_threshold = None
                    self.is_global_rxi_limit_reached = None
                    self.register_threshold = None
                    self.global_register_limit = None
                    self.is_global_register_limit_reached = None
                    self._segment_path = lambda: "summary"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/process/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.Process.Summary, ['route_limit', 'route_count', 'route_low_water_mark', 'is_route_limit_reached', 'topology_interface_state_limit', 'topology_interface_state_count', 'rxi_low_water_mark', 'rxi_limit_reached', 'register_limit', 'register_count', 'register_limit_reached', 'ranges_limit', 'ranges_count', 'ranges_threshold', 'is_ranges_limit_reached', 'bsr_ranges_limit', 'bsr_ranges_count', 'bsr_range_threshold', 'is_bsr_ranges_threshold_reached', 'bsr_candidate_rp_set_limit', 'bsr_candidate_rp_set_count', 'bsr_candidate_rp_set_threshold', 'is_maximum_enforcement_disabled', 'is_node_low_memory', 'route_threshold', 'global_auto_rp_ranges_limit', 'is_global_auto_rp_ranges_limit_reached', 'global_bsr_ranges_limit', 'global_bsr_ranges_count', 'global_bsr_ranges_threshold', 'is_global_bsr_ranges_limit_reached', 'global_bsr_candidate_rp_set_limit', 'global_bsr_candidate_rp_set_count', 'global_bsr_candidate_rp_set_threshold', 'is_global_route_limit_reached', 'topology_interface_state_threshold', 'is_global_rxi_limit_reached', 'register_threshold', 'global_register_limit', 'is_global_register_limit_reached'], name, value)


            class Nsf(Entity):
                """
                PIM NSF information
                
                .. attribute:: configured_state
                
                	Is Multicast NSF Configured
                	**type**\: bool
                
                .. attribute:: nsf_state
                
                	Are we currently in NSF
                	**type**\: bool
                
                .. attribute:: nsf_timeout
                
                	Multicast NSF timeout in seconds
                	**type**\: int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: nsf_time_left
                
                	Multicast NSF time left in seconds
                	**type**\: int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: waiting_timer
                
                	Waiting for NSF timer expiry
                	**type**\: bool
                
                .. attribute:: waiting_membership
                
                	Waiting for IGMP/MLD
                	**type**\: bool
                
                .. attribute:: respawn_count
                
                	Respawn Count
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: last_nsf_on
                
                	Last NSF time ON
                	**type**\: int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_nsf_off
                
                	Last NSF time off
                	**type**\: int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_nsf_on_sec
                
                	Last NSF time ON in Seconds
                	**type**\: int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: last_nsf_off_sec
                
                	Last NSF time OFF in Seconds
                	**type**\: int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: last_icd_notif_recv
                
                	Last ICD Notif Recv
                	**type**\: int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_icd_notif_recv_sec
                
                	Last ICD Notif Recv in Seconds
                	**type**\: int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Active.Process.Nsf, self).__init__()

                    self.yang_name = "nsf"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('configured_state', (YLeaf(YType.boolean, 'configured-state'), ['bool'])),
                        ('nsf_state', (YLeaf(YType.boolean, 'nsf-state'), ['bool'])),
                        ('nsf_timeout', (YLeaf(YType.uint32, 'nsf-timeout'), ['int'])),
                        ('nsf_time_left', (YLeaf(YType.uint32, 'nsf-time-left'), ['int'])),
                        ('waiting_timer', (YLeaf(YType.boolean, 'waiting-timer'), ['bool'])),
                        ('waiting_membership', (YLeaf(YType.boolean, 'waiting-membership'), ['bool'])),
                        ('respawn_count', (YLeaf(YType.uint32, 'respawn-count'), ['int'])),
                        ('last_nsf_on', (YLeaf(YType.int64, 'last-nsf-on'), ['int'])),
                        ('last_nsf_off', (YLeaf(YType.int64, 'last-nsf-off'), ['int'])),
                        ('last_nsf_on_sec', (YLeaf(YType.int32, 'last-nsf-on-sec'), ['int'])),
                        ('last_nsf_off_sec', (YLeaf(YType.int32, 'last-nsf-off-sec'), ['int'])),
                        ('last_icd_notif_recv', (YLeaf(YType.int64, 'last-icd-notif-recv'), ['int'])),
                        ('last_icd_notif_recv_sec', (YLeaf(YType.int32, 'last-icd-notif-recv-sec'), ['int'])),
                    ])
                    self.configured_state = None
                    self.nsf_state = None
                    self.nsf_timeout = None
                    self.nsf_time_left = None
                    self.waiting_timer = None
                    self.waiting_membership = None
                    self.respawn_count = None
                    self.last_nsf_on = None
                    self.last_nsf_off = None
                    self.last_nsf_on_sec = None
                    self.last_nsf_off_sec = None
                    self.last_icd_notif_recv = None
                    self.last_icd_notif_recv_sec = None
                    self._segment_path = lambda: "nsf"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/process/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.Process.Nsf, ['configured_state', 'nsf_state', 'nsf_timeout', 'nsf_time_left', 'waiting_timer', 'waiting_membership', 'respawn_count', 'last_nsf_on', 'last_nsf_off', 'last_nsf_on_sec', 'last_nsf_off_sec', 'last_icd_notif_recv', 'last_icd_notif_recv_sec'], name, value)


            class Issu(Entity):
                """
                ISSU Information
                
                .. attribute:: informationvalid
                
                	Is Information valid ?
                	**type**\: bool
                
                .. attribute:: role_ha
                
                	HA role
                	**type**\: int
                
                	**range:** \-2147483648..2147483647
                
                .. attribute:: role_issu
                
                	ISSU role
                	**type**\: int
                
                	**range:** \-2147483648..2147483647
                
                .. attribute:: phase_issu
                
                	ISSU Phase
                	**type**\: int
                
                	**range:** \-2147483648..2147483647
                
                .. attribute:: last_ha_role_notification_received
                
                	Time when last HA role nfn was received
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_issu_role_notification_received
                
                	Time when last ISSU role nfn was received
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_issu_phase_notification_received
                
                	Time when last ISSU Phase nfn was received
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: is_eoc_received
                
                	Was EOC received ?
                	**type**\: bool
                
                .. attribute:: eoc_received_timestamp
                
                	Time when EOC was received
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: is_ihms_done_received
                
                	Was IHMS done received ?
                	**type**\: bool
                
                .. attribute:: ihms_received_timestamp
                
                	Time when IHMS done was received
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: is_rib_sync_received
                
                	Was RIB Sync received ?
                	**type**\: bool
                
                .. attribute:: rib_sync_received_timestamp
                
                	Time when RIB Sync was received
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: is_nbr_sync_received
                
                	Was NBR Sync achieved ?
                	**type**\: bool
                
                .. attribute:: nbr_sync_received_timestamp
                
                	Time when NBR Sync was achieved
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: is_checkpoint_idt_done
                
                	Was Checkpoint IDT done ?
                	**type**\: bool
                
                .. attribute:: checkpoint_idt_timestamp
                
                	Time when Checkpoint IDT done
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Active.Process.Issu, self).__init__()

                    self.yang_name = "issu"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('informationvalid', (YLeaf(YType.boolean, 'informationvalid'), ['bool'])),
                        ('role_ha', (YLeaf(YType.int32, 'role-ha'), ['int'])),
                        ('role_issu', (YLeaf(YType.int32, 'role-issu'), ['int'])),
                        ('phase_issu', (YLeaf(YType.int32, 'phase-issu'), ['int'])),
                        ('last_ha_role_notification_received', (YLeaf(YType.uint64, 'last-ha-role-notification-received'), ['int'])),
                        ('last_issu_role_notification_received', (YLeaf(YType.uint64, 'last-issu-role-notification-received'), ['int'])),
                        ('last_issu_phase_notification_received', (YLeaf(YType.uint64, 'last-issu-phase-notification-received'), ['int'])),
                        ('is_eoc_received', (YLeaf(YType.boolean, 'is-eoc-received'), ['bool'])),
                        ('eoc_received_timestamp', (YLeaf(YType.uint64, 'eoc-received-timestamp'), ['int'])),
                        ('is_ihms_done_received', (YLeaf(YType.boolean, 'is-ihms-done-received'), ['bool'])),
                        ('ihms_received_timestamp', (YLeaf(YType.uint64, 'ihms-received-timestamp'), ['int'])),
                        ('is_rib_sync_received', (YLeaf(YType.boolean, 'is-rib-sync-received'), ['bool'])),
                        ('rib_sync_received_timestamp', (YLeaf(YType.uint64, 'rib-sync-received-timestamp'), ['int'])),
                        ('is_nbr_sync_received', (YLeaf(YType.boolean, 'is-nbr-sync-received'), ['bool'])),
                        ('nbr_sync_received_timestamp', (YLeaf(YType.uint64, 'nbr-sync-received-timestamp'), ['int'])),
                        ('is_checkpoint_idt_done', (YLeaf(YType.boolean, 'is-checkpoint-idt-done'), ['bool'])),
                        ('checkpoint_idt_timestamp', (YLeaf(YType.uint64, 'checkpoint-idt-timestamp'), ['int'])),
                    ])
                    self.informationvalid = None
                    self.role_ha = None
                    self.role_issu = None
                    self.phase_issu = None
                    self.last_ha_role_notification_received = None
                    self.last_issu_role_notification_received = None
                    self.last_issu_phase_notification_received = None
                    self.is_eoc_received = None
                    self.eoc_received_timestamp = None
                    self.is_ihms_done_received = None
                    self.ihms_received_timestamp = None
                    self.is_rib_sync_received = None
                    self.rib_sync_received_timestamp = None
                    self.is_nbr_sync_received = None
                    self.nbr_sync_received_timestamp = None
                    self.is_checkpoint_idt_done = None
                    self.checkpoint_idt_timestamp = None
                    self._segment_path = lambda: "issu"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/process/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.Process.Issu, ['informationvalid', 'role_ha', 'role_issu', 'phase_issu', 'last_ha_role_notification_received', 'last_issu_role_notification_received', 'last_issu_phase_notification_received', 'is_eoc_received', 'eoc_received_timestamp', 'is_ihms_done_received', 'ihms_received_timestamp', 'is_rib_sync_received', 'rib_sync_received_timestamp', 'is_nbr_sync_received', 'nbr_sync_received_timestamp', 'is_checkpoint_idt_done', 'checkpoint_idt_timestamp'], name, value)


        class Vrfs(Entity):
            """
            VRF Table
            
            .. attribute:: vrf
            
            	VRF name
            	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf>`
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(Ipv6Pim.Active.Vrfs, self).__init__()

                self.yang_name = "vrfs"
                self.yang_parent_name = "active"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("vrf", ("vrf", Ipv6Pim.Active.Vrfs.Vrf))])
                self._leafs = OrderedDict()

                self.vrf = YList(self)
                self._segment_path = lambda: "vrfs"
                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Ipv6Pim.Active.Vrfs, [], name, value)


            class Vrf(Entity):
                """
                VRF name
                
                .. attribute:: vrf_name  (key)
                
                	VRF name 
                	**type**\: str
                
                	**length:** 1..32
                
                .. attribute:: ifrs_interfaces
                
                	PIM interfaces in forward reference store table
                	**type**\:  :py:class:`IfrsInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces>`
                
                .. attribute:: safs
                
                	SAFI table and type
                	**type**\:  :py:class:`Safs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Safs>`
                
                .. attribute:: interface_statistics
                
                	PIM interface statistics
                	**type**\:  :py:class:`InterfaceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.InterfaceStatistics>`
                
                .. attribute:: topology_route_count
                
                	Topology route count information from PIM topology table
                	**type**\:  :py:class:`TopologyRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.TopologyRouteCount>`
                
                .. attribute:: jp_statistics
                
                	PIM join prune statistics table
                	**type**\:  :py:class:`JpStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.JpStatistics>`
                
                .. attribute:: mib_databases
                
                	PIM group database for mroute mibs table
                	**type**\:  :py:class:`MibDatabases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.MibDatabases>`
                
                .. attribute:: neighbor_old_formats
                
                	PIM neighbor table old format
                	**type**\:  :py:class:`NeighborOldFormats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.NeighborOldFormats>`
                
                .. attribute:: ifrs_summary
                
                	PIM interfaces in forward reference store summary
                	**type**\:  :py:class:`IfrsSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.IfrsSummary>`
                
                .. attribute:: ranges
                
                	PIM range list information
                	**type**\:  :py:class:`Ranges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Ranges>`
                
                .. attribute:: interface_old_formats
                
                	PIM interfaces in old format
                	**type**\:  :py:class:`InterfaceOldFormats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats>`
                
                .. attribute:: bsr
                
                	PIM BSR information
                	**type**\:  :py:class:`Bsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Bsr>`
                
                .. attribute:: route_policy
                
                	PIM route policy
                	**type**\:  :py:class:`RoutePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy>`
                
                .. attribute:: rpf_summary
                
                	PIM RPF registration summary
                	**type**\:  :py:class:`RpfSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.RpfSummary>`
                
                .. attribute:: interfaces
                
                	PIM interfaces
                	**type**\:  :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Interfaces>`
                
                .. attribute:: net_io_tunnels
                
                	Tunnel information that NETIO has 
                	**type**\:  :py:class:`NetIoTunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels>`
                
                .. attribute:: bidir_df_states
                
                	Bidirectional PIM DF election state table
                	**type**\:  :py:class:`BidirDfStates <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.BidirDfStates>`
                
                .. attribute:: topologies
                
                	PIM topology table
                	**type**\:  :py:class:`Topologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Topologies>`
                
                .. attribute:: bgp_afs
                
                	PIM BGP SAFI table
                	**type**\:  :py:class:`BgpAfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.BgpAfs>`
                
                .. attribute:: auto_rp
                
                	PIM Auto\-RP information
                	**type**\:  :py:class:`AutoRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.AutoRp>`
                
                .. attribute:: topology_interface_flag_route_counts
                
                	Route count for topology with interface flag set
                	**type**\:  :py:class:`TopologyInterfaceFlagRouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts>`
                
                .. attribute:: group_map_sources
                
                	PIM group\-mapping with source information
                	**type**\:  :py:class:`GroupMapSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources>`
                
                .. attribute:: traffic_counters
                
                	PIM message traffic counters
                	**type**\:  :py:class:`TrafficCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters>`
                
                .. attribute:: group_map_rpfs
                
                	PIM group mapping information
                	**type**\:  :py:class:`GroupMapRpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs>`
                
                .. attribute:: summary
                
                	PIM summary
                	**type**\:  :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Summary>`
                
                .. attribute:: gre
                
                	GRE information
                	**type**\:  :py:class:`Gre <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Gre>`
                
                .. attribute:: bidir_df_winners
                
                	Bidirectional PIM DF election winner table
                	**type**\:  :py:class:`BidirDfWinners <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners>`
                
                .. attribute:: table_contexts
                
                	PIM table context list
                	**type**\:  :py:class:`TableContexts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.TableContexts>`
                
                .. attribute:: neighbor_summaries
                
                	PIM neighbor summary table
                	**type**\:  :py:class:`NeighborSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.NeighborSummaries>`
                
                .. attribute:: context
                
                	PIM context information
                	**type**\:  :py:class:`Context <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Context>`
                
                .. attribute:: topology_entry_flag_route_counts
                
                	Route count for topology with entry flag set
                	**type**\:  :py:class:`TopologyEntryFlagRouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts>`
                
                .. attribute:: rpf_redirect
                
                	PIM ECMP RPF\-redirect bundle
                	**type**\:  :py:class:`RpfRedirect <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect>`
                
                .. attribute:: tunnels
                
                	Tunnels information that PIM has
                	**type**\:  :py:class:`Tunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Tunnels>`
                
                .. attribute:: multicast_static_routes
                
                	PIM multicast static route table
                	**type**\:  :py:class:`MulticastStaticRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes>`
                
                .. attribute:: neighbors
                
                	PIM neighbor table
                	**type**\:  :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Neighbors>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Pim.Active.Vrfs.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "vrfs"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['vrf_name']
                    self._child_classes = OrderedDict([("ifrs-interfaces", ("ifrs_interfaces", Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces)), ("safs", ("safs", Ipv6Pim.Active.Vrfs.Vrf.Safs)), ("interface-statistics", ("interface_statistics", Ipv6Pim.Active.Vrfs.Vrf.InterfaceStatistics)), ("topology-route-count", ("topology_route_count", Ipv6Pim.Active.Vrfs.Vrf.TopologyRouteCount)), ("jp-statistics", ("jp_statistics", Ipv6Pim.Active.Vrfs.Vrf.JpStatistics)), ("mib-databases", ("mib_databases", Ipv6Pim.Active.Vrfs.Vrf.MibDatabases)), ("neighbor-old-formats", ("neighbor_old_formats", Ipv6Pim.Active.Vrfs.Vrf.NeighborOldFormats)), ("ifrs-summary", ("ifrs_summary", Ipv6Pim.Active.Vrfs.Vrf.IfrsSummary)), ("ranges", ("ranges", Ipv6Pim.Active.Vrfs.Vrf.Ranges)), ("interface-old-formats", ("interface_old_formats", Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats)), ("bsr", ("bsr", Ipv6Pim.Active.Vrfs.Vrf.Bsr)), ("route-policy", ("route_policy", Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy)), ("rpf-summary", ("rpf_summary", Ipv6Pim.Active.Vrfs.Vrf.RpfSummary)), ("interfaces", ("interfaces", Ipv6Pim.Active.Vrfs.Vrf.Interfaces)), ("net-io-tunnels", ("net_io_tunnels", Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels)), ("bidir-df-states", ("bidir_df_states", Ipv6Pim.Active.Vrfs.Vrf.BidirDfStates)), ("topologies", ("topologies", Ipv6Pim.Active.Vrfs.Vrf.Topologies)), ("bgp-afs", ("bgp_afs", Ipv6Pim.Active.Vrfs.Vrf.BgpAfs)), ("auto-rp", ("auto_rp", Ipv6Pim.Active.Vrfs.Vrf.AutoRp)), ("topology-interface-flag-route-counts", ("topology_interface_flag_route_counts", Ipv6Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts)), ("group-map-sources", ("group_map_sources", Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources)), ("traffic-counters", ("traffic_counters", Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters)), ("group-map-rpfs", ("group_map_rpfs", Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs)), ("summary", ("summary", Ipv6Pim.Active.Vrfs.Vrf.Summary)), ("gre", ("gre", Ipv6Pim.Active.Vrfs.Vrf.Gre)), ("bidir-df-winners", ("bidir_df_winners", Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners)), ("table-contexts", ("table_contexts", Ipv6Pim.Active.Vrfs.Vrf.TableContexts)), ("neighbor-summaries", ("neighbor_summaries", Ipv6Pim.Active.Vrfs.Vrf.NeighborSummaries)), ("context", ("context", Ipv6Pim.Active.Vrfs.Vrf.Context)), ("topology-entry-flag-route-counts", ("topology_entry_flag_route_counts", Ipv6Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts)), ("rpf-redirect", ("rpf_redirect", Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect)), ("tunnels", ("tunnels", Ipv6Pim.Active.Vrfs.Vrf.Tunnels)), ("multicast-static-routes", ("multicast_static_routes", Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes)), ("neighbors", ("neighbors", Ipv6Pim.Active.Vrfs.Vrf.Neighbors))])
                    self._leafs = OrderedDict([
                        ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                    ])
                    self.vrf_name = None

                    self.ifrs_interfaces = Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces()
                    self.ifrs_interfaces.parent = self
                    self._children_name_map["ifrs_interfaces"] = "ifrs-interfaces"

                    self.safs = Ipv6Pim.Active.Vrfs.Vrf.Safs()
                    self.safs.parent = self
                    self._children_name_map["safs"] = "safs"

                    self.interface_statistics = Ipv6Pim.Active.Vrfs.Vrf.InterfaceStatistics()
                    self.interface_statistics.parent = self
                    self._children_name_map["interface_statistics"] = "interface-statistics"

                    self.topology_route_count = Ipv6Pim.Active.Vrfs.Vrf.TopologyRouteCount()
                    self.topology_route_count.parent = self
                    self._children_name_map["topology_route_count"] = "topology-route-count"

                    self.jp_statistics = Ipv6Pim.Active.Vrfs.Vrf.JpStatistics()
                    self.jp_statistics.parent = self
                    self._children_name_map["jp_statistics"] = "jp-statistics"

                    self.mib_databases = Ipv6Pim.Active.Vrfs.Vrf.MibDatabases()
                    self.mib_databases.parent = self
                    self._children_name_map["mib_databases"] = "mib-databases"

                    self.neighbor_old_formats = Ipv6Pim.Active.Vrfs.Vrf.NeighborOldFormats()
                    self.neighbor_old_formats.parent = self
                    self._children_name_map["neighbor_old_formats"] = "neighbor-old-formats"

                    self.ifrs_summary = Ipv6Pim.Active.Vrfs.Vrf.IfrsSummary()
                    self.ifrs_summary.parent = self
                    self._children_name_map["ifrs_summary"] = "ifrs-summary"

                    self.ranges = Ipv6Pim.Active.Vrfs.Vrf.Ranges()
                    self.ranges.parent = self
                    self._children_name_map["ranges"] = "ranges"

                    self.interface_old_formats = Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats()
                    self.interface_old_formats.parent = self
                    self._children_name_map["interface_old_formats"] = "interface-old-formats"

                    self.bsr = Ipv6Pim.Active.Vrfs.Vrf.Bsr()
                    self.bsr.parent = self
                    self._children_name_map["bsr"] = "bsr"

                    self.route_policy = Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy()
                    self.route_policy.parent = self
                    self._children_name_map["route_policy"] = "route-policy"

                    self.rpf_summary = Ipv6Pim.Active.Vrfs.Vrf.RpfSummary()
                    self.rpf_summary.parent = self
                    self._children_name_map["rpf_summary"] = "rpf-summary"

                    self.interfaces = Ipv6Pim.Active.Vrfs.Vrf.Interfaces()
                    self.interfaces.parent = self
                    self._children_name_map["interfaces"] = "interfaces"

                    self.net_io_tunnels = Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels()
                    self.net_io_tunnels.parent = self
                    self._children_name_map["net_io_tunnels"] = "net-io-tunnels"

                    self.bidir_df_states = Ipv6Pim.Active.Vrfs.Vrf.BidirDfStates()
                    self.bidir_df_states.parent = self
                    self._children_name_map["bidir_df_states"] = "bidir-df-states"

                    self.topologies = Ipv6Pim.Active.Vrfs.Vrf.Topologies()
                    self.topologies.parent = self
                    self._children_name_map["topologies"] = "topologies"

                    self.bgp_afs = Ipv6Pim.Active.Vrfs.Vrf.BgpAfs()
                    self.bgp_afs.parent = self
                    self._children_name_map["bgp_afs"] = "bgp-afs"

                    self.auto_rp = Ipv6Pim.Active.Vrfs.Vrf.AutoRp()
                    self.auto_rp.parent = self
                    self._children_name_map["auto_rp"] = "auto-rp"

                    self.topology_interface_flag_route_counts = Ipv6Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts()
                    self.topology_interface_flag_route_counts.parent = self
                    self._children_name_map["topology_interface_flag_route_counts"] = "topology-interface-flag-route-counts"

                    self.group_map_sources = Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources()
                    self.group_map_sources.parent = self
                    self._children_name_map["group_map_sources"] = "group-map-sources"

                    self.traffic_counters = Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters()
                    self.traffic_counters.parent = self
                    self._children_name_map["traffic_counters"] = "traffic-counters"

                    self.group_map_rpfs = Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs()
                    self.group_map_rpfs.parent = self
                    self._children_name_map["group_map_rpfs"] = "group-map-rpfs"

                    self.summary = Ipv6Pim.Active.Vrfs.Vrf.Summary()
                    self.summary.parent = self
                    self._children_name_map["summary"] = "summary"

                    self.gre = Ipv6Pim.Active.Vrfs.Vrf.Gre()
                    self.gre.parent = self
                    self._children_name_map["gre"] = "gre"

                    self.bidir_df_winners = Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners()
                    self.bidir_df_winners.parent = self
                    self._children_name_map["bidir_df_winners"] = "bidir-df-winners"

                    self.table_contexts = Ipv6Pim.Active.Vrfs.Vrf.TableContexts()
                    self.table_contexts.parent = self
                    self._children_name_map["table_contexts"] = "table-contexts"

                    self.neighbor_summaries = Ipv6Pim.Active.Vrfs.Vrf.NeighborSummaries()
                    self.neighbor_summaries.parent = self
                    self._children_name_map["neighbor_summaries"] = "neighbor-summaries"

                    self.context = Ipv6Pim.Active.Vrfs.Vrf.Context()
                    self.context.parent = self
                    self._children_name_map["context"] = "context"

                    self.topology_entry_flag_route_counts = Ipv6Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts()
                    self.topology_entry_flag_route_counts.parent = self
                    self._children_name_map["topology_entry_flag_route_counts"] = "topology-entry-flag-route-counts"

                    self.rpf_redirect = Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect()
                    self.rpf_redirect.parent = self
                    self._children_name_map["rpf_redirect"] = "rpf-redirect"

                    self.tunnels = Ipv6Pim.Active.Vrfs.Vrf.Tunnels()
                    self.tunnels.parent = self
                    self._children_name_map["tunnels"] = "tunnels"

                    self.multicast_static_routes = Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes()
                    self.multicast_static_routes.parent = self
                    self._children_name_map["multicast_static_routes"] = "multicast-static-routes"

                    self.neighbors = Ipv6Pim.Active.Vrfs.Vrf.Neighbors()
                    self.neighbors.parent = self
                    self._children_name_map["neighbors"] = "neighbors"
                    self._segment_path = lambda: "vrf" + "[vrf-name='" + str(self.vrf_name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/vrfs/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf, ['vrf_name'], name, value)


                class IfrsInterfaces(Entity):
                    """
                    PIM interfaces in forward reference store table
                    
                    .. attribute:: ifrs_interface
                    
                    	PIM IFRS interface information
                    	**type**\: list of  		 :py:class:`IfrsInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces, self).__init__()

                        self.yang_name = "ifrs-interfaces"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ifrs-interface", ("ifrs_interface", Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface))])
                        self._leafs = OrderedDict()

                        self.ifrs_interface = YList(self)
                        self._segment_path = lambda: "ifrs-interfaces"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces, [], name, value)


                    class IfrsInterface(Entity):
                        """
                        PIM IFRS interface information
                        
                        .. attribute:: interface_name  (key)
                        
                        	Interface name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: dr_address
                        
                        	PIM Designated Router
                        	**type**\:  :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress>`
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identfier
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: interface_address_mask
                        
                        	Interface IP Address Mask
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: is_enabled
                        
                        	Is PIM enabled on this IF ?
                        	**type**\: bool
                        
                        .. attribute:: neighbor_count
                        
                        	No. of neighbors on this IF
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: external_neighbor_count
                        
                        	No. of external neighbors on this IF
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: hello_interval
                        
                        	Hello Interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: dr_priority
                        
                        	DR Priority
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: hello_expiry
                        
                        	Hello Timer Expiry
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: are_we_dr
                        
                        	Are we the DR on this IF ?
                        	**type**\: bool
                        
                        .. attribute:: bfd_enabled
                        
                        	BFD state
                        	**type**\: bool
                        
                        .. attribute:: bfd_interval
                        
                        	BFD Interval
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bfd_multiplier
                        
                        	BFD Multiplier
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_interface
                        
                        	 is this a Virtual Interfaces ?
                        	**type**\: bool
                        
                        .. attribute:: passive_interface
                        
                        	Passive PIM interface
                        	**type**\: bool
                        
                        .. attribute:: neighbor_filter_name
                        
                        	Neighbor Filter Name
                        	**type**\: str
                        
                        .. attribute:: join_prune_interval
                        
                        	Join\-Prune Interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: prune_delay_enabled
                        
                        	Prune Delay Enabled
                        	**type**\: bool
                        
                        .. attribute:: configured_propagation_delay
                        
                        	Configured Propagation Delay
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: configured_override_interval
                        
                        	Configured Override Interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: generation_id
                        
                        	Generation Identifier
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Bidir Capable
                        	**type**\: bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Proxy Capable
                        	**type**\: bool
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Batch Asserts Capable
                        	**type**\: bool
                        
                        .. attribute:: idb_oor_enabled
                        
                        	Interface oor enabled
                        	**type**\: bool
                        
                        .. attribute:: idb_acl_provided
                        
                        	ACL name provided
                        	**type**\: bool
                        
                        .. attribute:: idb_max_count
                        
                        	Interface ole max count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_threshold_count
                        
                        	Interface ole threshold count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_current_count
                        
                        	Interface ole current count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_acl_name
                        
                        	Interface ole ACL Name
                        	**type**\: str
                        
                        	**length:** 0..64
                        
                        .. attribute:: interface_address
                        
                        	List of Interface IP Addresses
                        	**type**\: list of  		 :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.InterfaceAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface, self).__init__()

                            self.yang_name = "ifrs-interface"
                            self.yang_parent_name = "ifrs-interfaces"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['interface_name']
                            self._child_classes = OrderedDict([("dr-address", ("dr_address", Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress)), ("interface-address", ("interface_address", Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.InterfaceAddress))])
                            self._leafs = OrderedDict([
                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                                ('interface_address_mask', (YLeaf(YType.uint8, 'interface-address-mask'), ['int'])),
                                ('is_enabled', (YLeaf(YType.boolean, 'is-enabled'), ['bool'])),
                                ('neighbor_count', (YLeaf(YType.uint16, 'neighbor-count'), ['int'])),
                                ('external_neighbor_count', (YLeaf(YType.uint16, 'external-neighbor-count'), ['int'])),
                                ('hello_interval', (YLeaf(YType.uint16, 'hello-interval'), ['int'])),
                                ('dr_priority', (YLeaf(YType.uint32, 'dr-priority'), ['int'])),
                                ('hello_expiry', (YLeaf(YType.uint64, 'hello-expiry'), ['int'])),
                                ('are_we_dr', (YLeaf(YType.boolean, 'are-we-dr'), ['bool'])),
                                ('bfd_enabled', (YLeaf(YType.boolean, 'bfd-enabled'), ['bool'])),
                                ('bfd_interval', (YLeaf(YType.uint32, 'bfd-interval'), ['int'])),
                                ('bfd_multiplier', (YLeaf(YType.uint32, 'bfd-multiplier'), ['int'])),
                                ('virtual_interface', (YLeaf(YType.boolean, 'virtual-interface'), ['bool'])),
                                ('passive_interface', (YLeaf(YType.boolean, 'passive-interface'), ['bool'])),
                                ('neighbor_filter_name', (YLeaf(YType.str, 'neighbor-filter-name'), ['str'])),
                                ('join_prune_interval', (YLeaf(YType.uint16, 'join-prune-interval'), ['int'])),
                                ('prune_delay_enabled', (YLeaf(YType.boolean, 'prune-delay-enabled'), ['bool'])),
                                ('configured_propagation_delay', (YLeaf(YType.uint16, 'configured-propagation-delay'), ['int'])),
                                ('propagation_delay', (YLeaf(YType.uint16, 'propagation-delay'), ['int'])),
                                ('configured_override_interval', (YLeaf(YType.uint16, 'configured-override-interval'), ['int'])),
                                ('override_interval', (YLeaf(YType.uint16, 'override-interval'), ['int'])),
                                ('generation_id', (YLeaf(YType.uint32, 'generation-id'), ['int'])),
                                ('is_bidirectional_capable', (YLeaf(YType.boolean, 'is-bidirectional-capable'), ['bool'])),
                                ('is_proxy_capable', (YLeaf(YType.boolean, 'is-proxy-capable'), ['bool'])),
                                ('is_batch_asserts_capable', (YLeaf(YType.boolean, 'is-batch-asserts-capable'), ['bool'])),
                                ('idb_oor_enabled', (YLeaf(YType.boolean, 'idb-oor-enabled'), ['bool'])),
                                ('idb_acl_provided', (YLeaf(YType.boolean, 'idb-acl-provided'), ['bool'])),
                                ('idb_max_count', (YLeaf(YType.uint32, 'idb-max-count'), ['int'])),
                                ('idb_threshold_count', (YLeaf(YType.uint32, 'idb-threshold-count'), ['int'])),
                                ('idb_current_count', (YLeaf(YType.uint32, 'idb-current-count'), ['int'])),
                                ('idb_acl_name', (YLeaf(YType.str, 'idb-acl-name'), ['str'])),
                            ])
                            self.interface_name = None
                            self.interface_name_xr = None
                            self.interface_address_mask = None
                            self.is_enabled = None
                            self.neighbor_count = None
                            self.external_neighbor_count = None
                            self.hello_interval = None
                            self.dr_priority = None
                            self.hello_expiry = None
                            self.are_we_dr = None
                            self.bfd_enabled = None
                            self.bfd_interval = None
                            self.bfd_multiplier = None
                            self.virtual_interface = None
                            self.passive_interface = None
                            self.neighbor_filter_name = None
                            self.join_prune_interval = None
                            self.prune_delay_enabled = None
                            self.configured_propagation_delay = None
                            self.propagation_delay = None
                            self.configured_override_interval = None
                            self.override_interval = None
                            self.generation_id = None
                            self.is_bidirectional_capable = None
                            self.is_proxy_capable = None
                            self.is_batch_asserts_capable = None
                            self.idb_oor_enabled = None
                            self.idb_acl_provided = None
                            self.idb_max_count = None
                            self.idb_threshold_count = None
                            self.idb_current_count = None
                            self.idb_acl_name = None

                            self.dr_address = Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress()
                            self.dr_address.parent = self
                            self._children_name_map["dr_address"] = "dr-address"

                            self.interface_address = YList(self)
                            self._segment_path = lambda: "ifrs-interface" + "[interface-name='" + str(self.interface_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface, ['interface_name', 'interface_name_xr', 'interface_address_mask', 'is_enabled', 'neighbor_count', 'external_neighbor_count', 'hello_interval', 'dr_priority', 'hello_expiry', 'are_we_dr', 'bfd_enabled', 'bfd_interval', 'bfd_multiplier', 'virtual_interface', 'passive_interface', 'neighbor_filter_name', 'join_prune_interval', 'prune_delay_enabled', 'configured_propagation_delay', 'propagation_delay', 'configured_override_interval', 'override_interval', 'generation_id', 'is_bidirectional_capable', 'is_proxy_capable', 'is_batch_asserts_capable', 'idb_oor_enabled', 'idb_acl_provided', 'idb_max_count', 'idb_threshold_count', 'idb_current_count', 'idb_acl_name'], name, value)


                        class DrAddress(Entity):
                            """
                            PIM Designated Router
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress, self).__init__()

                                self.yang_name = "dr-address"
                                self.yang_parent_name = "ifrs-interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "dr-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class InterfaceAddress(Entity):
                            """
                            List of Interface IP Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.InterfaceAddress, self).__init__()

                                self.yang_name = "interface-address"
                                self.yang_parent_name = "ifrs-interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "interface-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.InterfaceAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class Safs(Entity):
                    """
                    SAFI table and type
                    
                    .. attribute:: saf
                    
                    	SAF name 
                    	**type**\: list of  		 :py:class:`Saf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.Safs, self).__init__()

                        self.yang_name = "safs"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("saf", ("saf", Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf))])
                        self._leafs = OrderedDict()

                        self.saf = YList(self)
                        self._segment_path = lambda: "safs"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Safs, [], name, value)


                    class Saf(Entity):
                        """
                        SAF name 
                        
                        .. attribute:: rpf_hash_source_groups
                        
                        	PIM RPF multipath hash outcome
                        	**type**\:  :py:class:`RpfHashSourceGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups>`
                        
                        .. attribute:: rpf_hash_sources
                        
                        	PIM RPF multipath hash outcome
                        	**type**\:  :py:class:`RpfHashSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources>`
                        
                        .. attribute:: rpfs
                        
                        	PIM RPF information table
                        	**type**\:  :py:class:`Rpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs>`
                        
                        .. attribute:: saf_name
                        
                        	SAF name 
                        	**type**\:  :py:class:`PimSafi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimSafi>`
                        
                        .. attribute:: topology_name
                        
                        	Topology name 
                        	**type**\: str
                        
                        	**length:** 1..32
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf, self).__init__()

                            self.yang_name = "saf"
                            self.yang_parent_name = "safs"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rpf-hash-source-groups", ("rpf_hash_source_groups", Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups)), ("rpf-hash-sources", ("rpf_hash_sources", Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources)), ("rpfs", ("rpfs", Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs))])
                            self._leafs = OrderedDict([
                                ('saf_name', (YLeaf(YType.enumeration, 'saf-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimSafi', '')])),
                                ('topology_name', (YLeaf(YType.str, 'topology-name'), ['str'])),
                            ])
                            self.saf_name = None
                            self.topology_name = None

                            self.rpf_hash_source_groups = Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups()
                            self.rpf_hash_source_groups.parent = self
                            self._children_name_map["rpf_hash_source_groups"] = "rpf-hash-source-groups"

                            self.rpf_hash_sources = Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources()
                            self.rpf_hash_sources.parent = self
                            self._children_name_map["rpf_hash_sources"] = "rpf-hash-sources"

                            self.rpfs = Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs()
                            self.rpfs.parent = self
                            self._children_name_map["rpfs"] = "rpfs"
                            self._segment_path = lambda: "saf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf, ['saf_name', 'topology_name'], name, value)


                        class RpfHashSourceGroups(Entity):
                            """
                            PIM RPF multipath hash outcome
                            
                            .. attribute:: rpf_hash_source_group
                            
                            	PIM RPF hash outcome for S,G
                            	**type**\: list of  		 :py:class:`RpfHashSourceGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups, self).__init__()

                                self.yang_name = "rpf-hash-source-groups"
                                self.yang_parent_name = "saf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("rpf-hash-source-group", ("rpf_hash_source_group", Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup))])
                                self._leafs = OrderedDict()

                                self.rpf_hash_source_group = YList(self)
                                self._segment_path = lambda: "rpf-hash-source-groups"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups, [], name, value)


                            class RpfHashSourceGroup(Entity):
                                """
                                PIM RPF hash outcome for S,G
                                
                                .. attribute:: source_address
                                
                                	Source address
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: group_address
                                
                                	Group address
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: mask_length
                                
                                	Hash mask length
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: mofrr
                                
                                	MOFRR
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_address
                                
                                	Next hop neighbor address
                                	**type**\:  :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress>`
                                
                                .. attribute:: secondary_next_hop_address
                                
                                	Secondary Next hop neighbor address
                                	**type**\:  :py:class:`SecondaryNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress>`
                                
                                .. attribute:: next_hop_multipath_enabled
                                
                                	Next hop multipath enabled?
                                	**type**\: bool
                                
                                .. attribute:: next_hop_interface
                                
                                	Next hop neighbor interface
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                .. attribute:: secondary_next_hop_interface
                                
                                	Secondary Next hop neighbor interface
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup, self).__init__()

                                    self.yang_name = "rpf-hash-source-group"
                                    self.yang_parent_name = "rpf-hash-source-groups"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("next-hop-address", ("next_hop_address", Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress)), ("secondary-next-hop-address", ("secondary_next_hop_address", Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress))])
                                    self._leafs = OrderedDict([
                                        ('source_address', (YLeaf(YType.str, 'source-address'), ['str','str'])),
                                        ('group_address', (YLeaf(YType.str, 'group-address'), ['str','str'])),
                                        ('mask_length', (YLeaf(YType.uint32, 'mask-length'), ['int'])),
                                        ('mofrr', (YLeaf(YType.uint32, 'mofrr'), ['int'])),
                                        ('next_hop_multipath_enabled', (YLeaf(YType.boolean, 'next-hop-multipath-enabled'), ['bool'])),
                                        ('next_hop_interface', (YLeaf(YType.str, 'next-hop-interface'), ['str'])),
                                        ('secondary_next_hop_interface', (YLeaf(YType.str, 'secondary-next-hop-interface'), ['str'])),
                                    ])
                                    self.source_address = None
                                    self.group_address = None
                                    self.mask_length = None
                                    self.mofrr = None
                                    self.next_hop_multipath_enabled = None
                                    self.next_hop_interface = None
                                    self.secondary_next_hop_interface = None

                                    self.next_hop_address = Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress()
                                    self.next_hop_address.parent = self
                                    self._children_name_map["next_hop_address"] = "next-hop-address"

                                    self.secondary_next_hop_address = Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress()
                                    self.secondary_next_hop_address.parent = self
                                    self._children_name_map["secondary_next_hop_address"] = "secondary-next-hop-address"
                                    self._segment_path = lambda: "rpf-hash-source-group"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup, ['source_address', 'group_address', 'mask_length', 'mofrr', 'next_hop_multipath_enabled', 'next_hop_interface', 'secondary_next_hop_interface'], name, value)


                                class NextHopAddress(Entity):
                                    """
                                    Next hop neighbor address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress, self).__init__()

                                        self.yang_name = "next-hop-address"
                                        self.yang_parent_name = "rpf-hash-source-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ])
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None
                                        self._segment_path = lambda: "next-hop-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                                class SecondaryNextHopAddress(Entity):
                                    """
                                    Secondary Next hop neighbor address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress, self).__init__()

                                        self.yang_name = "secondary-next-hop-address"
                                        self.yang_parent_name = "rpf-hash-source-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ])
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None
                                        self._segment_path = lambda: "secondary-next-hop-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class RpfHashSources(Entity):
                            """
                            PIM RPF multipath hash outcome
                            
                            .. attribute:: rpf_hash_source
                            
                            	PIM RPF hash outcome for S,G
                            	**type**\: list of  		 :py:class:`RpfHashSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources, self).__init__()

                                self.yang_name = "rpf-hash-sources"
                                self.yang_parent_name = "saf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("rpf-hash-source", ("rpf_hash_source", Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource))])
                                self._leafs = OrderedDict()

                                self.rpf_hash_source = YList(self)
                                self._segment_path = lambda: "rpf-hash-sources"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources, [], name, value)


                            class RpfHashSource(Entity):
                                """
                                PIM RPF hash outcome for S,G
                                
                                .. attribute:: source_address
                                
                                	Source address
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: mofrr
                                
                                	MOFRR
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_address
                                
                                	Next hop neighbor address
                                	**type**\:  :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress>`
                                
                                .. attribute:: secondary_next_hop_address
                                
                                	Secondary Next hop neighbor address
                                	**type**\:  :py:class:`SecondaryNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress>`
                                
                                .. attribute:: next_hop_multipath_enabled
                                
                                	Next hop multipath enabled?
                                	**type**\: bool
                                
                                .. attribute:: next_hop_interface
                                
                                	Next hop neighbor interface
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                .. attribute:: secondary_next_hop_interface
                                
                                	Secondary Next hop neighbor interface
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource, self).__init__()

                                    self.yang_name = "rpf-hash-source"
                                    self.yang_parent_name = "rpf-hash-sources"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("next-hop-address", ("next_hop_address", Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress)), ("secondary-next-hop-address", ("secondary_next_hop_address", Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress))])
                                    self._leafs = OrderedDict([
                                        ('source_address', (YLeaf(YType.str, 'source-address'), ['str','str'])),
                                        ('mofrr', (YLeaf(YType.uint32, 'mofrr'), ['int'])),
                                        ('next_hop_multipath_enabled', (YLeaf(YType.boolean, 'next-hop-multipath-enabled'), ['bool'])),
                                        ('next_hop_interface', (YLeaf(YType.str, 'next-hop-interface'), ['str'])),
                                        ('secondary_next_hop_interface', (YLeaf(YType.str, 'secondary-next-hop-interface'), ['str'])),
                                    ])
                                    self.source_address = None
                                    self.mofrr = None
                                    self.next_hop_multipath_enabled = None
                                    self.next_hop_interface = None
                                    self.secondary_next_hop_interface = None

                                    self.next_hop_address = Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress()
                                    self.next_hop_address.parent = self
                                    self._children_name_map["next_hop_address"] = "next-hop-address"

                                    self.secondary_next_hop_address = Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress()
                                    self.secondary_next_hop_address.parent = self
                                    self._children_name_map["secondary_next_hop_address"] = "secondary-next-hop-address"
                                    self._segment_path = lambda: "rpf-hash-source"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource, ['source_address', 'mofrr', 'next_hop_multipath_enabled', 'next_hop_interface', 'secondary_next_hop_interface'], name, value)


                                class NextHopAddress(Entity):
                                    """
                                    Next hop neighbor address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress, self).__init__()

                                        self.yang_name = "next-hop-address"
                                        self.yang_parent_name = "rpf-hash-source"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ])
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None
                                        self._segment_path = lambda: "next-hop-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                                class SecondaryNextHopAddress(Entity):
                                    """
                                    Secondary Next hop neighbor address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress, self).__init__()

                                        self.yang_name = "secondary-next-hop-address"
                                        self.yang_parent_name = "rpf-hash-source"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ])
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None
                                        self._segment_path = lambda: "secondary-next-hop-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class Rpfs(Entity):
                            """
                            PIM RPF information table
                            
                            .. attribute:: rpf
                            
                            	PIM RPF information
                            	**type**\: list of  		 :py:class:`Rpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs, self).__init__()

                                self.yang_name = "rpfs"
                                self.yang_parent_name = "saf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("rpf", ("rpf", Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf))])
                                self._leafs = OrderedDict()

                                self.rpf = YList(self)
                                self._segment_path = lambda: "rpfs"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs, [], name, value)


                            class Rpf(Entity):
                                """
                                PIM RPF information
                                
                                .. attribute:: registered_address  (key)
                                
                                	Address for which RPF lookup
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: registered_address_xr
                                
                                	Address registered
                                	**type**\:  :py:class:`RegisteredAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr>`
                                
                                .. attribute:: metric
                                
                                	Metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_preference
                                
                                	Metric preference
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_connected
                                
                                	Are we connected ?
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: is_rpf_bgp_route
                                
                                	Is RPF through BGP route
                                	**type**\: bool
                                
                                .. attribute:: rpf_path
                                
                                	RPF Paths list
                                	**type**\: list of  		 :py:class:`RpfPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf, self).__init__()

                                    self.yang_name = "rpf"
                                    self.yang_parent_name = "rpfs"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['registered_address']
                                    self._child_classes = OrderedDict([("registered-address-xr", ("registered_address_xr", Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr)), ("rpf-path", ("rpf_path", Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath))])
                                    self._leafs = OrderedDict([
                                        ('registered_address', (YLeaf(YType.str, 'registered-address'), ['str','str'])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('metric_preference', (YLeaf(YType.uint32, 'metric-preference'), ['int'])),
                                        ('is_connected', (YLeaf(YType.uint8, 'is-connected'), ['int'])),
                                        ('is_rpf_bgp_route', (YLeaf(YType.boolean, 'is-rpf-bgp-route'), ['bool'])),
                                    ])
                                    self.registered_address = None
                                    self.metric = None
                                    self.metric_preference = None
                                    self.is_connected = None
                                    self.is_rpf_bgp_route = None

                                    self.registered_address_xr = Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr()
                                    self.registered_address_xr.parent = self
                                    self._children_name_map["registered_address_xr"] = "registered-address-xr"

                                    self.rpf_path = YList(self)
                                    self._segment_path = lambda: "rpf" + "[registered-address='" + str(self.registered_address) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf, ['registered_address', 'metric', 'metric_preference', 'is_connected', 'is_rpf_bgp_route'], name, value)


                                class RegisteredAddressXr(Entity):
                                    """
                                    Address registered
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr, self).__init__()

                                        self.yang_name = "registered-address-xr"
                                        self.yang_parent_name = "rpf"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ])
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None
                                        self._segment_path = lambda: "registered-address-xr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                                class RpfPath(Entity):
                                    """
                                    RPF Paths list
                                    
                                    .. attribute:: rpf_neighbor
                                    
                                    	RPF neighbor
                                    	**type**\:  :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor>`
                                    
                                    .. attribute:: rpf_nexthop
                                    
                                    	RPF nexthop
                                    	**type**\:  :py:class:`RpfNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop>`
                                    
                                    .. attribute:: rpf_interface_name
                                    
                                    	RPF Interface
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: is_rpf_interface_disabled
                                    
                                    	Is the rpf interface disabled ?
                                    	**type**\: bool
                                    
                                    .. attribute:: is_via_lsm
                                    
                                    	Via LSM
                                    	**type**\: bool
                                    
                                    .. attribute:: is_via_mlsm
                                    
                                    	Via Mstatic LSM
                                    	**type**\: bool
                                    
                                    .. attribute:: is_connector_attribute_present
                                    
                                    	Connector attribute present
                                    	**type**\: bool
                                    
                                    .. attribute:: connector
                                    
                                    	Connector Attribute
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    .. attribute:: extranet_vrf_name
                                    
                                    	Extranet VRF name
                                    	**type**\: str
                                    
                                    	**length:** 0..33
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath, self).__init__()

                                        self.yang_name = "rpf-path"
                                        self.yang_parent_name = "rpf"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("rpf-neighbor", ("rpf_neighbor", Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor)), ("rpf-nexthop", ("rpf_nexthop", Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop))])
                                        self._leafs = OrderedDict([
                                            ('rpf_interface_name', (YLeaf(YType.str, 'rpf-interface-name'), ['str'])),
                                            ('is_rpf_interface_disabled', (YLeaf(YType.boolean, 'is-rpf-interface-disabled'), ['bool'])),
                                            ('is_via_lsm', (YLeaf(YType.boolean, 'is-via-lsm'), ['bool'])),
                                            ('is_via_mlsm', (YLeaf(YType.boolean, 'is-via-mlsm'), ['bool'])),
                                            ('is_connector_attribute_present', (YLeaf(YType.boolean, 'is-connector-attribute-present'), ['bool'])),
                                            ('connector', (YLeaf(YType.str, 'connector'), ['str'])),
                                            ('extranet_vrf_name', (YLeaf(YType.str, 'extranet-vrf-name'), ['str'])),
                                        ])
                                        self.rpf_interface_name = None
                                        self.is_rpf_interface_disabled = None
                                        self.is_via_lsm = None
                                        self.is_via_mlsm = None
                                        self.is_connector_attribute_present = None
                                        self.connector = None
                                        self.extranet_vrf_name = None

                                        self.rpf_neighbor = Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor()
                                        self.rpf_neighbor.parent = self
                                        self._children_name_map["rpf_neighbor"] = "rpf-neighbor"

                                        self.rpf_nexthop = Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop()
                                        self.rpf_nexthop.parent = self
                                        self._children_name_map["rpf_nexthop"] = "rpf-nexthop"
                                        self._segment_path = lambda: "rpf-path"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath, ['rpf_interface_name', 'is_rpf_interface_disabled', 'is_via_lsm', 'is_via_mlsm', 'is_connector_attribute_present', 'connector', 'extranet_vrf_name'], name, value)


                                    class RpfNeighbor(Entity):
                                        """
                                        RPF neighbor
                                        
                                        .. attribute:: af_name
                                        
                                        	AFName
                                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Address
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-pim-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor, self).__init__()

                                            self.yang_name = "rpf-neighbor"
                                            self.yang_parent_name = "rpf-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                            ])
                                            self.af_name = None
                                            self.ipv4_address = None
                                            self.ipv6_address = None
                                            self._segment_path = lambda: "rpf-neighbor"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                                    class RpfNexthop(Entity):
                                        """
                                        RPF nexthop
                                        
                                        .. attribute:: af_name
                                        
                                        	AFName
                                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Address
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-pim-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop, self).__init__()

                                            self.yang_name = "rpf-nexthop"
                                            self.yang_parent_name = "rpf-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                            ])
                                            self.af_name = None
                                            self.ipv4_address = None
                                            self.ipv6_address = None
                                            self._segment_path = lambda: "rpf-nexthop"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class InterfaceStatistics(Entity):
                    """
                    PIM interface statistics
                    
                    .. attribute:: interface_statistic
                    
                    	PIM interface statistics
                    	**type**\: list of  		 :py:class:`InterfaceStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.InterfaceStatistics.InterfaceStatistic>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.InterfaceStatistics, self).__init__()

                        self.yang_name = "interface-statistics"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("interface-statistic", ("interface_statistic", Ipv6Pim.Active.Vrfs.Vrf.InterfaceStatistics.InterfaceStatistic))])
                        self._leafs = OrderedDict()

                        self.interface_statistic = YList(self)
                        self._segment_path = lambda: "interface-statistics"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.InterfaceStatistics, [], name, value)


                    class InterfaceStatistic(Entity):
                        """
                        PIM interface statistics
                        
                        .. attribute:: interface_name  (key)
                        
                        	Interface name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: input_hello
                        
                        	Hello packets in
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_hello
                        
                        	Hello packets out
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_register
                        
                        	Register packets in
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_register
                        
                        	Register packets out
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_register_stop
                        
                        	Register Stop packets in
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_register_stop
                        
                        	Register Stop packets out
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_jp
                        
                        	Join Prune packets in
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_jp
                        
                        	Join Prune packets out
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_bsr_message
                        
                        	Input BSR Messages
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_bsr_message
                        
                        	Output BSR Messages
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_assert
                        
                        	Assert packets in
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_assert
                        
                        	Assert packets out
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_graft_message
                        
                        	Input Graft Messages
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_graft_message
                        
                        	Output Graft Messages
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_graft_ack_message
                        
                        	Input Graft Ack Messages
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_graft_ack_message
                        
                        	Output Graft Ack Messages
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_candidate_rp_advertisement
                        
                        	Input Candidate\-RP Advertisment
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_candidate_rp_advertisement
                        
                        	Output Candidate\-RP Advertisment
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_df_election
                        
                        	DF Election packets in
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_df_election
                        
                        	DF Election packets out
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_miscellaneous
                        
                        	Miscellaneous packet in
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.InterfaceStatistics.InterfaceStatistic, self).__init__()

                            self.yang_name = "interface-statistic"
                            self.yang_parent_name = "interface-statistics"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['interface_name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ('input_hello', (YLeaf(YType.uint32, 'input-hello'), ['int'])),
                                ('output_hello', (YLeaf(YType.uint32, 'output-hello'), ['int'])),
                                ('input_register', (YLeaf(YType.uint32, 'input-register'), ['int'])),
                                ('output_register', (YLeaf(YType.uint32, 'output-register'), ['int'])),
                                ('input_register_stop', (YLeaf(YType.uint32, 'input-register-stop'), ['int'])),
                                ('output_register_stop', (YLeaf(YType.uint32, 'output-register-stop'), ['int'])),
                                ('input_jp', (YLeaf(YType.uint32, 'input-jp'), ['int'])),
                                ('output_jp', (YLeaf(YType.uint32, 'output-jp'), ['int'])),
                                ('input_bsr_message', (YLeaf(YType.uint32, 'input-bsr-message'), ['int'])),
                                ('output_bsr_message', (YLeaf(YType.uint32, 'output-bsr-message'), ['int'])),
                                ('input_assert', (YLeaf(YType.uint32, 'input-assert'), ['int'])),
                                ('output_assert', (YLeaf(YType.uint32, 'output-assert'), ['int'])),
                                ('input_graft_message', (YLeaf(YType.uint32, 'input-graft-message'), ['int'])),
                                ('output_graft_message', (YLeaf(YType.uint32, 'output-graft-message'), ['int'])),
                                ('input_graft_ack_message', (YLeaf(YType.uint32, 'input-graft-ack-message'), ['int'])),
                                ('output_graft_ack_message', (YLeaf(YType.uint32, 'output-graft-ack-message'), ['int'])),
                                ('input_candidate_rp_advertisement', (YLeaf(YType.uint32, 'input-candidate-rp-advertisement'), ['int'])),
                                ('output_candidate_rp_advertisement', (YLeaf(YType.uint32, 'output-candidate-rp-advertisement'), ['int'])),
                                ('input_df_election', (YLeaf(YType.uint32, 'input-df-election'), ['int'])),
                                ('output_df_election', (YLeaf(YType.uint32, 'output-df-election'), ['int'])),
                                ('input_miscellaneous', (YLeaf(YType.uint32, 'input-miscellaneous'), ['int'])),
                            ])
                            self.interface_name = None
                            self.input_hello = None
                            self.output_hello = None
                            self.input_register = None
                            self.output_register = None
                            self.input_register_stop = None
                            self.output_register_stop = None
                            self.input_jp = None
                            self.output_jp = None
                            self.input_bsr_message = None
                            self.output_bsr_message = None
                            self.input_assert = None
                            self.output_assert = None
                            self.input_graft_message = None
                            self.output_graft_message = None
                            self.input_graft_ack_message = None
                            self.output_graft_ack_message = None
                            self.input_candidate_rp_advertisement = None
                            self.output_candidate_rp_advertisement = None
                            self.input_df_election = None
                            self.output_df_election = None
                            self.input_miscellaneous = None
                            self._segment_path = lambda: "interface-statistic" + "[interface-name='" + str(self.interface_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.InterfaceStatistics.InterfaceStatistic, ['interface_name', 'input_hello', 'output_hello', 'input_register', 'output_register', 'input_register_stop', 'output_register_stop', 'input_jp', 'output_jp', 'input_bsr_message', 'output_bsr_message', 'input_assert', 'output_assert', 'input_graft_message', 'output_graft_message', 'input_graft_ack_message', 'output_graft_ack_message', 'input_candidate_rp_advertisement', 'output_candidate_rp_advertisement', 'input_df_election', 'output_df_election', 'input_miscellaneous'], name, value)


                class TopologyRouteCount(Entity):
                    """
                    Topology route count information from PIM
                    topology table
                    
                    .. attribute:: group_ranges
                    
                    	No. of (\*,G/M) routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: active_group_ranges
                    
                    	No. of (\*,G/M) routes active in mrib
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: groute_count
                    
                    	No. of (\*,G) routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sg_route_count
                    
                    	No. of (S,G) routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sgr_route_count
                    
                    	No. of (S,G)RPT routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.TopologyRouteCount, self).__init__()

                        self.yang_name = "topology-route-count"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('group_ranges', (YLeaf(YType.uint32, 'group-ranges'), ['int'])),
                            ('active_group_ranges', (YLeaf(YType.uint32, 'active-group-ranges'), ['int'])),
                            ('groute_count', (YLeaf(YType.uint32, 'groute-count'), ['int'])),
                            ('sg_route_count', (YLeaf(YType.uint32, 'sg-route-count'), ['int'])),
                            ('sgr_route_count', (YLeaf(YType.uint32, 'sgr-route-count'), ['int'])),
                            ('is_node_low_memory', (YLeaf(YType.boolean, 'is-node-low-memory'), ['bool'])),
                        ])
                        self.group_ranges = None
                        self.active_group_ranges = None
                        self.groute_count = None
                        self.sg_route_count = None
                        self.sgr_route_count = None
                        self.is_node_low_memory = None
                        self._segment_path = lambda: "topology-route-count"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.TopologyRouteCount, ['group_ranges', 'active_group_ranges', 'groute_count', 'sg_route_count', 'sgr_route_count', 'is_node_low_memory'], name, value)


                class JpStatistics(Entity):
                    """
                    PIM join prune statistics table
                    
                    .. attribute:: jp_statistic
                    
                    	PIM Join Prune Statistics
                    	**type**\: list of  		 :py:class:`JpStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.JpStatistics.JpStatistic>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.JpStatistics, self).__init__()

                        self.yang_name = "jp-statistics"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("jp-statistic", ("jp_statistic", Ipv6Pim.Active.Vrfs.Vrf.JpStatistics.JpStatistic))])
                        self._leafs = OrderedDict()

                        self.jp_statistic = YList(self)
                        self._segment_path = lambda: "jp-statistics"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.JpStatistics, [], name, value)


                    class JpStatistic(Entity):
                        """
                        PIM Join Prune Statistics
                        
                        .. attribute:: interface_name  (key)
                        
                        	Interface name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identifier
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: mtu
                        
                        	Interface MTU
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: transmitted
                        
                        	Transmitted
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: transmitted100
                        
                        	Transmitted 100 average
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: transmitted_1k
                        
                        	Transmitted 1K average
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: transmitted_10k
                        
                        	Transmitted 10K average
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: transmitted_50k
                        
                        	Deprecated by Transmitted100
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: received
                        
                        	Received
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: received100
                        
                        	Received 100 average
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: received_1k
                        
                        	Received 1K average
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: received_10k
                        
                        	Received 10K average
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: received_50k
                        
                        	Deprecated by Received100
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.JpStatistics.JpStatistic, self).__init__()

                            self.yang_name = "jp-statistic"
                            self.yang_parent_name = "jp-statistics"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['interface_name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                                ('mtu', (YLeaf(YType.uint32, 'mtu'), ['int'])),
                                ('transmitted', (YLeaf(YType.uint32, 'transmitted'), ['int'])),
                                ('transmitted100', (YLeaf(YType.uint16, 'transmitted100'), ['int'])),
                                ('transmitted_1k', (YLeaf(YType.uint16, 'transmitted-1k'), ['int'])),
                                ('transmitted_10k', (YLeaf(YType.uint16, 'transmitted-10k'), ['int'])),
                                ('transmitted_50k', (YLeaf(YType.uint16, 'transmitted-50k'), ['int'])),
                                ('received', (YLeaf(YType.uint32, 'received'), ['int'])),
                                ('received100', (YLeaf(YType.uint16, 'received100'), ['int'])),
                                ('received_1k', (YLeaf(YType.uint16, 'received-1k'), ['int'])),
                                ('received_10k', (YLeaf(YType.uint16, 'received-10k'), ['int'])),
                                ('received_50k', (YLeaf(YType.uint16, 'received-50k'), ['int'])),
                            ])
                            self.interface_name = None
                            self.interface_name_xr = None
                            self.mtu = None
                            self.transmitted = None
                            self.transmitted100 = None
                            self.transmitted_1k = None
                            self.transmitted_10k = None
                            self.transmitted_50k = None
                            self.received = None
                            self.received100 = None
                            self.received_1k = None
                            self.received_10k = None
                            self.received_50k = None
                            self._segment_path = lambda: "jp-statistic" + "[interface-name='" + str(self.interface_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.JpStatistics.JpStatistic, ['interface_name', 'interface_name_xr', 'mtu', 'transmitted', 'transmitted100', 'transmitted_1k', 'transmitted_10k', 'transmitted_50k', 'received', 'received100', 'received_1k', 'received_10k', 'received_50k'], name, value)


                class MibDatabases(Entity):
                    """
                    PIM group database for mroute mibs table
                    
                    .. attribute:: mib_database
                    
                    	PIM multicast static route information
                    	**type**\: list of  		 :py:class:`MibDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.MibDatabases, self).__init__()

                        self.yang_name = "mib-databases"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("mib-database", ("mib_database", Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase))])
                        self._leafs = OrderedDict()

                        self.mib_database = YList(self)
                        self._segment_path = lambda: "mib-databases"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.MibDatabases, [], name, value)


                    class MibDatabase(Entity):
                        """
                        PIM multicast static route information
                        
                        .. attribute:: source_address
                        
                        	Multicast static route source address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: group_address
                        
                        	Multicast satic route group address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source_netmask
                        
                        	Source mask
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: source_address_xr
                        
                        	Source Address
                        	**type**\:  :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr>`
                        
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:  :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr>`
                        
                        .. attribute:: rpf_neighbor
                        
                        	The RPF Neighbor
                        	**type**\:  :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor>`
                        
                        .. attribute:: rpf_root
                        
                        	Root of this mcast tree
                        	**type**\:  :py:class:`RpfRoot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot>`
                        
                        .. attribute:: upstream_assert_timer
                        
                        	Upstream Assert Timer
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: assert_metric
                        
                        	Assert Metric
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: assert_metric_preference
                        
                        	Assert Metric Preference
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: assert_rpt_bit
                        
                        	Assert RPT Bit
                        	**type**\: bool
                        
                        .. attribute:: spt_bit
                        
                        	Is SPT bit set ?
                        	**type**\: bool
                        
                        .. attribute:: rpf_mask
                        
                        	Mask of the multicast root
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rpf_safi
                        
                        	Unicast or mcast
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: rpf_table_name
                        
                        	RPF Table name
                        	**type**\: str
                        
                        .. attribute:: rpf_drop
                        
                        	RPF route\-policy drop
                        	**type**\: bool
                        
                        .. attribute:: rpf_extranet
                        
                        	Extranet RPF route\-policy
                        	**type**\: bool
                        
                        .. attribute:: rpf_interface_name
                        
                        	RPF interface name 
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: rpf_vrf_name
                        
                        	RPF VRF Name
                        	**type**\: str
                        
                        	**length:** 0..33
                        
                        .. attribute:: bidirectional_route
                        
                        	Is this Bidir ?
                        	**type**\: bool
                        
                        .. attribute:: uptime
                        
                        	Uptime of route
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: protocol
                        
                        	The PIM protocol
                        	**type**\:  :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase, self).__init__()

                            self.yang_name = "mib-database"
                            self.yang_parent_name = "mib-databases"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("source-address-xr", ("source_address_xr", Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr)), ("group-address-xr", ("group_address_xr", Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr)), ("rpf-neighbor", ("rpf_neighbor", Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor)), ("rpf-root", ("rpf_root", Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot))])
                            self._leafs = OrderedDict([
                                ('source_address', (YLeaf(YType.str, 'source-address'), ['str','str'])),
                                ('group_address', (YLeaf(YType.str, 'group-address'), ['str','str'])),
                                ('source_netmask', (YLeaf(YType.uint32, 'source-netmask'), ['int'])),
                                ('upstream_assert_timer', (YLeaf(YType.int32, 'upstream-assert-timer'), ['int'])),
                                ('assert_metric', (YLeaf(YType.uint32, 'assert-metric'), ['int'])),
                                ('assert_metric_preference', (YLeaf(YType.uint32, 'assert-metric-preference'), ['int'])),
                                ('assert_rpt_bit', (YLeaf(YType.boolean, 'assert-rpt-bit'), ['bool'])),
                                ('spt_bit', (YLeaf(YType.boolean, 'spt-bit'), ['bool'])),
                                ('rpf_mask', (YLeaf(YType.uint32, 'rpf-mask'), ['int'])),
                                ('rpf_safi', (YLeaf(YType.uint8, 'rpf-safi'), ['int'])),
                                ('rpf_table_name', (YLeaf(YType.str, 'rpf-table-name'), ['str'])),
                                ('rpf_drop', (YLeaf(YType.boolean, 'rpf-drop'), ['bool'])),
                                ('rpf_extranet', (YLeaf(YType.boolean, 'rpf-extranet'), ['bool'])),
                                ('rpf_interface_name', (YLeaf(YType.str, 'rpf-interface-name'), ['str'])),
                                ('rpf_vrf_name', (YLeaf(YType.str, 'rpf-vrf-name'), ['str'])),
                                ('bidirectional_route', (YLeaf(YType.boolean, 'bidirectional-route'), ['bool'])),
                                ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                                ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowProtocol', '')])),
                            ])
                            self.source_address = None
                            self.group_address = None
                            self.source_netmask = None
                            self.upstream_assert_timer = None
                            self.assert_metric = None
                            self.assert_metric_preference = None
                            self.assert_rpt_bit = None
                            self.spt_bit = None
                            self.rpf_mask = None
                            self.rpf_safi = None
                            self.rpf_table_name = None
                            self.rpf_drop = None
                            self.rpf_extranet = None
                            self.rpf_interface_name = None
                            self.rpf_vrf_name = None
                            self.bidirectional_route = None
                            self.uptime = None
                            self.protocol = None

                            self.source_address_xr = Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr()
                            self.source_address_xr.parent = self
                            self._children_name_map["source_address_xr"] = "source-address-xr"

                            self.group_address_xr = Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"

                            self.rpf_neighbor = Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor()
                            self.rpf_neighbor.parent = self
                            self._children_name_map["rpf_neighbor"] = "rpf-neighbor"

                            self.rpf_root = Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot()
                            self.rpf_root.parent = self
                            self._children_name_map["rpf_root"] = "rpf-root"
                            self._segment_path = lambda: "mib-database"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase, ['source_address', 'group_address', 'source_netmask', 'upstream_assert_timer', 'assert_metric', 'assert_metric_preference', 'assert_rpt_bit', 'spt_bit', 'rpf_mask', 'rpf_safi', 'rpf_table_name', 'rpf_drop', 'rpf_extranet', 'rpf_interface_name', 'rpf_vrf_name', 'bidirectional_route', 'uptime', 'protocol'], name, value)


                        class SourceAddressXr(Entity):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr, self).__init__()

                                self.yang_name = "source-address-xr"
                                self.yang_parent_name = "mib-database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "source-address-xr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "mib-database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "group-address-xr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class RpfNeighbor(Entity):
                            """
                            The RPF Neighbor
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor, self).__init__()

                                self.yang_name = "rpf-neighbor"
                                self.yang_parent_name = "mib-database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "rpf-neighbor"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class RpfRoot(Entity):
                            """
                            Root of this mcast tree
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot, self).__init__()

                                self.yang_name = "rpf-root"
                                self.yang_parent_name = "mib-database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "rpf-root"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class NeighborOldFormats(Entity):
                    """
                    PIM neighbor table old format
                    
                    .. attribute:: neighbor_old_format
                    
                    	PIM neighbor information
                    	**type**\: list of  		 :py:class:`NeighborOldFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.NeighborOldFormats, self).__init__()

                        self.yang_name = "neighbor-old-formats"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("neighbor-old-format", ("neighbor_old_format", Ipv6Pim.Active.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat))])
                        self._leafs = OrderedDict()

                        self.neighbor_old_format = YList(self)
                        self._segment_path = lambda: "neighbor-old-formats"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.NeighborOldFormats, [], name, value)


                    class NeighborOldFormat(Entity):
                        """
                        PIM neighbor information
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: neighbor_address
                        
                        	Neighbor address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identifier
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: expires
                        
                        	Neighbor expiry in seconds
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: expiry_timer
                        
                        	Expiry timer in seconds
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: is_this_neighbor_us
                        
                        	Is this neighbor us ?
                        	**type**\: bool
                        
                        .. attribute:: is_this_neighbor_dr
                        
                        	Is this neighbor the DR
                        	**type**\: bool
                        
                        .. attribute:: is_dr_priority_capable
                        
                        	Is this neighbor DR priority capable ?
                        	**type**\: bool
                        
                        .. attribute:: dr_priority
                        
                        	DR priority
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Is this neighbor bidir capable ?
                        	**type**\: bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Is this neighbor proxy capable?
                        	**type**\: bool
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Is this neighbor capable of batching asserts?
                        	**type**\: bool
                        
                        .. attribute:: is_ecmp_redirect_capable
                        
                        	Is this neighbor capable of Ecmp Redirect?
                        	**type**\: bool
                        
                        .. attribute:: is_bfd_state
                        
                        	Is the neighbor bfd session created
                        	**type**\: bool
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_address_xr
                        
                        	List of Neighbor Addresses
                        	**type**\: list of  		 :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat, self).__init__()

                            self.yang_name = "neighbor-old-format"
                            self.yang_parent_name = "neighbor-old-formats"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("neighbor-address-xr", ("neighbor_address_xr", Ipv6Pim.Active.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr))])
                            self._leafs = OrderedDict([
                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                                ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                                ('expires', (YLeaf(YType.uint64, 'expires'), ['int'])),
                                ('expiry_timer', (YLeaf(YType.uint64, 'expiry-timer'), ['int'])),
                                ('is_this_neighbor_us', (YLeaf(YType.boolean, 'is-this-neighbor-us'), ['bool'])),
                                ('is_this_neighbor_dr', (YLeaf(YType.boolean, 'is-this-neighbor-dr'), ['bool'])),
                                ('is_dr_priority_capable', (YLeaf(YType.boolean, 'is-dr-priority-capable'), ['bool'])),
                                ('dr_priority', (YLeaf(YType.uint32, 'dr-priority'), ['int'])),
                                ('is_bidirectional_capable', (YLeaf(YType.boolean, 'is-bidirectional-capable'), ['bool'])),
                                ('is_proxy_capable', (YLeaf(YType.boolean, 'is-proxy-capable'), ['bool'])),
                                ('is_batch_asserts_capable', (YLeaf(YType.boolean, 'is-batch-asserts-capable'), ['bool'])),
                                ('is_ecmp_redirect_capable', (YLeaf(YType.boolean, 'is-ecmp-redirect-capable'), ['bool'])),
                                ('is_bfd_state', (YLeaf(YType.boolean, 'is-bfd-state'), ['bool'])),
                                ('propagation_delay', (YLeaf(YType.uint16, 'propagation-delay'), ['int'])),
                                ('override_interval', (YLeaf(YType.uint16, 'override-interval'), ['int'])),
                            ])
                            self.interface_name = None
                            self.neighbor_address = None
                            self.interface_name_xr = None
                            self.uptime = None
                            self.expires = None
                            self.expiry_timer = None
                            self.is_this_neighbor_us = None
                            self.is_this_neighbor_dr = None
                            self.is_dr_priority_capable = None
                            self.dr_priority = None
                            self.is_bidirectional_capable = None
                            self.is_proxy_capable = None
                            self.is_batch_asserts_capable = None
                            self.is_ecmp_redirect_capable = None
                            self.is_bfd_state = None
                            self.propagation_delay = None
                            self.override_interval = None

                            self.neighbor_address_xr = YList(self)
                            self._segment_path = lambda: "neighbor-old-format"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat, ['interface_name', 'neighbor_address', 'interface_name_xr', 'uptime', 'expires', 'expiry_timer', 'is_this_neighbor_us', 'is_this_neighbor_dr', 'is_dr_priority_capable', 'dr_priority', 'is_bidirectional_capable', 'is_proxy_capable', 'is_batch_asserts_capable', 'is_ecmp_redirect_capable', 'is_bfd_state', 'propagation_delay', 'override_interval'], name, value)


                        class NeighborAddressXr(Entity):
                            """
                            List of Neighbor Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr, self).__init__()

                                self.yang_name = "neighbor-address-xr"
                                self.yang_parent_name = "neighbor-old-format"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "neighbor-address-xr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class IfrsSummary(Entity):
                    """
                    PIM interfaces in forward reference store
                    summary
                    
                    .. attribute:: interface_count
                    
                    	Number of interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: configuration_count
                    
                    	Configuration counts
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.IfrsSummary, self).__init__()

                        self.yang_name = "ifrs-summary"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('interface_count', (YLeaf(YType.uint32, 'interface-count'), ['int'])),
                            ('configuration_count', (YLeaf(YType.uint32, 'configuration-count'), ['int'])),
                        ])
                        self.interface_count = None
                        self.configuration_count = None
                        self._segment_path = lambda: "ifrs-summary"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.IfrsSummary, ['interface_count', 'configuration_count'], name, value)


                class Ranges(Entity):
                    """
                    PIM range list information
                    
                    .. attribute:: range
                    
                    	PIM range list information
                    	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.Ranges, self).__init__()

                        self.yang_name = "ranges"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("range", ("range", Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range))])
                        self._leafs = OrderedDict()

                        self.range = YList(self)
                        self._segment_path = lambda: "ranges"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Ranges, [], name, value)


                    class Range(Entity):
                        """
                        PIM range list information
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: client
                        
                        	Client
                        	**type**\:  :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                        
                        .. attribute:: rp_address_xr
                        
                        	Rendezvous point address
                        	**type**\:  :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.RpAddressXr>`
                        
                        .. attribute:: source_of_information
                        
                        	Source of information
                        	**type**\:  :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.SourceOfInformation>`
                        
                        .. attribute:: protocol
                        
                        	PIM protocol
                        	**type**\:  :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: client_xr
                        
                        	Client mapping learnt via
                        	**type**\:  :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                        
                        .. attribute:: expires
                        
                        	When mapping expires
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: group_range
                        
                        	List of group ranges
                        	**type**\: list of  		 :py:class:`GroupRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range, self).__init__()

                            self.yang_name = "range"
                            self.yang_parent_name = "ranges"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rp-address-xr", ("rp_address_xr", Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.RpAddressXr)), ("source-of-information", ("source_of_information", Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.SourceOfInformation)), ("group-range", ("group_range", Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange))])
                            self._leafs = OrderedDict([
                                ('rp_address', (YLeaf(YType.str, 'rp-address'), ['str','str'])),
                                ('client', (YLeaf(YType.enumeration, 'client'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimClient', '')])),
                                ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowProtocol', '')])),
                                ('client_xr', (YLeaf(YType.enumeration, 'client-xr'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowRangeClient', '')])),
                                ('expires', (YLeaf(YType.uint64, 'expires'), ['int'])),
                            ])
                            self.rp_address = None
                            self.client = None
                            self.protocol = None
                            self.client_xr = None
                            self.expires = None

                            self.rp_address_xr = Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.RpAddressXr()
                            self.rp_address_xr.parent = self
                            self._children_name_map["rp_address_xr"] = "rp-address-xr"

                            self.source_of_information = Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.SourceOfInformation()
                            self.source_of_information.parent = self
                            self._children_name_map["source_of_information"] = "source-of-information"

                            self.group_range = YList(self)
                            self._segment_path = lambda: "range"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range, ['rp_address', 'client', 'protocol', 'client_xr', 'expires'], name, value)


                        class RpAddressXr(Entity):
                            """
                            Rendezvous point address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.RpAddressXr, self).__init__()

                                self.yang_name = "rp-address-xr"
                                self.yang_parent_name = "range"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "rp-address-xr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.RpAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class SourceOfInformation(Entity):
                            """
                            Source of information
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.SourceOfInformation, self).__init__()

                                self.yang_name = "source-of-information"
                                self.yang_parent_name = "range"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "source-of-information"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.SourceOfInformation, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class GroupRange(Entity):
                            """
                            List of group ranges
                            
                            .. attribute:: prefix
                            
                            	Group range prefix
                            	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix>`
                            
                            .. attribute:: source_of_information
                            
                            	Source of information
                            	**type**\:  :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation>`
                            
                            .. attribute:: prefix_length
                            
                            	Group range prefix length
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: expires
                            
                            	When mapping expires
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange, self).__init__()

                                self.yang_name = "group-range"
                                self.yang_parent_name = "range"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("prefix", ("prefix", Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix)), ("source-of-information", ("source_of_information", Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation))])
                                self._leafs = OrderedDict([
                                    ('prefix_length', (YLeaf(YType.int32, 'prefix-length'), ['int'])),
                                    ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                                    ('expires', (YLeaf(YType.uint64, 'expires'), ['int'])),
                                ])
                                self.prefix_length = None
                                self.uptime = None
                                self.expires = None

                                self.prefix = Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix()
                                self.prefix.parent = self
                                self._children_name_map["prefix"] = "prefix"

                                self.source_of_information = Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation()
                                self.source_of_information.parent = self
                                self._children_name_map["source_of_information"] = "source-of-information"
                                self._segment_path = lambda: "group-range"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange, ['prefix_length', 'uptime', 'expires'], name, value)


                            class Prefix(Entity):
                                """
                                Group range prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix, self).__init__()

                                    self.yang_name = "prefix"
                                    self.yang_parent_name = "group-range"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "prefix"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                            class SourceOfInformation(Entity):
                                """
                                Source of information
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation, self).__init__()

                                    self.yang_name = "source-of-information"
                                    self.yang_parent_name = "group-range"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "source-of-information"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class InterfaceOldFormats(Entity):
                    """
                    PIM interfaces in old format
                    
                    .. attribute:: interface_old_format
                    
                    	PIM interface name
                    	**type**\: list of  		 :py:class:`InterfaceOldFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats, self).__init__()

                        self.yang_name = "interface-old-formats"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("interface-old-format", ("interface_old_format", Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat))])
                        self._leafs = OrderedDict()

                        self.interface_old_format = YList(self)
                        self._segment_path = lambda: "interface-old-formats"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats, [], name, value)


                    class InterfaceOldFormat(Entity):
                        """
                        PIM interface name
                        
                        .. attribute:: interface_name  (key)
                        
                        	Interface name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: dr_address
                        
                        	PIM Designated Router
                        	**type**\:  :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress>`
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identfier
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: interface_address_mask
                        
                        	Interface IP Address Mask
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: is_enabled
                        
                        	Is PIM enabled on this IF ?
                        	**type**\: bool
                        
                        .. attribute:: neighbor_count
                        
                        	No. of neighbors on this IF
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: external_neighbor_count
                        
                        	No. of external neighbors on this IF
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: hello_interval
                        
                        	Hello Interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: dr_priority
                        
                        	DR Priority
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: hello_expiry
                        
                        	Hello Timer Expiry
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: are_we_dr
                        
                        	Are we the DR on this IF ?
                        	**type**\: bool
                        
                        .. attribute:: bfd_enabled
                        
                        	BFD state
                        	**type**\: bool
                        
                        .. attribute:: bfd_interval
                        
                        	BFD Interval
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bfd_multiplier
                        
                        	BFD Multiplier
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_interface
                        
                        	 is this a Virtual Interfaces ?
                        	**type**\: bool
                        
                        .. attribute:: passive_interface
                        
                        	Passive PIM interface
                        	**type**\: bool
                        
                        .. attribute:: neighbor_filter_name
                        
                        	Neighbor Filter Name
                        	**type**\: str
                        
                        .. attribute:: join_prune_interval
                        
                        	Join\-Prune Interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: prune_delay_enabled
                        
                        	Prune Delay Enabled
                        	**type**\: bool
                        
                        .. attribute:: configured_propagation_delay
                        
                        	Configured Propagation Delay
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: configured_override_interval
                        
                        	Configured Override Interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: generation_id
                        
                        	Generation Identifier
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Bidir Capable
                        	**type**\: bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Proxy Capable
                        	**type**\: bool
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Batch Asserts Capable
                        	**type**\: bool
                        
                        .. attribute:: idb_oor_enabled
                        
                        	Interface oor enabled
                        	**type**\: bool
                        
                        .. attribute:: idb_acl_provided
                        
                        	ACL name provided
                        	**type**\: bool
                        
                        .. attribute:: idb_max_count
                        
                        	Interface ole max count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_threshold_count
                        
                        	Interface ole threshold count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_current_count
                        
                        	Interface ole current count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_acl_name
                        
                        	Interface ole ACL Name
                        	**type**\: str
                        
                        	**length:** 0..64
                        
                        .. attribute:: interface_address
                        
                        	List of Interface IP Addresses
                        	**type**\: list of  		 :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat, self).__init__()

                            self.yang_name = "interface-old-format"
                            self.yang_parent_name = "interface-old-formats"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['interface_name']
                            self._child_classes = OrderedDict([("dr-address", ("dr_address", Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress)), ("interface-address", ("interface_address", Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress))])
                            self._leafs = OrderedDict([
                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                                ('interface_address_mask', (YLeaf(YType.uint8, 'interface-address-mask'), ['int'])),
                                ('is_enabled', (YLeaf(YType.boolean, 'is-enabled'), ['bool'])),
                                ('neighbor_count', (YLeaf(YType.uint16, 'neighbor-count'), ['int'])),
                                ('external_neighbor_count', (YLeaf(YType.uint16, 'external-neighbor-count'), ['int'])),
                                ('hello_interval', (YLeaf(YType.uint16, 'hello-interval'), ['int'])),
                                ('dr_priority', (YLeaf(YType.uint32, 'dr-priority'), ['int'])),
                                ('hello_expiry', (YLeaf(YType.uint64, 'hello-expiry'), ['int'])),
                                ('are_we_dr', (YLeaf(YType.boolean, 'are-we-dr'), ['bool'])),
                                ('bfd_enabled', (YLeaf(YType.boolean, 'bfd-enabled'), ['bool'])),
                                ('bfd_interval', (YLeaf(YType.uint32, 'bfd-interval'), ['int'])),
                                ('bfd_multiplier', (YLeaf(YType.uint32, 'bfd-multiplier'), ['int'])),
                                ('virtual_interface', (YLeaf(YType.boolean, 'virtual-interface'), ['bool'])),
                                ('passive_interface', (YLeaf(YType.boolean, 'passive-interface'), ['bool'])),
                                ('neighbor_filter_name', (YLeaf(YType.str, 'neighbor-filter-name'), ['str'])),
                                ('join_prune_interval', (YLeaf(YType.uint16, 'join-prune-interval'), ['int'])),
                                ('prune_delay_enabled', (YLeaf(YType.boolean, 'prune-delay-enabled'), ['bool'])),
                                ('configured_propagation_delay', (YLeaf(YType.uint16, 'configured-propagation-delay'), ['int'])),
                                ('propagation_delay', (YLeaf(YType.uint16, 'propagation-delay'), ['int'])),
                                ('configured_override_interval', (YLeaf(YType.uint16, 'configured-override-interval'), ['int'])),
                                ('override_interval', (YLeaf(YType.uint16, 'override-interval'), ['int'])),
                                ('generation_id', (YLeaf(YType.uint32, 'generation-id'), ['int'])),
                                ('is_bidirectional_capable', (YLeaf(YType.boolean, 'is-bidirectional-capable'), ['bool'])),
                                ('is_proxy_capable', (YLeaf(YType.boolean, 'is-proxy-capable'), ['bool'])),
                                ('is_batch_asserts_capable', (YLeaf(YType.boolean, 'is-batch-asserts-capable'), ['bool'])),
                                ('idb_oor_enabled', (YLeaf(YType.boolean, 'idb-oor-enabled'), ['bool'])),
                                ('idb_acl_provided', (YLeaf(YType.boolean, 'idb-acl-provided'), ['bool'])),
                                ('idb_max_count', (YLeaf(YType.uint32, 'idb-max-count'), ['int'])),
                                ('idb_threshold_count', (YLeaf(YType.uint32, 'idb-threshold-count'), ['int'])),
                                ('idb_current_count', (YLeaf(YType.uint32, 'idb-current-count'), ['int'])),
                                ('idb_acl_name', (YLeaf(YType.str, 'idb-acl-name'), ['str'])),
                            ])
                            self.interface_name = None
                            self.interface_name_xr = None
                            self.interface_address_mask = None
                            self.is_enabled = None
                            self.neighbor_count = None
                            self.external_neighbor_count = None
                            self.hello_interval = None
                            self.dr_priority = None
                            self.hello_expiry = None
                            self.are_we_dr = None
                            self.bfd_enabled = None
                            self.bfd_interval = None
                            self.bfd_multiplier = None
                            self.virtual_interface = None
                            self.passive_interface = None
                            self.neighbor_filter_name = None
                            self.join_prune_interval = None
                            self.prune_delay_enabled = None
                            self.configured_propagation_delay = None
                            self.propagation_delay = None
                            self.configured_override_interval = None
                            self.override_interval = None
                            self.generation_id = None
                            self.is_bidirectional_capable = None
                            self.is_proxy_capable = None
                            self.is_batch_asserts_capable = None
                            self.idb_oor_enabled = None
                            self.idb_acl_provided = None
                            self.idb_max_count = None
                            self.idb_threshold_count = None
                            self.idb_current_count = None
                            self.idb_acl_name = None

                            self.dr_address = Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress()
                            self.dr_address.parent = self
                            self._children_name_map["dr_address"] = "dr-address"

                            self.interface_address = YList(self)
                            self._segment_path = lambda: "interface-old-format" + "[interface-name='" + str(self.interface_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat, ['interface_name', 'interface_name_xr', 'interface_address_mask', 'is_enabled', 'neighbor_count', 'external_neighbor_count', 'hello_interval', 'dr_priority', 'hello_expiry', 'are_we_dr', 'bfd_enabled', 'bfd_interval', 'bfd_multiplier', 'virtual_interface', 'passive_interface', 'neighbor_filter_name', 'join_prune_interval', 'prune_delay_enabled', 'configured_propagation_delay', 'propagation_delay', 'configured_override_interval', 'override_interval', 'generation_id', 'is_bidirectional_capable', 'is_proxy_capable', 'is_batch_asserts_capable', 'idb_oor_enabled', 'idb_acl_provided', 'idb_max_count', 'idb_threshold_count', 'idb_current_count', 'idb_acl_name'], name, value)


                        class DrAddress(Entity):
                            """
                            PIM Designated Router
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress, self).__init__()

                                self.yang_name = "dr-address"
                                self.yang_parent_name = "interface-old-format"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "dr-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class InterfaceAddress(Entity):
                            """
                            List of Interface IP Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress, self).__init__()

                                self.yang_name = "interface-address"
                                self.yang_parent_name = "interface-old-format"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "interface-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class Bsr(Entity):
                    """
                    PIM BSR information
                    
                    .. attribute:: rp_caches
                    
                    	PIM BSR RP cache table
                    	**type**\:  :py:class:`RpCaches <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches>`
                    
                    .. attribute:: candidate_rps
                    
                    	PIM candidate\-RP
                    	**type**\:  :py:class:`CandidateRps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps>`
                    
                    .. attribute:: bsr_elections
                    
                    	PIM BSR election state
                    	**type**\:  :py:class:`BsrElections <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.Bsr, self).__init__()

                        self.yang_name = "bsr"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("rp-caches", ("rp_caches", Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches)), ("candidate-rps", ("candidate_rps", Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps)), ("bsr-elections", ("bsr_elections", Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections))])
                        self._leafs = OrderedDict()

                        self.rp_caches = Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches()
                        self.rp_caches.parent = self
                        self._children_name_map["rp_caches"] = "rp-caches"

                        self.candidate_rps = Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps()
                        self.candidate_rps.parent = self
                        self._children_name_map["candidate_rps"] = "candidate-rps"

                        self.bsr_elections = Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections()
                        self.bsr_elections.parent = self
                        self._children_name_map["bsr_elections"] = "bsr-elections"
                        self._segment_path = lambda: "bsr"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Bsr, [], name, value)


                    class RpCaches(Entity):
                        """
                        PIM BSR RP cache table
                        
                        .. attribute:: rp_cache
                        
                        	PIM BSR RP cache
                        	**type**\: list of  		 :py:class:`RpCache <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches, self).__init__()

                            self.yang_name = "rp-caches"
                            self.yang_parent_name = "bsr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rp-cache", ("rp_cache", Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache))])
                            self._leafs = OrderedDict()

                            self.rp_cache = YList(self)
                            self._segment_path = lambda: "rp-caches"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches, [], name, value)


                        class RpCache(Entity):
                            """
                            PIM BSR RP cache
                            
                            .. attribute:: group_prefix  (key)
                            
                            	Group prefix
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: group_prefix_xr
                            
                            	Group Prefix
                            	**type**\:  :py:class:`GroupPrefixXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr>`
                            
                            .. attribute:: candidate_rp_list
                            
                            	C\-RP list for this prefix
                            	**type**\:  :py:class:`CandidateRpList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList>`
                            
                            .. attribute:: group_prefix_length
                            
                            	Group Prefix Length
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: candidate_rp_group_count
                            
                            	C\-RP count for this Prefix
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache, self).__init__()

                                self.yang_name = "rp-cache"
                                self.yang_parent_name = "rp-caches"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['group_prefix']
                                self._child_classes = OrderedDict([("group-prefix-xr", ("group_prefix_xr", Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr)), ("candidate-rp-list", ("candidate_rp_list", Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList))])
                                self._leafs = OrderedDict([
                                    ('group_prefix', (YLeaf(YType.str, 'group-prefix'), ['str','str'])),
                                    ('group_prefix_length', (YLeaf(YType.uint32, 'group-prefix-length'), ['int'])),
                                    ('candidate_rp_group_count', (YLeaf(YType.uint32, 'candidate-rp-group-count'), ['int'])),
                                ])
                                self.group_prefix = None
                                self.group_prefix_length = None
                                self.candidate_rp_group_count = None

                                self.group_prefix_xr = Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr()
                                self.group_prefix_xr.parent = self
                                self._children_name_map["group_prefix_xr"] = "group-prefix-xr"

                                self.candidate_rp_list = Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList()
                                self.candidate_rp_list.parent = self
                                self._children_name_map["candidate_rp_list"] = "candidate-rp-list"
                                self._segment_path = lambda: "rp-cache" + "[group-prefix='" + str(self.group_prefix) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache, ['group_prefix', 'group_prefix_length', 'candidate_rp_group_count'], name, value)


                            class GroupPrefixXr(Entity):
                                """
                                Group Prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr, self).__init__()

                                    self.yang_name = "group-prefix-xr"
                                    self.yang_parent_name = "rp-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "group-prefix-xr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                            class CandidateRpList(Entity):
                                """
                                C\-RP list for this prefix
                                
                                .. attribute:: pim_bsr_crp_bag
                                
                                	pim bsr crp bag
                                	**type**\: list of  		 :py:class:`PimBsrCrpBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList, self).__init__()

                                    self.yang_name = "candidate-rp-list"
                                    self.yang_parent_name = "rp-cache"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("pim-bsr-crp-bag", ("pim_bsr_crp_bag", Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag))])
                                    self._leafs = OrderedDict()

                                    self.pim_bsr_crp_bag = YList(self)
                                    self._segment_path = lambda: "candidate-rp-list"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList, [], name, value)


                                class PimBsrCrpBag(Entity):
                                    """
                                    pim bsr crp bag
                                    
                                    .. attribute:: candidate_rp_address
                                    
                                    	C\-RP address
                                    	**type**\:  :py:class:`CandidateRpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress>`
                                    
                                    .. attribute:: candidate_rp_holdtime
                                    
                                    	C\-RP Holdtime
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: candidate_rp_priority
                                    
                                    	C\-RP Priority
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: candidate_rp_up_time
                                    
                                    	C\-RP Uptime
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: candidate_rp_expires
                                    
                                    	C\-RP Expires
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: protocol
                                    
                                    	PIM Protocol
                                    	**type**\:  :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag, self).__init__()

                                        self.yang_name = "pim-bsr-crp-bag"
                                        self.yang_parent_name = "candidate-rp-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("candidate-rp-address", ("candidate_rp_address", Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress))])
                                        self._leafs = OrderedDict([
                                            ('candidate_rp_holdtime', (YLeaf(YType.uint16, 'candidate-rp-holdtime'), ['int'])),
                                            ('candidate_rp_priority', (YLeaf(YType.uint8, 'candidate-rp-priority'), ['int'])),
                                            ('candidate_rp_up_time', (YLeaf(YType.uint16, 'candidate-rp-up-time'), ['int'])),
                                            ('candidate_rp_expires', (YLeaf(YType.uint16, 'candidate-rp-expires'), ['int'])),
                                            ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowProtocol', '')])),
                                        ])
                                        self.candidate_rp_holdtime = None
                                        self.candidate_rp_priority = None
                                        self.candidate_rp_up_time = None
                                        self.candidate_rp_expires = None
                                        self.protocol = None

                                        self.candidate_rp_address = Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress()
                                        self.candidate_rp_address.parent = self
                                        self._children_name_map["candidate_rp_address"] = "candidate-rp-address"
                                        self._segment_path = lambda: "pim-bsr-crp-bag"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag, ['candidate_rp_holdtime', 'candidate_rp_priority', 'candidate_rp_up_time', 'candidate_rp_expires', 'protocol'], name, value)


                                    class CandidateRpAddress(Entity):
                                        """
                                        C\-RP address
                                        
                                        .. attribute:: af_name
                                        
                                        	AFName
                                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Address
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-pim-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress, self).__init__()

                                            self.yang_name = "candidate-rp-address"
                                            self.yang_parent_name = "pim-bsr-crp-bag"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                            ])
                                            self.af_name = None
                                            self.ipv4_address = None
                                            self.ipv6_address = None
                                            self._segment_path = lambda: "candidate-rp-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class CandidateRps(Entity):
                        """
                        PIM candidate\-RP
                        
                        .. attribute:: candidate_rp
                        
                        	PIM BSR candidate RP information
                        	**type**\: list of  		 :py:class:`CandidateRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps, self).__init__()

                            self.yang_name = "candidate-rps"
                            self.yang_parent_name = "bsr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("candidate-rp", ("candidate_rp", Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp))])
                            self._leafs = OrderedDict()

                            self.candidate_rp = YList(self)
                            self._segment_path = lambda: "candidate-rps"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps, [], name, value)


                        class CandidateRp(Entity):
                            """
                            PIM BSR candidate RP information
                            
                            .. attribute:: rp_address  (key)
                            
                            	Candidate\-RP address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: candidate_rp
                            
                            	Cand\-RP Address
                            	**type**\:  :py:class:`CandidateRp_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp_>`
                            
                            .. attribute:: candidate_rp_mode
                            
                            	Cand\-RP Mode
                            	**type**\:  :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                            
                            .. attribute:: candidate_rp_scope
                            
                            	Cand\-RP Scope
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: crp_priority
                            
                            	Cand\-RP Priority
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: crp_holdtime
                            
                            	Cand\-RP Holdtime
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: candidate_rp_advance_interval
                            
                            	Cand\-RP Adv Interval in seconds
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: candidate_rp_uptime
                            
                            	Cand\-RP uptime
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: acl_name
                            
                            	Group Access\-List Name
                            	**type**\: str
                            
                            	**length:** 0..33
                            
                            .. attribute:: crp_access
                            
                            	Group Ranges Using this Cand\-RP
                            	**type**\: list of  		 :py:class:`CrpAccess <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CrpAccess>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp, self).__init__()

                                self.yang_name = "candidate-rp"
                                self.yang_parent_name = "candidate-rps"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['rp_address']
                                self._child_classes = OrderedDict([("candidate-rp", ("candidate_rp", Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp_)), ("crp-access", ("crp_access", Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CrpAccess))])
                                self._leafs = OrderedDict([
                                    ('rp_address', (YLeaf(YType.str, 'rp-address'), ['str','str'])),
                                    ('candidate_rp_mode', (YLeaf(YType.enumeration, 'candidate-rp-mode'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowProtocol', '')])),
                                    ('candidate_rp_scope', (YLeaf(YType.int32, 'candidate-rp-scope'), ['int'])),
                                    ('crp_priority', (YLeaf(YType.uint8, 'crp-priority'), ['int'])),
                                    ('crp_holdtime', (YLeaf(YType.uint16, 'crp-holdtime'), ['int'])),
                                    ('candidate_rp_advance_interval', (YLeaf(YType.uint16, 'candidate-rp-advance-interval'), ['int'])),
                                    ('candidate_rp_uptime', (YLeaf(YType.uint16, 'candidate-rp-uptime'), ['int'])),
                                    ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                                ])
                                self.rp_address = None
                                self.candidate_rp_mode = None
                                self.candidate_rp_scope = None
                                self.crp_priority = None
                                self.crp_holdtime = None
                                self.candidate_rp_advance_interval = None
                                self.candidate_rp_uptime = None
                                self.acl_name = None

                                self.candidate_rp = Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp_()
                                self.candidate_rp.parent = self
                                self._children_name_map["candidate_rp"] = "candidate-rp"

                                self.crp_access = YList(self)
                                self._segment_path = lambda: "candidate-rp" + "[rp-address='" + str(self.rp_address) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp, ['rp_address', 'candidate_rp_mode', 'candidate_rp_scope', 'crp_priority', 'crp_holdtime', 'candidate_rp_advance_interval', 'candidate_rp_uptime', 'acl_name'], name, value)


                            class CandidateRp_(Entity):
                                """
                                Cand\-RP Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp_, self).__init__()

                                    self.yang_name = "candidate-rp"
                                    self.yang_parent_name = "candidate-rp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "candidate-rp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp_, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                            class CrpAccess(Entity):
                                """
                                Group Ranges Using this Cand\-RP
                                
                                .. attribute:: candidate_rp_mode
                                
                                	Cand\-RP Mode
                                	**type**\:  :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                                
                                .. attribute:: acl_name
                                
                                	Group Access\-List Name
                                	**type**\: str
                                
                                	**length:** 0..33
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CrpAccess, self).__init__()

                                    self.yang_name = "crp-access"
                                    self.yang_parent_name = "candidate-rp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('candidate_rp_mode', (YLeaf(YType.enumeration, 'candidate-rp-mode'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowProtocol', '')])),
                                        ('acl_name', (YLeaf(YType.str, 'acl-name'), ['str'])),
                                    ])
                                    self.candidate_rp_mode = None
                                    self.acl_name = None
                                    self._segment_path = lambda: "crp-access"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CrpAccess, ['candidate_rp_mode', 'acl_name'], name, value)


                    class BsrElections(Entity):
                        """
                        PIM BSR election state
                        
                        .. attribute:: bsr_election
                        
                        	PIM BSR information
                        	**type**\: list of  		 :py:class:`BsrElection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections, self).__init__()

                            self.yang_name = "bsr-elections"
                            self.yang_parent_name = "bsr"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("bsr-election", ("bsr_election", Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection))])
                            self._leafs = OrderedDict()

                            self.bsr_election = YList(self)
                            self._segment_path = lambda: "bsr-elections"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections, [], name, value)


                        class BsrElection(Entity):
                            """
                            PIM BSR information
                            
                            .. attribute:: pim_scope  (key)
                            
                            	BSR information
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bsr_address
                            
                            	BSR address
                            	**type**\:  :py:class:`BsrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress>`
                            
                            .. attribute:: candidate_bsr_address
                            
                            	C\-BSR address
                            	**type**\:  :py:class:`CandidateBsrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress>`
                            
                            .. attribute:: bsr_priority
                            
                            	BSR Priority
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: bsr_mask_length
                            
                            	Hash Function Mask Length
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: bsr_up_time
                            
                            	BSR Uptime
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: bootstrap_timeout
                            
                            	Bootstrap Timeout
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: candidate_bsr_state
                            
                            	BSR Candidate State
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bsr_election_state
                            
                            	BSR Election State
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bsr_scope
                            
                            	BSR Scope
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: candidate_bsr_flag
                            
                            	BSR Candidate Config Flag
                            	**type**\: bool
                            
                            .. attribute:: candidate_bsr_priority
                            
                            	C\-BSR Priority
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: candidate_bsr_mask_length
                            
                            	C\-BSR Hash Func. Mask Len
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection, self).__init__()

                                self.yang_name = "bsr-election"
                                self.yang_parent_name = "bsr-elections"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['pim_scope']
                                self._child_classes = OrderedDict([("bsr-address", ("bsr_address", Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress)), ("candidate-bsr-address", ("candidate_bsr_address", Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress))])
                                self._leafs = OrderedDict([
                                    ('pim_scope', (YLeaf(YType.uint32, 'pim-scope'), ['int'])),
                                    ('bsr_priority', (YLeaf(YType.uint8, 'bsr-priority'), ['int'])),
                                    ('bsr_mask_length', (YLeaf(YType.uint8, 'bsr-mask-length'), ['int'])),
                                    ('bsr_up_time', (YLeaf(YType.uint16, 'bsr-up-time'), ['int'])),
                                    ('bootstrap_timeout', (YLeaf(YType.uint16, 'bootstrap-timeout'), ['int'])),
                                    ('candidate_bsr_state', (YLeaf(YType.uint32, 'candidate-bsr-state'), ['int'])),
                                    ('bsr_election_state', (YLeaf(YType.uint32, 'bsr-election-state'), ['int'])),
                                    ('bsr_scope', (YLeaf(YType.uint16, 'bsr-scope'), ['int'])),
                                    ('candidate_bsr_flag', (YLeaf(YType.boolean, 'candidate-bsr-flag'), ['bool'])),
                                    ('candidate_bsr_priority', (YLeaf(YType.uint8, 'candidate-bsr-priority'), ['int'])),
                                    ('candidate_bsr_mask_length', (YLeaf(YType.uint8, 'candidate-bsr-mask-length'), ['int'])),
                                ])
                                self.pim_scope = None
                                self.bsr_priority = None
                                self.bsr_mask_length = None
                                self.bsr_up_time = None
                                self.bootstrap_timeout = None
                                self.candidate_bsr_state = None
                                self.bsr_election_state = None
                                self.bsr_scope = None
                                self.candidate_bsr_flag = None
                                self.candidate_bsr_priority = None
                                self.candidate_bsr_mask_length = None

                                self.bsr_address = Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress()
                                self.bsr_address.parent = self
                                self._children_name_map["bsr_address"] = "bsr-address"

                                self.candidate_bsr_address = Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress()
                                self.candidate_bsr_address.parent = self
                                self._children_name_map["candidate_bsr_address"] = "candidate-bsr-address"
                                self._segment_path = lambda: "bsr-election" + "[pim-scope='" + str(self.pim_scope) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection, ['pim_scope', 'bsr_priority', 'bsr_mask_length', 'bsr_up_time', 'bootstrap_timeout', 'candidate_bsr_state', 'bsr_election_state', 'bsr_scope', 'candidate_bsr_flag', 'candidate_bsr_priority', 'candidate_bsr_mask_length'], name, value)


                            class BsrAddress(Entity):
                                """
                                BSR address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress, self).__init__()

                                    self.yang_name = "bsr-address"
                                    self.yang_parent_name = "bsr-election"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "bsr-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                            class CandidateBsrAddress(Entity):
                                """
                                C\-BSR address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress, self).__init__()

                                    self.yang_name = "candidate-bsr-address"
                                    self.yang_parent_name = "bsr-election"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "candidate-bsr-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class RoutePolicy(Entity):
                    """
                    PIM route policy
                    
                    .. attribute:: route_policy_statistics
                    
                    	PIM route policy statistics
                    	**type**\:  :py:class:`RoutePolicyStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics>`
                    
                    .. attribute:: route_policy_tests
                    
                    	PIM route policy test run table
                    	**type**\:  :py:class:`RoutePolicyTests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy, self).__init__()

                        self.yang_name = "route-policy"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("route-policy-statistics", ("route_policy_statistics", Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics)), ("route-policy-tests", ("route_policy_tests", Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests))])
                        self._leafs = OrderedDict()

                        self.route_policy_statistics = Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics()
                        self.route_policy_statistics.parent = self
                        self._children_name_map["route_policy_statistics"] = "route-policy-statistics"

                        self.route_policy_tests = Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests()
                        self.route_policy_tests.parent = self
                        self._children_name_map["route_policy_tests"] = "route-policy-tests"
                        self._segment_path = lambda: "route-policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy, [], name, value)


                    class RoutePolicyStatistics(Entity):
                        """
                        PIM route policy statistics
                        
                        .. attribute:: policy_name
                        
                        	RPF policy name
                        	**type**\: str
                        
                        .. attribute:: requests
                        
                        	Number of RPF lookup requests
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pass_
                        
                        	Number of RPF pass
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: drop
                        
                        	Number of RPF drops
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: default_table
                        
                        	Number of RPF lookup in default\-only Table
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: any_table
                        
                        	Number of RPF lookup in any Table
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics, self).__init__()

                            self.yang_name = "route-policy-statistics"
                            self.yang_parent_name = "route-policy"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('policy_name', (YLeaf(YType.str, 'policy-name'), ['str'])),
                                ('requests', (YLeaf(YType.uint32, 'requests'), ['int'])),
                                ('pass_', (YLeaf(YType.uint32, 'pass'), ['int'])),
                                ('drop', (YLeaf(YType.uint32, 'drop'), ['int'])),
                                ('default_table', (YLeaf(YType.uint32, 'default-table'), ['int'])),
                                ('any_table', (YLeaf(YType.uint32, 'any-table'), ['int'])),
                            ])
                            self.policy_name = None
                            self.requests = None
                            self.pass_ = None
                            self.drop = None
                            self.default_table = None
                            self.any_table = None
                            self._segment_path = lambda: "route-policy-statistics"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics, ['policy_name', 'requests', 'pass_', 'drop', 'default_table', 'any_table'], name, value)


                    class RoutePolicyTests(Entity):
                        """
                        PIM route policy test run table
                        
                        .. attribute:: route_policy_test
                        
                        	PIM route policy test run
                        	**type**\: list of  		 :py:class:`RoutePolicyTest <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests, self).__init__()

                            self.yang_name = "route-policy-tests"
                            self.yang_parent_name = "route-policy"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("route-policy-test", ("route_policy_test", Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest))])
                            self._leafs = OrderedDict()

                            self.route_policy_test = YList(self)
                            self._segment_path = lambda: "route-policy-tests"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests, [], name, value)


                        class RoutePolicyTest(Entity):
                            """
                            PIM route policy test run
                            
                            .. attribute:: source_address
                            
                            	Source IP address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: group_address
                            
                            	Group IP address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ext_comm
                            
                            	Extended Community
                            	**type**\: str
                            
                            	**length:** 1..8
                            
                            .. attribute:: source_address_xr
                            
                            	Source address
                            	**type**\:  :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr>`
                            
                            .. attribute:: group_address_xr
                            
                            	Source address
                            	**type**\:  :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr>`
                            
                            .. attribute:: policy_name
                            
                            	RPF policy name
                            	**type**\: str
                            
                            .. attribute:: extended_community_rt
                            
                            	Route Target
                            	**type**\: str
                            
                            	**length:** 0..33
                            
                            .. attribute:: pass_
                            
                            	Pass
                            	**type**\: bool
                            
                            .. attribute:: default_table
                            
                            	Default table selected
                            	**type**\: bool
                            
                            .. attribute:: vrf_name
                            
                            	VRF name
                            	**type**\: str
                            
                            	**length:** 0..33
                            
                            .. attribute:: afi
                            
                            	AFI
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: safi
                            
                            	SAFI
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: table_name
                            
                            	Table name
                            	**type**\: str
                            
                            .. attribute:: table_exists
                            
                            	Table exists
                            	**type**\: bool
                            
                            .. attribute:: table_active
                            
                            	Table active
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest, self).__init__()

                                self.yang_name = "route-policy-test"
                                self.yang_parent_name = "route-policy-tests"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("source-address-xr", ("source_address_xr", Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr)), ("group-address-xr", ("group_address_xr", Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr))])
                                self._leafs = OrderedDict([
                                    ('source_address', (YLeaf(YType.str, 'source-address'), ['str','str'])),
                                    ('group_address', (YLeaf(YType.str, 'group-address'), ['str','str'])),
                                    ('ext_comm', (YLeaf(YType.str, 'ext-comm'), ['str'])),
                                    ('policy_name', (YLeaf(YType.str, 'policy-name'), ['str'])),
                                    ('extended_community_rt', (YLeaf(YType.str, 'extended-community-rt'), ['str'])),
                                    ('pass_', (YLeaf(YType.boolean, 'pass'), ['bool'])),
                                    ('default_table', (YLeaf(YType.boolean, 'default-table'), ['bool'])),
                                    ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                    ('afi', (YLeaf(YType.uint32, 'afi'), ['int'])),
                                    ('safi', (YLeaf(YType.uint32, 'safi'), ['int'])),
                                    ('table_name', (YLeaf(YType.str, 'table-name'), ['str'])),
                                    ('table_exists', (YLeaf(YType.boolean, 'table-exists'), ['bool'])),
                                    ('table_active', (YLeaf(YType.boolean, 'table-active'), ['bool'])),
                                ])
                                self.source_address = None
                                self.group_address = None
                                self.ext_comm = None
                                self.policy_name = None
                                self.extended_community_rt = None
                                self.pass_ = None
                                self.default_table = None
                                self.vrf_name = None
                                self.afi = None
                                self.safi = None
                                self.table_name = None
                                self.table_exists = None
                                self.table_active = None

                                self.source_address_xr = Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr()
                                self.source_address_xr.parent = self
                                self._children_name_map["source_address_xr"] = "source-address-xr"

                                self.group_address_xr = Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"
                                self._segment_path = lambda: "route-policy-test"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest, ['source_address', 'group_address', 'ext_comm', 'policy_name', 'extended_community_rt', 'pass_', 'default_table', 'vrf_name', 'afi', 'safi', 'table_name', 'table_exists', 'table_active'], name, value)


                            class SourceAddressXr(Entity):
                                """
                                Source address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr, self).__init__()

                                    self.yang_name = "source-address-xr"
                                    self.yang_parent_name = "route-policy-test"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "source-address-xr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                            class GroupAddressXr(Entity):
                                """
                                Source address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr, self).__init__()

                                    self.yang_name = "group-address-xr"
                                    self.yang_parent_name = "route-policy-test"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "group-address-xr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class RpfSummary(Entity):
                    """
                    PIM RPF registration summary
                    
                    .. attribute:: default_safi
                    
                    	Default RPF Table SAFI
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: default_table_name
                    
                    	Default RPF Table Name
                    	**type**\: str
                    
                    .. attribute:: is_mbgp_configured
                    
                    	Is MBGP configured?
                    	**type**\: bool
                    
                    .. attribute:: is_ospf_te_configured
                    
                    	Is OSPF TE configured?
                    	**type**\: bool
                    
                    .. attribute:: is_isis_te_configured
                    
                    	Is ISIS TE configured?
                    	**type**\: bool
                    
                    .. attribute:: is_isis_mtr_configured
                    
                    	Is ISIS MTR configured?
                    	**type**\: bool
                    
                    .. attribute:: mo_frr_configured
                    
                    	Is MoFRR configured?
                    	**type**\: bool
                    
                    .. attribute:: rib_mo_frr_configured
                    
                    	Is MoFRR RIB configured?
                    	**type**\: bool
                    
                    .. attribute:: rump_enabled
                    
                    	Is RUMP MuRIB enabled?
                    	**type**\: bool
                    
                    .. attribute:: rib_convergence_timeout
                    
                    	RIB convergence timeout in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: rib_convergence_time_left
                    
                    	RIB convergence time left in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: is_multipath_enabled
                    
                    	Is Multipath Enabled ?
                    	**type**\: bool
                    
                    .. attribute:: is_multipath_interface_hash_enabled
                    
                    	Is Multipath Interface Hash Extension Enabled ?
                    	**type**\: bool
                    
                    .. attribute:: is_multipath_source_hash_enabled
                    
                    	Is Multipath Source based Hash Enabled ?
                    	**type**\: bool
                    
                    .. attribute:: is_multipath_source_next_hop_hash_enabled
                    
                    	Is Multipath Source\-Nexthop Hash Enabled ?
                    	**type**\: bool
                    
                    .. attribute:: rpf_registrations
                    
                    	RPF Registration count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_rib_convergence
                    
                    	RIB Convergence status
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.RpfSummary, self).__init__()

                        self.yang_name = "rpf-summary"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('default_safi', (YLeaf(YType.uint32, 'default-safi'), ['int'])),
                            ('default_table_name', (YLeaf(YType.str, 'default-table-name'), ['str'])),
                            ('is_mbgp_configured', (YLeaf(YType.boolean, 'is-mbgp-configured'), ['bool'])),
                            ('is_ospf_te_configured', (YLeaf(YType.boolean, 'is-ospf-te-configured'), ['bool'])),
                            ('is_isis_te_configured', (YLeaf(YType.boolean, 'is-isis-te-configured'), ['bool'])),
                            ('is_isis_mtr_configured', (YLeaf(YType.boolean, 'is-isis-mtr-configured'), ['bool'])),
                            ('mo_frr_configured', (YLeaf(YType.boolean, 'mo-frr-configured'), ['bool'])),
                            ('rib_mo_frr_configured', (YLeaf(YType.boolean, 'rib-mo-frr-configured'), ['bool'])),
                            ('rump_enabled', (YLeaf(YType.boolean, 'rump-enabled'), ['bool'])),
                            ('rib_convergence_timeout', (YLeaf(YType.uint32, 'rib-convergence-timeout'), ['int'])),
                            ('rib_convergence_time_left', (YLeaf(YType.uint32, 'rib-convergence-time-left'), ['int'])),
                            ('is_multipath_enabled', (YLeaf(YType.boolean, 'is-multipath-enabled'), ['bool'])),
                            ('is_multipath_interface_hash_enabled', (YLeaf(YType.boolean, 'is-multipath-interface-hash-enabled'), ['bool'])),
                            ('is_multipath_source_hash_enabled', (YLeaf(YType.boolean, 'is-multipath-source-hash-enabled'), ['bool'])),
                            ('is_multipath_source_next_hop_hash_enabled', (YLeaf(YType.boolean, 'is-multipath-source-next-hop-hash-enabled'), ['bool'])),
                            ('rpf_registrations', (YLeaf(YType.uint32, 'rpf-registrations'), ['int'])),
                            ('is_rib_convergence', (YLeaf(YType.boolean, 'is-rib-convergence'), ['bool'])),
                        ])
                        self.default_safi = None
                        self.default_table_name = None
                        self.is_mbgp_configured = None
                        self.is_ospf_te_configured = None
                        self.is_isis_te_configured = None
                        self.is_isis_mtr_configured = None
                        self.mo_frr_configured = None
                        self.rib_mo_frr_configured = None
                        self.rump_enabled = None
                        self.rib_convergence_timeout = None
                        self.rib_convergence_time_left = None
                        self.is_multipath_enabled = None
                        self.is_multipath_interface_hash_enabled = None
                        self.is_multipath_source_hash_enabled = None
                        self.is_multipath_source_next_hop_hash_enabled = None
                        self.rpf_registrations = None
                        self.is_rib_convergence = None
                        self._segment_path = lambda: "rpf-summary"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.RpfSummary, ['default_safi', 'default_table_name', 'is_mbgp_configured', 'is_ospf_te_configured', 'is_isis_te_configured', 'is_isis_mtr_configured', 'mo_frr_configured', 'rib_mo_frr_configured', 'rump_enabled', 'rib_convergence_timeout', 'rib_convergence_time_left', 'is_multipath_enabled', 'is_multipath_interface_hash_enabled', 'is_multipath_source_hash_enabled', 'is_multipath_source_next_hop_hash_enabled', 'rpf_registrations', 'is_rib_convergence'], name, value)


                class Interfaces(Entity):
                    """
                    PIM interfaces
                    
                    .. attribute:: interface
                    
                    	PIM interface name
                    	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Interfaces.Interface>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.Interfaces, self).__init__()

                        self.yang_name = "interfaces"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("interface", ("interface", Ipv6Pim.Active.Vrfs.Vrf.Interfaces.Interface))])
                        self._leafs = OrderedDict()

                        self.interface = YList(self)
                        self._segment_path = lambda: "interfaces"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Interfaces, [], name, value)


                    class Interface(Entity):
                        """
                        PIM interface name
                        
                        .. attribute:: interface_name  (key)
                        
                        	Interface name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: dr_address
                        
                        	PIM Designated Router
                        	**type**\:  :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Interfaces.Interface.DrAddress>`
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identfier
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: interface_address_mask
                        
                        	Interface IP Address Mask
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: is_enabled
                        
                        	Is PIM enabled on this IF ?
                        	**type**\: bool
                        
                        .. attribute:: neighbor_count
                        
                        	No. of neighbors on this IF
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: external_neighbor_count
                        
                        	No. of external neighbors on this IF
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: hello_interval
                        
                        	Hello Interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: dr_priority
                        
                        	DR Priority
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: hello_expiry
                        
                        	Hello Timer Expiry
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: are_we_dr
                        
                        	Are we the DR on this IF ?
                        	**type**\: bool
                        
                        .. attribute:: bfd_enabled
                        
                        	BFD state
                        	**type**\: bool
                        
                        .. attribute:: bfd_interval
                        
                        	BFD Interval
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bfd_multiplier
                        
                        	BFD Multiplier
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_interface
                        
                        	 is this a Virtual Interfaces ?
                        	**type**\: bool
                        
                        .. attribute:: passive_interface
                        
                        	Passive PIM interface
                        	**type**\: bool
                        
                        .. attribute:: neighbor_filter_name
                        
                        	Neighbor Filter Name
                        	**type**\: str
                        
                        .. attribute:: join_prune_interval
                        
                        	Join\-Prune Interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: prune_delay_enabled
                        
                        	Prune Delay Enabled
                        	**type**\: bool
                        
                        .. attribute:: configured_propagation_delay
                        
                        	Configured Propagation Delay
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: configured_override_interval
                        
                        	Configured Override Interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: generation_id
                        
                        	Generation Identifier
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Bidir Capable
                        	**type**\: bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Proxy Capable
                        	**type**\: bool
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Batch Asserts Capable
                        	**type**\: bool
                        
                        .. attribute:: idb_oor_enabled
                        
                        	Interface oor enabled
                        	**type**\: bool
                        
                        .. attribute:: idb_acl_provided
                        
                        	ACL name provided
                        	**type**\: bool
                        
                        .. attribute:: idb_max_count
                        
                        	Interface ole max count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_threshold_count
                        
                        	Interface ole threshold count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_current_count
                        
                        	Interface ole current count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_acl_name
                        
                        	Interface ole ACL Name
                        	**type**\: str
                        
                        	**length:** 0..64
                        
                        .. attribute:: interface_address
                        
                        	List of Interface IP Addresses
                        	**type**\: list of  		 :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Interfaces.Interface.InterfaceAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.Interfaces.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "interfaces"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['interface_name']
                            self._child_classes = OrderedDict([("dr-address", ("dr_address", Ipv6Pim.Active.Vrfs.Vrf.Interfaces.Interface.DrAddress)), ("interface-address", ("interface_address", Ipv6Pim.Active.Vrfs.Vrf.Interfaces.Interface.InterfaceAddress))])
                            self._leafs = OrderedDict([
                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                                ('interface_address_mask', (YLeaf(YType.uint8, 'interface-address-mask'), ['int'])),
                                ('is_enabled', (YLeaf(YType.boolean, 'is-enabled'), ['bool'])),
                                ('neighbor_count', (YLeaf(YType.uint16, 'neighbor-count'), ['int'])),
                                ('external_neighbor_count', (YLeaf(YType.uint16, 'external-neighbor-count'), ['int'])),
                                ('hello_interval', (YLeaf(YType.uint16, 'hello-interval'), ['int'])),
                                ('dr_priority', (YLeaf(YType.uint32, 'dr-priority'), ['int'])),
                                ('hello_expiry', (YLeaf(YType.uint64, 'hello-expiry'), ['int'])),
                                ('are_we_dr', (YLeaf(YType.boolean, 'are-we-dr'), ['bool'])),
                                ('bfd_enabled', (YLeaf(YType.boolean, 'bfd-enabled'), ['bool'])),
                                ('bfd_interval', (YLeaf(YType.uint32, 'bfd-interval'), ['int'])),
                                ('bfd_multiplier', (YLeaf(YType.uint32, 'bfd-multiplier'), ['int'])),
                                ('virtual_interface', (YLeaf(YType.boolean, 'virtual-interface'), ['bool'])),
                                ('passive_interface', (YLeaf(YType.boolean, 'passive-interface'), ['bool'])),
                                ('neighbor_filter_name', (YLeaf(YType.str, 'neighbor-filter-name'), ['str'])),
                                ('join_prune_interval', (YLeaf(YType.uint16, 'join-prune-interval'), ['int'])),
                                ('prune_delay_enabled', (YLeaf(YType.boolean, 'prune-delay-enabled'), ['bool'])),
                                ('configured_propagation_delay', (YLeaf(YType.uint16, 'configured-propagation-delay'), ['int'])),
                                ('propagation_delay', (YLeaf(YType.uint16, 'propagation-delay'), ['int'])),
                                ('configured_override_interval', (YLeaf(YType.uint16, 'configured-override-interval'), ['int'])),
                                ('override_interval', (YLeaf(YType.uint16, 'override-interval'), ['int'])),
                                ('generation_id', (YLeaf(YType.uint32, 'generation-id'), ['int'])),
                                ('is_bidirectional_capable', (YLeaf(YType.boolean, 'is-bidirectional-capable'), ['bool'])),
                                ('is_proxy_capable', (YLeaf(YType.boolean, 'is-proxy-capable'), ['bool'])),
                                ('is_batch_asserts_capable', (YLeaf(YType.boolean, 'is-batch-asserts-capable'), ['bool'])),
                                ('idb_oor_enabled', (YLeaf(YType.boolean, 'idb-oor-enabled'), ['bool'])),
                                ('idb_acl_provided', (YLeaf(YType.boolean, 'idb-acl-provided'), ['bool'])),
                                ('idb_max_count', (YLeaf(YType.uint32, 'idb-max-count'), ['int'])),
                                ('idb_threshold_count', (YLeaf(YType.uint32, 'idb-threshold-count'), ['int'])),
                                ('idb_current_count', (YLeaf(YType.uint32, 'idb-current-count'), ['int'])),
                                ('idb_acl_name', (YLeaf(YType.str, 'idb-acl-name'), ['str'])),
                            ])
                            self.interface_name = None
                            self.interface_name_xr = None
                            self.interface_address_mask = None
                            self.is_enabled = None
                            self.neighbor_count = None
                            self.external_neighbor_count = None
                            self.hello_interval = None
                            self.dr_priority = None
                            self.hello_expiry = None
                            self.are_we_dr = None
                            self.bfd_enabled = None
                            self.bfd_interval = None
                            self.bfd_multiplier = None
                            self.virtual_interface = None
                            self.passive_interface = None
                            self.neighbor_filter_name = None
                            self.join_prune_interval = None
                            self.prune_delay_enabled = None
                            self.configured_propagation_delay = None
                            self.propagation_delay = None
                            self.configured_override_interval = None
                            self.override_interval = None
                            self.generation_id = None
                            self.is_bidirectional_capable = None
                            self.is_proxy_capable = None
                            self.is_batch_asserts_capable = None
                            self.idb_oor_enabled = None
                            self.idb_acl_provided = None
                            self.idb_max_count = None
                            self.idb_threshold_count = None
                            self.idb_current_count = None
                            self.idb_acl_name = None

                            self.dr_address = Ipv6Pim.Active.Vrfs.Vrf.Interfaces.Interface.DrAddress()
                            self.dr_address.parent = self
                            self._children_name_map["dr_address"] = "dr-address"

                            self.interface_address = YList(self)
                            self._segment_path = lambda: "interface" + "[interface-name='" + str(self.interface_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Interfaces.Interface, ['interface_name', 'interface_name_xr', 'interface_address_mask', 'is_enabled', 'neighbor_count', 'external_neighbor_count', 'hello_interval', 'dr_priority', 'hello_expiry', 'are_we_dr', 'bfd_enabled', 'bfd_interval', 'bfd_multiplier', 'virtual_interface', 'passive_interface', 'neighbor_filter_name', 'join_prune_interval', 'prune_delay_enabled', 'configured_propagation_delay', 'propagation_delay', 'configured_override_interval', 'override_interval', 'generation_id', 'is_bidirectional_capable', 'is_proxy_capable', 'is_batch_asserts_capable', 'idb_oor_enabled', 'idb_acl_provided', 'idb_max_count', 'idb_threshold_count', 'idb_current_count', 'idb_acl_name'], name, value)


                        class DrAddress(Entity):
                            """
                            PIM Designated Router
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Interfaces.Interface.DrAddress, self).__init__()

                                self.yang_name = "dr-address"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "dr-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Interfaces.Interface.DrAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class InterfaceAddress(Entity):
                            """
                            List of Interface IP Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Interfaces.Interface.InterfaceAddress, self).__init__()

                                self.yang_name = "interface-address"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "interface-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Interfaces.Interface.InterfaceAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class NetIoTunnels(Entity):
                    """
                    Tunnel information that NETIO has 
                    
                    .. attribute:: net_io_tunnel
                    
                    	PIM netio tunnel information
                    	**type**\: list of  		 :py:class:`NetIoTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels, self).__init__()

                        self.yang_name = "net-io-tunnels"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("net-io-tunnel", ("net_io_tunnel", Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel))])
                        self._leafs = OrderedDict()

                        self.net_io_tunnel = YList(self)
                        self._segment_path = lambda: "net-io-tunnels"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels, [], name, value)


                    class NetIoTunnel(Entity):
                        """
                        PIM netio tunnel information
                        
                        .. attribute:: tunnel_name  (key)
                        
                        	Tunnel name
                        	**type**\: str
                        
                        	**length:** 1..64
                        
                        .. attribute:: source_address
                        
                        	Source addr known to PIM
                        	**type**\:  :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress>`
                        
                        .. attribute:: rp_address
                        
                        	RP addr known to PIM
                        	**type**\:  :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress>`
                        
                        .. attribute:: source_address_netio
                        
                        	Source addr from netio
                        	**type**\:  :py:class:`SourceAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio>`
                        
                        .. attribute:: group_address_netio
                        
                        	Group addr from netio
                        	**type**\:  :py:class:`GroupAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio>`
                        
                        .. attribute:: vrf_name
                        
                        	VRF Name
                        	**type**\: str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel, self).__init__()

                            self.yang_name = "net-io-tunnel"
                            self.yang_parent_name = "net-io-tunnels"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['tunnel_name']
                            self._child_classes = OrderedDict([("source-address", ("source_address", Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress)), ("rp-address", ("rp_address", Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress)), ("source-address-netio", ("source_address_netio", Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio)), ("group-address-netio", ("group_address_netio", Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio))])
                            self._leafs = OrderedDict([
                                ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                            ])
                            self.tunnel_name = None
                            self.vrf_name = None

                            self.source_address = Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"

                            self.rp_address = Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"

                            self.source_address_netio = Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio()
                            self.source_address_netio.parent = self
                            self._children_name_map["source_address_netio"] = "source-address-netio"

                            self.group_address_netio = Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio()
                            self.group_address_netio.parent = self
                            self._children_name_map["group_address_netio"] = "group-address-netio"
                            self._segment_path = lambda: "net-io-tunnel" + "[tunnel-name='" + str(self.tunnel_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel, ['tunnel_name', 'vrf_name'], name, value)


                        class SourceAddress(Entity):
                            """
                            Source addr known to PIM
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "net-io-tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "source-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class RpAddress(Entity):
                            """
                            RP addr known to PIM
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "net-io-tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "rp-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class SourceAddressNetio(Entity):
                            """
                            Source addr from netio
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio, self).__init__()

                                self.yang_name = "source-address-netio"
                                self.yang_parent_name = "net-io-tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "source-address-netio"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class GroupAddressNetio(Entity):
                            """
                            Group addr from netio
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio, self).__init__()

                                self.yang_name = "group-address-netio"
                                self.yang_parent_name = "net-io-tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "group-address-netio"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class BidirDfStates(Entity):
                    """
                    Bidirectional PIM DF election state table
                    
                    .. attribute:: bidir_df_state
                    
                    	Bidirectional PIM DF Election Table Entry
                    	**type**\: list of  		 :py:class:`BidirDfState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.BidirDfStates, self).__init__()

                        self.yang_name = "bidir-df-states"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("bidir-df-state", ("bidir_df_state", Ipv6Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState))])
                        self._leafs = OrderedDict()

                        self.bidir_df_state = YList(self)
                        self._segment_path = lambda: "bidir-df-states"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.BidirDfStates, [], name, value)


                    class BidirDfState(Entity):
                        """
                        Bidirectional PIM DF Election Table Entry
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: rp_address_xr
                        
                        	RP Address
                        	**type**\:  :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr>`
                        
                        .. attribute:: pim_interface_name
                        
                        	Interface Name
                        	**type**\: str
                        
                        .. attribute:: election_state
                        
                        	DF Election State
                        	**type**\: str
                        
                        .. attribute:: time_seconds
                        
                        	Timer expires (seconds)
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: time_nano_seconds
                        
                        	Timer expires (nseconds)
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: nanosecond
                        
                        .. attribute:: our_metric
                        
                        	Metric
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: our_metric_preference
                        
                        	MetricPreference
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState, self).__init__()

                            self.yang_name = "bidir-df-state"
                            self.yang_parent_name = "bidir-df-states"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rp-address-xr", ("rp_address_xr", Ipv6Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr))])
                            self._leafs = OrderedDict([
                                ('rp_address', (YLeaf(YType.str, 'rp-address'), ['str','str'])),
                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ('pim_interface_name', (YLeaf(YType.str, 'pim-interface-name'), ['str'])),
                                ('election_state', (YLeaf(YType.str, 'election-state'), ['str'])),
                                ('time_seconds', (YLeaf(YType.uint64, 'time-seconds'), ['int'])),
                                ('time_nano_seconds', (YLeaf(YType.uint64, 'time-nano-seconds'), ['int'])),
                                ('our_metric', (YLeaf(YType.uint32, 'our-metric'), ['int'])),
                                ('our_metric_preference', (YLeaf(YType.uint32, 'our-metric-preference'), ['int'])),
                            ])
                            self.rp_address = None
                            self.interface_name = None
                            self.pim_interface_name = None
                            self.election_state = None
                            self.time_seconds = None
                            self.time_nano_seconds = None
                            self.our_metric = None
                            self.our_metric_preference = None

                            self.rp_address_xr = Ipv6Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr()
                            self.rp_address_xr.parent = self
                            self._children_name_map["rp_address_xr"] = "rp-address-xr"
                            self._segment_path = lambda: "bidir-df-state"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState, ['rp_address', 'interface_name', 'pim_interface_name', 'election_state', 'time_seconds', 'time_nano_seconds', 'our_metric', 'our_metric_preference'], name, value)


                        class RpAddressXr(Entity):
                            """
                            RP Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr, self).__init__()

                                self.yang_name = "rp-address-xr"
                                self.yang_parent_name = "bidir-df-state"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "rp-address-xr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class Topologies(Entity):
                    """
                    PIM topology table
                    
                    .. attribute:: topology
                    
                    	PIM topology information
                    	**type**\: list of  		 :py:class:`Topology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.Topologies, self).__init__()

                        self.yang_name = "topologies"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("topology", ("topology", Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology))])
                        self._leafs = OrderedDict()

                        self.topology = YList(self)
                        self._segment_path = lambda: "topologies"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Topologies, [], name, value)


                    class Topology(Entity):
                        """
                        PIM topology information
                        
                        .. attribute:: source_address
                        
                        	Source address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: group_address
                        
                        	Group address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: rpt
                        
                        	RPT bit
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:  :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.GroupAddressXr>`
                        
                        .. attribute:: source_address_xr
                        
                        	Source Address
                        	**type**\:  :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.SourceAddressXr>`
                        
                        .. attribute:: rp_address
                        
                        	RP Address (If rpt)
                        	**type**\:  :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.RpAddress>`
                        
                        .. attribute:: rpf_neighbor
                        
                        	RPF Neighbor
                        	**type**\:  :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfNeighbor>`
                        
                        .. attribute:: secondary_rpf_neighbor
                        
                        	Secondary RPF Neighbor
                        	**type**\:  :py:class:`SecondaryRpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor>`
                        
                        .. attribute:: rpf_root
                        
                        	Root of this mcast tree
                        	**type**\:  :py:class:`RpfRoot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfRoot>`
                        
                        .. attribute:: proxy_address
                        
                        	RPF Proxy address
                        	**type**\:  :py:class:`ProxyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.ProxyAddress>`
                        
                        .. attribute:: orig_src_address
                        
                        	Orig Src Address
                        	**type**\:  :py:class:`OrigSrcAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress>`
                        
                        .. attribute:: limit_reached
                        
                        	Have we throttled the creation of routes or interfaces ?
                        	**type**\: bool
                        
                        .. attribute:: low_memory
                        
                        	Node is running low on memory
                        	**type**\: bool
                        
                        .. attribute:: protocol
                        
                        	The PIM protocol
                        	**type**\:  :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: wildcard
                        
                        	WC \-Wildcard
                        	**type**\: bool
                        
                        .. attribute:: rpt_xr
                        
                        	Is this on the RPT ?
                        	**type**\: bool
                        
                        .. attribute:: spt
                        
                        	Is this on the SPT ?
                        	**type**\: bool
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: expiry
                        
                        	When this entry expires
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: alive
                        
                        	Alive time in seconds (\-1 if never)
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: register_received_timer
                        
                        	Register Received Timer in seconds (\-1 if never)
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: remote_source
                        
                        	MSDP told us
                        	**type**\: bool
                        
                        .. attribute:: crossed_threshold
                        
                        	Incoming traffic crossed threshold. MT flag set
                        	**type**\: bool
                        
                        .. attribute:: data_mdt_addr_assigned
                        
                        	PIM has assigned a Data MDT Address
                        	**type**\: bool
                        
                        .. attribute:: rpf_interface_name
                        
                        	Interface Identifier
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: rpf_vrf_name
                        
                        	RPF VRF Name
                        	**type**\: str
                        
                        	**length:** 0..33
                        
                        .. attribute:: rpf_safi
                        
                        	Unicast or mcast
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: rpf_table_name
                        
                        	RPF Table name
                        	**type**\: str
                        
                        .. attribute:: rpf_drop
                        
                        	RPF route\-policy drop
                        	**type**\: bool
                        
                        .. attribute:: rpf_extranet
                        
                        	Extranet RPF route\-policy
                        	**type**\: bool
                        
                        .. attribute:: is_via_lsm
                        
                        	Via LSM
                        	**type**\: bool
                        
                        .. attribute:: secondary_rpf_interface_name
                        
                        	Secondary Interface Identifier
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: connected
                        
                        	Is Connected ?
                        	**type**\: bool
                        
                        .. attribute:: proxy
                        
                        	Is the RPF target a proxy?
                        	**type**\: bool
                        
                        .. attribute:: rpf_proxy_enabled
                        
                        	Is rpf if proxy enabled?
                        	**type**\: bool
                        
                        .. attribute:: mofrr_enabled
                        
                        	Is this SG MoFRR enabled?
                        	**type**\: bool
                        
                        .. attribute:: rib_mo_frr_enabled
                        
                        	Is this SG MoFRR enabled?
                        	**type**\: bool
                        
                        .. attribute:: jp_timer
                        
                        	Join\-Prune Timer
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: jp_status
                        
                        	Join\-Prune Status
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: suppress_registers
                        
                        	When the Null register probe expires
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: assume_alive
                        
                        	The Assume Alive Bit
                        	**type**\: bool
                        
                        .. attribute:: probe_alive
                        
                        	The Probe Alive Bit
                        	**type**\: bool
                        
                        .. attribute:: really_alive
                        
                        	The Really Alive Bit
                        	**type**\: bool
                        
                        .. attribute:: inherit_alive
                        
                        	The Inherit Alive Bit
                        	**type**\: bool
                        
                        .. attribute:: inherit_spt
                        
                        	The Inherit SPT Bit
                        	**type**\: bool
                        
                        .. attribute:: signal_sources
                        
                        	Signal Sources on route?
                        	**type**\: bool
                        
                        .. attribute:: dont_check_connected
                        
                        	Do we need to make the connected check on this route ?
                        	**type**\: bool
                        
                        .. attribute:: register_received
                        
                        	Have registers been received for this source ?
                        	**type**\: bool
                        
                        .. attribute:: last_hop
                        
                        	Are we last hop ?
                        	**type**\: bool
                        
                        .. attribute:: sending_registers
                        
                        	Are we sending registers for this route ?
                        	**type**\: bool
                        
                        .. attribute:: sending_null_registers
                        
                        	Are we sending null registers for this route ?
                        	**type**\: bool
                        
                        .. attribute:: sa_sent
                        
                        	BGP SA sent
                        	**type**\: bool
                        
                        .. attribute:: sa_received
                        
                        	BGP SA received
                        	**type**\: bool
                        
                        .. attribute:: sa_joined
                        
                        	BGP SA join
                        	**type**\: bool
                        
                        .. attribute:: anycast_rp_match
                        
                        	Group matches Anycast\-RP policy
                        	**type**\: bool
                        
                        .. attribute:: anycast_rp_route_target
                        
                        	Anycast\-RP RT
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: bgp_join
                        
                        	BGP C JOIN
                        	**type**\: bool
                        
                        .. attribute:: bgp_jp_time
                        
                        	BGP C JP Time
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: customer_routing_type
                        
                        	Type of Customer Routing in the MVPN
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: extranet_route
                        
                        	Is a Extranet route ?
                        	**type**\: bool
                        
                        .. attribute:: mofrr_active
                        
                        	Is MoFRR Active?
                        	**type**\: bool
                        
                        .. attribute:: mofrr_primary
                        
                        	Is this Mofrr Primary?
                        	**type**\: bool
                        
                        .. attribute:: mofrr_backup
                        
                        	Is this Mofrr Backup?
                        	**type**\: bool
                        
                        .. attribute:: vxlan
                        
                        	Is this VXLAN?
                        	**type**\: bool
                        
                        .. attribute:: kat_state
                        
                        	Keep Alive Timer State
                        	**type**\: bool
                        
                        .. attribute:: outgoing_interface
                        
                        	Outgoing interface list
                        	**type**\: list of  		 :py:class:`OutgoingInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology, self).__init__()

                            self.yang_name = "topology"
                            self.yang_parent_name = "topologies"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("group-address-xr", ("group_address_xr", Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.GroupAddressXr)), ("source-address-xr", ("source_address_xr", Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.SourceAddressXr)), ("rp-address", ("rp_address", Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.RpAddress)), ("rpf-neighbor", ("rpf_neighbor", Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfNeighbor)), ("secondary-rpf-neighbor", ("secondary_rpf_neighbor", Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor)), ("rpf-root", ("rpf_root", Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfRoot)), ("proxy-address", ("proxy_address", Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.ProxyAddress)), ("orig-src-address", ("orig_src_address", Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress)), ("outgoing-interface", ("outgoing_interface", Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface))])
                            self._leafs = OrderedDict([
                                ('source_address', (YLeaf(YType.str, 'source-address'), ['str','str'])),
                                ('group_address', (YLeaf(YType.str, 'group-address'), ['str','str'])),
                                ('rpt', (YLeaf(YType.uint32, 'rpt'), ['int'])),
                                ('limit_reached', (YLeaf(YType.boolean, 'limit-reached'), ['bool'])),
                                ('low_memory', (YLeaf(YType.boolean, 'low-memory'), ['bool'])),
                                ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowProtocol', '')])),
                                ('wildcard', (YLeaf(YType.boolean, 'wildcard'), ['bool'])),
                                ('rpt_xr', (YLeaf(YType.boolean, 'rpt-xr'), ['bool'])),
                                ('spt', (YLeaf(YType.boolean, 'spt'), ['bool'])),
                                ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                                ('expiry', (YLeaf(YType.uint64, 'expiry'), ['int'])),
                                ('alive', (YLeaf(YType.int32, 'alive'), ['int'])),
                                ('register_received_timer', (YLeaf(YType.int32, 'register-received-timer'), ['int'])),
                                ('remote_source', (YLeaf(YType.boolean, 'remote-source'), ['bool'])),
                                ('crossed_threshold', (YLeaf(YType.boolean, 'crossed-threshold'), ['bool'])),
                                ('data_mdt_addr_assigned', (YLeaf(YType.boolean, 'data-mdt-addr-assigned'), ['bool'])),
                                ('rpf_interface_name', (YLeaf(YType.str, 'rpf-interface-name'), ['str'])),
                                ('rpf_vrf_name', (YLeaf(YType.str, 'rpf-vrf-name'), ['str'])),
                                ('rpf_safi', (YLeaf(YType.uint8, 'rpf-safi'), ['int'])),
                                ('rpf_table_name', (YLeaf(YType.str, 'rpf-table-name'), ['str'])),
                                ('rpf_drop', (YLeaf(YType.boolean, 'rpf-drop'), ['bool'])),
                                ('rpf_extranet', (YLeaf(YType.boolean, 'rpf-extranet'), ['bool'])),
                                ('is_via_lsm', (YLeaf(YType.boolean, 'is-via-lsm'), ['bool'])),
                                ('secondary_rpf_interface_name', (YLeaf(YType.str, 'secondary-rpf-interface-name'), ['str'])),
                                ('connected', (YLeaf(YType.boolean, 'connected'), ['bool'])),
                                ('proxy', (YLeaf(YType.boolean, 'proxy'), ['bool'])),
                                ('rpf_proxy_enabled', (YLeaf(YType.boolean, 'rpf-proxy-enabled'), ['bool'])),
                                ('mofrr_enabled', (YLeaf(YType.boolean, 'mofrr-enabled'), ['bool'])),
                                ('rib_mo_frr_enabled', (YLeaf(YType.boolean, 'rib-mo-frr-enabled'), ['bool'])),
                                ('jp_timer', (YLeaf(YType.int32, 'jp-timer'), ['int'])),
                                ('jp_status', (YLeaf(YType.int32, 'jp-status'), ['int'])),
                                ('suppress_registers', (YLeaf(YType.int32, 'suppress-registers'), ['int'])),
                                ('assume_alive', (YLeaf(YType.boolean, 'assume-alive'), ['bool'])),
                                ('probe_alive', (YLeaf(YType.boolean, 'probe-alive'), ['bool'])),
                                ('really_alive', (YLeaf(YType.boolean, 'really-alive'), ['bool'])),
                                ('inherit_alive', (YLeaf(YType.boolean, 'inherit-alive'), ['bool'])),
                                ('inherit_spt', (YLeaf(YType.boolean, 'inherit-spt'), ['bool'])),
                                ('signal_sources', (YLeaf(YType.boolean, 'signal-sources'), ['bool'])),
                                ('dont_check_connected', (YLeaf(YType.boolean, 'dont-check-connected'), ['bool'])),
                                ('register_received', (YLeaf(YType.boolean, 'register-received'), ['bool'])),
                                ('last_hop', (YLeaf(YType.boolean, 'last-hop'), ['bool'])),
                                ('sending_registers', (YLeaf(YType.boolean, 'sending-registers'), ['bool'])),
                                ('sending_null_registers', (YLeaf(YType.boolean, 'sending-null-registers'), ['bool'])),
                                ('sa_sent', (YLeaf(YType.boolean, 'sa-sent'), ['bool'])),
                                ('sa_received', (YLeaf(YType.boolean, 'sa-received'), ['bool'])),
                                ('sa_joined', (YLeaf(YType.boolean, 'sa-joined'), ['bool'])),
                                ('anycast_rp_match', (YLeaf(YType.boolean, 'anycast-rp-match'), ['bool'])),
                                ('anycast_rp_route_target', (YLeaf(YType.str, 'anycast-rp-route-target'), ['str'])),
                                ('bgp_join', (YLeaf(YType.boolean, 'bgp-join'), ['bool'])),
                                ('bgp_jp_time', (YLeaf(YType.uint64, 'bgp-jp-time'), ['int'])),
                                ('customer_routing_type', (YLeaf(YType.int32, 'customer-routing-type'), ['int'])),
                                ('extranet_route', (YLeaf(YType.boolean, 'extranet-route'), ['bool'])),
                                ('mofrr_active', (YLeaf(YType.boolean, 'mofrr-active'), ['bool'])),
                                ('mofrr_primary', (YLeaf(YType.boolean, 'mofrr-primary'), ['bool'])),
                                ('mofrr_backup', (YLeaf(YType.boolean, 'mofrr-backup'), ['bool'])),
                                ('vxlan', (YLeaf(YType.boolean, 'vxlan'), ['bool'])),
                                ('kat_state', (YLeaf(YType.boolean, 'kat-state'), ['bool'])),
                            ])
                            self.source_address = None
                            self.group_address = None
                            self.rpt = None
                            self.limit_reached = None
                            self.low_memory = None
                            self.protocol = None
                            self.wildcard = None
                            self.rpt_xr = None
                            self.spt = None
                            self.uptime = None
                            self.expiry = None
                            self.alive = None
                            self.register_received_timer = None
                            self.remote_source = None
                            self.crossed_threshold = None
                            self.data_mdt_addr_assigned = None
                            self.rpf_interface_name = None
                            self.rpf_vrf_name = None
                            self.rpf_safi = None
                            self.rpf_table_name = None
                            self.rpf_drop = None
                            self.rpf_extranet = None
                            self.is_via_lsm = None
                            self.secondary_rpf_interface_name = None
                            self.connected = None
                            self.proxy = None
                            self.rpf_proxy_enabled = None
                            self.mofrr_enabled = None
                            self.rib_mo_frr_enabled = None
                            self.jp_timer = None
                            self.jp_status = None
                            self.suppress_registers = None
                            self.assume_alive = None
                            self.probe_alive = None
                            self.really_alive = None
                            self.inherit_alive = None
                            self.inherit_spt = None
                            self.signal_sources = None
                            self.dont_check_connected = None
                            self.register_received = None
                            self.last_hop = None
                            self.sending_registers = None
                            self.sending_null_registers = None
                            self.sa_sent = None
                            self.sa_received = None
                            self.sa_joined = None
                            self.anycast_rp_match = None
                            self.anycast_rp_route_target = None
                            self.bgp_join = None
                            self.bgp_jp_time = None
                            self.customer_routing_type = None
                            self.extranet_route = None
                            self.mofrr_active = None
                            self.mofrr_primary = None
                            self.mofrr_backup = None
                            self.vxlan = None
                            self.kat_state = None

                            self.group_address_xr = Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"

                            self.source_address_xr = Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.SourceAddressXr()
                            self.source_address_xr.parent = self
                            self._children_name_map["source_address_xr"] = "source-address-xr"

                            self.rp_address = Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"

                            self.rpf_neighbor = Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfNeighbor()
                            self.rpf_neighbor.parent = self
                            self._children_name_map["rpf_neighbor"] = "rpf-neighbor"

                            self.secondary_rpf_neighbor = Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor()
                            self.secondary_rpf_neighbor.parent = self
                            self._children_name_map["secondary_rpf_neighbor"] = "secondary-rpf-neighbor"

                            self.rpf_root = Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfRoot()
                            self.rpf_root.parent = self
                            self._children_name_map["rpf_root"] = "rpf-root"

                            self.proxy_address = Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.ProxyAddress()
                            self.proxy_address.parent = self
                            self._children_name_map["proxy_address"] = "proxy-address"

                            self.orig_src_address = Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress()
                            self.orig_src_address.parent = self
                            self._children_name_map["orig_src_address"] = "orig-src-address"

                            self.outgoing_interface = YList(self)
                            self._segment_path = lambda: "topology"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology, ['source_address', 'group_address', 'rpt', 'limit_reached', 'low_memory', 'protocol', 'wildcard', 'rpt_xr', 'spt', 'uptime', 'expiry', 'alive', 'register_received_timer', 'remote_source', 'crossed_threshold', 'data_mdt_addr_assigned', 'rpf_interface_name', 'rpf_vrf_name', 'rpf_safi', 'rpf_table_name', 'rpf_drop', 'rpf_extranet', 'is_via_lsm', 'secondary_rpf_interface_name', 'connected', 'proxy', 'rpf_proxy_enabled', 'mofrr_enabled', 'rib_mo_frr_enabled', 'jp_timer', 'jp_status', 'suppress_registers', 'assume_alive', 'probe_alive', 'really_alive', 'inherit_alive', 'inherit_spt', 'signal_sources', 'dont_check_connected', 'register_received', 'last_hop', 'sending_registers', 'sending_null_registers', 'sa_sent', 'sa_received', 'sa_joined', 'anycast_rp_match', 'anycast_rp_route_target', 'bgp_join', 'bgp_jp_time', 'customer_routing_type', 'extranet_route', 'mofrr_active', 'mofrr_primary', 'mofrr_backup', 'vxlan', 'kat_state'], name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "group-address-xr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.GroupAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class SourceAddressXr(Entity):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.SourceAddressXr, self).__init__()

                                self.yang_name = "source-address-xr"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "source-address-xr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.SourceAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class RpAddress(Entity):
                            """
                            RP Address (If rpt)
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "rp-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.RpAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class RpfNeighbor(Entity):
                            """
                            RPF Neighbor
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfNeighbor, self).__init__()

                                self.yang_name = "rpf-neighbor"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "rpf-neighbor"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfNeighbor, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class SecondaryRpfNeighbor(Entity):
                            """
                            Secondary RPF Neighbor
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor, self).__init__()

                                self.yang_name = "secondary-rpf-neighbor"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "secondary-rpf-neighbor"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class RpfRoot(Entity):
                            """
                            Root of this mcast tree
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfRoot, self).__init__()

                                self.yang_name = "rpf-root"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "rpf-root"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfRoot, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class ProxyAddress(Entity):
                            """
                            RPF Proxy address.
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.ProxyAddress, self).__init__()

                                self.yang_name = "proxy-address"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "proxy-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.ProxyAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class OrigSrcAddress(Entity):
                            """
                            Orig Src Address.
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress, self).__init__()

                                self.yang_name = "orig-src-address"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "orig-src-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class OutgoingInterface(Entity):
                            """
                            Outgoing interface list
                            
                            .. attribute:: assert_winner
                            
                            	Assert Winner
                            	**type**\:  :py:class:`AssertWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner>`
                            
                            .. attribute:: interface_name
                            
                            	Interface Identifier
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: expiry
                            
                            	Expiry in seconds
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: bgp_c_mcast_prune_delay_timer
                            
                            	BGP C\-MCAST Prune Suppression in seconds
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: jp_timer
                            
                            	Join\-Prune Timer (secs)
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: second
                            
                            .. attribute:: jp_state
                            
                            	Join\-Prune State
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: assert_timer
                            
                            	Assert Timer in seconds
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: second
                            
                            .. attribute:: local_members
                            
                            	Local Information. Deprecated \- use 'local\-members\-information' instead
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: internal_interest_info
                            
                            	Internal Interest. Deprecated \- use 'internal\-interest\-information' instead
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: forwarding_state
                            
                            	Forward or Prune
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: immediate_state
                            
                            	Immediate fwding state
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: last_hop
                            
                            	Are we last hop ?
                            	**type**\: bool
                            
                            .. attribute:: mldp_inband_mdt
                            
                            	MLDP Inband MDT interface
                            	**type**\: bool
                            
                            .. attribute:: mldp_stale
                            
                            	OLE is stale
                            	**type**\: bool
                            
                            .. attribute:: sa_prune
                            
                            	BGP SA Prune state
                            	**type**\: bool
                            
                            .. attribute:: admin_boundary
                            
                            	Is this an administrative boundary ?
                            	**type**\: bool
                            
                            .. attribute:: igmp_membership
                            
                            	IGMP membership
                            	**type**\: bool
                            
                            .. attribute:: mdt_safi_join
                            
                            	MDT Safi join
                            	**type**\: bool
                            
                            .. attribute:: mvpn_safi_join
                            
                            	MVPN Safi join
                            	**type**\: bool
                            
                            .. attribute:: local_mdt_join
                            
                            	Default MDT Join
                            	**type**\: bool
                            
                            .. attribute:: data_mdt_join
                            
                            	Data MDT join
                            	**type**\: bool
                            
                            .. attribute:: mvpnv6_safi_join
                            
                            	MVPN IPv6 Safi join
                            	**type**\: bool
                            
                            .. attribute:: bgp_c_mcast_join
                            
                            	BGP C\-Mcast join
                            	**type**\: bool
                            
                            .. attribute:: vrf_name
                            
                            	VRF which physically owns
                            	**type**\: str
                            
                            	**length:** 0..33
                            
                            .. attribute:: extranet_interface
                            
                            	Is this an Extranet Interface ?
                            	**type**\: bool
                            
                            .. attribute:: internal_interest_information
                            
                            	Internal Interest. Replaces internal\-interest\-info
                            	**type**\:  :py:class:`PimInternalInterestInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimInternalInterestInfo>`
                            
                            .. attribute:: local_members_information
                            
                            	Local Information. Replaces local\-members
                            	**type**\:  :py:class:`PimShowLocalInterest <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowLocalInterest>`
                            
                            .. attribute:: assert_state
                            
                            	Assert State
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface, self).__init__()

                                self.yang_name = "outgoing-interface"
                                self.yang_parent_name = "topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("assert-winner", ("assert_winner", Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner))])
                                self._leafs = OrderedDict([
                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                    ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                                    ('expiry', (YLeaf(YType.uint64, 'expiry'), ['int'])),
                                    ('bgp_c_mcast_prune_delay_timer', (YLeaf(YType.uint64, 'bgp-c-mcast-prune-delay-timer'), ['int'])),
                                    ('jp_timer', (YLeaf(YType.int32, 'jp-timer'), ['int'])),
                                    ('jp_state', (YLeaf(YType.int32, 'jp-state'), ['int'])),
                                    ('assert_timer', (YLeaf(YType.int32, 'assert-timer'), ['int'])),
                                    ('local_members', (YLeaf(YType.int32, 'local-members'), ['int'])),
                                    ('internal_interest_info', (YLeaf(YType.int32, 'internal-interest-info'), ['int'])),
                                    ('forwarding_state', (YLeaf(YType.int32, 'forwarding-state'), ['int'])),
                                    ('immediate_state', (YLeaf(YType.int32, 'immediate-state'), ['int'])),
                                    ('last_hop', (YLeaf(YType.boolean, 'last-hop'), ['bool'])),
                                    ('mldp_inband_mdt', (YLeaf(YType.boolean, 'mldp-inband-mdt'), ['bool'])),
                                    ('mldp_stale', (YLeaf(YType.boolean, 'mldp-stale'), ['bool'])),
                                    ('sa_prune', (YLeaf(YType.boolean, 'sa-prune'), ['bool'])),
                                    ('admin_boundary', (YLeaf(YType.boolean, 'admin-boundary'), ['bool'])),
                                    ('igmp_membership', (YLeaf(YType.boolean, 'igmp-membership'), ['bool'])),
                                    ('mdt_safi_join', (YLeaf(YType.boolean, 'mdt-safi-join'), ['bool'])),
                                    ('mvpn_safi_join', (YLeaf(YType.boolean, 'mvpn-safi-join'), ['bool'])),
                                    ('local_mdt_join', (YLeaf(YType.boolean, 'local-mdt-join'), ['bool'])),
                                    ('data_mdt_join', (YLeaf(YType.boolean, 'data-mdt-join'), ['bool'])),
                                    ('mvpnv6_safi_join', (YLeaf(YType.boolean, 'mvpnv6-safi-join'), ['bool'])),
                                    ('bgp_c_mcast_join', (YLeaf(YType.boolean, 'bgp-c-mcast-join'), ['bool'])),
                                    ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                    ('extranet_interface', (YLeaf(YType.boolean, 'extranet-interface'), ['bool'])),
                                    ('internal_interest_information', (YLeaf(YType.enumeration, 'internal-interest-information'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimInternalInterestInfo', '')])),
                                    ('local_members_information', (YLeaf(YType.enumeration, 'local-members-information'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowLocalInterest', '')])),
                                    ('assert_state', (YLeaf(YType.boolean, 'assert-state'), ['bool'])),
                                ])
                                self.interface_name = None
                                self.uptime = None
                                self.expiry = None
                                self.bgp_c_mcast_prune_delay_timer = None
                                self.jp_timer = None
                                self.jp_state = None
                                self.assert_timer = None
                                self.local_members = None
                                self.internal_interest_info = None
                                self.forwarding_state = None
                                self.immediate_state = None
                                self.last_hop = None
                                self.mldp_inband_mdt = None
                                self.mldp_stale = None
                                self.sa_prune = None
                                self.admin_boundary = None
                                self.igmp_membership = None
                                self.mdt_safi_join = None
                                self.mvpn_safi_join = None
                                self.local_mdt_join = None
                                self.data_mdt_join = None
                                self.mvpnv6_safi_join = None
                                self.bgp_c_mcast_join = None
                                self.vrf_name = None
                                self.extranet_interface = None
                                self.internal_interest_information = None
                                self.local_members_information = None
                                self.assert_state = None

                                self.assert_winner = Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner()
                                self.assert_winner.parent = self
                                self._children_name_map["assert_winner"] = "assert-winner"
                                self._segment_path = lambda: "outgoing-interface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface, ['interface_name', 'uptime', 'expiry', 'bgp_c_mcast_prune_delay_timer', 'jp_timer', 'jp_state', 'assert_timer', 'local_members', 'internal_interest_info', 'forwarding_state', 'immediate_state', 'last_hop', 'mldp_inband_mdt', 'mldp_stale', 'sa_prune', 'admin_boundary', 'igmp_membership', 'mdt_safi_join', 'mvpn_safi_join', 'local_mdt_join', 'data_mdt_join', 'mvpnv6_safi_join', 'bgp_c_mcast_join', 'vrf_name', 'extranet_interface', 'internal_interest_information', 'local_members_information', 'assert_state'], name, value)


                            class AssertWinner(Entity):
                                """
                                Assert Winner
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner, self).__init__()

                                    self.yang_name = "assert-winner"
                                    self.yang_parent_name = "outgoing-interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "assert-winner"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class BgpAfs(Entity):
                    """
                    PIM BGP SAFI table
                    
                    .. attribute:: bgp_af
                    
                    	PIM BGP SAFI information
                    	**type**\: list of  		 :py:class:`BgpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.BgpAfs, self).__init__()

                        self.yang_name = "bgp-afs"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("bgp-af", ("bgp_af", Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf))])
                        self._leafs = OrderedDict()

                        self.bgp_af = YList(self)
                        self._segment_path = lambda: "bgp-afs"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.BgpAfs, [], name, value)


                    class BgpAf(Entity):
                        """
                        PIM BGP SAFI information
                        
                        .. attribute:: source_address
                        
                        	Source IP address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: group_address
                        
                        	Group IP address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source
                        
                        	Source address
                        	**type**\:  :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Source>`
                        
                        .. attribute:: group
                        
                        	Group address
                        	**type**\:  :py:class:`Group <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Group>`
                        
                        .. attribute:: next_hop
                        
                        	Next hop address
                        	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.NextHop>`
                        
                        .. attribute:: route_distinguisher
                        
                        	Router ID
                        	**type**\: str
                        
                        	**length:** 0..256
                        
                        .. attribute:: extranet_path_count
                        
                        	Count of dependent extranet paths
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_bgp_added
                        
                        	SAFI learnt from BGP
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf, self).__init__()

                            self.yang_name = "bgp-af"
                            self.yang_parent_name = "bgp-afs"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("source", ("source", Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Source)), ("group", ("group", Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Group)), ("next-hop", ("next_hop", Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.NextHop))])
                            self._leafs = OrderedDict([
                                ('source_address', (YLeaf(YType.str, 'source-address'), ['str','str'])),
                                ('group_address', (YLeaf(YType.str, 'group-address'), ['str','str'])),
                                ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                ('extranet_path_count', (YLeaf(YType.uint32, 'extranet-path-count'), ['int'])),
                                ('is_bgp_added', (YLeaf(YType.boolean, 'is-bgp-added'), ['bool'])),
                            ])
                            self.source_address = None
                            self.group_address = None
                            self.route_distinguisher = None
                            self.extranet_path_count = None
                            self.is_bgp_added = None

                            self.source = Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Source()
                            self.source.parent = self
                            self._children_name_map["source"] = "source"

                            self.group = Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Group()
                            self.group.parent = self
                            self._children_name_map["group"] = "group"

                            self.next_hop = Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.NextHop()
                            self.next_hop.parent = self
                            self._children_name_map["next_hop"] = "next-hop"
                            self._segment_path = lambda: "bgp-af"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf, ['source_address', 'group_address', 'route_distinguisher', 'extranet_path_count', 'is_bgp_added'], name, value)


                        class Source(Entity):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "bgp-af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "source"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Source, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class Group(Entity):
                            """
                            Group address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Group, self).__init__()

                                self.yang_name = "group"
                                self.yang_parent_name = "bgp-af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "group"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Group, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class NextHop(Entity):
                            """
                            Next hop address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.NextHop, self).__init__()

                                self.yang_name = "next-hop"
                                self.yang_parent_name = "bgp-af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "next-hop"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.NextHop, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class AutoRp(Entity):
                    """
                    PIM Auto\-RP information
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.AutoRp, self).__init__()

                        self.yang_name = "auto-rp"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "auto-rp"
                        self._is_frozen = True


                class TopologyInterfaceFlagRouteCounts(Entity):
                    """
                    Route count for topology with interface flag set
                    
                    .. attribute:: topology_interface_flag_route_count
                    
                    	Route count for topology with interface flag set
                    	**type**\: list of  		 :py:class:`TopologyInterfaceFlagRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts, self).__init__()

                        self.yang_name = "topology-interface-flag-route-counts"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("topology-interface-flag-route-count", ("topology_interface_flag_route_count", Ipv6Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount))])
                        self._leafs = OrderedDict()

                        self.topology_interface_flag_route_count = YList(self)
                        self._segment_path = lambda: "topology-interface-flag-route-counts"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts, [], name, value)


                    class TopologyInterfaceFlagRouteCount(Entity):
                        """
                        Route count for topology with interface flag
                        set
                        
                        .. attribute:: interface_flag  (key)
                        
                        	Interface flag
                        	**type**\:  :py:class:`PimTopologyInterfaceFlag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimTopologyInterfaceFlag>`
                        
                        .. attribute:: group_ranges
                        
                        	No. of (\*,G/M) routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: active_group_ranges
                        
                        	No. of (\*,G/M) routes active in mrib
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: groute_count
                        
                        	No. of (\*,G) routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sg_route_count
                        
                        	No. of (S,G) routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sgr_route_count
                        
                        	No. of (S,G)RPT routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_node_low_memory
                        
                        	Is node in low memory condition
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount, self).__init__()

                            self.yang_name = "topology-interface-flag-route-count"
                            self.yang_parent_name = "topology-interface-flag-route-counts"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['interface_flag']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface_flag', (YLeaf(YType.enumeration, 'interface-flag'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimTopologyInterfaceFlag', '')])),
                                ('group_ranges', (YLeaf(YType.uint32, 'group-ranges'), ['int'])),
                                ('active_group_ranges', (YLeaf(YType.uint32, 'active-group-ranges'), ['int'])),
                                ('groute_count', (YLeaf(YType.uint32, 'groute-count'), ['int'])),
                                ('sg_route_count', (YLeaf(YType.uint32, 'sg-route-count'), ['int'])),
                                ('sgr_route_count', (YLeaf(YType.uint32, 'sgr-route-count'), ['int'])),
                                ('is_node_low_memory', (YLeaf(YType.boolean, 'is-node-low-memory'), ['bool'])),
                            ])
                            self.interface_flag = None
                            self.group_ranges = None
                            self.active_group_ranges = None
                            self.groute_count = None
                            self.sg_route_count = None
                            self.sgr_route_count = None
                            self.is_node_low_memory = None
                            self._segment_path = lambda: "topology-interface-flag-route-count" + "[interface-flag='" + str(self.interface_flag) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount, ['interface_flag', 'group_ranges', 'active_group_ranges', 'groute_count', 'sg_route_count', 'sgr_route_count', 'is_node_low_memory'], name, value)


                class GroupMapSources(Entity):
                    """
                    PIM group\-mapping with source information
                    
                    .. attribute:: group_map_source
                    
                    	PIM Group Mapping Entry with source information
                    	**type**\: list of  		 :py:class:`GroupMapSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources, self).__init__()

                        self.yang_name = "group-map-sources"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("group-map-source", ("group_map_source", Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource))])
                        self._leafs = OrderedDict()

                        self.group_map_source = YList(self)
                        self._segment_path = lambda: "group-map-sources"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources, [], name, value)


                    class GroupMapSource(Entity):
                        """
                        PIM Group Mapping Entry with source information
                        
                        .. attribute:: prefix
                        
                        	Prefix
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: client
                        
                        	Client
                        	**type**\:  :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:  :py:class:`PimProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimProtocol>`
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: priority
                        
                        	RP Priority
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: source_of_information
                        
                        	The source of information
                        	**type**\:  :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation>`
                        
                        .. attribute:: group_map_information
                        
                        	Group Mapping information
                        	**type**\:  :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation>`
                        
                        .. attribute:: holdtime
                        
                        	Holdtime in seconds
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: expires
                        
                        	Mapping expiry time in seconds
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: uptime
                        
                        	Mapping uptime in seconds
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource, self).__init__()

                            self.yang_name = "group-map-source"
                            self.yang_parent_name = "group-map-sources"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("source-of-information", ("source_of_information", Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation)), ("group-map-information", ("group_map_information", Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation))])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                ('client', (YLeaf(YType.enumeration, 'client'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimClient', '')])),
                                ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimProtocol', '')])),
                                ('rp_address', (YLeaf(YType.str, 'rp-address'), ['str','str'])),
                                ('priority', (YLeaf(YType.uint32, 'priority'), ['int'])),
                                ('holdtime', (YLeaf(YType.int32, 'holdtime'), ['int'])),
                                ('expires', (YLeaf(YType.uint64, 'expires'), ['int'])),
                                ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                            ])
                            self.prefix = None
                            self.prefix_length = None
                            self.client = None
                            self.protocol = None
                            self.rp_address = None
                            self.priority = None
                            self.holdtime = None
                            self.expires = None
                            self.uptime = None

                            self.source_of_information = Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation()
                            self.source_of_information.parent = self
                            self._children_name_map["source_of_information"] = "source-of-information"

                            self.group_map_information = Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation()
                            self.group_map_information.parent = self
                            self._children_name_map["group_map_information"] = "group-map-information"
                            self._segment_path = lambda: "group-map-source"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource, ['prefix', 'prefix_length', 'client', 'protocol', 'rp_address', 'priority', 'holdtime', 'expires', 'uptime'], name, value)


                        class SourceOfInformation(Entity):
                            """
                            The source of information
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation, self).__init__()

                                self.yang_name = "source-of-information"
                                self.yang_parent_name = "group-map-source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "source-of-information"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class GroupMapInformation(Entity):
                            """
                            Group Mapping information
                            
                            .. attribute:: prefix
                            
                            	Group range prefix
                            	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix>`
                            
                            .. attribute:: rp_address
                            
                            	Rendezvous Point Address
                            	**type**\:  :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress>`
                            
                            .. attribute:: prefix_length
                            
                            	Group range prefix length
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: client
                            
                            	Client mapping learnt from
                            	**type**\:  :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                            
                            .. attribute:: protocol
                            
                            	Protocol mode of the range
                            	**type**\:  :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                            
                            .. attribute:: group_count
                            
                            	No. of groups in this range
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_used
                            
                            	Is this mapping being used?
                            	**type**\: bool
                            
                            .. attribute:: mrib_active
                            
                            	Is this mapping active in MRIB?
                            	**type**\: bool
                            
                            .. attribute:: is_override
                            
                            	Is this the override range?
                            	**type**\: bool
                            
                            .. attribute:: priority
                            
                            	Bootstrap priority
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation, self).__init__()

                                self.yang_name = "group-map-information"
                                self.yang_parent_name = "group-map-source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("prefix", ("prefix", Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix)), ("rp-address", ("rp_address", Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress))])
                                self._leafs = OrderedDict([
                                    ('prefix_length', (YLeaf(YType.int32, 'prefix-length'), ['int'])),
                                    ('client', (YLeaf(YType.enumeration, 'client'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowRangeClient', '')])),
                                    ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowProtocol', '')])),
                                    ('group_count', (YLeaf(YType.uint32, 'group-count'), ['int'])),
                                    ('is_used', (YLeaf(YType.boolean, 'is-used'), ['bool'])),
                                    ('mrib_active', (YLeaf(YType.boolean, 'mrib-active'), ['bool'])),
                                    ('is_override', (YLeaf(YType.boolean, 'is-override'), ['bool'])),
                                    ('priority', (YLeaf(YType.uint32, 'priority'), ['int'])),
                                ])
                                self.prefix_length = None
                                self.client = None
                                self.protocol = None
                                self.group_count = None
                                self.is_used = None
                                self.mrib_active = None
                                self.is_override = None
                                self.priority = None

                                self.prefix = Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix()
                                self.prefix.parent = self
                                self._children_name_map["prefix"] = "prefix"

                                self.rp_address = Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress()
                                self.rp_address.parent = self
                                self._children_name_map["rp_address"] = "rp-address"
                                self._segment_path = lambda: "group-map-information"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation, ['prefix_length', 'client', 'protocol', 'group_count', 'is_used', 'mrib_active', 'is_override', 'priority'], name, value)


                            class Prefix(Entity):
                                """
                                Group range prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix, self).__init__()

                                    self.yang_name = "prefix"
                                    self.yang_parent_name = "group-map-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "prefix"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                            class RpAddress(Entity):
                                """
                                Rendezvous Point Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress, self).__init__()

                                    self.yang_name = "rp-address"
                                    self.yang_parent_name = "group-map-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "rp-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class TrafficCounters(Entity):
                    """
                    PIM message traffic counters
                    
                    .. attribute:: elapsed_time
                    
                    	Running time for counters in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: inputs
                    
                    	Packets in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: outputs
                    
                    	Packets out
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: format_error
                    
                    	Malformed packets in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pakman_error
                    
                    	Pakman packets dropped
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: standby_packets_error
                    
                    	Packets received in standby state
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: checksum_error
                    
                    	Checksum errors
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: socket_error
                    
                    	Socket errors
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: send_queue_full
                    
                    	Packets dropped since send queue was full
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: boundary_acl_rx_drop
                    
                    	Inc. JP dropped since boundary ACL confg
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: boundary_acl_tx_drop
                    
                    	Out JP dropped since boundary ACL confg
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: no_socket_connection
                    
                    	Packets dropped since no socket connection
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: no_source_address
                    
                    	Packets dropped since no source address
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_hello
                    
                    	Hello packets in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_hello
                    
                    	Hello packets out
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_jp
                    
                    	Join Prune packets in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_jp
                    
                    	Join Prune packets out
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_data_register
                    
                    	Data Register packets in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_null_register
                    
                    	Null Register packets in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_null_register
                    
                    	Null Register packets out
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_register_stop
                    
                    	Register Stop packets in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_register_stop
                    
                    	Register Stop packets out
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_assert
                    
                    	Assert packets in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_assert_batched
                    
                    	Batched Assert packets in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_assert
                    
                    	Assert packets out
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_assert_batched
                    
                    	Batched Assert packets out
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_df_election
                    
                    	DF Election packets in
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_df_election
                    
                    	DF Election packets out
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_bsr_message
                    
                    	Input BSR Messages
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_bsr_message
                    
                    	Output BSR Messages
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_candidate_rp_advertisement
                    
                    	Input Candidate\-RP Advertisment
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_candidate_rp_advertisement
                    
                    	Output Candidate\-RP Advertisment
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_ecmp_redirect
                    
                    	Input Ecmp Redirect
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_ecmp_redirect
                    
                    	Output Ecmp Redirect
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_loop_error
                    
                    	Output on loopback error
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_invalid_lsm_identifier
                    
                    	 Invalid LSM ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_idb_error
                    
                    	No IDB for intf error
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_vrf_error
                    
                    	No VRF for idb error
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_pim_error
                    
                    	PIM Disabled on intf error
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_pim_version_error
                    
                    	Invalid PIM version error
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_join_group
                    
                    	Output Join Groups
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_prune_group
                    
                    	Output Prune Groups
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_join_prune_bytes
                    
                    	Output JP Bytes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: byte
                    
                    .. attribute:: output_hello_bytes
                    
                    	Output Hello Bytes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: byte
                    
                    .. attribute:: non_supported_packets
                    
                    	PIM non supported pckets
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_registers
                    
                    	PIM invalid registers received
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_join_prunes
                    
                    	PIM invalid Join/Prunes received
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_packman_error
                    
                    	Packets Dropped due to Pakman Error
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_read_socket_error
                    
                    	Packet Read Socket Error
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_queue_last_clear
                    
                    	Time in seconds since the last clear of all packet queues stats
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: packets_standby
                    
                    	Packets Dropped due to Standby Error
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: no_mdt_socket_connection
                    
                    	Packets dropped since no mdt socket connection
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_send_queue_full
                    
                    	Packets dropped since mdt send queue was full
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_socket_error
                    
                    	MDT Socket errors
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_join_tlv_sent
                    
                    	Data MDT Join Msgs sent
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_join_tlv_received
                    
                    	Data MDT Join Msgs received
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_join_bad_type
                    
                    	Data MDT TLV bad type
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_drop_local_source_address
                    
                    	Data MDT Join msgs dropped due to local source addr
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_drop_null_local_address
                    
                    	Data MDT Join msgs dropped due to null local addr
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_drop_no_idb
                    
                    	Data MDT Join msgs dropped due to idb missing
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_drop_no_vrf
                    
                    	Data MDT Join msgs dropped due to vrf missing
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_destination_packets
                    
                    	Control Packets with Invalid Destination
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_joins_drop_multiple_encapsulation
                    
                    	MDT Join msgs dropped due to multiple Encap limitation
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: truncated_pim_packets
                    
                    	Packets dropped due to truncated Joins or Prunes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_source_encodings
                    
                    	Number of invalid source encodings received
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_hello_options
                    
                    	Number of invalid hello options received
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_queue
                    
                    	Packet queue state and statistics
                    	**type**\: list of  		 :py:class:`PacketQueue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters, self).__init__()

                        self.yang_name = "traffic-counters"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("packet-queue", ("packet_queue", Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue))])
                        self._leafs = OrderedDict([
                            ('elapsed_time', (YLeaf(YType.uint32, 'elapsed-time'), ['int'])),
                            ('inputs', (YLeaf(YType.uint32, 'inputs'), ['int'])),
                            ('outputs', (YLeaf(YType.uint32, 'outputs'), ['int'])),
                            ('format_error', (YLeaf(YType.uint32, 'format-error'), ['int'])),
                            ('pakman_error', (YLeaf(YType.uint32, 'pakman-error'), ['int'])),
                            ('standby_packets_error', (YLeaf(YType.uint32, 'standby-packets-error'), ['int'])),
                            ('checksum_error', (YLeaf(YType.uint32, 'checksum-error'), ['int'])),
                            ('socket_error', (YLeaf(YType.uint32, 'socket-error'), ['int'])),
                            ('send_queue_full', (YLeaf(YType.uint32, 'send-queue-full'), ['int'])),
                            ('boundary_acl_rx_drop', (YLeaf(YType.uint32, 'boundary-acl-rx-drop'), ['int'])),
                            ('boundary_acl_tx_drop', (YLeaf(YType.uint32, 'boundary-acl-tx-drop'), ['int'])),
                            ('no_socket_connection', (YLeaf(YType.uint32, 'no-socket-connection'), ['int'])),
                            ('no_source_address', (YLeaf(YType.uint32, 'no-source-address'), ['int'])),
                            ('input_hello', (YLeaf(YType.uint32, 'input-hello'), ['int'])),
                            ('output_hello', (YLeaf(YType.uint32, 'output-hello'), ['int'])),
                            ('input_jp', (YLeaf(YType.uint32, 'input-jp'), ['int'])),
                            ('output_jp', (YLeaf(YType.uint32, 'output-jp'), ['int'])),
                            ('input_data_register', (YLeaf(YType.uint32, 'input-data-register'), ['int'])),
                            ('input_null_register', (YLeaf(YType.uint32, 'input-null-register'), ['int'])),
                            ('output_null_register', (YLeaf(YType.uint32, 'output-null-register'), ['int'])),
                            ('input_register_stop', (YLeaf(YType.uint32, 'input-register-stop'), ['int'])),
                            ('output_register_stop', (YLeaf(YType.uint32, 'output-register-stop'), ['int'])),
                            ('input_assert', (YLeaf(YType.uint32, 'input-assert'), ['int'])),
                            ('input_assert_batched', (YLeaf(YType.uint32, 'input-assert-batched'), ['int'])),
                            ('output_assert', (YLeaf(YType.uint32, 'output-assert'), ['int'])),
                            ('output_assert_batched', (YLeaf(YType.uint32, 'output-assert-batched'), ['int'])),
                            ('input_df_election', (YLeaf(YType.uint32, 'input-df-election'), ['int'])),
                            ('output_df_election', (YLeaf(YType.uint32, 'output-df-election'), ['int'])),
                            ('input_bsr_message', (YLeaf(YType.uint32, 'input-bsr-message'), ['int'])),
                            ('output_bsr_message', (YLeaf(YType.uint32, 'output-bsr-message'), ['int'])),
                            ('input_candidate_rp_advertisement', (YLeaf(YType.uint32, 'input-candidate-rp-advertisement'), ['int'])),
                            ('output_candidate_rp_advertisement', (YLeaf(YType.uint32, 'output-candidate-rp-advertisement'), ['int'])),
                            ('input_ecmp_redirect', (YLeaf(YType.uint32, 'input-ecmp-redirect'), ['int'])),
                            ('output_ecmp_redirect', (YLeaf(YType.uint32, 'output-ecmp-redirect'), ['int'])),
                            ('output_loop_error', (YLeaf(YType.uint32, 'output-loop-error'), ['int'])),
                            ('mldp_mdt_invalid_lsm_identifier', (YLeaf(YType.uint32, 'mldp-mdt-invalid-lsm-identifier'), ['int'])),
                            ('input_no_idb_error', (YLeaf(YType.uint32, 'input-no-idb-error'), ['int'])),
                            ('input_no_vrf_error', (YLeaf(YType.uint32, 'input-no-vrf-error'), ['int'])),
                            ('input_no_pim_error', (YLeaf(YType.uint32, 'input-no-pim-error'), ['int'])),
                            ('input_pim_version_error', (YLeaf(YType.uint32, 'input-pim-version-error'), ['int'])),
                            ('output_join_group', (YLeaf(YType.uint32, 'output-join-group'), ['int'])),
                            ('output_prune_group', (YLeaf(YType.uint32, 'output-prune-group'), ['int'])),
                            ('output_join_prune_bytes', (YLeaf(YType.uint32, 'output-join-prune-bytes'), ['int'])),
                            ('output_hello_bytes', (YLeaf(YType.uint32, 'output-hello-bytes'), ['int'])),
                            ('non_supported_packets', (YLeaf(YType.uint32, 'non-supported-packets'), ['int'])),
                            ('invalid_registers', (YLeaf(YType.uint32, 'invalid-registers'), ['int'])),
                            ('invalid_join_prunes', (YLeaf(YType.uint32, 'invalid-join-prunes'), ['int'])),
                            ('packet_packman_error', (YLeaf(YType.uint32, 'packet-packman-error'), ['int'])),
                            ('packet_read_socket_error', (YLeaf(YType.uint32, 'packet-read-socket-error'), ['int'])),
                            ('packet_queue_last_clear', (YLeaf(YType.uint32, 'packet-queue-last-clear'), ['int'])),
                            ('packets_standby', (YLeaf(YType.uint32, 'packets-standby'), ['int'])),
                            ('no_mdt_socket_connection', (YLeaf(YType.uint32, 'no-mdt-socket-connection'), ['int'])),
                            ('mdt_send_queue_full', (YLeaf(YType.uint32, 'mdt-send-queue-full'), ['int'])),
                            ('mdt_socket_error', (YLeaf(YType.uint32, 'mdt-socket-error'), ['int'])),
                            ('mdt_join_tlv_sent', (YLeaf(YType.uint32, 'mdt-join-tlv-sent'), ['int'])),
                            ('mdt_join_tlv_received', (YLeaf(YType.uint32, 'mdt-join-tlv-received'), ['int'])),
                            ('mdt_join_bad_type', (YLeaf(YType.uint32, 'mdt-join-bad-type'), ['int'])),
                            ('mdt_drop_local_source_address', (YLeaf(YType.uint32, 'mdt-drop-local-source-address'), ['int'])),
                            ('mdt_drop_null_local_address', (YLeaf(YType.uint32, 'mdt-drop-null-local-address'), ['int'])),
                            ('mdt_drop_no_idb', (YLeaf(YType.uint32, 'mdt-drop-no-idb'), ['int'])),
                            ('mdt_drop_no_vrf', (YLeaf(YType.uint32, 'mdt-drop-no-vrf'), ['int'])),
                            ('invalid_destination_packets', (YLeaf(YType.uint32, 'invalid-destination-packets'), ['int'])),
                            ('mdt_joins_drop_multiple_encapsulation', (YLeaf(YType.uint32, 'mdt-joins-drop-multiple-encapsulation'), ['int'])),
                            ('truncated_pim_packets', (YLeaf(YType.uint32, 'truncated-pim-packets'), ['int'])),
                            ('invalid_source_encodings', (YLeaf(YType.uint32, 'invalid-source-encodings'), ['int'])),
                            ('invalid_hello_options', (YLeaf(YType.uint32, 'invalid-hello-options'), ['int'])),
                        ])
                        self.elapsed_time = None
                        self.inputs = None
                        self.outputs = None
                        self.format_error = None
                        self.pakman_error = None
                        self.standby_packets_error = None
                        self.checksum_error = None
                        self.socket_error = None
                        self.send_queue_full = None
                        self.boundary_acl_rx_drop = None
                        self.boundary_acl_tx_drop = None
                        self.no_socket_connection = None
                        self.no_source_address = None
                        self.input_hello = None
                        self.output_hello = None
                        self.input_jp = None
                        self.output_jp = None
                        self.input_data_register = None
                        self.input_null_register = None
                        self.output_null_register = None
                        self.input_register_stop = None
                        self.output_register_stop = None
                        self.input_assert = None
                        self.input_assert_batched = None
                        self.output_assert = None
                        self.output_assert_batched = None
                        self.input_df_election = None
                        self.output_df_election = None
                        self.input_bsr_message = None
                        self.output_bsr_message = None
                        self.input_candidate_rp_advertisement = None
                        self.output_candidate_rp_advertisement = None
                        self.input_ecmp_redirect = None
                        self.output_ecmp_redirect = None
                        self.output_loop_error = None
                        self.mldp_mdt_invalid_lsm_identifier = None
                        self.input_no_idb_error = None
                        self.input_no_vrf_error = None
                        self.input_no_pim_error = None
                        self.input_pim_version_error = None
                        self.output_join_group = None
                        self.output_prune_group = None
                        self.output_join_prune_bytes = None
                        self.output_hello_bytes = None
                        self.non_supported_packets = None
                        self.invalid_registers = None
                        self.invalid_join_prunes = None
                        self.packet_packman_error = None
                        self.packet_read_socket_error = None
                        self.packet_queue_last_clear = None
                        self.packets_standby = None
                        self.no_mdt_socket_connection = None
                        self.mdt_send_queue_full = None
                        self.mdt_socket_error = None
                        self.mdt_join_tlv_sent = None
                        self.mdt_join_tlv_received = None
                        self.mdt_join_bad_type = None
                        self.mdt_drop_local_source_address = None
                        self.mdt_drop_null_local_address = None
                        self.mdt_drop_no_idb = None
                        self.mdt_drop_no_vrf = None
                        self.invalid_destination_packets = None
                        self.mdt_joins_drop_multiple_encapsulation = None
                        self.truncated_pim_packets = None
                        self.invalid_source_encodings = None
                        self.invalid_hello_options = None

                        self.packet_queue = YList(self)
                        self._segment_path = lambda: "traffic-counters"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters, ['elapsed_time', 'inputs', 'outputs', 'format_error', 'pakman_error', 'standby_packets_error', 'checksum_error', 'socket_error', 'send_queue_full', 'boundary_acl_rx_drop', 'boundary_acl_tx_drop', 'no_socket_connection', 'no_source_address', 'input_hello', 'output_hello', 'input_jp', 'output_jp', 'input_data_register', 'input_null_register', 'output_null_register', 'input_register_stop', 'output_register_stop', 'input_assert', 'input_assert_batched', 'output_assert', 'output_assert_batched', 'input_df_election', 'output_df_election', 'input_bsr_message', 'output_bsr_message', 'input_candidate_rp_advertisement', 'output_candidate_rp_advertisement', 'input_ecmp_redirect', 'output_ecmp_redirect', 'output_loop_error', 'mldp_mdt_invalid_lsm_identifier', 'input_no_idb_error', 'input_no_vrf_error', 'input_no_pim_error', 'input_pim_version_error', 'output_join_group', 'output_prune_group', 'output_join_prune_bytes', 'output_hello_bytes', 'non_supported_packets', 'invalid_registers', 'invalid_join_prunes', 'packet_packman_error', 'packet_read_socket_error', 'packet_queue_last_clear', 'packets_standby', 'no_mdt_socket_connection', 'mdt_send_queue_full', 'mdt_socket_error', 'mdt_join_tlv_sent', 'mdt_join_tlv_received', 'mdt_join_bad_type', 'mdt_drop_local_source_address', 'mdt_drop_null_local_address', 'mdt_drop_no_idb', 'mdt_drop_no_vrf', 'invalid_destination_packets', 'mdt_joins_drop_multiple_encapsulation', 'truncated_pim_packets', 'invalid_source_encodings', 'invalid_hello_options'], name, value)


                    class PacketQueue(Entity):
                        """
                        Packet queue state and statistics
                        
                        .. attribute:: packet_queue_state
                        
                        	State of the queue
                        	**type**\:  :py:class:`PacketQueueState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState>`
                        
                        .. attribute:: packet_queue_stats
                        
                        	Statistics about the queue
                        	**type**\:  :py:class:`PacketQueueStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats>`
                        
                        .. attribute:: packet_queue_priority
                        
                        	Priority of this packet queue
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue, self).__init__()

                            self.yang_name = "packet-queue"
                            self.yang_parent_name = "traffic-counters"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("packet-queue-state", ("packet_queue_state", Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState)), ("packet-queue-stats", ("packet_queue_stats", Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats))])
                            self._leafs = OrderedDict([
                                ('packet_queue_priority', (YLeaf(YType.uint32, 'packet-queue-priority'), ['int'])),
                            ])
                            self.packet_queue_priority = None

                            self.packet_queue_state = Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState()
                            self.packet_queue_state.parent = self
                            self._children_name_map["packet_queue_state"] = "packet-queue-state"

                            self.packet_queue_stats = Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats()
                            self.packet_queue_stats.parent = self
                            self._children_name_map["packet_queue_stats"] = "packet-queue-stats"
                            self._segment_path = lambda: "packet-queue"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue, ['packet_queue_priority'], name, value)


                        class PacketQueueState(Entity):
                            """
                            State of the queue
                            
                            .. attribute:: max_queue_size
                            
                            	Maximum size of queue in bytes
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: queue_size_bytes
                            
                            	Size of queue in bytes
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: queue_size_packets
                            
                            	Size of queue in number of packets
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState, self).__init__()

                                self.yang_name = "packet-queue-state"
                                self.yang_parent_name = "packet-queue"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('max_queue_size', (YLeaf(YType.uint32, 'max-queue-size'), ['int'])),
                                    ('queue_size_bytes', (YLeaf(YType.uint32, 'queue-size-bytes'), ['int'])),
                                    ('queue_size_packets', (YLeaf(YType.uint32, 'queue-size-packets'), ['int'])),
                                ])
                                self.max_queue_size = None
                                self.queue_size_bytes = None
                                self.queue_size_packets = None
                                self._segment_path = lambda: "packet-queue-state"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState, ['max_queue_size', 'queue_size_bytes', 'queue_size_packets'], name, value)


                        class PacketQueueStats(Entity):
                            """
                            Statistics about the queue
                            
                            .. attribute:: enqueued_packets
                            
                            	Total number of packets enqueued to this queue
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: dequeued_packets
                            
                            	Total number of packets dequeued from this queue
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: high_water_mark_packets
                            
                            	Highest number of packets enqueued in this queue
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: high_water_mark_bytes
                            
                            	Highest number of bytes enqueued in this queue
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: tail_drops
                            
                            	Number packets dropped from this queue due to max size
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats, self).__init__()

                                self.yang_name = "packet-queue-stats"
                                self.yang_parent_name = "packet-queue"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('enqueued_packets', (YLeaf(YType.uint32, 'enqueued-packets'), ['int'])),
                                    ('dequeued_packets', (YLeaf(YType.uint32, 'dequeued-packets'), ['int'])),
                                    ('high_water_mark_packets', (YLeaf(YType.uint32, 'high-water-mark-packets'), ['int'])),
                                    ('high_water_mark_bytes', (YLeaf(YType.uint32, 'high-water-mark-bytes'), ['int'])),
                                    ('tail_drops', (YLeaf(YType.uint32, 'tail-drops'), ['int'])),
                                ])
                                self.enqueued_packets = None
                                self.dequeued_packets = None
                                self.high_water_mark_packets = None
                                self.high_water_mark_bytes = None
                                self.tail_drops = None
                                self._segment_path = lambda: "packet-queue-stats"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats, ['enqueued_packets', 'dequeued_packets', 'high_water_mark_packets', 'high_water_mark_bytes', 'tail_drops'], name, value)


                class GroupMapRpfs(Entity):
                    """
                    PIM group mapping information
                    
                    .. attribute:: group_map_rpf
                    
                    	PIM group mapping entry
                    	**type**\: list of  		 :py:class:`GroupMapRpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs, self).__init__()

                        self.yang_name = "group-map-rpfs"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("group-map-rpf", ("group_map_rpf", Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf))])
                        self._leafs = OrderedDict()

                        self.group_map_rpf = YList(self)
                        self._segment_path = lambda: "group-map-rpfs"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs, [], name, value)


                    class GroupMapRpf(Entity):
                        """
                        PIM group mapping entry
                        
                        .. attribute:: prefix
                        
                        	Prefix
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: client
                        
                        	Client
                        	**type**\:  :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:  :py:class:`PimProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimProtocol>`
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: rp_priority
                        
                        	RP priority
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rpf_neighbor
                        
                        	RPF neighbor to the RP
                        	**type**\:  :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor>`
                        
                        .. attribute:: group_map_information
                        
                        	Group Mapping information
                        	**type**\:  :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation>`
                        
                        .. attribute:: are_we_rp
                        
                        	Are we the RP?
                        	**type**\: bool
                        
                        .. attribute:: rpf_interface_name
                        
                        	RPF interface to the RP
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: rpf_vrf_name
                        
                        	RPF VRF Name
                        	**type**\: str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf, self).__init__()

                            self.yang_name = "group-map-rpf"
                            self.yang_parent_name = "group-map-rpfs"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rpf-neighbor", ("rpf_neighbor", Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor)), ("group-map-information", ("group_map_information", Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation))])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                ('client', (YLeaf(YType.enumeration, 'client'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimClient', '')])),
                                ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimProtocol', '')])),
                                ('rp_address', (YLeaf(YType.str, 'rp-address'), ['str','str'])),
                                ('rp_priority', (YLeaf(YType.uint32, 'rp-priority'), ['int'])),
                                ('are_we_rp', (YLeaf(YType.boolean, 'are-we-rp'), ['bool'])),
                                ('rpf_interface_name', (YLeaf(YType.str, 'rpf-interface-name'), ['str'])),
                                ('rpf_vrf_name', (YLeaf(YType.str, 'rpf-vrf-name'), ['str'])),
                            ])
                            self.prefix = None
                            self.prefix_length = None
                            self.client = None
                            self.protocol = None
                            self.rp_address = None
                            self.rp_priority = None
                            self.are_we_rp = None
                            self.rpf_interface_name = None
                            self.rpf_vrf_name = None

                            self.rpf_neighbor = Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor()
                            self.rpf_neighbor.parent = self
                            self._children_name_map["rpf_neighbor"] = "rpf-neighbor"

                            self.group_map_information = Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation()
                            self.group_map_information.parent = self
                            self._children_name_map["group_map_information"] = "group-map-information"
                            self._segment_path = lambda: "group-map-rpf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf, ['prefix', 'prefix_length', 'client', 'protocol', 'rp_address', 'rp_priority', 'are_we_rp', 'rpf_interface_name', 'rpf_vrf_name'], name, value)


                        class RpfNeighbor(Entity):
                            """
                            RPF neighbor to the RP
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor, self).__init__()

                                self.yang_name = "rpf-neighbor"
                                self.yang_parent_name = "group-map-rpf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "rpf-neighbor"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class GroupMapInformation(Entity):
                            """
                            Group Mapping information
                            
                            .. attribute:: prefix
                            
                            	Group range prefix
                            	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix>`
                            
                            .. attribute:: rp_address
                            
                            	Rendezvous Point Address
                            	**type**\:  :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress>`
                            
                            .. attribute:: prefix_length
                            
                            	Group range prefix length
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: client
                            
                            	Client mapping learnt from
                            	**type**\:  :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                            
                            .. attribute:: protocol
                            
                            	Protocol mode of the range
                            	**type**\:  :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                            
                            .. attribute:: group_count
                            
                            	No. of groups in this range
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_used
                            
                            	Is this mapping being used?
                            	**type**\: bool
                            
                            .. attribute:: mrib_active
                            
                            	Is this mapping active in MRIB?
                            	**type**\: bool
                            
                            .. attribute:: is_override
                            
                            	Is this the override range?
                            	**type**\: bool
                            
                            .. attribute:: priority
                            
                            	Bootstrap priority
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation, self).__init__()

                                self.yang_name = "group-map-information"
                                self.yang_parent_name = "group-map-rpf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("prefix", ("prefix", Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix)), ("rp-address", ("rp_address", Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress))])
                                self._leafs = OrderedDict([
                                    ('prefix_length', (YLeaf(YType.int32, 'prefix-length'), ['int'])),
                                    ('client', (YLeaf(YType.enumeration, 'client'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowRangeClient', '')])),
                                    ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimShowProtocol', '')])),
                                    ('group_count', (YLeaf(YType.uint32, 'group-count'), ['int'])),
                                    ('is_used', (YLeaf(YType.boolean, 'is-used'), ['bool'])),
                                    ('mrib_active', (YLeaf(YType.boolean, 'mrib-active'), ['bool'])),
                                    ('is_override', (YLeaf(YType.boolean, 'is-override'), ['bool'])),
                                    ('priority', (YLeaf(YType.uint32, 'priority'), ['int'])),
                                ])
                                self.prefix_length = None
                                self.client = None
                                self.protocol = None
                                self.group_count = None
                                self.is_used = None
                                self.mrib_active = None
                                self.is_override = None
                                self.priority = None

                                self.prefix = Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix()
                                self.prefix.parent = self
                                self._children_name_map["prefix"] = "prefix"

                                self.rp_address = Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress()
                                self.rp_address.parent = self
                                self._children_name_map["rp_address"] = "rp-address"
                                self._segment_path = lambda: "group-map-information"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation, ['prefix_length', 'client', 'protocol', 'group_count', 'is_used', 'mrib_active', 'is_override', 'priority'], name, value)


                            class Prefix(Entity):
                                """
                                Group range prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix, self).__init__()

                                    self.yang_name = "prefix"
                                    self.yang_parent_name = "group-map-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "prefix"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                            class RpAddress(Entity):
                                """
                                Rendezvous Point Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress, self).__init__()

                                    self.yang_name = "rp-address"
                                    self.yang_parent_name = "group-map-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "rp-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class Summary(Entity):
                    """
                    PIM summary
                    
                    .. attribute:: route_limit
                    
                    	Maximum routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_count
                    
                    	Current routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_low_water_mark
                    
                    	The number of routes below which the throttle on route creation will be lifted
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_route_limit_reached
                    
                    	Is route creation throttled
                    	**type**\: bool
                    
                    .. attribute:: topology_interface_state_limit
                    
                    	Maximum Topology Interface State count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: topology_interface_state_count
                    
                    	Current Topology Interface State count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rxi_low_water_mark
                    
                    	The rxi below which the throttle on interface creation will be lifted
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rxi_limit_reached
                    
                    	Is interface creation throttled
                    	**type**\: bool
                    
                    .. attribute:: register_limit
                    
                    	Maximum registers
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: register_count
                    
                    	Current registers
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: register_limit_reached
                    
                    	Is PIM SM register handling throttled
                    	**type**\: bool
                    
                    .. attribute:: ranges_limit
                    
                    	Maximum group ranges from Autorp
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ranges_count
                    
                    	Current group ranges from Autorp
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ranges_threshold
                    
                    	OOR theshold of grange ranges from AutoRP
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_ranges_limit_reached
                    
                    	Is Auto\-RP group\-to\-RP mapping range creation throttled
                    	**type**\: bool
                    
                    .. attribute:: bsr_ranges_limit
                    
                    	Maximum group ranges from BSR
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_ranges_count
                    
                    	Current group ranges from BSR
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_range_threshold
                    
                    	Threshold group range from BSR
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_bsr_ranges_threshold_reached
                    
                    	Is VRF\-specific BSR group\-to\-RP mapping range creation throttled
                    	**type**\: bool
                    
                    .. attribute:: bsr_candidate_rp_set_limit
                    
                    	Maximum crp\-set from BSR
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_candidate_rp_set_count
                    
                    	Current crp\-set count from BSR
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_candidate_rp_set_threshold
                    
                    	Threshold crp\-set from BSR
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_maximum_enforcement_disabled
                    
                    	Is maximum enforcement disabled
                    	**type**\: bool
                    
                    .. attribute:: is_node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\: bool
                    
                    .. attribute:: route_threshold
                    
                    	Threshold routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_auto_rp_ranges_limit
                    
                    	Global Auto\-RP maximum group ranges
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_global_auto_rp_ranges_limit_reached
                    
                    	Is global AutoRP group\-to\-RP mapping range creation throttled
                    	**type**\: bool
                    
                    .. attribute:: global_bsr_ranges_limit
                    
                    	Global BSR maximum group ranges
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_ranges_count
                    
                    	Global BSR current group ranges
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_ranges_threshold
                    
                    	Global BSR Threshold group ranges
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_global_bsr_ranges_limit_reached
                    
                    	Is global BSR group\-to\-RP mapping range creation throttled
                    	**type**\: bool
                    
                    .. attribute:: global_bsr_candidate_rp_set_limit
                    
                    	Global BSR maximum crp\-set
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_candidate_rp_set_count
                    
                    	Global BSR current crp\-set count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_candidate_rp_set_threshold
                    
                    	Global BSR Threshold crp\-set
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_global_route_limit_reached
                    
                    	Is global route creation throttled
                    	**type**\: bool
                    
                    .. attribute:: topology_interface_state_threshold
                    
                    	Topology Interface State threshold
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_global_rxi_limit_reached
                    
                    	Is global interface creation throttled
                    	**type**\: bool
                    
                    .. attribute:: register_threshold
                    
                    	Threshold registers
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_register_limit
                    
                    	Maximum global registers
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_global_register_limit_reached
                    
                    	Is global PIM SM register handling throttled
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.Summary, self).__init__()

                        self.yang_name = "summary"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_limit', (YLeaf(YType.uint32, 'route-limit'), ['int'])),
                            ('route_count', (YLeaf(YType.uint32, 'route-count'), ['int'])),
                            ('route_low_water_mark', (YLeaf(YType.uint32, 'route-low-water-mark'), ['int'])),
                            ('is_route_limit_reached', (YLeaf(YType.boolean, 'is-route-limit-reached'), ['bool'])),
                            ('topology_interface_state_limit', (YLeaf(YType.uint32, 'topology-interface-state-limit'), ['int'])),
                            ('topology_interface_state_count', (YLeaf(YType.uint32, 'topology-interface-state-count'), ['int'])),
                            ('rxi_low_water_mark', (YLeaf(YType.uint32, 'rxi-low-water-mark'), ['int'])),
                            ('rxi_limit_reached', (YLeaf(YType.boolean, 'rxi-limit-reached'), ['bool'])),
                            ('register_limit', (YLeaf(YType.uint32, 'register-limit'), ['int'])),
                            ('register_count', (YLeaf(YType.uint32, 'register-count'), ['int'])),
                            ('register_limit_reached', (YLeaf(YType.boolean, 'register-limit-reached'), ['bool'])),
                            ('ranges_limit', (YLeaf(YType.uint32, 'ranges-limit'), ['int'])),
                            ('ranges_count', (YLeaf(YType.uint32, 'ranges-count'), ['int'])),
                            ('ranges_threshold', (YLeaf(YType.uint32, 'ranges-threshold'), ['int'])),
                            ('is_ranges_limit_reached', (YLeaf(YType.boolean, 'is-ranges-limit-reached'), ['bool'])),
                            ('bsr_ranges_limit', (YLeaf(YType.uint32, 'bsr-ranges-limit'), ['int'])),
                            ('bsr_ranges_count', (YLeaf(YType.uint32, 'bsr-ranges-count'), ['int'])),
                            ('bsr_range_threshold', (YLeaf(YType.uint32, 'bsr-range-threshold'), ['int'])),
                            ('is_bsr_ranges_threshold_reached', (YLeaf(YType.boolean, 'is-bsr-ranges-threshold-reached'), ['bool'])),
                            ('bsr_candidate_rp_set_limit', (YLeaf(YType.uint32, 'bsr-candidate-rp-set-limit'), ['int'])),
                            ('bsr_candidate_rp_set_count', (YLeaf(YType.uint32, 'bsr-candidate-rp-set-count'), ['int'])),
                            ('bsr_candidate_rp_set_threshold', (YLeaf(YType.uint32, 'bsr-candidate-rp-set-threshold'), ['int'])),
                            ('is_maximum_enforcement_disabled', (YLeaf(YType.boolean, 'is-maximum-enforcement-disabled'), ['bool'])),
                            ('is_node_low_memory', (YLeaf(YType.boolean, 'is-node-low-memory'), ['bool'])),
                            ('route_threshold', (YLeaf(YType.uint32, 'route-threshold'), ['int'])),
                            ('global_auto_rp_ranges_limit', (YLeaf(YType.uint32, 'global-auto-rp-ranges-limit'), ['int'])),
                            ('is_global_auto_rp_ranges_limit_reached', (YLeaf(YType.boolean, 'is-global-auto-rp-ranges-limit-reached'), ['bool'])),
                            ('global_bsr_ranges_limit', (YLeaf(YType.uint32, 'global-bsr-ranges-limit'), ['int'])),
                            ('global_bsr_ranges_count', (YLeaf(YType.uint32, 'global-bsr-ranges-count'), ['int'])),
                            ('global_bsr_ranges_threshold', (YLeaf(YType.uint32, 'global-bsr-ranges-threshold'), ['int'])),
                            ('is_global_bsr_ranges_limit_reached', (YLeaf(YType.boolean, 'is-global-bsr-ranges-limit-reached'), ['bool'])),
                            ('global_bsr_candidate_rp_set_limit', (YLeaf(YType.uint32, 'global-bsr-candidate-rp-set-limit'), ['int'])),
                            ('global_bsr_candidate_rp_set_count', (YLeaf(YType.uint32, 'global-bsr-candidate-rp-set-count'), ['int'])),
                            ('global_bsr_candidate_rp_set_threshold', (YLeaf(YType.uint32, 'global-bsr-candidate-rp-set-threshold'), ['int'])),
                            ('is_global_route_limit_reached', (YLeaf(YType.boolean, 'is-global-route-limit-reached'), ['bool'])),
                            ('topology_interface_state_threshold', (YLeaf(YType.uint32, 'topology-interface-state-threshold'), ['int'])),
                            ('is_global_rxi_limit_reached', (YLeaf(YType.boolean, 'is-global-rxi-limit-reached'), ['bool'])),
                            ('register_threshold', (YLeaf(YType.uint32, 'register-threshold'), ['int'])),
                            ('global_register_limit', (YLeaf(YType.uint32, 'global-register-limit'), ['int'])),
                            ('is_global_register_limit_reached', (YLeaf(YType.boolean, 'is-global-register-limit-reached'), ['bool'])),
                        ])
                        self.route_limit = None
                        self.route_count = None
                        self.route_low_water_mark = None
                        self.is_route_limit_reached = None
                        self.topology_interface_state_limit = None
                        self.topology_interface_state_count = None
                        self.rxi_low_water_mark = None
                        self.rxi_limit_reached = None
                        self.register_limit = None
                        self.register_count = None
                        self.register_limit_reached = None
                        self.ranges_limit = None
                        self.ranges_count = None
                        self.ranges_threshold = None
                        self.is_ranges_limit_reached = None
                        self.bsr_ranges_limit = None
                        self.bsr_ranges_count = None
                        self.bsr_range_threshold = None
                        self.is_bsr_ranges_threshold_reached = None
                        self.bsr_candidate_rp_set_limit = None
                        self.bsr_candidate_rp_set_count = None
                        self.bsr_candidate_rp_set_threshold = None
                        self.is_maximum_enforcement_disabled = None
                        self.is_node_low_memory = None
                        self.route_threshold = None
                        self.global_auto_rp_ranges_limit = None
                        self.is_global_auto_rp_ranges_limit_reached = None
                        self.global_bsr_ranges_limit = None
                        self.global_bsr_ranges_count = None
                        self.global_bsr_ranges_threshold = None
                        self.is_global_bsr_ranges_limit_reached = None
                        self.global_bsr_candidate_rp_set_limit = None
                        self.global_bsr_candidate_rp_set_count = None
                        self.global_bsr_candidate_rp_set_threshold = None
                        self.is_global_route_limit_reached = None
                        self.topology_interface_state_threshold = None
                        self.is_global_rxi_limit_reached = None
                        self.register_threshold = None
                        self.global_register_limit = None
                        self.is_global_register_limit_reached = None
                        self._segment_path = lambda: "summary"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Summary, ['route_limit', 'route_count', 'route_low_water_mark', 'is_route_limit_reached', 'topology_interface_state_limit', 'topology_interface_state_count', 'rxi_low_water_mark', 'rxi_limit_reached', 'register_limit', 'register_count', 'register_limit_reached', 'ranges_limit', 'ranges_count', 'ranges_threshold', 'is_ranges_limit_reached', 'bsr_ranges_limit', 'bsr_ranges_count', 'bsr_range_threshold', 'is_bsr_ranges_threshold_reached', 'bsr_candidate_rp_set_limit', 'bsr_candidate_rp_set_count', 'bsr_candidate_rp_set_threshold', 'is_maximum_enforcement_disabled', 'is_node_low_memory', 'route_threshold', 'global_auto_rp_ranges_limit', 'is_global_auto_rp_ranges_limit_reached', 'global_bsr_ranges_limit', 'global_bsr_ranges_count', 'global_bsr_ranges_threshold', 'is_global_bsr_ranges_limit_reached', 'global_bsr_candidate_rp_set_limit', 'global_bsr_candidate_rp_set_count', 'global_bsr_candidate_rp_set_threshold', 'is_global_route_limit_reached', 'topology_interface_state_threshold', 'is_global_rxi_limit_reached', 'register_threshold', 'global_register_limit', 'is_global_register_limit_reached'], name, value)


                class Gre(Entity):
                    """
                    GRE information
                    
                    .. attribute:: gre_hashes
                    
                    	GRE hash
                    	**type**\:  :py:class:`GreHashes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Gre.GreHashes>`
                    
                    .. attribute:: gre_next_hops
                    
                    	GRE destination neighbor table
                    	**type**\:  :py:class:`GreNextHops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.Gre, self).__init__()

                        self.yang_name = "gre"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("gre-hashes", ("gre_hashes", Ipv6Pim.Active.Vrfs.Vrf.Gre.GreHashes)), ("gre-next-hops", ("gre_next_hops", Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops))])
                        self._leafs = OrderedDict()

                        self.gre_hashes = Ipv6Pim.Active.Vrfs.Vrf.Gre.GreHashes()
                        self.gre_hashes.parent = self
                        self._children_name_map["gre_hashes"] = "gre-hashes"

                        self.gre_next_hops = Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops()
                        self.gre_next_hops.parent = self
                        self._children_name_map["gre_next_hops"] = "gre-next-hops"
                        self._segment_path = lambda: "gre"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Gre, [], name, value)


                    class GreHashes(Entity):
                        """
                        GRE hash
                        
                        .. attribute:: gre_hash
                        
                        	PIM GRE Hashed Underlying Interface
                        	**type**\: list of  		 :py:class:`GreHash <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Gre.GreHashes.GreHash>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.Gre.GreHashes, self).__init__()

                            self.yang_name = "gre-hashes"
                            self.yang_parent_name = "gre"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("gre-hash", ("gre_hash", Ipv6Pim.Active.Vrfs.Vrf.Gre.GreHashes.GreHash))])
                            self._leafs = OrderedDict()

                            self.gre_hash = YList(self)
                            self._segment_path = lambda: "gre-hashes"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Gre.GreHashes, [], name, value)


                        class GreHash(Entity):
                            """
                            PIM GRE Hashed Underlying Interface
                            
                            .. attribute:: source_address  (key)
                            
                            	Source address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: destination_address  (key)
                            
                            	Destination address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ifname  (key)
                            
                            	GRE Tunnel Interface
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: next_hop_interface
                            
                            	Next hop neighbor interface
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Gre.GreHashes.GreHash, self).__init__()

                                self.yang_name = "gre-hash"
                                self.yang_parent_name = "gre-hashes"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['source_address','destination_address','ifname']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('source_address', (YLeaf(YType.str, 'source-address'), ['str','str'])),
                                    ('destination_address', (YLeaf(YType.str, 'destination-address'), ['str','str'])),
                                    ('ifname', (YLeaf(YType.str, 'ifname'), ['str'])),
                                    ('next_hop_interface', (YLeaf(YType.str, 'next-hop-interface'), ['str'])),
                                ])
                                self.source_address = None
                                self.destination_address = None
                                self.ifname = None
                                self.next_hop_interface = None
                                self._segment_path = lambda: "gre-hash" + "[source-address='" + str(self.source_address) + "']" + "[destination-address='" + str(self.destination_address) + "']" + "[ifname='" + str(self.ifname) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Gre.GreHashes.GreHash, ['source_address', 'destination_address', 'ifname', 'next_hop_interface'], name, value)


                    class GreNextHops(Entity):
                        """
                        GRE destination neighbor table
                        
                        .. attribute:: gre_next_hop
                        
                        	PIM GRE address next\-hop information
                        	**type**\: list of  		 :py:class:`GreNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops, self).__init__()

                            self.yang_name = "gre-next-hops"
                            self.yang_parent_name = "gre"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("gre-next-hop", ("gre_next_hop", Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop))])
                            self._leafs = OrderedDict()

                            self.gre_next_hop = YList(self)
                            self._segment_path = lambda: "gre-next-hops"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops, [], name, value)


                        class GreNextHop(Entity):
                            """
                            PIM GRE address next\-hop information
                            
                            .. attribute:: destination_address  (key)
                            
                            	GRE destination address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: registered_address
                            
                            	Address registered
                            	**type**\:  :py:class:`RegisteredAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress>`
                            
                            .. attribute:: metric
                            
                            	Metric
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_preference
                            
                            	Metric preference
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_connected
                            
                            	Are we connected ?
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: gre_path
                            
                            	GRE Paths list
                            	**type**\: list of  		 :py:class:`GrePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop, self).__init__()

                                self.yang_name = "gre-next-hop"
                                self.yang_parent_name = "gre-next-hops"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['destination_address']
                                self._child_classes = OrderedDict([("registered-address", ("registered_address", Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress)), ("gre-path", ("gre_path", Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath))])
                                self._leafs = OrderedDict([
                                    ('destination_address', (YLeaf(YType.str, 'destination-address'), ['str','str'])),
                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                    ('metric_preference', (YLeaf(YType.uint32, 'metric-preference'), ['int'])),
                                    ('is_connected', (YLeaf(YType.uint8, 'is-connected'), ['int'])),
                                ])
                                self.destination_address = None
                                self.metric = None
                                self.metric_preference = None
                                self.is_connected = None

                                self.registered_address = Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress()
                                self.registered_address.parent = self
                                self._children_name_map["registered_address"] = "registered-address"

                                self.gre_path = YList(self)
                                self._segment_path = lambda: "gre-next-hop" + "[destination-address='" + str(self.destination_address) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop, ['destination_address', 'metric', 'metric_preference', 'is_connected'], name, value)


                            class RegisteredAddress(Entity):
                                """
                                Address registered
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress, self).__init__()

                                    self.yang_name = "registered-address"
                                    self.yang_parent_name = "gre-next-hop"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "registered-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                            class GrePath(Entity):
                                """
                                GRE Paths list
                                
                                .. attribute:: gre_neighbor
                                
                                	GRE neighbor
                                	**type**\:  :py:class:`GreNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor>`
                                
                                .. attribute:: gre_next_hop
                                
                                	GRE nexthop
                                	**type**\:  :py:class:`GreNextHop_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop_>`
                                
                                .. attribute:: gre_interface_name
                                
                                	GRE Interface
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                .. attribute:: is_gre_interface_disabled
                                
                                	Is the gre interface disabled ?
                                	**type**\: bool
                                
                                .. attribute:: is_via_lsm
                                
                                	Via LSM
                                	**type**\: bool
                                
                                .. attribute:: is_connector_attribute_present
                                
                                	Connector attribute present
                                	**type**\: bool
                                
                                .. attribute:: extranet_vrf_name
                                
                                	Extranet VRF name
                                	**type**\: str
                                
                                	**length:** 0..33
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath, self).__init__()

                                    self.yang_name = "gre-path"
                                    self.yang_parent_name = "gre-next-hop"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("gre-neighbor", ("gre_neighbor", Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor)), ("gre-next-hop", ("gre_next_hop", Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop_))])
                                    self._leafs = OrderedDict([
                                        ('gre_interface_name', (YLeaf(YType.str, 'gre-interface-name'), ['str'])),
                                        ('is_gre_interface_disabled', (YLeaf(YType.boolean, 'is-gre-interface-disabled'), ['bool'])),
                                        ('is_via_lsm', (YLeaf(YType.boolean, 'is-via-lsm'), ['bool'])),
                                        ('is_connector_attribute_present', (YLeaf(YType.boolean, 'is-connector-attribute-present'), ['bool'])),
                                        ('extranet_vrf_name', (YLeaf(YType.str, 'extranet-vrf-name'), ['str'])),
                                    ])
                                    self.gre_interface_name = None
                                    self.is_gre_interface_disabled = None
                                    self.is_via_lsm = None
                                    self.is_connector_attribute_present = None
                                    self.extranet_vrf_name = None

                                    self.gre_neighbor = Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor()
                                    self.gre_neighbor.parent = self
                                    self._children_name_map["gre_neighbor"] = "gre-neighbor"

                                    self.gre_next_hop = Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop_()
                                    self.gre_next_hop.parent = self
                                    self._children_name_map["gre_next_hop"] = "gre-next-hop"
                                    self._segment_path = lambda: "gre-path"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath, ['gre_interface_name', 'is_gre_interface_disabled', 'is_via_lsm', 'is_connector_attribute_present', 'extranet_vrf_name'], name, value)


                                class GreNeighbor(Entity):
                                    """
                                    GRE neighbor
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor, self).__init__()

                                        self.yang_name = "gre-neighbor"
                                        self.yang_parent_name = "gre-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ])
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None
                                        self._segment_path = lambda: "gre-neighbor"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                                class GreNextHop_(Entity):
                                    """
                                    GRE nexthop
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop_, self).__init__()

                                        self.yang_name = "gre-next-hop"
                                        self.yang_parent_name = "gre-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ])
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None
                                        self._segment_path = lambda: "gre-next-hop"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop_, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class BidirDfWinners(Entity):
                    """
                    Bidirectional PIM DF election winner table
                    
                    .. attribute:: bidir_df_winner
                    
                    	Bidirectional PIM DF election table entry
                    	**type**\: list of  		 :py:class:`BidirDfWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners, self).__init__()

                        self.yang_name = "bidir-df-winners"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("bidir-df-winner", ("bidir_df_winner", Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner))])
                        self._leafs = OrderedDict()

                        self.bidir_df_winner = YList(self)
                        self._segment_path = lambda: "bidir-df-winners"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners, [], name, value)


                    class BidirDfWinner(Entity):
                        """
                        Bidirectional PIM DF election table entry
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: rp_address_xr
                        
                        	RP Address
                        	**type**\:  :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr>`
                        
                        .. attribute:: df_winner
                        
                        	DF Winner
                        	**type**\:  :py:class:`DfWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner>`
                        
                        .. attribute:: pim_interface_name
                        
                        	Interface Name
                        	**type**\: str
                        
                        .. attribute:: are_we_df
                        
                        	Are we DF
                        	**type**\: bool
                        
                        .. attribute:: rp_lan
                        
                        	Is this the RP LAN
                        	**type**\: bool
                        
                        .. attribute:: metric
                        
                        	Metric
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: metric_preference
                        
                        	Metric Preference
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner, self).__init__()

                            self.yang_name = "bidir-df-winner"
                            self.yang_parent_name = "bidir-df-winners"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rp-address-xr", ("rp_address_xr", Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr)), ("df-winner", ("df_winner", Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner))])
                            self._leafs = OrderedDict([
                                ('rp_address', (YLeaf(YType.str, 'rp-address'), ['str','str'])),
                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ('pim_interface_name', (YLeaf(YType.str, 'pim-interface-name'), ['str'])),
                                ('are_we_df', (YLeaf(YType.boolean, 'are-we-df'), ['bool'])),
                                ('rp_lan', (YLeaf(YType.boolean, 'rp-lan'), ['bool'])),
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                ('metric_preference', (YLeaf(YType.uint32, 'metric-preference'), ['int'])),
                                ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                            ])
                            self.rp_address = None
                            self.interface_name = None
                            self.pim_interface_name = None
                            self.are_we_df = None
                            self.rp_lan = None
                            self.metric = None
                            self.metric_preference = None
                            self.uptime = None

                            self.rp_address_xr = Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr()
                            self.rp_address_xr.parent = self
                            self._children_name_map["rp_address_xr"] = "rp-address-xr"

                            self.df_winner = Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner()
                            self.df_winner.parent = self
                            self._children_name_map["df_winner"] = "df-winner"
                            self._segment_path = lambda: "bidir-df-winner"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner, ['rp_address', 'interface_name', 'pim_interface_name', 'are_we_df', 'rp_lan', 'metric', 'metric_preference', 'uptime'], name, value)


                        class RpAddressXr(Entity):
                            """
                            RP Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr, self).__init__()

                                self.yang_name = "rp-address-xr"
                                self.yang_parent_name = "bidir-df-winner"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "rp-address-xr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class DfWinner(Entity):
                            """
                            DF Winner
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner, self).__init__()

                                self.yang_name = "df-winner"
                                self.yang_parent_name = "bidir-df-winner"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "df-winner"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class TableContexts(Entity):
                    """
                    PIM table context list
                    
                    .. attribute:: table_context
                    
                    	PIM table context information
                    	**type**\: list of  		 :py:class:`TableContext <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.TableContexts.TableContext>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.TableContexts, self).__init__()

                        self.yang_name = "table-contexts"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("table-context", ("table_context", Ipv6Pim.Active.Vrfs.Vrf.TableContexts.TableContext))])
                        self._leafs = OrderedDict()

                        self.table_context = YList(self)
                        self._segment_path = lambda: "table-contexts"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.TableContexts, [], name, value)


                    class TableContext(Entity):
                        """
                        PIM table context information
                        
                        .. attribute:: saf_name
                        
                        	SAF name
                        	**type**\:  :py:class:`PimSafi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimSafi>`
                        
                        .. attribute:: topology_name
                        
                        	Topology name
                        	**type**\: str
                        
                        	**length:** 1..32
                        
                        .. attribute:: afi
                        
                        	AFI
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: safi
                        
                        	SAFI
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_name
                        
                        	Table name
                        	**type**\: str
                        
                        .. attribute:: vrf_id
                        
                        	VRF ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_id
                        
                        	Table ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_active
                        
                        	Active status
                        	**type**\: bool
                        
                        .. attribute:: is_ital_registration_done
                        
                        	ITAL reg status
                        	**type**\: bool
                        
                        .. attribute:: is_rib_registration_done
                        
                        	RIB reg status
                        	**type**\: bool
                        
                        .. attribute:: is_rib_convergence_received
                        
                        	RIB Convergence receive status
                        	**type**\: bool
                        
                        .. attribute:: is_rib_convergence
                        
                        	RIB Convergence status
                        	**type**\: bool
                        
                        .. attribute:: rpf_registrations
                        
                        	RPF Registration count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.TableContexts.TableContext, self).__init__()

                            self.yang_name = "table-context"
                            self.yang_parent_name = "table-contexts"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('saf_name', (YLeaf(YType.enumeration, 'saf-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimSafi', '')])),
                                ('topology_name', (YLeaf(YType.str, 'topology-name'), ['str'])),
                                ('afi', (YLeaf(YType.uint32, 'afi'), ['int'])),
                                ('safi', (YLeaf(YType.uint32, 'safi'), ['int'])),
                                ('table_name', (YLeaf(YType.str, 'table-name'), ['str'])),
                                ('vrf_id', (YLeaf(YType.uint32, 'vrf-id'), ['int'])),
                                ('table_id', (YLeaf(YType.uint32, 'table-id'), ['int'])),
                                ('is_active', (YLeaf(YType.boolean, 'is-active'), ['bool'])),
                                ('is_ital_registration_done', (YLeaf(YType.boolean, 'is-ital-registration-done'), ['bool'])),
                                ('is_rib_registration_done', (YLeaf(YType.boolean, 'is-rib-registration-done'), ['bool'])),
                                ('is_rib_convergence_received', (YLeaf(YType.boolean, 'is-rib-convergence-received'), ['bool'])),
                                ('is_rib_convergence', (YLeaf(YType.boolean, 'is-rib-convergence'), ['bool'])),
                                ('rpf_registrations', (YLeaf(YType.uint32, 'rpf-registrations'), ['int'])),
                            ])
                            self.saf_name = None
                            self.topology_name = None
                            self.afi = None
                            self.safi = None
                            self.table_name = None
                            self.vrf_id = None
                            self.table_id = None
                            self.is_active = None
                            self.is_ital_registration_done = None
                            self.is_rib_registration_done = None
                            self.is_rib_convergence_received = None
                            self.is_rib_convergence = None
                            self.rpf_registrations = None
                            self._segment_path = lambda: "table-context"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.TableContexts.TableContext, ['saf_name', 'topology_name', 'afi', 'safi', 'table_name', 'vrf_id', 'table_id', 'is_active', 'is_ital_registration_done', 'is_rib_registration_done', 'is_rib_convergence_received', 'is_rib_convergence', 'rpf_registrations'], name, value)


                class NeighborSummaries(Entity):
                    """
                    PIM neighbor summary table
                    
                    .. attribute:: neighbor_summary
                    
                    	PIM neighbor summary information
                    	**type**\: list of  		 :py:class:`NeighborSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.NeighborSummaries.NeighborSummary>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.NeighborSummaries, self).__init__()

                        self.yang_name = "neighbor-summaries"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("neighbor-summary", ("neighbor_summary", Ipv6Pim.Active.Vrfs.Vrf.NeighborSummaries.NeighborSummary))])
                        self._leafs = OrderedDict()

                        self.neighbor_summary = YList(self)
                        self._segment_path = lambda: "neighbor-summaries"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.NeighborSummaries, [], name, value)


                    class NeighborSummary(Entity):
                        """
                        PIM neighbor summary information
                        
                        .. attribute:: interface_name  (key)
                        
                        	Interface name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: number_of_neighbors
                        
                        	Number of neighbors
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: number_of_external_neighbors
                        
                        	Number of external neighbors
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.NeighborSummaries.NeighborSummary, self).__init__()

                            self.yang_name = "neighbor-summary"
                            self.yang_parent_name = "neighbor-summaries"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['interface_name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ('number_of_neighbors', (YLeaf(YType.int32, 'number-of-neighbors'), ['int'])),
                                ('number_of_external_neighbors', (YLeaf(YType.int32, 'number-of-external-neighbors'), ['int'])),
                            ])
                            self.interface_name = None
                            self.number_of_neighbors = None
                            self.number_of_external_neighbors = None
                            self._segment_path = lambda: "neighbor-summary" + "[interface-name='" + str(self.interface_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.NeighborSummaries.NeighborSummary, ['interface_name', 'number_of_neighbors', 'number_of_external_neighbors'], name, value)


                class Context(Entity):
                    """
                    PIM context information
                    
                    .. attribute:: remote_default_group
                    
                    	Remote Default Group
                    	**type**\:  :py:class:`RemoteDefaultGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Context.RemoteDefaultGroup>`
                    
                    .. attribute:: rpf_default_table
                    
                    	RPF Default Table
                    	**type**\:  :py:class:`RpfDefaultTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Context.RpfDefaultTable>`
                    
                    .. attribute:: vrf_id
                    
                    	VRF ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_id
                    
                    	Table ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: murib_id
                    
                    	MURIB ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rpf_id
                    
                    	RPF ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: remote_table_id
                    
                    	Remote Table ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_default_group
                    
                    	MDT Default group
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: mdt_source
                    
                    	MDT source
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: mdt_source_interface
                    
                    	MDT Source Interface Name
                    	**type**\: str
                    
                    .. attribute:: mdt_interface
                    
                    	MDT handle
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: mdt_gre_rpf_identifier
                    
                    	GRE\-MDT RPF Identifier
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_gre_remote_rpf_identifier
                    
                    	GRE\-MDT Remote RPF Identifier
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_unicast_rib_registration
                    
                    	Ucast RIB Registration
                    	**type**\: bool
                    
                    .. attribute:: is_multicast_rib_registration
                    
                    	Mcast RIB Registration
                    	**type**\: bool
                    
                    .. attribute:: is_active
                    
                    	Active
                    	**type**\: bool
                    
                    .. attribute:: is_active_ital
                    
                    	Active ITAL
                    	**type**\: bool
                    
                    .. attribute:: is_mrib_register
                    
                    	MRIB Register
                    	**type**\: bool
                    
                    .. attribute:: is_mdt_owner
                    
                    	MDT Owner
                    	**type**\: bool
                    
                    .. attribute:: is_routing_enabled
                    
                    	Routing Enabled
                    	**type**\: bool
                    
                    .. attribute:: is_socket_add_required
                    
                    	VRF required on Socket
                    	**type**\: bool
                    
                    .. attribute:: is_socket_added
                    
                    	VRF added on Socket
                    	**type**\: bool
                    
                    .. attribute:: is_lpts_socket_add_required
                    
                    	VRF LPTS filter required on Socket
                    	**type**\: bool
                    
                    .. attribute:: is_lpts_socket_added
                    
                    	VRF LPTS filter added on Socket
                    	**type**\: bool
                    
                    .. attribute:: is_udp_socket_add_required
                    
                    	VRF added on UDP Socket
                    	**type**\: bool
                    
                    .. attribute:: is_udp_socket_added
                    
                    	VRF added on UDP Socket
                    	**type**\: bool
                    
                    .. attribute:: is_udp_socket_bind_required
                    
                    	VRF bind required on UDP Socket
                    	**type**\: bool
                    
                    .. attribute:: is_udp_socket_bind
                    
                    	VRF bound on UDP Socket
                    	**type**\: bool
                    
                    .. attribute:: is_register_injection_socket_add_required
                    
                    	VRF required on Register Injection Socket
                    	**type**\: bool
                    
                    .. attribute:: is_register_injection_socket_added
                    
                    	VRF added on Register Injection Socket
                    	**type**\: bool
                    
                    .. attribute:: is_register_injection_lpts_socket_add_required
                    
                    	VRF LPTS filter required on Register Injection Socket
                    	**type**\: bool
                    
                    .. attribute:: is_register_injection_lpts_socket_added
                    
                    	VRF LPTS filter added on Register Injection Socket
                    	**type**\: bool
                    
                    .. attribute:: is_m_host_publish_pending
                    
                    	Publish pending for MHost Default interface
                    	**type**\: bool
                    
                    .. attribute:: mhost_interface
                    
                    	MHost handle
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: mhost_default_interface_config
                    
                    	Configured Mhost Defint
                    	**type**\: str
                    
                    .. attribute:: mdt_mtu
                    
                    	MDT MTU
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: maximum_mdt_aggregation
                    
                    	MDT max aggregation
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_data_switchover_interval
                    
                    	Data MDT Switchover interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_data_announce_interval
                    
                    	Data MDT Announce interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: non_default_vrf_count_on_socket
                    
                    	Count of non\-default vrfs on raw socket
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\: str
                    
                    .. attribute:: mdt_neighbor_filter_name
                    
                    	MDT Neighbor Filter Name
                    	**type**\: str
                    
                    .. attribute:: allow_rp_configured
                    
                    	Allow RP Configured
                    	**type**\: bool
                    
                    .. attribute:: allow_rp_group_list
                    
                    	Allow RP Group\-List ACL Name
                    	**type**\: str
                    
                    	**length:** 0..64
                    
                    .. attribute:: allow_rp_rp_list
                    
                    	Allow RP RP\-list ACL Name
                    	**type**\: str
                    
                    	**length:** 0..64
                    
                    .. attribute:: sg_expiry_timer_configured
                    
                    	S,G Expiry Timer Configured
                    	**type**\: bool
                    
                    .. attribute:: sg_expiry_time
                    
                    	S,G Expiry Time Configured, in seconds
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    	**units**\: second
                    
                    .. attribute:: sg_expiry_timer_sg_list
                    
                    	S,G expiry timer ACL name
                    	**type**\: str
                    
                    	**length:** 0..64
                    
                    .. attribute:: mldp_mdt_name
                    
                    	MLDP MDT Name
                    	**type**\: str
                    
                    .. attribute:: mldp_mdt_interface
                    
                    	MLDP MDT handle
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: mldp_mdt_mtu
                    
                    	MLDP MDT MTU
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_maximum_mdt_aggregation
                    
                    	MLDP MDT max aggregation
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_data_switchover_interval
                    
                    	MLDP Data MDT Switchover interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_data_announce_interval
                    
                    	MLDP Data MDT Announce interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_rpf_identifier
                    
                    	MLDP RPF\-ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_remote_rpf_identifier
                    
                    	MLDP Remote RPF\-ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_create_mldp_mdt_interface
                    
                    	Create MLDP MDT interface
                    	**type**\: bool
                    
                    .. attribute:: is_mldp_mdt_owner
                    
                    	MLDP MDT Owner
                    	**type**\: bool
                    
                    .. attribute:: mldp_root_count
                    
                    	MLDP Root count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_head_lsm_identifier
                    
                    	MLDP Head LSM\-ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_remote_head_lsm_identifier
                    
                    	MLDP Remote Head LSM\-ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: organization_unique_identifier
                    
                    	OUI for VPN\-ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vpn_index
                    
                    	VPN Index
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_partitioned_mdt_configured
                    
                    	MLDP Partitioned MDT
                    	**type**\: bool
                    
                    .. attribute:: mldp_remote_partitioned_mdt_configured
                    
                    	MLDP Remote Partitioned MDT
                    	**type**\: bool
                    
                    .. attribute:: mldp_partioned_mp2m_ptree
                    
                    	MP2MP Partitioned MDT tree
                    	**type**\: bool
                    
                    .. attribute:: mldp_partitioned_head_lsm_identifier
                    
                    	Partitioned MDT Head LSM\-ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_head_local_label
                    
                    	Partitioned MDT Head local label
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_partitioned_mdt_identifier
                    
                    	MLDP Partitioned MDT Identifier
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bgp_auto_discovery_configured
                    
                    	BGP Auto\-Discovery configured
                    	**type**\: bool
                    
                    .. attribute:: suppress_pim_data_mdt_tlv
                    
                    	Suppress PIM Data\-MDT TLV Announcements
                    	**type**\: bool
                    
                    .. attribute:: inter_autonomous_system_enabled
                    
                    	Inter\-AS Enabled
                    	**type**\: bool
                    
                    .. attribute:: bgp_source_active_announce
                    
                    	Send BGP Source\-Active Announcements
                    	**type**\: bool
                    
                    .. attribute:: bgp_i_pmsi_added
                    
                    	BGP I\-PMSI Added
                    	**type**\: bool
                    
                    .. attribute:: mldp_bsr_control_tree_added
                    
                    	MLDP BSR Control tree added
                    	**type**\: bool
                    
                    .. attribute:: mldp_auto_rp_discovery_tree_added
                    
                    	MLDP Autorp Discovery Control tree added
                    	**type**\: bool
                    
                    .. attribute:: mldp_auto_rp_announce_tree_added
                    
                    	MLDP Autorp Announce Control tree added
                    	**type**\: bool
                    
                    .. attribute:: bgp_auto_discovery_type
                    
                    	BGP Auto Discovery Type
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_partitioned_mdt_control_identifier
                    
                    	Partitioned MDT Control Identifier
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_partitioned_ir_control_identifier
                    
                    	Partitioned IR MDT Control Identifier
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_control_head_lsm_identifier
                    
                    	MLDP MVPN Identifier
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: umh
                    
                    	Join UMH Core\-Tree
                    	**type**\: bool
                    
                    .. attribute:: suppress_shared_tree_join
                    
                    	Suppress Shared\-Tree Joins
                    	**type**\: bool
                    
                    .. attribute:: rsvp_te_mdt_name
                    
                    	RSVP\-TE MDT Name
                    	**type**\: str
                    
                    .. attribute:: rsvp_te_mdt_interface
                    
                    	RSVP\-TEMDT handle
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: rsvp_te_mdt_mtu
                    
                    	RSVP\-TEMDT MTU
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_maximum_mdt_aggregation
                    
                    	RSVP\-TE MDT max aggregation
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_data_switchover_interval
                    
                    	RSVP\-TE Data MDT Switchover interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_data_announce_interval
                    
                    	RSVP\-TE Data MDT Announce interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_rpf_identifier
                    
                    	RSVP\-TE RPF\-ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_create_rsvp_te_mdt_interface
                    
                    	Create RSVP\-TE MDT interface
                    	**type**\: bool
                    
                    .. attribute:: is_rsvp_te_mdt_owner
                    
                    	RSVP\-TE MDT Owner
                    	**type**\: bool
                    
                    .. attribute:: rsvp_te_mdt_static_p2mp_count
                    
                    	Number of Static P2MP\-TE MDT
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: p2mpte_li_drop
                    
                    	Route LI updates dropped for P2MP
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_name
                    
                    	IR MDT Name
                    	**type**\: str
                    
                    .. attribute:: ir_mdt_interface
                    
                    	IRMDT handle
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: ir_mdt_mtu
                    
                    	IRMDT MTU
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_maximum_mdt_aggregation
                    
                    	IR MDT max aggregation
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_data_switchover_interval
                    
                    	IR Data MDT Switchover interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_data_announce_interval
                    
                    	IR Data MDT Announce interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_rpf_identifier
                    
                    	IR RPF\-ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_tail_label
                    
                    	IR Tail Label
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_create_ir_mdt_interface
                    
                    	Create IR MDT interface
                    	**type**\: bool
                    
                    .. attribute:: is_ir_mdt_owner
                    
                    	IR MDT Owner
                    	**type**\: bool
                    
                    .. attribute:: in_b_and_mdt_name
                    
                    	Inband MDT Name
                    	**type**\: str
                    
                    .. attribute:: in_b_and_mdt_interface
                    
                    	Inband MDT handle
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: in_b_and_mdt_mtu
                    
                    	Inband MDT MTU
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_band_maximum_mdt_aggregation
                    
                    	Inband MDT max aggregation
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_b_and_mdt_data_switchover_interval
                    
                    	Inband Data MDT Switchover interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_b_and_mdt_data_announce_interval
                    
                    	Inband Data MDT Announce interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_b_and_mdt_rpf_identifier
                    
                    	Inband RPF\-ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_create_in_b_and_mdt_interface
                    
                    	Create Inband MDT interface
                    	**type**\: bool
                    
                    .. attribute:: is_in_b_and_mdt_owner
                    
                    	Inband MDT Owner
                    	**type**\: bool
                    
                    .. attribute:: in_band_signaling_local_enabled
                    
                    	Inband signaling Local enabled
                    	**type**\: bool
                    
                    .. attribute:: in_band_signaling_remote_enabled
                    
                    	Inband signaling Remote enabled
                    	**type**\: bool
                    
                    .. attribute:: valid_rd_present
                    
                    	RD is valid
                    	**type**\: bool
                    
                    .. attribute:: stale_rd_present
                    
                    	RD is stale
                    	**type**\: bool
                    
                    .. attribute:: route_distinguisher
                    
                    	RD value
                    	**type**\: str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: gin_b_and_mdt_name
                    
                    	Inband MDT Name
                    	**type**\: str
                    
                    .. attribute:: gin_b_and_mdt_interface
                    
                    	Inband MDT handle
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: gin_b_and_mdt_mtu
                    
                    	Inband MDT MTU
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gin_band_maximum_mdt_aggregation
                    
                    	Inband MDT max aggregation
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gin_b_and_mdt_data_switchover_interval
                    
                    	Inband Data MDT Switchover interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gin_b_and_mdt_data_announce_interval
                    
                    	Inband Data MDT Announce interval
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gin_b_and_mdt_rpf_identifier
                    
                    	Inband RPF\-ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_create_gin_b_and_mdt_interface
                    
                    	Create Inband MDT interface
                    	**type**\: bool
                    
                    .. attribute:: is_gin_b_and_mdt_owner
                    
                    	Inband MDT Owner
                    	**type**\: bool
                    
                    .. attribute:: is_pim_nsf_rib_converged
                    
                    	PIM NSF RIB converged
                    	**type**\: bool
                    
                    .. attribute:: is_pim_nsf_rib_converge_received
                    
                    	PIM NSF RIB converge received
                    	**type**\: bool
                    
                    .. attribute:: is_rib_multipath_enabled
                    
                    	PIM RIB multiplath enabled
                    	**type**\: bool
                    
                    .. attribute:: is_rib_multipath_interface_hash
                    
                    	PIM RIB multipath interface hash
                    	**type**\: bool
                    
                    .. attribute:: is_rib_multipath_source_hash
                    
                    	PIM RIB multipath source based hash
                    	**type**\: bool
                    
                    .. attribute:: is_rib_multipath_source_next_hop_hash
                    
                    	PIM RIB multipath source\-nexthop hash
                    	**type**\: bool
                    
                    .. attribute:: rump_enabled
                    
                    	PIM is using MuRIB
                    	**type**\: bool
                    
                    .. attribute:: is_create_mdt_interface
                    
                    	Create MDT interface
                    	**type**\: bool
                    
                    .. attribute:: is_auto_rp_listen_enabled
                    
                    	Auto RP Listen Enabled
                    	**type**\: bool
                    
                    .. attribute:: is_all_interface_disable_operation
                    
                    	PIM all interface disable operation
                    	**type**\: bool
                    
                    .. attribute:: is_default_granges
                    
                    	Default granges
                    	**type**\: bool
                    
                    .. attribute:: is_auto_rp_listen_sock_add
                    
                    	Auto RP listen sock add
                    	**type**\: bool
                    
                    .. attribute:: is_redistribution_reset
                    
                    	Pending redist reset
                    	**type**\: bool
                    
                    .. attribute:: redistribution_reset_count
                    
                    	Redist reset count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rpf_policy_name
                    
                    	RPF topology selection route\-policy name
                    	**type**\: str
                    
                    .. attribute:: table_count
                    
                    	Number of configured Tables
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: active_table_count
                    
                    	Number of active Tables
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: anycast_rp_policy_name
                    
                    	Anycast\-RP Policy Name
                    	**type**\: str
                    
                    .. attribute:: anycast_rp_configured
                    
                    	Anycast\-RP config
                    	**type**\: bool
                    
                    .. attribute:: bgp_remote_on
                    
                    	BGP remote interface status
                    	**type**\: bool
                    
                    .. attribute:: bgp_remote_interface_name
                    
                    	BGP remote interface name
                    	**type**\: str
                    
                    .. attribute:: bgp_remote_interface
                    
                    	BGP remote interface handle
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: bgp_remote_address
                    
                    	BGP remote interface address
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: bgp_remote_state
                    
                    	BGP remote interface state
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: physical_interface_count
                    
                    	Enabled Physical Interface Count
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: virtual_interface_count
                    
                    	Enabled Virtual Interface Count
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: virtual_mlc_interface_name
                    
                    	Virtual master line card Interface
                    	**type**\: str
                    
                    .. attribute:: mdt_immediate_switch
                    
                    	MDT Immediate Switch
                    	**type**\: bool
                    
                    .. attribute:: mldp_root_address
                    
                    	MLDP Root addresses
                    	**type**\: list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: export_route_target
                    
                    	Export Route Targets
                    	**type**\: list of  		 :py:class:`ExportRouteTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Context.ExportRouteTarget>`
                    
                    .. attribute:: import_route_target
                    
                    	Import Route Targets
                    	**type**\: list of  		 :py:class:`ImportRouteTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Context.ImportRouteTarget>`
                    
                    .. attribute:: anycast_rp_range
                    
                    	Anycast\-RP Ranges
                    	**type**\: list of  		 :py:class:`AnycastRpRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Context.AnycastRpRange>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.Context, self).__init__()

                        self.yang_name = "context"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("remote-default-group", ("remote_default_group", Ipv6Pim.Active.Vrfs.Vrf.Context.RemoteDefaultGroup)), ("rpf-default-table", ("rpf_default_table", Ipv6Pim.Active.Vrfs.Vrf.Context.RpfDefaultTable)), ("export-route-target", ("export_route_target", Ipv6Pim.Active.Vrfs.Vrf.Context.ExportRouteTarget)), ("import-route-target", ("import_route_target", Ipv6Pim.Active.Vrfs.Vrf.Context.ImportRouteTarget)), ("anycast-rp-range", ("anycast_rp_range", Ipv6Pim.Active.Vrfs.Vrf.Context.AnycastRpRange))])
                        self._leafs = OrderedDict([
                            ('vrf_id', (YLeaf(YType.uint32, 'vrf-id'), ['int'])),
                            ('table_id', (YLeaf(YType.uint32, 'table-id'), ['int'])),
                            ('murib_id', (YLeaf(YType.uint32, 'murib-id'), ['int'])),
                            ('rpf_id', (YLeaf(YType.uint32, 'rpf-id'), ['int'])),
                            ('remote_table_id', (YLeaf(YType.uint32, 'remote-table-id'), ['int'])),
                            ('mdt_default_group', (YLeaf(YType.str, 'mdt-default-group'), ['str'])),
                            ('mdt_source', (YLeaf(YType.str, 'mdt-source'), ['str'])),
                            ('mdt_source_interface', (YLeaf(YType.str, 'mdt-source-interface'), ['str'])),
                            ('mdt_interface', (YLeaf(YType.str, 'mdt-interface'), ['str'])),
                            ('mdt_gre_rpf_identifier', (YLeaf(YType.uint32, 'mdt-gre-rpf-identifier'), ['int'])),
                            ('mdt_gre_remote_rpf_identifier', (YLeaf(YType.uint32, 'mdt-gre-remote-rpf-identifier'), ['int'])),
                            ('is_unicast_rib_registration', (YLeaf(YType.boolean, 'is-unicast-rib-registration'), ['bool'])),
                            ('is_multicast_rib_registration', (YLeaf(YType.boolean, 'is-multicast-rib-registration'), ['bool'])),
                            ('is_active', (YLeaf(YType.boolean, 'is-active'), ['bool'])),
                            ('is_active_ital', (YLeaf(YType.boolean, 'is-active-ital'), ['bool'])),
                            ('is_mrib_register', (YLeaf(YType.boolean, 'is-mrib-register'), ['bool'])),
                            ('is_mdt_owner', (YLeaf(YType.boolean, 'is-mdt-owner'), ['bool'])),
                            ('is_routing_enabled', (YLeaf(YType.boolean, 'is-routing-enabled'), ['bool'])),
                            ('is_socket_add_required', (YLeaf(YType.boolean, 'is-socket-add-required'), ['bool'])),
                            ('is_socket_added', (YLeaf(YType.boolean, 'is-socket-added'), ['bool'])),
                            ('is_lpts_socket_add_required', (YLeaf(YType.boolean, 'is-lpts-socket-add-required'), ['bool'])),
                            ('is_lpts_socket_added', (YLeaf(YType.boolean, 'is-lpts-socket-added'), ['bool'])),
                            ('is_udp_socket_add_required', (YLeaf(YType.boolean, 'is-udp-socket-add-required'), ['bool'])),
                            ('is_udp_socket_added', (YLeaf(YType.boolean, 'is-udp-socket-added'), ['bool'])),
                            ('is_udp_socket_bind_required', (YLeaf(YType.boolean, 'is-udp-socket-bind-required'), ['bool'])),
                            ('is_udp_socket_bind', (YLeaf(YType.boolean, 'is-udp-socket-bind'), ['bool'])),
                            ('is_register_injection_socket_add_required', (YLeaf(YType.boolean, 'is-register-injection-socket-add-required'), ['bool'])),
                            ('is_register_injection_socket_added', (YLeaf(YType.boolean, 'is-register-injection-socket-added'), ['bool'])),
                            ('is_register_injection_lpts_socket_add_required', (YLeaf(YType.boolean, 'is-register-injection-lpts-socket-add-required'), ['bool'])),
                            ('is_register_injection_lpts_socket_added', (YLeaf(YType.boolean, 'is-register-injection-lpts-socket-added'), ['bool'])),
                            ('is_m_host_publish_pending', (YLeaf(YType.boolean, 'is-m-host-publish-pending'), ['bool'])),
                            ('mhost_interface', (YLeaf(YType.str, 'mhost-interface'), ['str'])),
                            ('mhost_default_interface_config', (YLeaf(YType.str, 'mhost-default-interface-config'), ['str'])),
                            ('mdt_mtu', (YLeaf(YType.uint32, 'mdt-mtu'), ['int'])),
                            ('maximum_mdt_aggregation', (YLeaf(YType.uint32, 'maximum-mdt-aggregation'), ['int'])),
                            ('mdt_data_switchover_interval', (YLeaf(YType.uint32, 'mdt-data-switchover-interval'), ['int'])),
                            ('mdt_data_announce_interval', (YLeaf(YType.uint32, 'mdt-data-announce-interval'), ['int'])),
                            ('non_default_vrf_count_on_socket', (YLeaf(YType.uint32, 'non-default-vrf-count-on-socket'), ['int'])),
                            ('neighbor_filter_name', (YLeaf(YType.str, 'neighbor-filter-name'), ['str'])),
                            ('mdt_neighbor_filter_name', (YLeaf(YType.str, 'mdt-neighbor-filter-name'), ['str'])),
                            ('allow_rp_configured', (YLeaf(YType.boolean, 'allow-rp-configured'), ['bool'])),
                            ('allow_rp_group_list', (YLeaf(YType.str, 'allow-rp-group-list'), ['str'])),
                            ('allow_rp_rp_list', (YLeaf(YType.str, 'allow-rp-rp-list'), ['str'])),
                            ('sg_expiry_timer_configured', (YLeaf(YType.boolean, 'sg-expiry-timer-configured'), ['bool'])),
                            ('sg_expiry_time', (YLeaf(YType.uint16, 'sg-expiry-time'), ['int'])),
                            ('sg_expiry_timer_sg_list', (YLeaf(YType.str, 'sg-expiry-timer-sg-list'), ['str'])),
                            ('mldp_mdt_name', (YLeaf(YType.str, 'mldp-mdt-name'), ['str'])),
                            ('mldp_mdt_interface', (YLeaf(YType.str, 'mldp-mdt-interface'), ['str'])),
                            ('mldp_mdt_mtu', (YLeaf(YType.uint32, 'mldp-mdt-mtu'), ['int'])),
                            ('mldp_maximum_mdt_aggregation', (YLeaf(YType.uint32, 'mldp-maximum-mdt-aggregation'), ['int'])),
                            ('mldp_mdt_data_switchover_interval', (YLeaf(YType.uint32, 'mldp-mdt-data-switchover-interval'), ['int'])),
                            ('mldp_mdt_data_announce_interval', (YLeaf(YType.uint32, 'mldp-mdt-data-announce-interval'), ['int'])),
                            ('mldp_mdt_rpf_identifier', (YLeaf(YType.uint32, 'mldp-mdt-rpf-identifier'), ['int'])),
                            ('mldp_mdt_remote_rpf_identifier', (YLeaf(YType.uint32, 'mldp-mdt-remote-rpf-identifier'), ['int'])),
                            ('is_create_mldp_mdt_interface', (YLeaf(YType.boolean, 'is-create-mldp-mdt-interface'), ['bool'])),
                            ('is_mldp_mdt_owner', (YLeaf(YType.boolean, 'is-mldp-mdt-owner'), ['bool'])),
                            ('mldp_root_count', (YLeaf(YType.uint32, 'mldp-root-count'), ['int'])),
                            ('mldp_head_lsm_identifier', (YLeaf(YType.uint32, 'mldp-head-lsm-identifier'), ['int'])),
                            ('mldp_remote_head_lsm_identifier', (YLeaf(YType.uint32, 'mldp-remote-head-lsm-identifier'), ['int'])),
                            ('organization_unique_identifier', (YLeaf(YType.uint32, 'organization-unique-identifier'), ['int'])),
                            ('vpn_index', (YLeaf(YType.uint32, 'vpn-index'), ['int'])),
                            ('mldp_partitioned_mdt_configured', (YLeaf(YType.boolean, 'mldp-partitioned-mdt-configured'), ['bool'])),
                            ('mldp_remote_partitioned_mdt_configured', (YLeaf(YType.boolean, 'mldp-remote-partitioned-mdt-configured'), ['bool'])),
                            ('mldp_partioned_mp2m_ptree', (YLeaf(YType.boolean, 'mldp-partioned-mp2m-ptree'), ['bool'])),
                            ('mldp_partitioned_head_lsm_identifier', (YLeaf(YType.uint32, 'mldp-partitioned-head-lsm-identifier'), ['int'])),
                            ('mldp_head_local_label', (YLeaf(YType.uint32, 'mldp-head-local-label'), ['int'])),
                            ('mldp_partitioned_mdt_identifier', (YLeaf(YType.uint32, 'mldp-partitioned-mdt-identifier'), ['int'])),
                            ('bgp_auto_discovery_configured', (YLeaf(YType.boolean, 'bgp-auto-discovery-configured'), ['bool'])),
                            ('suppress_pim_data_mdt_tlv', (YLeaf(YType.boolean, 'suppress-pim-data-mdt-tlv'), ['bool'])),
                            ('inter_autonomous_system_enabled', (YLeaf(YType.boolean, 'inter-autonomous-system-enabled'), ['bool'])),
                            ('bgp_source_active_announce', (YLeaf(YType.boolean, 'bgp-source-active-announce'), ['bool'])),
                            ('bgp_i_pmsi_added', (YLeaf(YType.boolean, 'bgp-i-pmsi-added'), ['bool'])),
                            ('mldp_bsr_control_tree_added', (YLeaf(YType.boolean, 'mldp-bsr-control-tree-added'), ['bool'])),
                            ('mldp_auto_rp_discovery_tree_added', (YLeaf(YType.boolean, 'mldp-auto-rp-discovery-tree-added'), ['bool'])),
                            ('mldp_auto_rp_announce_tree_added', (YLeaf(YType.boolean, 'mldp-auto-rp-announce-tree-added'), ['bool'])),
                            ('bgp_auto_discovery_type', (YLeaf(YType.uint32, 'bgp-auto-discovery-type'), ['int'])),
                            ('mdt_partitioned_mdt_control_identifier', (YLeaf(YType.uint32, 'mdt-partitioned-mdt-control-identifier'), ['int'])),
                            ('mdt_partitioned_ir_control_identifier', (YLeaf(YType.uint32, 'mdt-partitioned-ir-control-identifier'), ['int'])),
                            ('mldp_control_head_lsm_identifier', (YLeaf(YType.uint32, 'mldp-control-head-lsm-identifier'), ['int'])),
                            ('umh', (YLeaf(YType.boolean, 'umh'), ['bool'])),
                            ('suppress_shared_tree_join', (YLeaf(YType.boolean, 'suppress-shared-tree-join'), ['bool'])),
                            ('rsvp_te_mdt_name', (YLeaf(YType.str, 'rsvp-te-mdt-name'), ['str'])),
                            ('rsvp_te_mdt_interface', (YLeaf(YType.str, 'rsvp-te-mdt-interface'), ['str'])),
                            ('rsvp_te_mdt_mtu', (YLeaf(YType.uint32, 'rsvp-te-mdt-mtu'), ['int'])),
                            ('rsvp_te_maximum_mdt_aggregation', (YLeaf(YType.uint32, 'rsvp-te-maximum-mdt-aggregation'), ['int'])),
                            ('rsvp_te_mdt_data_switchover_interval', (YLeaf(YType.uint32, 'rsvp-te-mdt-data-switchover-interval'), ['int'])),
                            ('rsvp_te_mdt_data_announce_interval', (YLeaf(YType.uint32, 'rsvp-te-mdt-data-announce-interval'), ['int'])),
                            ('rsvp_te_mdt_rpf_identifier', (YLeaf(YType.uint32, 'rsvp-te-mdt-rpf-identifier'), ['int'])),
                            ('is_create_rsvp_te_mdt_interface', (YLeaf(YType.boolean, 'is-create-rsvp-te-mdt-interface'), ['bool'])),
                            ('is_rsvp_te_mdt_owner', (YLeaf(YType.boolean, 'is-rsvp-te-mdt-owner'), ['bool'])),
                            ('rsvp_te_mdt_static_p2mp_count', (YLeaf(YType.uint32, 'rsvp-te-mdt-static-p2mp-count'), ['int'])),
                            ('p2mpte_li_drop', (YLeaf(YType.uint32, 'p2mpte-li-drop'), ['int'])),
                            ('ir_mdt_name', (YLeaf(YType.str, 'ir-mdt-name'), ['str'])),
                            ('ir_mdt_interface', (YLeaf(YType.str, 'ir-mdt-interface'), ['str'])),
                            ('ir_mdt_mtu', (YLeaf(YType.uint32, 'ir-mdt-mtu'), ['int'])),
                            ('ir_maximum_mdt_aggregation', (YLeaf(YType.uint32, 'ir-maximum-mdt-aggregation'), ['int'])),
                            ('ir_mdt_data_switchover_interval', (YLeaf(YType.uint32, 'ir-mdt-data-switchover-interval'), ['int'])),
                            ('ir_mdt_data_announce_interval', (YLeaf(YType.uint32, 'ir-mdt-data-announce-interval'), ['int'])),
                            ('ir_mdt_rpf_identifier', (YLeaf(YType.uint32, 'ir-mdt-rpf-identifier'), ['int'])),
                            ('ir_mdt_tail_label', (YLeaf(YType.uint32, 'ir-mdt-tail-label'), ['int'])),
                            ('is_create_ir_mdt_interface', (YLeaf(YType.boolean, 'is-create-ir-mdt-interface'), ['bool'])),
                            ('is_ir_mdt_owner', (YLeaf(YType.boolean, 'is-ir-mdt-owner'), ['bool'])),
                            ('in_b_and_mdt_name', (YLeaf(YType.str, 'in-b-and-mdt-name'), ['str'])),
                            ('in_b_and_mdt_interface', (YLeaf(YType.str, 'in-b-and-mdt-interface'), ['str'])),
                            ('in_b_and_mdt_mtu', (YLeaf(YType.uint32, 'in-b-and-mdt-mtu'), ['int'])),
                            ('in_band_maximum_mdt_aggregation', (YLeaf(YType.uint32, 'in-band-maximum-mdt-aggregation'), ['int'])),
                            ('in_b_and_mdt_data_switchover_interval', (YLeaf(YType.uint32, 'in-b-and-mdt-data-switchover-interval'), ['int'])),
                            ('in_b_and_mdt_data_announce_interval', (YLeaf(YType.uint32, 'in-b-and-mdt-data-announce-interval'), ['int'])),
                            ('in_b_and_mdt_rpf_identifier', (YLeaf(YType.uint32, 'in-b-and-mdt-rpf-identifier'), ['int'])),
                            ('is_create_in_b_and_mdt_interface', (YLeaf(YType.boolean, 'is-create-in-b-and-mdt-interface'), ['bool'])),
                            ('is_in_b_and_mdt_owner', (YLeaf(YType.boolean, 'is-in-b-and-mdt-owner'), ['bool'])),
                            ('in_band_signaling_local_enabled', (YLeaf(YType.boolean, 'in-band-signaling-local-enabled'), ['bool'])),
                            ('in_band_signaling_remote_enabled', (YLeaf(YType.boolean, 'in-band-signaling-remote-enabled'), ['bool'])),
                            ('valid_rd_present', (YLeaf(YType.boolean, 'valid-rd-present'), ['bool'])),
                            ('stale_rd_present', (YLeaf(YType.boolean, 'stale-rd-present'), ['bool'])),
                            ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                            ('gin_b_and_mdt_name', (YLeaf(YType.str, 'gin-b-and-mdt-name'), ['str'])),
                            ('gin_b_and_mdt_interface', (YLeaf(YType.str, 'gin-b-and-mdt-interface'), ['str'])),
                            ('gin_b_and_mdt_mtu', (YLeaf(YType.uint32, 'gin-b-and-mdt-mtu'), ['int'])),
                            ('gin_band_maximum_mdt_aggregation', (YLeaf(YType.uint32, 'gin-band-maximum-mdt-aggregation'), ['int'])),
                            ('gin_b_and_mdt_data_switchover_interval', (YLeaf(YType.uint32, 'gin-b-and-mdt-data-switchover-interval'), ['int'])),
                            ('gin_b_and_mdt_data_announce_interval', (YLeaf(YType.uint32, 'gin-b-and-mdt-data-announce-interval'), ['int'])),
                            ('gin_b_and_mdt_rpf_identifier', (YLeaf(YType.uint32, 'gin-b-and-mdt-rpf-identifier'), ['int'])),
                            ('is_create_gin_b_and_mdt_interface', (YLeaf(YType.boolean, 'is-create-gin-b-and-mdt-interface'), ['bool'])),
                            ('is_gin_b_and_mdt_owner', (YLeaf(YType.boolean, 'is-gin-b-and-mdt-owner'), ['bool'])),
                            ('is_pim_nsf_rib_converged', (YLeaf(YType.boolean, 'is-pim-nsf-rib-converged'), ['bool'])),
                            ('is_pim_nsf_rib_converge_received', (YLeaf(YType.boolean, 'is-pim-nsf-rib-converge-received'), ['bool'])),
                            ('is_rib_multipath_enabled', (YLeaf(YType.boolean, 'is-rib-multipath-enabled'), ['bool'])),
                            ('is_rib_multipath_interface_hash', (YLeaf(YType.boolean, 'is-rib-multipath-interface-hash'), ['bool'])),
                            ('is_rib_multipath_source_hash', (YLeaf(YType.boolean, 'is-rib-multipath-source-hash'), ['bool'])),
                            ('is_rib_multipath_source_next_hop_hash', (YLeaf(YType.boolean, 'is-rib-multipath-source-next-hop-hash'), ['bool'])),
                            ('rump_enabled', (YLeaf(YType.boolean, 'rump-enabled'), ['bool'])),
                            ('is_create_mdt_interface', (YLeaf(YType.boolean, 'is-create-mdt-interface'), ['bool'])),
                            ('is_auto_rp_listen_enabled', (YLeaf(YType.boolean, 'is-auto-rp-listen-enabled'), ['bool'])),
                            ('is_all_interface_disable_operation', (YLeaf(YType.boolean, 'is-all-interface-disable-operation'), ['bool'])),
                            ('is_default_granges', (YLeaf(YType.boolean, 'is-default-granges'), ['bool'])),
                            ('is_auto_rp_listen_sock_add', (YLeaf(YType.boolean, 'is-auto-rp-listen-sock-add'), ['bool'])),
                            ('is_redistribution_reset', (YLeaf(YType.boolean, 'is-redistribution-reset'), ['bool'])),
                            ('redistribution_reset_count', (YLeaf(YType.uint32, 'redistribution-reset-count'), ['int'])),
                            ('rpf_policy_name', (YLeaf(YType.str, 'rpf-policy-name'), ['str'])),
                            ('table_count', (YLeaf(YType.uint32, 'table-count'), ['int'])),
                            ('active_table_count', (YLeaf(YType.uint32, 'active-table-count'), ['int'])),
                            ('anycast_rp_policy_name', (YLeaf(YType.str, 'anycast-rp-policy-name'), ['str'])),
                            ('anycast_rp_configured', (YLeaf(YType.boolean, 'anycast-rp-configured'), ['bool'])),
                            ('bgp_remote_on', (YLeaf(YType.boolean, 'bgp-remote-on'), ['bool'])),
                            ('bgp_remote_interface_name', (YLeaf(YType.str, 'bgp-remote-interface-name'), ['str'])),
                            ('bgp_remote_interface', (YLeaf(YType.str, 'bgp-remote-interface'), ['str'])),
                            ('bgp_remote_address', (YLeaf(YType.str, 'bgp-remote-address'), ['str'])),
                            ('bgp_remote_state', (YLeaf(YType.uint32, 'bgp-remote-state'), ['int'])),
                            ('physical_interface_count', (YLeaf(YType.uint64, 'physical-interface-count'), ['int'])),
                            ('virtual_interface_count', (YLeaf(YType.uint64, 'virtual-interface-count'), ['int'])),
                            ('virtual_mlc_interface_name', (YLeaf(YType.str, 'virtual-mlc-interface-name'), ['str'])),
                            ('mdt_immediate_switch', (YLeaf(YType.boolean, 'mdt-immediate-switch'), ['bool'])),
                            ('mldp_root_address', (YLeafList(YType.uint32, 'mldp-root-address'), ['int'])),
                        ])
                        self.vrf_id = None
                        self.table_id = None
                        self.murib_id = None
                        self.rpf_id = None
                        self.remote_table_id = None
                        self.mdt_default_group = None
                        self.mdt_source = None
                        self.mdt_source_interface = None
                        self.mdt_interface = None
                        self.mdt_gre_rpf_identifier = None
                        self.mdt_gre_remote_rpf_identifier = None
                        self.is_unicast_rib_registration = None
                        self.is_multicast_rib_registration = None
                        self.is_active = None
                        self.is_active_ital = None
                        self.is_mrib_register = None
                        self.is_mdt_owner = None
                        self.is_routing_enabled = None
                        self.is_socket_add_required = None
                        self.is_socket_added = None
                        self.is_lpts_socket_add_required = None
                        self.is_lpts_socket_added = None
                        self.is_udp_socket_add_required = None
                        self.is_udp_socket_added = None
                        self.is_udp_socket_bind_required = None
                        self.is_udp_socket_bind = None
                        self.is_register_injection_socket_add_required = None
                        self.is_register_injection_socket_added = None
                        self.is_register_injection_lpts_socket_add_required = None
                        self.is_register_injection_lpts_socket_added = None
                        self.is_m_host_publish_pending = None
                        self.mhost_interface = None
                        self.mhost_default_interface_config = None
                        self.mdt_mtu = None
                        self.maximum_mdt_aggregation = None
                        self.mdt_data_switchover_interval = None
                        self.mdt_data_announce_interval = None
                        self.non_default_vrf_count_on_socket = None
                        self.neighbor_filter_name = None
                        self.mdt_neighbor_filter_name = None
                        self.allow_rp_configured = None
                        self.allow_rp_group_list = None
                        self.allow_rp_rp_list = None
                        self.sg_expiry_timer_configured = None
                        self.sg_expiry_time = None
                        self.sg_expiry_timer_sg_list = None
                        self.mldp_mdt_name = None
                        self.mldp_mdt_interface = None
                        self.mldp_mdt_mtu = None
                        self.mldp_maximum_mdt_aggregation = None
                        self.mldp_mdt_data_switchover_interval = None
                        self.mldp_mdt_data_announce_interval = None
                        self.mldp_mdt_rpf_identifier = None
                        self.mldp_mdt_remote_rpf_identifier = None
                        self.is_create_mldp_mdt_interface = None
                        self.is_mldp_mdt_owner = None
                        self.mldp_root_count = None
                        self.mldp_head_lsm_identifier = None
                        self.mldp_remote_head_lsm_identifier = None
                        self.organization_unique_identifier = None
                        self.vpn_index = None
                        self.mldp_partitioned_mdt_configured = None
                        self.mldp_remote_partitioned_mdt_configured = None
                        self.mldp_partioned_mp2m_ptree = None
                        self.mldp_partitioned_head_lsm_identifier = None
                        self.mldp_head_local_label = None
                        self.mldp_partitioned_mdt_identifier = None
                        self.bgp_auto_discovery_configured = None
                        self.suppress_pim_data_mdt_tlv = None
                        self.inter_autonomous_system_enabled = None
                        self.bgp_source_active_announce = None
                        self.bgp_i_pmsi_added = None
                        self.mldp_bsr_control_tree_added = None
                        self.mldp_auto_rp_discovery_tree_added = None
                        self.mldp_auto_rp_announce_tree_added = None
                        self.bgp_auto_discovery_type = None
                        self.mdt_partitioned_mdt_control_identifier = None
                        self.mdt_partitioned_ir_control_identifier = None
                        self.mldp_control_head_lsm_identifier = None
                        self.umh = None
                        self.suppress_shared_tree_join = None
                        self.rsvp_te_mdt_name = None
                        self.rsvp_te_mdt_interface = None
                        self.rsvp_te_mdt_mtu = None
                        self.rsvp_te_maximum_mdt_aggregation = None
                        self.rsvp_te_mdt_data_switchover_interval = None
                        self.rsvp_te_mdt_data_announce_interval = None
                        self.rsvp_te_mdt_rpf_identifier = None
                        self.is_create_rsvp_te_mdt_interface = None
                        self.is_rsvp_te_mdt_owner = None
                        self.rsvp_te_mdt_static_p2mp_count = None
                        self.p2mpte_li_drop = None
                        self.ir_mdt_name = None
                        self.ir_mdt_interface = None
                        self.ir_mdt_mtu = None
                        self.ir_maximum_mdt_aggregation = None
                        self.ir_mdt_data_switchover_interval = None
                        self.ir_mdt_data_announce_interval = None
                        self.ir_mdt_rpf_identifier = None
                        self.ir_mdt_tail_label = None
                        self.is_create_ir_mdt_interface = None
                        self.is_ir_mdt_owner = None
                        self.in_b_and_mdt_name = None
                        self.in_b_and_mdt_interface = None
                        self.in_b_and_mdt_mtu = None
                        self.in_band_maximum_mdt_aggregation = None
                        self.in_b_and_mdt_data_switchover_interval = None
                        self.in_b_and_mdt_data_announce_interval = None
                        self.in_b_and_mdt_rpf_identifier = None
                        self.is_create_in_b_and_mdt_interface = None
                        self.is_in_b_and_mdt_owner = None
                        self.in_band_signaling_local_enabled = None
                        self.in_band_signaling_remote_enabled = None
                        self.valid_rd_present = None
                        self.stale_rd_present = None
                        self.route_distinguisher = None
                        self.gin_b_and_mdt_name = None
                        self.gin_b_and_mdt_interface = None
                        self.gin_b_and_mdt_mtu = None
                        self.gin_band_maximum_mdt_aggregation = None
                        self.gin_b_and_mdt_data_switchover_interval = None
                        self.gin_b_and_mdt_data_announce_interval = None
                        self.gin_b_and_mdt_rpf_identifier = None
                        self.is_create_gin_b_and_mdt_interface = None
                        self.is_gin_b_and_mdt_owner = None
                        self.is_pim_nsf_rib_converged = None
                        self.is_pim_nsf_rib_converge_received = None
                        self.is_rib_multipath_enabled = None
                        self.is_rib_multipath_interface_hash = None
                        self.is_rib_multipath_source_hash = None
                        self.is_rib_multipath_source_next_hop_hash = None
                        self.rump_enabled = None
                        self.is_create_mdt_interface = None
                        self.is_auto_rp_listen_enabled = None
                        self.is_all_interface_disable_operation = None
                        self.is_default_granges = None
                        self.is_auto_rp_listen_sock_add = None
                        self.is_redistribution_reset = None
                        self.redistribution_reset_count = None
                        self.rpf_policy_name = None
                        self.table_count = None
                        self.active_table_count = None
                        self.anycast_rp_policy_name = None
                        self.anycast_rp_configured = None
                        self.bgp_remote_on = None
                        self.bgp_remote_interface_name = None
                        self.bgp_remote_interface = None
                        self.bgp_remote_address = None
                        self.bgp_remote_state = None
                        self.physical_interface_count = None
                        self.virtual_interface_count = None
                        self.virtual_mlc_interface_name = None
                        self.mdt_immediate_switch = None
                        self.mldp_root_address = []

                        self.remote_default_group = Ipv6Pim.Active.Vrfs.Vrf.Context.RemoteDefaultGroup()
                        self.remote_default_group.parent = self
                        self._children_name_map["remote_default_group"] = "remote-default-group"

                        self.rpf_default_table = Ipv6Pim.Active.Vrfs.Vrf.Context.RpfDefaultTable()
                        self.rpf_default_table.parent = self
                        self._children_name_map["rpf_default_table"] = "rpf-default-table"

                        self.export_route_target = YList(self)
                        self.import_route_target = YList(self)
                        self.anycast_rp_range = YList(self)
                        self._segment_path = lambda: "context"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Context, ['vrf_id', 'table_id', 'murib_id', 'rpf_id', 'remote_table_id', 'mdt_default_group', 'mdt_source', 'mdt_source_interface', 'mdt_interface', 'mdt_gre_rpf_identifier', 'mdt_gre_remote_rpf_identifier', 'is_unicast_rib_registration', 'is_multicast_rib_registration', 'is_active', 'is_active_ital', 'is_mrib_register', 'is_mdt_owner', 'is_routing_enabled', 'is_socket_add_required', 'is_socket_added', 'is_lpts_socket_add_required', 'is_lpts_socket_added', 'is_udp_socket_add_required', 'is_udp_socket_added', 'is_udp_socket_bind_required', 'is_udp_socket_bind', 'is_register_injection_socket_add_required', 'is_register_injection_socket_added', 'is_register_injection_lpts_socket_add_required', 'is_register_injection_lpts_socket_added', 'is_m_host_publish_pending', 'mhost_interface', 'mhost_default_interface_config', 'mdt_mtu', 'maximum_mdt_aggregation', 'mdt_data_switchover_interval', 'mdt_data_announce_interval', 'non_default_vrf_count_on_socket', 'neighbor_filter_name', 'mdt_neighbor_filter_name', 'allow_rp_configured', 'allow_rp_group_list', 'allow_rp_rp_list', 'sg_expiry_timer_configured', 'sg_expiry_time', 'sg_expiry_timer_sg_list', 'mldp_mdt_name', 'mldp_mdt_interface', 'mldp_mdt_mtu', 'mldp_maximum_mdt_aggregation', 'mldp_mdt_data_switchover_interval', 'mldp_mdt_data_announce_interval', 'mldp_mdt_rpf_identifier', 'mldp_mdt_remote_rpf_identifier', 'is_create_mldp_mdt_interface', 'is_mldp_mdt_owner', 'mldp_root_count', 'mldp_head_lsm_identifier', 'mldp_remote_head_lsm_identifier', 'organization_unique_identifier', 'vpn_index', 'mldp_partitioned_mdt_configured', 'mldp_remote_partitioned_mdt_configured', 'mldp_partioned_mp2m_ptree', 'mldp_partitioned_head_lsm_identifier', 'mldp_head_local_label', 'mldp_partitioned_mdt_identifier', 'bgp_auto_discovery_configured', 'suppress_pim_data_mdt_tlv', 'inter_autonomous_system_enabled', 'bgp_source_active_announce', 'bgp_i_pmsi_added', 'mldp_bsr_control_tree_added', 'mldp_auto_rp_discovery_tree_added', 'mldp_auto_rp_announce_tree_added', 'bgp_auto_discovery_type', 'mdt_partitioned_mdt_control_identifier', 'mdt_partitioned_ir_control_identifier', 'mldp_control_head_lsm_identifier', 'umh', 'suppress_shared_tree_join', 'rsvp_te_mdt_name', 'rsvp_te_mdt_interface', 'rsvp_te_mdt_mtu', 'rsvp_te_maximum_mdt_aggregation', 'rsvp_te_mdt_data_switchover_interval', 'rsvp_te_mdt_data_announce_interval', 'rsvp_te_mdt_rpf_identifier', 'is_create_rsvp_te_mdt_interface', 'is_rsvp_te_mdt_owner', 'rsvp_te_mdt_static_p2mp_count', 'p2mpte_li_drop', 'ir_mdt_name', 'ir_mdt_interface', 'ir_mdt_mtu', 'ir_maximum_mdt_aggregation', 'ir_mdt_data_switchover_interval', 'ir_mdt_data_announce_interval', 'ir_mdt_rpf_identifier', 'ir_mdt_tail_label', 'is_create_ir_mdt_interface', 'is_ir_mdt_owner', 'in_b_and_mdt_name', 'in_b_and_mdt_interface', 'in_b_and_mdt_mtu', 'in_band_maximum_mdt_aggregation', 'in_b_and_mdt_data_switchover_interval', 'in_b_and_mdt_data_announce_interval', 'in_b_and_mdt_rpf_identifier', 'is_create_in_b_and_mdt_interface', 'is_in_b_and_mdt_owner', 'in_band_signaling_local_enabled', 'in_band_signaling_remote_enabled', 'valid_rd_present', 'stale_rd_present', 'route_distinguisher', 'gin_b_and_mdt_name', 'gin_b_and_mdt_interface', 'gin_b_and_mdt_mtu', 'gin_band_maximum_mdt_aggregation', 'gin_b_and_mdt_data_switchover_interval', 'gin_b_and_mdt_data_announce_interval', 'gin_b_and_mdt_rpf_identifier', 'is_create_gin_b_and_mdt_interface', 'is_gin_b_and_mdt_owner', 'is_pim_nsf_rib_converged', 'is_pim_nsf_rib_converge_received', 'is_rib_multipath_enabled', 'is_rib_multipath_interface_hash', 'is_rib_multipath_source_hash', 'is_rib_multipath_source_next_hop_hash', 'rump_enabled', 'is_create_mdt_interface', 'is_auto_rp_listen_enabled', 'is_all_interface_disable_operation', 'is_default_granges', 'is_auto_rp_listen_sock_add', 'is_redistribution_reset', 'redistribution_reset_count', 'rpf_policy_name', 'table_count', 'active_table_count', 'anycast_rp_policy_name', 'anycast_rp_configured', 'bgp_remote_on', 'bgp_remote_interface_name', 'bgp_remote_interface', 'bgp_remote_address', 'bgp_remote_state', 'physical_interface_count', 'virtual_interface_count', 'virtual_mlc_interface_name', 'mdt_immediate_switch', 'mldp_root_address'], name, value)


                    class RemoteDefaultGroup(Entity):
                        """
                        Remote Default Group
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.Context.RemoteDefaultGroup, self).__init__()

                            self.yang_name = "remote-default-group"
                            self.yang_parent_name = "context"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "remote-default-group"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Context.RemoteDefaultGroup, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class RpfDefaultTable(Entity):
                        """
                        RPF Default Table
                        
                        .. attribute:: afi
                        
                        	AFI
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: safi
                        
                        	SAFI
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_name
                        
                        	Table name
                        	**type**\: str
                        
                        .. attribute:: vrf_id
                        
                        	VRF ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_id
                        
                        	Table ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_active
                        
                        	Active status
                        	**type**\: bool
                        
                        .. attribute:: is_ital_registration_done
                        
                        	ITAL reg status
                        	**type**\: bool
                        
                        .. attribute:: is_rib_registration_done
                        
                        	RIB reg status
                        	**type**\: bool
                        
                        .. attribute:: is_rib_convergence_received
                        
                        	RIB Convergence receive status
                        	**type**\: bool
                        
                        .. attribute:: is_rib_convergence
                        
                        	RIB Convergence status
                        	**type**\: bool
                        
                        .. attribute:: rpf_registrations
                        
                        	RPF Registration count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.Context.RpfDefaultTable, self).__init__()

                            self.yang_name = "rpf-default-table"
                            self.yang_parent_name = "context"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('afi', (YLeaf(YType.uint32, 'afi'), ['int'])),
                                ('safi', (YLeaf(YType.uint32, 'safi'), ['int'])),
                                ('table_name', (YLeaf(YType.str, 'table-name'), ['str'])),
                                ('vrf_id', (YLeaf(YType.uint32, 'vrf-id'), ['int'])),
                                ('table_id', (YLeaf(YType.uint32, 'table-id'), ['int'])),
                                ('is_active', (YLeaf(YType.boolean, 'is-active'), ['bool'])),
                                ('is_ital_registration_done', (YLeaf(YType.boolean, 'is-ital-registration-done'), ['bool'])),
                                ('is_rib_registration_done', (YLeaf(YType.boolean, 'is-rib-registration-done'), ['bool'])),
                                ('is_rib_convergence_received', (YLeaf(YType.boolean, 'is-rib-convergence-received'), ['bool'])),
                                ('is_rib_convergence', (YLeaf(YType.boolean, 'is-rib-convergence'), ['bool'])),
                                ('rpf_registrations', (YLeaf(YType.uint32, 'rpf-registrations'), ['int'])),
                            ])
                            self.afi = None
                            self.safi = None
                            self.table_name = None
                            self.vrf_id = None
                            self.table_id = None
                            self.is_active = None
                            self.is_ital_registration_done = None
                            self.is_rib_registration_done = None
                            self.is_rib_convergence_received = None
                            self.is_rib_convergence = None
                            self.rpf_registrations = None
                            self._segment_path = lambda: "rpf-default-table"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Context.RpfDefaultTable, ['afi', 'safi', 'table_name', 'vrf_id', 'table_id', 'is_active', 'is_ital_registration_done', 'is_rib_registration_done', 'is_rib_convergence_received', 'is_rib_convergence', 'rpf_registrations'], name, value)


                    class ExportRouteTarget(Entity):
                        """
                        Export Route Targets
                        
                        .. attribute:: route_target
                        
                        	Route Target Extended community value
                        	**type**\: str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        .. attribute:: configured
                        
                        	Configured Route Target
                        	**type**\: bool
                        
                        .. attribute:: anycast_rp
                        
                        	Anycast\-RP Group
                        	**type**\: bool
                        
                        .. attribute:: anycast_rp_marked
                        
                        	Anycast\-RP Group marked
                        	**type**\: bool
                        
                        .. attribute:: update_pending
                        
                        	Update Pending to BGP
                        	**type**\: bool
                        
                        .. attribute:: bgp_auto_discovery
                        
                        	BGP Auto Discovery
                        	**type**\: bool
                        
                        .. attribute:: segment_border
                        
                        	Segment Border
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.Context.ExportRouteTarget, self).__init__()

                            self.yang_name = "export-route-target"
                            self.yang_parent_name = "context"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('route_target', (YLeaf(YType.str, 'route-target'), ['str'])),
                                ('configured', (YLeaf(YType.boolean, 'configured'), ['bool'])),
                                ('anycast_rp', (YLeaf(YType.boolean, 'anycast-rp'), ['bool'])),
                                ('anycast_rp_marked', (YLeaf(YType.boolean, 'anycast-rp-marked'), ['bool'])),
                                ('update_pending', (YLeaf(YType.boolean, 'update-pending'), ['bool'])),
                                ('bgp_auto_discovery', (YLeaf(YType.boolean, 'bgp-auto-discovery'), ['bool'])),
                                ('segment_border', (YLeaf(YType.boolean, 'segment-border'), ['bool'])),
                            ])
                            self.route_target = None
                            self.configured = None
                            self.anycast_rp = None
                            self.anycast_rp_marked = None
                            self.update_pending = None
                            self.bgp_auto_discovery = None
                            self.segment_border = None
                            self._segment_path = lambda: "export-route-target"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Context.ExportRouteTarget, ['route_target', 'configured', 'anycast_rp', 'anycast_rp_marked', 'update_pending', 'bgp_auto_discovery', 'segment_border'], name, value)


                    class ImportRouteTarget(Entity):
                        """
                        Import Route Targets
                        
                        .. attribute:: route_target
                        
                        	Route Target Extended community value
                        	**type**\: str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        .. attribute:: configured
                        
                        	Configured Route Target
                        	**type**\: bool
                        
                        .. attribute:: anycast_rp
                        
                        	Anycast\-RP Group
                        	**type**\: bool
                        
                        .. attribute:: anycast_rp_marked
                        
                        	Anycast\-RP Group marked
                        	**type**\: bool
                        
                        .. attribute:: update_pending
                        
                        	Update Pending to BGP
                        	**type**\: bool
                        
                        .. attribute:: bgp_auto_discovery
                        
                        	BGP Auto Discovery
                        	**type**\: bool
                        
                        .. attribute:: segment_border
                        
                        	Segment Border
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.Context.ImportRouteTarget, self).__init__()

                            self.yang_name = "import-route-target"
                            self.yang_parent_name = "context"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('route_target', (YLeaf(YType.str, 'route-target'), ['str'])),
                                ('configured', (YLeaf(YType.boolean, 'configured'), ['bool'])),
                                ('anycast_rp', (YLeaf(YType.boolean, 'anycast-rp'), ['bool'])),
                                ('anycast_rp_marked', (YLeaf(YType.boolean, 'anycast-rp-marked'), ['bool'])),
                                ('update_pending', (YLeaf(YType.boolean, 'update-pending'), ['bool'])),
                                ('bgp_auto_discovery', (YLeaf(YType.boolean, 'bgp-auto-discovery'), ['bool'])),
                                ('segment_border', (YLeaf(YType.boolean, 'segment-border'), ['bool'])),
                            ])
                            self.route_target = None
                            self.configured = None
                            self.anycast_rp = None
                            self.anycast_rp_marked = None
                            self.update_pending = None
                            self.bgp_auto_discovery = None
                            self.segment_border = None
                            self._segment_path = lambda: "import-route-target"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Context.ImportRouteTarget, ['route_target', 'configured', 'anycast_rp', 'anycast_rp_marked', 'update_pending', 'bgp_auto_discovery', 'segment_border'], name, value)


                    class AnycastRpRange(Entity):
                        """
                        Anycast\-RP Ranges
                        
                        .. attribute:: prefix
                        
                        	Anycast\-RP Range Prefix
                        	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Context.AnycastRpRange.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Anycast\-RP Range Prefix Length
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: ancast_rp_marked
                        
                        	Anycast\-RP Range marked
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.Context.AnycastRpRange, self).__init__()

                            self.yang_name = "anycast-rp-range"
                            self.yang_parent_name = "context"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("prefix", ("prefix", Ipv6Pim.Active.Vrfs.Vrf.Context.AnycastRpRange.Prefix))])
                            self._leafs = OrderedDict([
                                ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                ('ancast_rp_marked', (YLeaf(YType.boolean, 'ancast-rp-marked'), ['bool'])),
                            ])
                            self.prefix_length = None
                            self.ancast_rp_marked = None

                            self.prefix = Ipv6Pim.Active.Vrfs.Vrf.Context.AnycastRpRange.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"
                            self._segment_path = lambda: "anycast-rp-range"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Context.AnycastRpRange, ['prefix_length', 'ancast_rp_marked'], name, value)


                        class Prefix(Entity):
                            """
                            Anycast\-RP Range Prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Context.AnycastRpRange.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "anycast-rp-range"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "prefix"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Context.AnycastRpRange.Prefix, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class TopologyEntryFlagRouteCounts(Entity):
                    """
                    Route count for topology with entry flag set
                    
                    .. attribute:: topology_entry_flag_route_count
                    
                    	Route count for topology with entry flag set
                    	**type**\: list of  		 :py:class:`TopologyEntryFlagRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts, self).__init__()

                        self.yang_name = "topology-entry-flag-route-counts"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("topology-entry-flag-route-count", ("topology_entry_flag_route_count", Ipv6Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount))])
                        self._leafs = OrderedDict()

                        self.topology_entry_flag_route_count = YList(self)
                        self._segment_path = lambda: "topology-entry-flag-route-counts"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts, [], name, value)


                    class TopologyEntryFlagRouteCount(Entity):
                        """
                        Route count for topology with entry flag set
                        
                        .. attribute:: entry_flag  (key)
                        
                        	entry flag
                        	**type**\:  :py:class:`PimTopologyEntryFlag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimTopologyEntryFlag>`
                        
                        .. attribute:: group_ranges
                        
                        	No. of (\*,G/M) routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: active_group_ranges
                        
                        	No. of (\*,G/M) routes active in mrib
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: groute_count
                        
                        	No. of (\*,G) routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sg_route_count
                        
                        	No. of (S,G) routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sgr_route_count
                        
                        	No. of (S,G)RPT routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_node_low_memory
                        
                        	Is node in low memory condition
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount, self).__init__()

                            self.yang_name = "topology-entry-flag-route-count"
                            self.yang_parent_name = "topology-entry-flag-route-counts"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['entry_flag']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('entry_flag', (YLeaf(YType.enumeration, 'entry-flag'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimTopologyEntryFlag', '')])),
                                ('group_ranges', (YLeaf(YType.uint32, 'group-ranges'), ['int'])),
                                ('active_group_ranges', (YLeaf(YType.uint32, 'active-group-ranges'), ['int'])),
                                ('groute_count', (YLeaf(YType.uint32, 'groute-count'), ['int'])),
                                ('sg_route_count', (YLeaf(YType.uint32, 'sg-route-count'), ['int'])),
                                ('sgr_route_count', (YLeaf(YType.uint32, 'sgr-route-count'), ['int'])),
                                ('is_node_low_memory', (YLeaf(YType.boolean, 'is-node-low-memory'), ['bool'])),
                            ])
                            self.entry_flag = None
                            self.group_ranges = None
                            self.active_group_ranges = None
                            self.groute_count = None
                            self.sg_route_count = None
                            self.sgr_route_count = None
                            self.is_node_low_memory = None
                            self._segment_path = lambda: "topology-entry-flag-route-count" + "[entry-flag='" + str(self.entry_flag) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount, ['entry_flag', 'group_ranges', 'active_group_ranges', 'groute_count', 'sg_route_count', 'sgr_route_count', 'is_node_low_memory'], name, value)


                class RpfRedirect(Entity):
                    """
                    PIM ECMP RPF\-redirect bundle
                    
                    .. attribute:: redirect_route_databases
                    
                    	PIM ECMP RPF\-redirect route database
                    	**type**\:  :py:class:`RedirectRouteDatabases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases>`
                    
                    .. attribute:: bundle_interfaces
                    
                    	PIM ECMP RPF\-redirect bundle information
                    	**type**\:  :py:class:`BundleInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect, self).__init__()

                        self.yang_name = "rpf-redirect"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("redirect-route-databases", ("redirect_route_databases", Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases)), ("bundle-interfaces", ("bundle_interfaces", Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces))])
                        self._leafs = OrderedDict()

                        self.redirect_route_databases = Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases()
                        self.redirect_route_databases.parent = self
                        self._children_name_map["redirect_route_databases"] = "redirect-route-databases"

                        self.bundle_interfaces = Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces()
                        self.bundle_interfaces.parent = self
                        self._children_name_map["bundle_interfaces"] = "bundle-interfaces"
                        self._segment_path = lambda: "rpf-redirect"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect, [], name, value)


                    class RedirectRouteDatabases(Entity):
                        """
                        PIM ECMP RPF\-redirect route database
                        
                        .. attribute:: redirect_route_database
                        
                        	PIM ECMP RPF\-redirect route information
                        	**type**\: list of  		 :py:class:`RedirectRouteDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases, self).__init__()

                            self.yang_name = "redirect-route-databases"
                            self.yang_parent_name = "rpf-redirect"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("redirect-route-database", ("redirect_route_database", Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase))])
                            self._leafs = OrderedDict()

                            self.redirect_route_database = YList(self)
                            self._segment_path = lambda: "redirect-route-databases"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases, [], name, value)


                        class RedirectRouteDatabase(Entity):
                            """
                            PIM ECMP RPF\-redirect route information
                            
                            .. attribute:: source_address
                            
                            	Source address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: group_address
                            
                            	Group address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: group_address_xr
                            
                            	Group ddress
                            	**type**\:  :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr>`
                            
                            .. attribute:: source_address_xr
                            
                            	Source address
                            	**type**\:  :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr>`
                            
                            .. attribute:: bandwidth
                            
                            	Bandwidth in Kbps
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: interface
                            
                            	Outgoing interface list
                            	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase, self).__init__()

                                self.yang_name = "redirect-route-database"
                                self.yang_parent_name = "redirect-route-databases"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("group-address-xr", ("group_address_xr", Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr)), ("source-address-xr", ("source_address_xr", Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr)), ("interface", ("interface", Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface))])
                                self._leafs = OrderedDict([
                                    ('source_address', (YLeaf(YType.str, 'source-address'), ['str','str'])),
                                    ('group_address', (YLeaf(YType.str, 'group-address'), ['str','str'])),
                                    ('bandwidth', (YLeaf(YType.uint32, 'bandwidth'), ['int'])),
                                    ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                                ])
                                self.source_address = None
                                self.group_address = None
                                self.bandwidth = None
                                self.uptime = None

                                self.group_address_xr = Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"

                                self.source_address_xr = Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr()
                                self.source_address_xr.parent = self
                                self._children_name_map["source_address_xr"] = "source-address-xr"

                                self.interface = YList(self)
                                self._segment_path = lambda: "redirect-route-database"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase, ['source_address', 'group_address', 'bandwidth', 'uptime'], name, value)


                            class GroupAddressXr(Entity):
                                """
                                Group ddress
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr, self).__init__()

                                    self.yang_name = "group-address-xr"
                                    self.yang_parent_name = "redirect-route-database"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "group-address-xr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                            class SourceAddressXr(Entity):
                                """
                                Source address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr, self).__init__()

                                    self.yang_name = "source-address-xr"
                                    self.yang_parent_name = "redirect-route-database"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ])
                                    self.af_name = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self._segment_path = lambda: "source-address-xr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                            class Interface(Entity):
                                """
                                Outgoing interface list
                                
                                .. attribute:: rpf_address
                                
                                	RPF Address
                                	**type**\:  :py:class:`RpfAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress>`
                                
                                .. attribute:: interface_name
                                
                                	Interface name
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                .. attribute:: uptime
                                
                                	Uptime in seconds
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: second
                                
                                .. attribute:: expiry
                                
                                	Expiry in seconds
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: second
                                
                                .. attribute:: is_rpf_interface
                                
                                	Is RPF Interface
                                	**type**\: bool
                                
                                .. attribute:: is_outgoing_interface
                                
                                	Is outgoing Interface
                                	**type**\: bool
                                
                                .. attribute:: is_snoop_interface
                                
                                	Is snooping Interface
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface, self).__init__()

                                    self.yang_name = "interface"
                                    self.yang_parent_name = "redirect-route-database"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("rpf-address", ("rpf_address", Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress))])
                                    self._leafs = OrderedDict([
                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                        ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                                        ('expiry', (YLeaf(YType.uint64, 'expiry'), ['int'])),
                                        ('is_rpf_interface', (YLeaf(YType.boolean, 'is-rpf-interface'), ['bool'])),
                                        ('is_outgoing_interface', (YLeaf(YType.boolean, 'is-outgoing-interface'), ['bool'])),
                                        ('is_snoop_interface', (YLeaf(YType.boolean, 'is-snoop-interface'), ['bool'])),
                                    ])
                                    self.interface_name = None
                                    self.uptime = None
                                    self.expiry = None
                                    self.is_rpf_interface = None
                                    self.is_outgoing_interface = None
                                    self.is_snoop_interface = None

                                    self.rpf_address = Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress()
                                    self.rpf_address.parent = self
                                    self._children_name_map["rpf_address"] = "rpf-address"
                                    self._segment_path = lambda: "interface"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface, ['interface_name', 'uptime', 'expiry', 'is_rpf_interface', 'is_outgoing_interface', 'is_snoop_interface'], name, value)


                                class RpfAddress(Entity):
                                    """
                                    RPF Address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress, self).__init__()

                                        self.yang_name = "rpf-address"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ])
                                        self.af_name = None
                                        self.ipv4_address = None
                                        self.ipv6_address = None
                                        self._segment_path = lambda: "rpf-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class BundleInterfaces(Entity):
                        """
                        PIM ECMP RPF\-redirect bundle information
                        
                        .. attribute:: bundle_interface
                        
                        	PIM ECMP RPF\-redirect bundle interface information
                        	**type**\: list of  		 :py:class:`BundleInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces.BundleInterface>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces, self).__init__()

                            self.yang_name = "bundle-interfaces"
                            self.yang_parent_name = "rpf-redirect"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("bundle-interface", ("bundle_interface", Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces.BundleInterface))])
                            self._leafs = OrderedDict()

                            self.bundle_interface = YList(self)
                            self._segment_path = lambda: "bundle-interfaces"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces, [], name, value)


                        class BundleInterface(Entity):
                            """
                            PIM ECMP RPF\-redirect bundle interface
                            information
                            
                            .. attribute:: bundle_name
                            
                            	Bundle name
                            	**type**\: str
                            
                            	**length:** 1..32
                            
                            .. attribute:: interface_name
                            
                            	Bundle interface name
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: rpf_redirect_bundle_name
                            
                            	RPF redirect bundle name
                            	**type**\: str
                            
                            	**length:** 0..33
                            
                            .. attribute:: rpf_redirect_interface_name
                            
                            	RPF redirect interface name
                            	**type**\: str
                            
                            	**length:** 0..33
                            
                            .. attribute:: available_bandwidth
                            
                            	Bandwidth available in Kbps
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: allocated_bandwidth
                            
                            	Bandwidth allocated in Kbps
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: total_bandwidth
                            
                            	Total bandwidth used in Kbps
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: topology_bandwidth_used
                            
                            	Bandwidth used by topology in Kbps
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: snooping_bandwidth_used
                            
                            	Bandwidth used by snooped entries in Kbps
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: allocated_threshold_bandwidth
                            
                            	Configured threshold in Kbps
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: available_threshold_bandwidth
                            
                            	Available threshold in Kbps
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces.BundleInterface, self).__init__()

                                self.yang_name = "bundle-interface"
                                self.yang_parent_name = "bundle-interfaces"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('bundle_name', (YLeaf(YType.str, 'bundle-name'), ['str'])),
                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                    ('rpf_redirect_bundle_name', (YLeaf(YType.str, 'rpf-redirect-bundle-name'), ['str'])),
                                    ('rpf_redirect_interface_name', (YLeaf(YType.str, 'rpf-redirect-interface-name'), ['str'])),
                                    ('available_bandwidth', (YLeaf(YType.int32, 'available-bandwidth'), ['int'])),
                                    ('allocated_bandwidth', (YLeaf(YType.int32, 'allocated-bandwidth'), ['int'])),
                                    ('total_bandwidth', (YLeaf(YType.int32, 'total-bandwidth'), ['int'])),
                                    ('topology_bandwidth_used', (YLeaf(YType.int32, 'topology-bandwidth-used'), ['int'])),
                                    ('snooping_bandwidth_used', (YLeaf(YType.int32, 'snooping-bandwidth-used'), ['int'])),
                                    ('allocated_threshold_bandwidth', (YLeaf(YType.int32, 'allocated-threshold-bandwidth'), ['int'])),
                                    ('available_threshold_bandwidth', (YLeaf(YType.int32, 'available-threshold-bandwidth'), ['int'])),
                                ])
                                self.bundle_name = None
                                self.interface_name = None
                                self.rpf_redirect_bundle_name = None
                                self.rpf_redirect_interface_name = None
                                self.available_bandwidth = None
                                self.allocated_bandwidth = None
                                self.total_bandwidth = None
                                self.topology_bandwidth_used = None
                                self.snooping_bandwidth_used = None
                                self.allocated_threshold_bandwidth = None
                                self.available_threshold_bandwidth = None
                                self._segment_path = lambda: "bundle-interface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces.BundleInterface, ['bundle_name', 'interface_name', 'rpf_redirect_bundle_name', 'rpf_redirect_interface_name', 'available_bandwidth', 'allocated_bandwidth', 'total_bandwidth', 'topology_bandwidth_used', 'snooping_bandwidth_used', 'allocated_threshold_bandwidth', 'available_threshold_bandwidth'], name, value)


                class Tunnels(Entity):
                    """
                    Tunnels information that PIM has
                    
                    .. attribute:: tunnel
                    
                    	PIM tunnel information
                    	**type**\: list of  		 :py:class:`Tunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.Tunnels, self).__init__()

                        self.yang_name = "tunnels"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("tunnel", ("tunnel", Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel))])
                        self._leafs = OrderedDict()

                        self.tunnel = YList(self)
                        self._segment_path = lambda: "tunnels"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Tunnels, [], name, value)


                    class Tunnel(Entity):
                        """
                        PIM tunnel information
                        
                        .. attribute:: tunnel_name  (key)
                        
                        	Tunnel name
                        	**type**\: str
                        
                        	**length:** 1..64
                        
                        .. attribute:: source_address
                        
                        	Source addr known to PIM
                        	**type**\:  :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress>`
                        
                        .. attribute:: rp_address
                        
                        	RP addr known to PIM
                        	**type**\:  :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.RpAddress>`
                        
                        .. attribute:: source_address_netio
                        
                        	Source addr from netio
                        	**type**\:  :py:class:`SourceAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio>`
                        
                        .. attribute:: group_address_netio
                        
                        	Group addr from netio
                        	**type**\:  :py:class:`GroupAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio>`
                        
                        .. attribute:: vrf_name
                        
                        	VRF Name
                        	**type**\: str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel, self).__init__()

                            self.yang_name = "tunnel"
                            self.yang_parent_name = "tunnels"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['tunnel_name']
                            self._child_classes = OrderedDict([("source-address", ("source_address", Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress)), ("rp-address", ("rp_address", Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.RpAddress)), ("source-address-netio", ("source_address_netio", Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio)), ("group-address-netio", ("group_address_netio", Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio))])
                            self._leafs = OrderedDict([
                                ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                            ])
                            self.tunnel_name = None
                            self.vrf_name = None

                            self.source_address = Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"

                            self.rp_address = Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"

                            self.source_address_netio = Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio()
                            self.source_address_netio.parent = self
                            self._children_name_map["source_address_netio"] = "source-address-netio"

                            self.group_address_netio = Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio()
                            self.group_address_netio.parent = self
                            self._children_name_map["group_address_netio"] = "group-address-netio"
                            self._segment_path = lambda: "tunnel" + "[tunnel-name='" + str(self.tunnel_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel, ['tunnel_name', 'vrf_name'], name, value)


                        class SourceAddress(Entity):
                            """
                            Source addr known to PIM
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "source-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class RpAddress(Entity):
                            """
                            RP addr known to PIM
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "rp-address"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.RpAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class SourceAddressNetio(Entity):
                            """
                            Source addr from netio
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio, self).__init__()

                                self.yang_name = "source-address-netio"
                                self.yang_parent_name = "tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "source-address-netio"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class GroupAddressNetio(Entity):
                            """
                            Group addr from netio
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio, self).__init__()

                                self.yang_name = "group-address-netio"
                                self.yang_parent_name = "tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "group-address-netio"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class MulticastStaticRoutes(Entity):
                    """
                    PIM multicast static route table
                    
                    .. attribute:: multicast_static_route
                    
                    	PIM multicast static route information
                    	**type**\: list of  		 :py:class:`MulticastStaticRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes, self).__init__()

                        self.yang_name = "multicast-static-routes"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("multicast-static-route", ("multicast_static_route", Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute))])
                        self._leafs = OrderedDict()

                        self.multicast_static_route = YList(self)
                        self._segment_path = lambda: "multicast-static-routes"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes, [], name, value)


                    class MulticastStaticRoute(Entity):
                        """
                        PIM multicast static route information
                        
                        .. attribute:: address
                        
                        	Network address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: prefix
                        
                        	Prefix
                        	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix>`
                        
                        .. attribute:: nexthop
                        
                        	Next Hop
                        	**type**\:  :py:class:`Nexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop>`
                        
                        .. attribute:: interface_name
                        
                        	Interface Handle
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: distance
                        
                        	Distance
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: prefix_length_xr
                        
                        	Prefix Length
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: is_via_lsm
                        
                        	LSM flag
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute, self).__init__()

                            self.yang_name = "multicast-static-route"
                            self.yang_parent_name = "multicast-static-routes"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("prefix", ("prefix", Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix)), ("nexthop", ("nexthop", Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop))])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str','str'])),
                                ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ('distance', (YLeaf(YType.uint32, 'distance'), ['int'])),
                                ('prefix_length_xr', (YLeaf(YType.uint8, 'prefix-length-xr'), ['int'])),
                                ('is_via_lsm', (YLeaf(YType.boolean, 'is-via-lsm'), ['bool'])),
                            ])
                            self.address = None
                            self.prefix_length = None
                            self.interface_name = None
                            self.distance = None
                            self.prefix_length_xr = None
                            self.is_via_lsm = None

                            self.prefix = Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"

                            self.nexthop = Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop()
                            self.nexthop.parent = self
                            self._children_name_map["nexthop"] = "nexthop"
                            self._segment_path = lambda: "multicast-static-route"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute, ['address', 'prefix_length', 'interface_name', 'distance', 'prefix_length_xr', 'is_via_lsm'], name, value)


                        class Prefix(Entity):
                            """
                            Prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "multicast-static-route"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "prefix"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                        class Nexthop(Entity):
                            """
                            Next Hop
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop, self).__init__()

                                self.yang_name = "nexthop"
                                self.yang_parent_name = "multicast-static-route"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "nexthop"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                class Neighbors(Entity):
                    """
                    PIM neighbor table
                    
                    .. attribute:: neighbor
                    
                    	PIM neighbor information
                    	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Neighbors.Neighbor>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.Neighbors, self).__init__()

                        self.yang_name = "neighbors"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("neighbor", ("neighbor", Ipv6Pim.Active.Vrfs.Vrf.Neighbors.Neighbor))])
                        self._leafs = OrderedDict()

                        self.neighbor = YList(self)
                        self._segment_path = lambda: "neighbors"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Neighbors, [], name, value)


                    class Neighbor(Entity):
                        """
                        PIM neighbor information
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: neighbor_address
                        
                        	Neighbor address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identifier
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: expires
                        
                        	Neighbor expiry in seconds
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: expiry_timer
                        
                        	Expiry timer in seconds
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: is_this_neighbor_us
                        
                        	Is this neighbor us ?
                        	**type**\: bool
                        
                        .. attribute:: is_this_neighbor_dr
                        
                        	Is this neighbor the DR
                        	**type**\: bool
                        
                        .. attribute:: is_dr_priority_capable
                        
                        	Is this neighbor DR priority capable ?
                        	**type**\: bool
                        
                        .. attribute:: dr_priority
                        
                        	DR priority
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Is this neighbor bidir capable ?
                        	**type**\: bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Is this neighbor proxy capable?
                        	**type**\: bool
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Is this neighbor capable of batching asserts?
                        	**type**\: bool
                        
                        .. attribute:: is_ecmp_redirect_capable
                        
                        	Is this neighbor capable of Ecmp Redirect?
                        	**type**\: bool
                        
                        .. attribute:: is_bfd_state
                        
                        	Is the neighbor bfd session created
                        	**type**\: bool
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_address_xr
                        
                        	List of Neighbor Addresses
                        	**type**\: list of  		 :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Neighbors.Neighbor.NeighborAddressXr>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.Neighbors.Neighbor, self).__init__()

                            self.yang_name = "neighbor"
                            self.yang_parent_name = "neighbors"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("neighbor-address-xr", ("neighbor_address_xr", Ipv6Pim.Active.Vrfs.Vrf.Neighbors.Neighbor.NeighborAddressXr))])
                            self._leafs = OrderedDict([
                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                                ('uptime', (YLeaf(YType.uint64, 'uptime'), ['int'])),
                                ('expires', (YLeaf(YType.uint64, 'expires'), ['int'])),
                                ('expiry_timer', (YLeaf(YType.uint64, 'expiry-timer'), ['int'])),
                                ('is_this_neighbor_us', (YLeaf(YType.boolean, 'is-this-neighbor-us'), ['bool'])),
                                ('is_this_neighbor_dr', (YLeaf(YType.boolean, 'is-this-neighbor-dr'), ['bool'])),
                                ('is_dr_priority_capable', (YLeaf(YType.boolean, 'is-dr-priority-capable'), ['bool'])),
                                ('dr_priority', (YLeaf(YType.uint32, 'dr-priority'), ['int'])),
                                ('is_bidirectional_capable', (YLeaf(YType.boolean, 'is-bidirectional-capable'), ['bool'])),
                                ('is_proxy_capable', (YLeaf(YType.boolean, 'is-proxy-capable'), ['bool'])),
                                ('is_batch_asserts_capable', (YLeaf(YType.boolean, 'is-batch-asserts-capable'), ['bool'])),
                                ('is_ecmp_redirect_capable', (YLeaf(YType.boolean, 'is-ecmp-redirect-capable'), ['bool'])),
                                ('is_bfd_state', (YLeaf(YType.boolean, 'is-bfd-state'), ['bool'])),
                                ('propagation_delay', (YLeaf(YType.uint16, 'propagation-delay'), ['int'])),
                                ('override_interval', (YLeaf(YType.uint16, 'override-interval'), ['int'])),
                            ])
                            self.interface_name = None
                            self.neighbor_address = None
                            self.interface_name_xr = None
                            self.uptime = None
                            self.expires = None
                            self.expiry_timer = None
                            self.is_this_neighbor_us = None
                            self.is_this_neighbor_dr = None
                            self.is_dr_priority_capable = None
                            self.dr_priority = None
                            self.is_bidirectional_capable = None
                            self.is_proxy_capable = None
                            self.is_batch_asserts_capable = None
                            self.is_ecmp_redirect_capable = None
                            self.is_bfd_state = None
                            self.propagation_delay = None
                            self.override_interval = None

                            self.neighbor_address_xr = YList(self)
                            self._segment_path = lambda: "neighbor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Neighbors.Neighbor, ['interface_name', 'neighbor_address', 'interface_name_xr', 'uptime', 'expires', 'expiry_timer', 'is_this_neighbor_us', 'is_this_neighbor_dr', 'is_dr_priority_capable', 'dr_priority', 'is_bidirectional_capable', 'is_proxy_capable', 'is_batch_asserts_capable', 'is_ecmp_redirect_capable', 'is_bfd_state', 'propagation_delay', 'override_interval'], name, value)


                        class NeighborAddressXr(Entity):
                            """
                            List of Neighbor Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Neighbors.Neighbor.NeighborAddressXr, self).__init__()

                                self.yang_name = "neighbor-address-xr"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                ])
                                self.af_name = None
                                self.ipv4_address = None
                                self.ipv6_address = None
                                self._segment_path = lambda: "neighbor-address-xr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Pim.Active.Vrfs.Vrf.Neighbors.Neighbor.NeighborAddressXr, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)

    def clone_ptr(self):
        self._top_entity = Ipv6Pim()
        return self._top_entity

class Pim6Ma(Entity):
    """
    pim6 ma
    
    .. attribute:: active
    
    	Active Process
    	**type**\:  :py:class:`Active <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Active>`
    
    .. attribute:: standby
    
    	Standby Process
    	**type**\:  :py:class:`Standby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Standby>`
    
    

    """

    _prefix = 'ipv4-pim-oper'
    _revision = '2017-09-07'

    def __init__(self):
        super(Pim6Ma, self).__init__()
        self._top_entity = None

        self.yang_name = "pim6-ma"
        self.yang_parent_name = "Cisco-IOS-XR-ipv4-pim-oper"
        self.is_top_level_class = True
        self.has_list_ancestor = False
        self.ylist_key_names = []
        self._child_classes = OrderedDict([("active", ("active", Pim6Ma.Active)), ("standby", ("standby", Pim6Ma.Standby))])
        self._leafs = OrderedDict()

        self.active = Pim6Ma.Active()
        self.active.parent = self
        self._children_name_map["active"] = "active"

        self.standby = Pim6Ma.Standby()
        self.standby.parent = self
        self._children_name_map["standby"] = "standby"
        self._segment_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim6-ma"
        self._is_frozen = True

    def __setattr__(self, name, value):
        self._perform_setattr(Pim6Ma, [], name, value)


    class Active(Entity):
        """
        Active Process
        
        .. attribute:: interface_table
        
        	Interface Table
        	**type**\:  :py:class:`InterfaceTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Active.InterfaceTable>`
        
        .. attribute:: pim_ma_summary
        
        	PIM MA summary
        	**type**\:  :py:class:`PimMaSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Active.PimMaSummary>`
        
        

        """

        _prefix = 'ipv4-pim-oper'
        _revision = '2017-09-07'

        def __init__(self):
            super(Pim6Ma.Active, self).__init__()

            self.yang_name = "active"
            self.yang_parent_name = "pim6-ma"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("interface-table", ("interface_table", Pim6Ma.Active.InterfaceTable)), ("pim-ma-summary", ("pim_ma_summary", Pim6Ma.Active.PimMaSummary))])
            self._leafs = OrderedDict()

            self.interface_table = Pim6Ma.Active.InterfaceTable()
            self.interface_table.parent = self
            self._children_name_map["interface_table"] = "interface-table"

            self.pim_ma_summary = Pim6Ma.Active.PimMaSummary()
            self.pim_ma_summary.parent = self
            self._children_name_map["pim_ma_summary"] = "pim-ma-summary"
            self._segment_path = lambda: "active"
            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim6-ma/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Pim6Ma.Active, [], name, value)


        class InterfaceTable(Entity):
            """
            Interface Table
            
            .. attribute:: interface_by_handles
            
            	Table of PIM MA interfaces indexed by handle
            	**type**\:  :py:class:`InterfaceByHandles <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Active.InterfaceTable.InterfaceByHandles>`
            
            .. attribute:: interface_by_names
            
            	Table of PIM MA interfaces indexed by name
            	**type**\:  :py:class:`InterfaceByNames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Active.InterfaceTable.InterfaceByNames>`
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(Pim6Ma.Active.InterfaceTable, self).__init__()

                self.yang_name = "interface-table"
                self.yang_parent_name = "active"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("interface-by-handles", ("interface_by_handles", Pim6Ma.Active.InterfaceTable.InterfaceByHandles)), ("interface-by-names", ("interface_by_names", Pim6Ma.Active.InterfaceTable.InterfaceByNames))])
                self._leafs = OrderedDict()

                self.interface_by_handles = Pim6Ma.Active.InterfaceTable.InterfaceByHandles()
                self.interface_by_handles.parent = self
                self._children_name_map["interface_by_handles"] = "interface-by-handles"

                self.interface_by_names = Pim6Ma.Active.InterfaceTable.InterfaceByNames()
                self.interface_by_names.parent = self
                self._children_name_map["interface_by_names"] = "interface-by-names"
                self._segment_path = lambda: "interface-table"
                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim6-ma/active/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Pim6Ma.Active.InterfaceTable, [], name, value)


            class InterfaceByHandles(Entity):
                """
                Table of PIM MA interfaces indexed by handle
                
                .. attribute:: interface_by_handle
                
                	PIM MA interface referenced by handle
                	**type**\: list of  		 :py:class:`InterfaceByHandle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim6Ma.Active.InterfaceTable.InterfaceByHandles, self).__init__()

                    self.yang_name = "interface-by-handles"
                    self.yang_parent_name = "interface-table"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("interface-by-handle", ("interface_by_handle", Pim6Ma.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle))])
                    self._leafs = OrderedDict()

                    self.interface_by_handle = YList(self)
                    self._segment_path = lambda: "interface-by-handles"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim6-ma/active/interface-table/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim6Ma.Active.InterfaceTable.InterfaceByHandles, [], name, value)


                class InterfaceByHandle(Entity):
                    """
                    PIM MA interface referenced by handle
                    
                    .. attribute:: interface_handle  (key)
                    
                    	Interface handle
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rp_address
                    
                    	RP Address
                    	**type**\:  :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress>`
                    
                    .. attribute:: source_address
                    
                    	Source Address
                    	**type**\:  :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress>`
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Name
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: vrf_name
                    
                    	VRF Name
                    	**type**\: str
                    
                    .. attribute:: interface_type
                    
                    	Interface Type
                    	**type**\:  :py:class:`PimInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimInterface>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim6Ma.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle, self).__init__()

                        self.yang_name = "interface-by-handle"
                        self.yang_parent_name = "interface-by-handles"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['interface_handle']
                        self._child_classes = OrderedDict([("rp-address", ("rp_address", Pim6Ma.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress)), ("source-address", ("source_address", Pim6Ma.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress))])
                        self._leafs = OrderedDict([
                            ('interface_handle', (YLeaf(YType.uint32, 'interface-handle'), ['int'])),
                            ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                            ('interface_type', (YLeaf(YType.enumeration, 'interface-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimInterface', '')])),
                        ])
                        self.interface_handle = None
                        self.interface_name_xr = None
                        self.vrf_name = None
                        self.interface_type = None

                        self.rp_address = Pim6Ma.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress()
                        self.rp_address.parent = self
                        self._children_name_map["rp_address"] = "rp-address"

                        self.source_address = Pim6Ma.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress()
                        self.source_address.parent = self
                        self._children_name_map["source_address"] = "source-address"
                        self._segment_path = lambda: "interface-by-handle" + "[interface-handle='" + str(self.interface_handle) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim6-ma/active/interface-table/interface-by-handles/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim6Ma.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle, ['interface_handle', u'interface_name_xr', u'vrf_name', u'interface_type'], name, value)


                    class RpAddress(Entity):
                        """
                        RP Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim6Ma.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress, self).__init__()

                            self.yang_name = "rp-address"
                            self.yang_parent_name = "interface-by-handle"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "rp-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim6Ma.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class SourceAddress(Entity):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim6Ma.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress, self).__init__()

                            self.yang_name = "source-address"
                            self.yang_parent_name = "interface-by-handle"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "source-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim6Ma.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class InterfaceByNames(Entity):
                """
                Table of PIM MA interfaces indexed by name
                
                .. attribute:: interface_by_name
                
                	PIM MA interface referenced by name
                	**type**\: list of  		 :py:class:`InterfaceByName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Active.InterfaceTable.InterfaceByNames.InterfaceByName>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim6Ma.Active.InterfaceTable.InterfaceByNames, self).__init__()

                    self.yang_name = "interface-by-names"
                    self.yang_parent_name = "interface-table"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("interface-by-name", ("interface_by_name", Pim6Ma.Active.InterfaceTable.InterfaceByNames.InterfaceByName))])
                    self._leafs = OrderedDict()

                    self.interface_by_name = YList(self)
                    self._segment_path = lambda: "interface-by-names"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim6-ma/active/interface-table/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim6Ma.Active.InterfaceTable.InterfaceByNames, [], name, value)


                class InterfaceByName(Entity):
                    """
                    PIM MA interface referenced by name
                    
                    .. attribute:: interface_name  (key)
                    
                    	Interface name
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: rp_address
                    
                    	RP Address
                    	**type**\:  :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Active.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress>`
                    
                    .. attribute:: source_address
                    
                    	Source Address
                    	**type**\:  :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Active.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress>`
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Name
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: vrf_name
                    
                    	VRF Name
                    	**type**\: str
                    
                    .. attribute:: interface_type
                    
                    	Interface Type
                    	**type**\:  :py:class:`PimInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimInterface>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim6Ma.Active.InterfaceTable.InterfaceByNames.InterfaceByName, self).__init__()

                        self.yang_name = "interface-by-name"
                        self.yang_parent_name = "interface-by-names"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['interface_name']
                        self._child_classes = OrderedDict([("rp-address", ("rp_address", Pim6Ma.Active.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress)), ("source-address", ("source_address", Pim6Ma.Active.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress))])
                        self._leafs = OrderedDict([
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                            ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                            ('interface_type', (YLeaf(YType.enumeration, 'interface-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimInterface', '')])),
                        ])
                        self.interface_name = None
                        self.interface_name_xr = None
                        self.vrf_name = None
                        self.interface_type = None

                        self.rp_address = Pim6Ma.Active.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress()
                        self.rp_address.parent = self
                        self._children_name_map["rp_address"] = "rp-address"

                        self.source_address = Pim6Ma.Active.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress()
                        self.source_address.parent = self
                        self._children_name_map["source_address"] = "source-address"
                        self._segment_path = lambda: "interface-by-name" + "[interface-name='" + str(self.interface_name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim6-ma/active/interface-table/interface-by-names/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim6Ma.Active.InterfaceTable.InterfaceByNames.InterfaceByName, ['interface_name', u'interface_name_xr', u'vrf_name', u'interface_type'], name, value)


                    class RpAddress(Entity):
                        """
                        RP Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim6Ma.Active.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress, self).__init__()

                            self.yang_name = "rp-address"
                            self.yang_parent_name = "interface-by-name"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "rp-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim6Ma.Active.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class SourceAddress(Entity):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim6Ma.Active.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress, self).__init__()

                            self.yang_name = "source-address"
                            self.yang_parent_name = "interface-by-name"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "source-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim6Ma.Active.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


        class PimMaSummary(Entity):
            """
            PIM MA summary
            
            .. attribute:: is_im_connection_open
            
            	IM Connection Open
            	**type**\: bool
            
            .. attribute:: is_netio_connection_open
            
            	Netio Connection Open
            	**type**\: bool
            
            .. attribute:: is_edm_connection_open
            
            	EDM Connection Open
            	**type**\: bool
            
            .. attribute:: is_standby_edm_connection_open
            
            	Standby EDM Connection Open
            	**type**\: bool
            
            .. attribute:: encap_interface_count
            
            	Encap Interface Count
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: decap_interface_count
            
            	Decap Interface Count
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: mdt_interface_count
            
            	MDT Interface Count
            	**type**\: int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(Pim6Ma.Active.PimMaSummary, self).__init__()

                self.yang_name = "pim-ma-summary"
                self.yang_parent_name = "active"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('is_im_connection_open', (YLeaf(YType.boolean, 'is-im-connection-open'), ['bool'])),
                    ('is_netio_connection_open', (YLeaf(YType.boolean, 'is-netio-connection-open'), ['bool'])),
                    ('is_edm_connection_open', (YLeaf(YType.boolean, 'is-edm-connection-open'), ['bool'])),
                    ('is_standby_edm_connection_open', (YLeaf(YType.boolean, 'is-standby-edm-connection-open'), ['bool'])),
                    ('encap_interface_count', (YLeaf(YType.uint32, 'encap-interface-count'), ['int'])),
                    ('decap_interface_count', (YLeaf(YType.uint32, 'decap-interface-count'), ['int'])),
                    ('mdt_interface_count', (YLeaf(YType.uint32, 'mdt-interface-count'), ['int'])),
                ])
                self.is_im_connection_open = None
                self.is_netio_connection_open = None
                self.is_edm_connection_open = None
                self.is_standby_edm_connection_open = None
                self.encap_interface_count = None
                self.decap_interface_count = None
                self.mdt_interface_count = None
                self._segment_path = lambda: "pim-ma-summary"
                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim6-ma/active/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Pim6Ma.Active.PimMaSummary, [u'is_im_connection_open', u'is_netio_connection_open', u'is_edm_connection_open', u'is_standby_edm_connection_open', u'encap_interface_count', u'decap_interface_count', u'mdt_interface_count'], name, value)


    class Standby(Entity):
        """
        Standby Process
        
        .. attribute:: interface_table
        
        	Interface Table
        	**type**\:  :py:class:`InterfaceTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Standby.InterfaceTable>`
        
        .. attribute:: pim_ma_summary
        
        	PIM MA summary
        	**type**\:  :py:class:`PimMaSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Standby.PimMaSummary>`
        
        

        """

        _prefix = 'ipv4-pim-oper'
        _revision = '2017-09-07'

        def __init__(self):
            super(Pim6Ma.Standby, self).__init__()

            self.yang_name = "standby"
            self.yang_parent_name = "pim6-ma"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("interface-table", ("interface_table", Pim6Ma.Standby.InterfaceTable)), ("pim-ma-summary", ("pim_ma_summary", Pim6Ma.Standby.PimMaSummary))])
            self._leafs = OrderedDict()

            self.interface_table = Pim6Ma.Standby.InterfaceTable()
            self.interface_table.parent = self
            self._children_name_map["interface_table"] = "interface-table"

            self.pim_ma_summary = Pim6Ma.Standby.PimMaSummary()
            self.pim_ma_summary.parent = self
            self._children_name_map["pim_ma_summary"] = "pim-ma-summary"
            self._segment_path = lambda: "standby"
            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim6-ma/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Pim6Ma.Standby, [], name, value)


        class InterfaceTable(Entity):
            """
            Interface Table
            
            .. attribute:: interface_by_handles
            
            	Table of PIM MA interfaces indexed by handle
            	**type**\:  :py:class:`InterfaceByHandles <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Standby.InterfaceTable.InterfaceByHandles>`
            
            .. attribute:: interface_by_names
            
            	Table of PIM MA interfaces indexed by name
            	**type**\:  :py:class:`InterfaceByNames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Standby.InterfaceTable.InterfaceByNames>`
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(Pim6Ma.Standby.InterfaceTable, self).__init__()

                self.yang_name = "interface-table"
                self.yang_parent_name = "standby"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("interface-by-handles", ("interface_by_handles", Pim6Ma.Standby.InterfaceTable.InterfaceByHandles)), ("interface-by-names", ("interface_by_names", Pim6Ma.Standby.InterfaceTable.InterfaceByNames))])
                self._leafs = OrderedDict()

                self.interface_by_handles = Pim6Ma.Standby.InterfaceTable.InterfaceByHandles()
                self.interface_by_handles.parent = self
                self._children_name_map["interface_by_handles"] = "interface-by-handles"

                self.interface_by_names = Pim6Ma.Standby.InterfaceTable.InterfaceByNames()
                self.interface_by_names.parent = self
                self._children_name_map["interface_by_names"] = "interface-by-names"
                self._segment_path = lambda: "interface-table"
                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim6-ma/standby/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Pim6Ma.Standby.InterfaceTable, [], name, value)


            class InterfaceByHandles(Entity):
                """
                Table of PIM MA interfaces indexed by handle
                
                .. attribute:: interface_by_handle
                
                	PIM MA interface referenced by handle
                	**type**\: list of  		 :py:class:`InterfaceByHandle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim6Ma.Standby.InterfaceTable.InterfaceByHandles, self).__init__()

                    self.yang_name = "interface-by-handles"
                    self.yang_parent_name = "interface-table"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("interface-by-handle", ("interface_by_handle", Pim6Ma.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle))])
                    self._leafs = OrderedDict()

                    self.interface_by_handle = YList(self)
                    self._segment_path = lambda: "interface-by-handles"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim6-ma/standby/interface-table/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim6Ma.Standby.InterfaceTable.InterfaceByHandles, [], name, value)


                class InterfaceByHandle(Entity):
                    """
                    PIM MA interface referenced by handle
                    
                    .. attribute:: interface_handle  (key)
                    
                    	Interface handle
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rp_address
                    
                    	RP Address
                    	**type**\:  :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress>`
                    
                    .. attribute:: source_address
                    
                    	Source Address
                    	**type**\:  :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress>`
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Name
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: vrf_name
                    
                    	VRF Name
                    	**type**\: str
                    
                    .. attribute:: interface_type
                    
                    	Interface Type
                    	**type**\:  :py:class:`PimInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimInterface>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim6Ma.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle, self).__init__()

                        self.yang_name = "interface-by-handle"
                        self.yang_parent_name = "interface-by-handles"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['interface_handle']
                        self._child_classes = OrderedDict([("rp-address", ("rp_address", Pim6Ma.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress)), ("source-address", ("source_address", Pim6Ma.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress))])
                        self._leafs = OrderedDict([
                            ('interface_handle', (YLeaf(YType.uint32, 'interface-handle'), ['int'])),
                            ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                            ('interface_type', (YLeaf(YType.enumeration, 'interface-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimInterface', '')])),
                        ])
                        self.interface_handle = None
                        self.interface_name_xr = None
                        self.vrf_name = None
                        self.interface_type = None

                        self.rp_address = Pim6Ma.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress()
                        self.rp_address.parent = self
                        self._children_name_map["rp_address"] = "rp-address"

                        self.source_address = Pim6Ma.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress()
                        self.source_address.parent = self
                        self._children_name_map["source_address"] = "source-address"
                        self._segment_path = lambda: "interface-by-handle" + "[interface-handle='" + str(self.interface_handle) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim6-ma/standby/interface-table/interface-by-handles/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim6Ma.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle, ['interface_handle', u'interface_name_xr', u'vrf_name', u'interface_type'], name, value)


                    class RpAddress(Entity):
                        """
                        RP Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim6Ma.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress, self).__init__()

                            self.yang_name = "rp-address"
                            self.yang_parent_name = "interface-by-handle"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "rp-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim6Ma.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class SourceAddress(Entity):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim6Ma.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress, self).__init__()

                            self.yang_name = "source-address"
                            self.yang_parent_name = "interface-by-handle"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "source-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim6Ma.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


            class InterfaceByNames(Entity):
                """
                Table of PIM MA interfaces indexed by name
                
                .. attribute:: interface_by_name
                
                	PIM MA interface referenced by name
                	**type**\: list of  		 :py:class:`InterfaceByName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Standby.InterfaceTable.InterfaceByNames.InterfaceByName>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Pim6Ma.Standby.InterfaceTable.InterfaceByNames, self).__init__()

                    self.yang_name = "interface-by-names"
                    self.yang_parent_name = "interface-table"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("interface-by-name", ("interface_by_name", Pim6Ma.Standby.InterfaceTable.InterfaceByNames.InterfaceByName))])
                    self._leafs = OrderedDict()

                    self.interface_by_name = YList(self)
                    self._segment_path = lambda: "interface-by-names"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim6-ma/standby/interface-table/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Pim6Ma.Standby.InterfaceTable.InterfaceByNames, [], name, value)


                class InterfaceByName(Entity):
                    """
                    PIM MA interface referenced by name
                    
                    .. attribute:: interface_name  (key)
                    
                    	Interface name
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: rp_address
                    
                    	RP Address
                    	**type**\:  :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress>`
                    
                    .. attribute:: source_address
                    
                    	Source Address
                    	**type**\:  :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress>`
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Name
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: vrf_name
                    
                    	VRF Name
                    	**type**\: str
                    
                    .. attribute:: interface_type
                    
                    	Interface Type
                    	**type**\:  :py:class:`PimInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimInterface>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Pim6Ma.Standby.InterfaceTable.InterfaceByNames.InterfaceByName, self).__init__()

                        self.yang_name = "interface-by-name"
                        self.yang_parent_name = "interface-by-names"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['interface_name']
                        self._child_classes = OrderedDict([("rp-address", ("rp_address", Pim6Ma.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress)), ("source-address", ("source_address", Pim6Ma.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress))])
                        self._leafs = OrderedDict([
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                            ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                            ('interface_type', (YLeaf(YType.enumeration, 'interface-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimInterface', '')])),
                        ])
                        self.interface_name = None
                        self.interface_name_xr = None
                        self.vrf_name = None
                        self.interface_type = None

                        self.rp_address = Pim6Ma.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress()
                        self.rp_address.parent = self
                        self._children_name_map["rp_address"] = "rp-address"

                        self.source_address = Pim6Ma.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress()
                        self.source_address.parent = self
                        self._children_name_map["source_address"] = "source-address"
                        self._segment_path = lambda: "interface-by-name" + "[interface-name='" + str(self.interface_name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim6-ma/standby/interface-table/interface-by-names/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Pim6Ma.Standby.InterfaceTable.InterfaceByNames.InterfaceByName, ['interface_name', u'interface_name_xr', u'vrf_name', u'interface_type'], name, value)


                    class RpAddress(Entity):
                        """
                        RP Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim6Ma.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress, self).__init__()

                            self.yang_name = "rp-address"
                            self.yang_parent_name = "interface-by-name"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "rp-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim6Ma.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


                    class SourceAddress(Entity):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Pim6Ma.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress, self).__init__()

                            self.yang_name = "source-address"
                            self.yang_parent_name = "interface-by-name"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper', 'PimAfi', '')])),
                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4_address = None
                            self.ipv6_address = None
                            self._segment_path = lambda: "source-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Pim6Ma.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress, [u'af_name', u'ipv4_address', u'ipv6_address'], name, value)


        class PimMaSummary(Entity):
            """
            PIM MA summary
            
            .. attribute:: is_im_connection_open
            
            	IM Connection Open
            	**type**\: bool
            
            .. attribute:: is_netio_connection_open
            
            	Netio Connection Open
            	**type**\: bool
            
            .. attribute:: is_edm_connection_open
            
            	EDM Connection Open
            	**type**\: bool
            
            .. attribute:: is_standby_edm_connection_open
            
            	Standby EDM Connection Open
            	**type**\: bool
            
            .. attribute:: encap_interface_count
            
            	Encap Interface Count
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: decap_interface_count
            
            	Decap Interface Count
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: mdt_interface_count
            
            	MDT Interface Count
            	**type**\: int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(Pim6Ma.Standby.PimMaSummary, self).__init__()

                self.yang_name = "pim-ma-summary"
                self.yang_parent_name = "standby"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('is_im_connection_open', (YLeaf(YType.boolean, 'is-im-connection-open'), ['bool'])),
                    ('is_netio_connection_open', (YLeaf(YType.boolean, 'is-netio-connection-open'), ['bool'])),
                    ('is_edm_connection_open', (YLeaf(YType.boolean, 'is-edm-connection-open'), ['bool'])),
                    ('is_standby_edm_connection_open', (YLeaf(YType.boolean, 'is-standby-edm-connection-open'), ['bool'])),
                    ('encap_interface_count', (YLeaf(YType.uint32, 'encap-interface-count'), ['int'])),
                    ('decap_interface_count', (YLeaf(YType.uint32, 'decap-interface-count'), ['int'])),
                    ('mdt_interface_count', (YLeaf(YType.uint32, 'mdt-interface-count'), ['int'])),
                ])
                self.is_im_connection_open = None
                self.is_netio_connection_open = None
                self.is_edm_connection_open = None
                self.is_standby_edm_connection_open = None
                self.encap_interface_count = None
                self.decap_interface_count = None
                self.mdt_interface_count = None
                self._segment_path = lambda: "pim-ma-summary"
                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-pim-oper:pim6-ma/standby/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Pim6Ma.Standby.PimMaSummary, [u'is_im_connection_open', u'is_netio_connection_open', u'is_edm_connection_open', u'is_standby_edm_connection_open', u'encap_interface_count', u'decap_interface_count', u'mdt_interface_count'], name, value)

    def clone_ptr(self):
        self._top_entity = Pim6Ma()
        return self._top_entity

